(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    560735,      13295]*)
(*NotebookOutlinePosition[    589430,      14297]*)
(*  CellTagsIndexPosition[    588377,      14264]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Continuation of file 2004-08-02-A.PartI.ppt", "SmallText"],

Cell[CellGroupData[{

Cell["\<\
Gr\[ODoubleDot]bner Bases:
An Overview\
\>", "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\

Bruno Buchberger
RISC and RICAM,Linz,Austria

Talk at RIMS, Kyoto University
August 2,2004
\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Copyright",
    FontWeight->"Bold"],
  " Bruno Buchberger 2004\n\n",
  StyleBox["Copyright Note:  ",
    FontWeight->"Bold"],
  "This file may be copied and stored under the following conditions:\n\n-  \
the file must be kept unchanged including the copyright note\n-  a mail must \
be send to buchberger@risc.uni-linz.ac.at\n-  if material of this talk is \
used the talk must be cited approrpiately."
}], "Text"],

Cell[CellGroupData[{

Cell["Groebner Bases: What and How?", "Section"],

Cell[CellGroupData[{

Cell["What are Groebner Bases?", "Subsection"],

Cell[CellGroupData[{

Cell["The Linear Combination of Polynomials", "Subsubsection",
  CellTags->"division-reduction"],

Cell["Consider the two bivariate polynomials", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(f\_1\), "=", 
      RowBox[{\(\(-2\) y\), "+", 
        StyleBox[\(x\ y\),
          FontColor->RGBColor[0, 0, 1]]}]}], "\[IndentingNewLine]", 
    RowBox[{\(f\_2\), "=", 
      RowBox[{\(-x\^2\), "+", 
        StyleBox[\(y\^2\),
          FontColor->RGBColor[0, 0, 1]]}]}]}], "Input"],

Cell[BoxData[
    \(\(-2\)\ y + x\ y\)], "Output"],

Cell[BoxData[
    \(\(-x\^2\) + y\^2\)], "Output"]
}, Open  ]],

Cell["\<\
We assume the power products in the polynomials \"lexicographically\" \
ordered! ( y \"is ranked higher than\" x.)\
\>", "Text"],

Cell[TextData[{
  "Consider now the following linear combination of ",
  Cell[BoxData[
      \(f\_1\)]],
  " and ",
  Cell[BoxData[
      \(f\_2\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g = \((y)\)\ f\_1 + \ \(\((\(-x\) + 2)\) \(f\_2\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(y\ \((\(-2\)\ y + x\ y)\) + \((2 - x)\)\ \((\(-x\^2\) + 
            y\^2)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g = \((y)\)\ f\_1 + \ \((\(-x\) + 2)\) f\_2\  // Expand\)], "Input"],

Cell[BoxData[
    \(\(-2\)\ x\^2 + x\^3\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Observation: \nThe leading power product ",
  Cell[BoxData[
      \(x\^3\)]],
  " of g is \n     neither a multiple of the leading power product of ",
  Cell[BoxData[
      \(f\_1\)]],
  "\n     nor      a multiple of the leading power product of ",
  Cell[BoxData[
      \(f\_2\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of Groebner Bases", "Subsubsection"],

Cell["\<\
We consider polynomials in n indeterminates over a coefficient field K. 
(We also assume a fixed \"admissible\", e.g. lexicographic ordering of the \
power products.)\
\>", "Text"],

Cell[TextData[{
  "A set F of polynomials is called a ",
  StyleBox["Groebner basis",
    FontColor->RGBColor[0, 0, 1]],
  " iff the above phenomenon cannot happen, i.e. iff"
}], "Text"],

Cell[TextData[{
  "     for all ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(f\_1\),
            "TraditionalForm"], ",", "...", ",", \(f\_m\)}], 
        TraditionalForm]]],
  "\[Element] F and polynomials ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(h\_1\),
            "TraditionalForm"], ",", "...", ",", \(h\_m\)}], 
        TraditionalForm]]],
  ",\n\n          the leading power product of  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(h\_1\ f\_1\)\(\ \)\(+\)\)\  ... \)\  + \ 
        h\_m\ f\_m\)]],
  " \n          is a multiple of the leading power product of \n              \
 at least one of the polynomials in F."
}], "Text"]
}, Open  ]],

Cell[TextData[{
  "The Set ",
  Cell[BoxData[
      \(TraditionalForm\`F = {f\_1, f\_2}\)]],
  " of the Above Example is Not a Groebner Bases "
}], "Subsubsection"],

Cell[CellGroupData[{

Cell["Example of a Groebner Basis", "Subsubsection"],

Cell[TextData[{
  "The following set G (results from F by adding ",
  Cell[BoxData[
      \(\(-2\)\ x\^2 + x\^3\)]],
  ") is a Groebner basis:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(F = {\(-2\)\ x\^2 + x\^3, \(-2\)\ y + x\ y, \(-x\^2\) + 
          y\^2}\)], "Input"],

Cell[BoxData[
    \({\(-2\)\ x\^2 + x\^3, \(-2\)\ y + x\ y, \(-x\^2\) + y\^2}\)], "Output"]
}, Open  ]],

Cell["For example,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((1 + 3  y)\) \((\(-2\)\ x\^2 + x\^3)\) + \((8  x + 
              3  x\ y)\) \((\(-2\)\ y + x\ y)\) + \((2 - x - 
              y\^2)\) \((\(-x\^2\) + y\^2)\) // Expand\)], "Input"],

Cell[BoxData[
    \(\(-4\)\ x\^2 + 2\ x\^3 - 16\ x\ y + 2\ x\^2\ y + 3\ x\^3\ y + 2\ y\^2 - 
      7\ x\ y\^2 + 4\ x\^2\ y\^2 - y\^4\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((1)\) \((\(-2\)\ x\^2 + x\^3)\) + \((8  x)\) \((\(-2\)\ y + 
              x\ y)\) + \((y)\) \((\(-x\^2\) + y\^2)\) // Expand\)], "Input"],

Cell[BoxData[
    \(\(-2\)\ x\^2 + x\^3 - 16\ x\ y + 7\ x\^2\ y + y\^3\)], "Output"]
}, Open  ]],

Cell["\<\
Why is it difficult to check whether a given F is a Groebner basis?\
\>", "Text"],

Cell["How can we check whether a given F is a Groebner basis?", "Text"],

Cell["\<\
How can we get an \"equivalent\" Groebner basis G for a given F (which may \
not be a Groebner basis)?\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Why are Groebner Bases Interesting?", "Subsubsection"],

Cell["Why is this litte game with +, *, and x interesting?", "Text"],

Cell[TextData[StyleBox["Fact",
  FontWeight->"Bold"]], "Text",
  CellTags->"application-theory"],

Cell["\<\
Dozens seemingly very different \"hard\" problems (like algebraic equations, \
Hilbert function computation, diophantine equations with poly coefficients \
etc.) can all be reduced to the problem of constructing Groebner bases (by \
various \"reductions\"; most of them \"easy\", some of them \"quite \
intelligent\".)\
\>", "Text",
  CellTags->"application-theory"],

Cell[TextData[StyleBox["Examples",
  FontWeight->"Bold"]], "Text"],

Cell["\<\
Literature (approx. 10 textbooks, 600 papers in journals) and the examples \
later in this talk.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["How Can We Check Groebnerianity?", "Subsection"],

Cell[CellGroupData[{

Cell["The \"Main Theorem\" of GB Theory (BB 1965):", "Subsubsection"],

Cell[TextData[{
  StyleBox["F",
    FontSlant->"Italic"],
  " is a Gr\[ODoubleDot]bner basis  \[DoubleLongLeftRightArrow]  \n      ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \+\(f\_1, f\_2 \[Element] F\)\)]],
  "  remainder[ ",
  StyleBox["F",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\[Dash]polynomial[f\_1, f\_2]\)]],
  "] = 0."
}], "Text",
  CellFrame->True],

Cell[TextData[{
  StyleBox["Proof:",
    FontWeight->"Bold"],
  " Nontrivial. Combinatorial. \nAll details see:\nBB, PhD thesis 1965, \
published in aequationes mathematicae 1970. \n(English translation in the \
appendix of BB, F. Winkler: GB and Applications, Cambridge Univ. Press, \
1998.).\nModern version of proof: see overview paper by BB in the same book."
}], "Text"],

Cell["\<\
The power of the Gr\[ODoubleDot]bner bases method is contained in this \
theorem and its proof.\
\>", "Text",
  CellFrame->True,
  CellTags->"power"],

Cell[TextData[{
  "The theorem ",
  StyleBox["reduces",
    FontWeight->"Bold"],
  " an ",
  StyleBox["infinite",
    FontWeight->"Bold"],
  " check to a ",
  StyleBox["finite",
    FontWeight->"Bold"],
  " check."
}], "Text"],

Cell[TextData[{
  "The theorem, at the same time, is an ",
  StyleBox["algorithm!",
    FontWeight->"Bold"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["S-Polynomials", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(f\_1\), "=", 
      RowBox[{\(\(-2\) y\), "+", 
        StyleBox[\(x\ y\),
          FontColor->RGBColor[0, 0, 1]]}]}], "\[IndentingNewLine]", 
    RowBox[{\(f\_2\), "=", 
      RowBox[{\(-x\^2\), "+", 
        StyleBox[\(y\^2\),
          FontColor->RGBColor[0, 0, 1]]}]}]}], "Input"],

Cell[BoxData[
    \(\(-2\)\ y + x\ y\)], "Output"],

Cell[BoxData[
    \(\(-x\^2\) + y\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(S\[Dash]polynomial[f\_1, f\_2]\), "=", 
      RowBox[{
        RowBox[{
          StyleBox["y",
            FontColor->RGBColor[0, 0, 1]], "  ", \(f\_1\)}], "-", 
        RowBox[{
          StyleBox["x",
            FontColor->RGBColor[0, 0, 1]], "  ", \(f\_2\), 
          "       "}]}]}]], "Input"],

Cell[BoxData[
    \(y\ \((\(-2\)\ y + x\ y)\) - x\ \((\(-x\^2\) + y\^2)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(S\[Dash]polynomial[f\_1, f\_2]\), "=", 
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox["y",
              FontColor->RGBColor[0, 0, 1]], "  ", \(f\_1\)}], "-", 
          RowBox[{
            StyleBox["x",
              FontColor->RGBColor[0, 0, 1]], "  ", \(f\_2\)}]}], "       ", "//",
         "Expand"}]}]], "Input"],

Cell[BoxData[
    \(x\^3 - 2\ y\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Algorithm 'remainder'", "Subsubsection"],

Cell["\<\
Roughly, remainder[ F, g] results from a generalized \"division\" of g w.r.t. \
to the \"divisors\" in F.\
\>", "Text"],

Cell[TextData[StyleBox["Example:",
  FontWeight->"Bold"]], "Text"],

Cell["Consider, again,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(f\_1 = \(-2\)\ x\^2 + x\^3\), "\[IndentingNewLine]", 
    \(f\_2 = \(-2\)\ y + x\ y\), "\[IndentingNewLine]", 
    \(f\_3 = \(-x\^2\) + y\^2\)}], "Input"],

Cell[BoxData[
    \(\(-2\)\ x\^2 + x\^3\)], "Output"],

Cell[BoxData[
    \(\(-2\)\ y + x\ y\)], "Output"],

Cell[BoxData[
    \(\(-x\^2\) + y\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(F = {f\_1, f\_2, f\_3}\)], "Input"],

Cell[BoxData[
    \({\(-2\)\ x\^2 + x\^3, \(-2\)\ y + x\ y, \(-x\^2\) + y\^2}\)], "Output"]
}, Open  ]],

Cell["and ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g = x\ y - 3\ x\ y\^2\)], "Input"],

Cell[BoxData[
    \(x\ y - 3\ x\ y\^2\)], "Output"]
}, Open  ]],

Cell["A division step on g w.r.t. F:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g\_1 = g\  + \((3\ x)\) f\_3\)], "Input",
  CellTags->"reduction-not-unique"],

Cell[BoxData[
    \(x\ y - 3\ x\ y\^2 + 3\ x\ \((\(-x\^2\) + y\^2)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g\_1 = g\  + \((3\ x)\) f\_3 // Expand\)], "Input",
  CellTags->"reduction-not-unique"],

Cell[BoxData[
    \(\(-3\)\ x\^3 + x\ y\)], "Output"]
}, Open  ]],

Cell["A next division step w.r.t. F:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(F = {f\_1, f\_2, f\_3}\)], "Input"],

Cell[BoxData[
    \({\(-2\)\ x\^2 + x\^3, \(-2\)\ y + x\ y, \(-x\^2\) + y\^2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g\_2 = g\_1\  + \((\(-1\))\) f\_2\  // Expand\)], "Input"],

Cell[BoxData[
    \(\(-3\)\ x\^3 + 2\ y\)], "Output"]
}, Open  ]],

Cell["A next division step w.r.t. F:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(F = {f\_1, f\_2, f\_3}\)], "Input"],

Cell[BoxData[
    \({\(-2\)\ x\^2 + x\^3, \(-2\)\ y + x\ y, \(-x\^2\) + y\^2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g\_3 = g\_2\  + \((3)\) f\_1\  // Expand\)], "Input"],

Cell[BoxData[
    \(\(-6\)\ x\^2 + 2\ y\)], "Output"]
}, Open  ]],

Cell["\<\
This is the remainder of the division of g w.r.t. F because ...\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "A Remainder Algorithm is Available in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialReduce[g, F, {y, x}]\)], "Input"],

Cell[BoxData[
    \({{0, 1 - 3\ y, \(-6\)}, \(-6\)\ x\^2 + 2\ y}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Now We Can Check Groebnerianity", "Subsubsection"],

Cell["Let's again look to the above example:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(F = {f\_1, f\_2, f\_3}\)], "Input"],

Cell[BoxData[
    \({\(-2\)\ x\^2 + x\^3, \(-2\)\ y + x\ y, \(-x\^2\) + y\^2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialReduce[f\_1\ y\  - \ \(f\_2\) x\^2, F, {y, x}]\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0}, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialReduce[f\_1\ y\^2\  - \ \(f\_3\) x\^3, F, {y, x}]\)], "Input"],

Cell[BoxData[
    \({{4 + 2\ x + x\^2, \(-4\)\ y - 2\ x\ y, \(-8\)}, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialReduce[f\_2\ y\  - \ \(f\_3\) x, F, {y, x}]\)], "Input"],

Cell[BoxData[
    \({{1, 0, \(-2\)}, 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Remark for Rewrite Experts", "Subsubsection"],

Cell["\<\
S-polynomials relate to remaindering like unification to pattern matching.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["How Can We Construct Groebner Bases?", "Subsection"],

Cell[CellGroupData[{

Cell["The Problem", "Subsubsection",
  CellTags->"Groebner-bases-construction"],

Cell[TextData[{
  "Given ",
  StyleBox["F",
    FontSlant->"Italic"],
  ",  find ",
  StyleBox["G",
    FontSlant->"Italic"],
  "   s.t. Ideal(",
  StyleBox["F",
    FontSlant->"Italic"],
  ") = Ideal(",
  StyleBox["G",
    FontSlant->"Italic"],
  ") and ",
  StyleBox["G",
    FontSlant->"Italic"],
  " is a ",
  "Gr\[ODoubleDot]bner",
  " basis."
}], "Text"],

Cell[TextData[{
  "(Ideal(F) := the set of all linear combinations  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(h\_1\ f\_1\)\(\ \)\(+\)\)\  ... \)\  + \ 
        h\_m\ f\_m\)]],
  " \n                 \n                with ",
  Cell[BoxData[
      \(TraditionalForm\`f\_1\)]],
  ", ..., ",
  Cell[BoxData[
      \(TraditionalForm\`f\_m\)]],
  " \[Element] F and  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(h\_1\),
            "TraditionalForm"], ",", "...", ",", \(h\_m\)}], 
        TraditionalForm]]],
  " arbitrary polynomials.)"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["An Algorithm", "Subsubsection"],

Cell["Recall the main theorem:", "Text"],

Cell[TextData[{
  StyleBox["F",
    FontSlant->"Italic"],
  " is a Gr\[ODoubleDot]bner basis  \[DoubleLongLeftRightArrow]  \n      ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \+\(f\_1, f\_2 \[Element] F\)\)]],
  "  remainder[ ",
  StyleBox["F",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\[Dash]polynomial[f\_1, f\_2]\)]],
  "] = 0."
}], "Text",
  CellFrame->False,
  CellMargins->{{58.375, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Based on the main theorem, the problem can be solved by the following \
algorithm (BB 1965 ...)\
\>", "Text",
  CellTags->"algorithm"],

Cell[TextData[{
  "Start with G:= F. \nFor any pair of polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`f\_1, f\_2 \[Element] G\)]],
  ":\n\n      h := remainder[ ",
  StyleBox["F",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\[Dash]polynomial[f\_1, f\_2]\)]],
  "] \n      \n      If ",
  StyleBox["h ",
    FontSlant->"Italic"],
  "= 0, consider the next pair.\n      \n      If ",
  StyleBox["h",
    FontSlant->"Italic"],
  " \[NotEqual] 0, add ",
  StyleBox["h",
    FontSlant->"Italic"],
  " to ",
  StyleBox["G",
    FontSlant->"Italic"],
  " and iterate.          "
}], "Text",
  CellFrame->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Correctness of the Algorithm", "Subsubsection"],

Cell["Easy as soon as we know the main theorem.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Termination of the Algorithm", "Subsubsection",
  CellTags->"termination"],

Cell["An application of \"Dickson's Lemma\" (1913, BB 1970).", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Specializations", "Subsubsection"],

Cell[TextData[{
  "The ",
  StyleBox["Gr\[ODoubleDot]bner bases algorithm",
    FontColor->RGBColor[0, 0, 1]],
  ",\n\n        for linear polynomials, specializes to ",
  StyleBox["Gauss' algorithm",
    FontColor->RGBColor[0, 0, 1]],
  ", and\n\n        for univariate polynomials, specializes to ",
  StyleBox["Euclid's algorithm",
    FontColor->RGBColor[0, 0, 1]],
  "."
}], "Text",
  CellTags->"Gauss-algorithm"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example", "Subsubsection"],

Cell["Let's again look at", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(f\_1\), "=", 
      RowBox[{\(\(-2\) y\), "+", 
        StyleBox[\(x\ y\),
          FontColor->RGBColor[0, 0, 1]]}]}], "\[IndentingNewLine]", 
    RowBox[{\(f\_2\), "=", 
      RowBox[{\(-x\^2\), "+", 
        StyleBox[\(y\^2\),
          FontColor->RGBColor[0, 0, 1]]}]}]}], "Input"],

Cell[BoxData[
    \(\(-2\)\ y + x\ y\)], "Output"],

Cell[BoxData[
    \(\(-x\^2\) + y\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(F = {f\_1, f\_2}\)], "Input"],

Cell[BoxData[
    \({\(-2\)\ y + x\ y, \(-x\^2\) + y\^2}\)], "Output"]
}, Open  ]],

Cell["F is not a Groebner basis.", "Text"],

Cell[TextData[{
  "The S-polynomial of ",
  Cell[BoxData[
      \(f\_1, f\_2\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(S\[Dash]polynomial[f\_1, f\_2]\), "=", 
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox["y",
              FontColor->RGBColor[0, 0, 1]], "  ", \(f\_1\)}], "-", 
          RowBox[{
            StyleBox["x",
              FontColor->RGBColor[0, 0, 1]], "  ", \(f\_2\)}]}], "       ", "//",
         "Expand"}]}]], "Input"],

Cell[BoxData[
    \(x\^3 - 2\ y\^2\)], "Output"]
}, Open  ]],

Cell["Its remainder w.r.t. F is:", "Text"],

Cell[BoxData[
    \(\(-2\)\ x\^2 + \(\(x\^3\)\(.\)\)\)], "Input"],

Cell["\<\
All the other S-polynomials have remainder 0. Hence, we arrived at a Groebner \
basis.\
\>", "Text"],

Cell[TextData[{
  "The Groebner basis algorithm is available in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " (and in all other current math software systems):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(G = GroebnerBasis[F, {y, x}]\)], "Input"],

Cell[BoxData[
    \({\(-2\)\ x\^2 + x\^3, \(-2\)\ y + x\ y, \(-x\^2\) + y\^2}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Applications", "Section"],

Cell[CellGroupData[{

Cell["Application: Solving Polynomial Systems", "Subsection"],

Cell[CellGroupData[{

Cell["A Simple System of Equations", "Subsubsection",
  CellTags->"simple-equations"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(f\_1\), "=", 
      RowBox[{\(\(-2\) y\), "+", 
        StyleBox[\(x\ y\),
          FontColor->RGBColor[0, 0, 1]]}]}], "\[IndentingNewLine]", 
    RowBox[{\(f\_2\), "=", 
      RowBox[{\(-x\^2\), "+", 
        StyleBox[\(y\^2\),
          FontColor->RGBColor[0, 0, 1]]}]}]}], "Input"],

Cell[BoxData[
    \(\(-2\)\ y + x\ y\)], "Output"],

Cell[BoxData[
    \(\(-x\^2\) + y\^2\)], "Output"]
}, Open  ]],

Cell["Find x, y such that", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(\(-2\) y\), "+", 
        StyleBox[\(x\ y\),
          FontColor->RGBColor[0, 0, 1]]}], "=", "0"}], "\[IndentingNewLine]", 
  
    RowBox[{
      RowBox[{\(-x\^2\), "+", 
        StyleBox[\(y\^2\),
          FontColor->RGBColor[0, 0, 1]]}], "=", "0"}]}], "Input"],

Cell["We compute", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(G = GroebnerBasis[F, {y, x}]\)], "Input"],

Cell[BoxData[
    \({\(-2\)\ x\^2 + x\^3, \(-2\)\ y + x\ y, \(-x\^2\) + y\^2}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Theorem (BB, Trinks):",
    FontWeight->"Bold"],
  " In Groebner bases (w.r.t. lexicographic orderings), the variables are \
\"decoupled\" and each partial solution can be continued."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[\(-2\)\ x\^2 + x\^3 == 0, x]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] 0}, {x \[Rule] 0}, {x \[Rule] 2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({G[\([2]\)], G[\([3]\)]} /. {x \[Rule] 2}\)], "Input"],

Cell[BoxData[
    \({0, \(-4\) + y\^2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[\(-4\) + y\^2 == 0, y]\)], "Input"],

Cell[BoxData[
    \({{y \[Rule] \(-2\)}, {y \[Rule] 2}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "All this is already implemented in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " general Solve function:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[{f\_1 == 0, f\_2 == 0}, {x, y}]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] 0, y \[Rule] 0}, {x \[Rule] 0, y \[Rule] 0}, {x \[Rule] 2, 
        y \[Rule] \(-2\)}, {x \[Rule] 2, y \[Rule] 2}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Theorem (BB): ",
    FontWeight->"Bold"],
  "The number of solutions can be predicted from the form of the Groebner \
basis."
}], "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0001iX0@0006`0000:00001`000742001:0P00
00000000003g?@00BSd00215CDH00040J1h008d100040000000000000000000000@00003003n0000
b`000000000000000000033P0`3h60<02P000100001`0000H00000T0000@0000O@800542000D0000
300000d0000W000060000040000000000<bI0000000U000030000040000V00007000008000000000
0@000000000000029@0000`000020000:`0001P0003@0000`0000=P0001`0P009@0000`000000020
:00000`0000100009@0000`000070020:00000`0000200003000010000000000000002L0000H0000
0P0000000000c9T0000002D0000<00000P0002H0000L00000@0000000001000000000000008U0000
30000040000[0000600002P200380000<08007P2000U000030000000080X000030000080000U0000
300000L0080X000030000040000<000040000000000000009`0001P0000100000000003<V@000000
9@0000`0000100009P0001`000020000000000400000000000000RD0000<00000P0002/0000H0000
>0400=0000100@00P08002D0000<00000000P2P0000<00000@0002D0000<00001`00P2P0000<0000
0P0000`0000@000000000000000W000060000080000000000<bI0000000U000030000080000V0000
70000040000000000@000000000000029@0000`000010000:`0001P0002X0@00b0000;01001h0P00
9@0000`000000020:00000`0000200009@0000`000070020:00000`0000100003000010000000000
000002L0000H00000@0000000000c9T0000002D0000<00000@0002H0000L00000P00000000010000
00000000008U000030000080000[000060000:P000180P00Z0800502000U000030000000080X0000
30000040000U0000300000L0080X000030000080000<000040000000000000009`0001P000020000
0000003<V@0000009@0000`0000200009P0001`000010000000000400000000000000RD0000<0000
0@0002/0000H0000Z0000>01002X0P00j04002D0000<00000000P2P0000<00000P0002D0000<0000
1`00P2P0000<00000@0000`0000@000000000000000W000060000040000000000<bI0000000U0000
30000040000V000070000080000000000@000000000000029@0000`000020000:`0001P0002P0000
L0400:02001h0@009@0000`000000020:00000`0000100009@0000`000070020:00000`000020000
3000010000000000000002L0000H00000P0000000000c9T0000002D0000<00000P0002H0000L0000
0@0000000001000000000000008U000030000040000[000060000:P000000@00Z08000P1000U0000
30000000080X000030000080000U0000300000L0080X000030000040000<00004000000000000000
9`0001P00001000000000?oo000000009@0000`0000100009P0001`0000200000000004000000000
00000RD0000<00000P0002X0000H0000^0000601003X0000T04002D0000<00000000P2P0000<0000
0@0002D0000<00001`00P2P0000<00000P0000`0000@000000000000000W00006000008000000000
ool00000000U000030000080000V000070000040000000000@000000000000029@0000`000010000
:P0001P0000X0@00b04005P1003h0@009@0000`000000020:00000`0000200009@0000`000070020
:00000`0000100003000010000000000000002L0000H00000@000000003oo`00000002D0000<0000
0@0002H0000L00000P0000000001000000000000008U000030000080000Z0000600001P2000h0P00
B08006P2000U000030000000080X000030000040000U0000300000L0080X000030000080000<0000
40000000000000009@0000`0000500209@0000`000080020:`0001P000300P00:0800>/2001[0P00
9@0000`0000000209@0000`000070020DP0007010002000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000001P00004000100P00@0800010002@QaT0/@`QcZQ4nGLN0000:0`E00005@2P]aL0
g>LC0040000TjQ<0l8SjMg0hmGOoooooZ4CiMg1mmGLjR_Eg000005/1003oooooA2A50L@QA@5P5ZP1
0000000000000000J7_:000000000000000000000000;@00Z`00008000101QD00000000000000000
@00005H100000000@2=50L@QA@400:P1<1NX0E3W4`1@jA<0P>TC0;cY4`1`N/X0iP00000000000000
n4M50Aa8A@40jA<0G[bB<80000010000I7H02000000U000030000080000H000030000000008I0000
30000?ooo`8K00004000000000000000DP00070100010000d?ooo`00000000000000090100000000
04008T40LP1Y0640K000000000000000000000000000000000000000000000000000000000000000
0000000000000<X0[>4C031ebP3mL@<`000009Q00c0?00000P0002aebP000000@>8C0=/o0c0/MLX0
00000?QabP10hQ<0Zd@3<4l;0G`M?0<`9C`3<60000180000H00004P0001/ha<0H00004P0001P0000
B00004El0S070000H0000000000dhQ<0TS/3<0L00028ha<0Nj2<<2aebP1P0000B000060000180000
;7G:0;cS4`0<>`<`K><C0040000001<0Q;l9OTl;0Gb0hQ<0i0@0013T4`0000000R2><4l;0Gb0hQ<0
0@00013T4`0@LLX0M>@C0000000]0000I7H02000000U000030000040000X000030000080000H0000
30000000008I000030000?ooo`8K000040000000000000005P0000`0000H00004P0000`000010000
E00005@0001J0P00c`40074200050P000@00001`aT5EMM=1bP8005`200010000C000000000000000
00000?ooooooooooD00007P0000H00005P0000`0000000004P0000`0000200004P0000`000020000
3000010000000000000002D0000<00001@00P2D0000<00002000P2/0000H0000^0000600003S0000
X`0002D0000<00000000P2D0000<00001`00P1P0000<000000000QT0000<0000oooo0Q/0000@0000
00000000000H000030000000008I000030000?ooo`8K000040000000000000005P0000`0000H0000
4P0000`000010000E00005@0001B00001`0006P0000m00000@00001`aT5EMM=1`P0009@000010000
C00000000000000000000?ooooooooooD00007T0000G00005P0000`0000000004P0000`000020000
4P0000`0000200003000010000000000000002L0000H00000P000000003o0000000002D0000<0000
0P0002H0000L00000`0000000001000000000000008U0000300000<0000Z0000600009P1003X0000
b04001P1000U000030000000080X000030000080000U0000300000L0080X0000300000<0000<0000
40000000000000009`0001P00003000000000?l0000000009@0000`0000300009P0001`000020000
000000400000000000000RD0000<00000P0002X0000H0000T04005P100300@00R04002D0000<0000
0000P2P0000<00000`0002D0000<00001`00P2P0000<00000P0000`0000@000000000000000W0000
6000008000000000o`000000000U000030000080000V0000700000<0000000000@00000000000002
9@0000`000030000:P0001P0000@0P00b0400402003h0@009@0000`000000020:00000`000020000
9@0000`000070020:00000`0000300003000010000000000000002L0000H00000`000000003o0000
000002D0000<00000`0002H0000L00000P0000000001000000000000008U000030000080000Z0000
600001P2001H0@00B08008P1000U000030000000080X0000300000<0000U0000300000L0080X0000
30000080000<000040000000000000009`0001P00002000000000?l0000000009@0000`000020000
9P0001`000030000000000400000000000000RD0000<00000`0002X0000H000060800?0000180P00
804002D0000<00000000P2P0000<00000P0002D0000<00001`00P2P0000<00000`0000`0000@0000
00000000000W0000600000<000000000o`000000000U0000300000<0000V00007000008000000000
0@000000000000029@0000`000020000:P0001P0000X0@00F04005P100280@009@0000`000000020
:00000`0000300009@0000`000070020:00000`0000200003000010000000000000002L0000H0000
0P000000003o0000000002D0000<00000P0002H0000L00000`0000000001000000000000008U0000
300000<0000Z000060000<00003`0000l0000201000U000030000000080X000030000080000U0000
300000L0080X0000300000<0000<000040000000000000009`0001P00003000000000?l000000000
9@0000`0000300009P0001`000020000000000400000000000000RD0000<00000P0002X0000H0000
<0400?00001P0@00804002D0000<00000000P2P0000<00000`0002D0000<00001`00P2P0000<0000
0P0000`0000@000000000000000W00006000008000000000o`000000000U000030000080000V0000
700000<0000000000@000000000000029@0000`000030000:P0001P0002@0@00b0400<01003h0@00
9@0000`000000020:00000`0000200009@0000`000070020:00000`0000300003000010000000000
000002D0000<00001@00P2D0000<00002000P2/0000H0000b00007P2003]0000Z08002D0000<0000
0000P2D0000<00001`00P1P0000<000000000QT0000<0000oooo0Q/0000@000000000000001B0000
L04000<0003Poooo0000000000000000T04000000000@00R@@1b06T0H@1/00000000000000000000
00000000000000000000000000000000000000000000000000000000bP2/hA<0<7G:0?ea0c000000
V403<0l000020000;7G:00000010hQ<0fcl3<2aebP000000n77:043R4`2[A0<`C`/1O1dl0c0U?0<`
H00004P0001P0000B00006cS4`1P0000B000060000180000AG`2<0L0001P0000000003CR4`2B>`<`
1`0008SS4`1kX8``;7G:060000180000H00004P0000/MLX0_><C00`k0c1/ha<00@0000004`24_`Un
C`/1O83R4`3T10004>@C0000000288h`C`/1O83R4`0100004>@C011abP1di1<0000002d0001TMP08
000002D0000<00000`0002P0000<00000@0001P0000<000000000QT0000<0000oooo0Q/0000@0000
00000000000F0000300001P0000B000030000040001D0000E0000680000O0P00L`00048200010000
0736@EEedd7B0000W0800040001<00000000000000000000oooooooooom@0000<0000180000F0000
30000000000B000030000080000B000030000080000<000040000000000000009@0000`000050020
9@0000`000080020:`0001P0000X0@00P08004d1002`0P009@0000`0000000209@0000`000070020
600000`0000000026@0000`0003oool26`00010000000000000001P0000<000000000QT0000<0000
oooo0Q/0000@000000000000000F0000300001P0000B000030000040001D0000E0000<80000W0P00
d`0004X2000100000736@EEedd4b0@00Y0800040001<00000000000000000000oooooooooom@0000
<@000180000F000030000000000B000030000080000B000030000080000<00004000000000000000
9@0000`0000500209@0000`000080020:`0001P0000@0P00N08003D2002X0P009@0000`000000020
9@0000`000070020600000`0000000026@0000`0003oool26`00010000000000000001P0000<0000
00000QT0000<0000oooo0Q/0000@000000000000000F0000300001P0000B000030000040001D0000
E0000:X1000O0P00^`400482000100000736@EEedd4J0P00W0800040001<00000000000000000000
oooooooooom@0000<`000180000F000030000000000B000030000080000B000030000080000<0000
40000000000000009@0000`0000500209@0000`000080020:`0001P0002@0@00P0800;D1002`0P00
9@0000`0000000209@0000`000070020600000`0000000026@0000`0003oool26`00010000000000
000001P0000<000000000QT0000<0000oooo0Q/0000@000000000000000F0000300001P0000B0000
30000040001D0000E00002X1000W0P00>`4004X2000100000736@EEedd6J0@00Y0800040001<0000
0000000000000000oooooooooom@0000<P000180000F000030000000000B000030000080000B0000
30000080000<000040000000000000009@0000`0000500209@0000`000080020:`0001P0001h0000
d04009d000000P009@0000`0000000209@0000`000070020600000`0000000026@0000`0003oool2
6`00010000000000000001P0000<000000000QT0000<0000oooo0Q/0000@000000000000000F0000
300001P0000B000030000040001D0000E0000180001g0@008`0009X1000100000736@EEedd620000
m0400040001<00000000000000000000oooooooooom@0000<@000180000F000030000000000B0000
30000080000B000030000080000<000040000000000000009@0000`0000500209@0000`000080020
:`0001P0001`0000J04009D0002H0@009@0000`0000000209@0000`000070020600000`000000002
6@0000`0003oool26`00010000000000000001P0000<000000000QT0000<0000oooo0Q/0000@0000
00000000000F0000300001P0000B000030000040001D0000E00000X0000?0@006`00038100010000
0736@EEedd5j0000S0400040001<00000000000000000000oooooooooom@0000<P000180000F0000
30000000000B000030000080000B000030000080000<000040000000000000009@0000`000050020
9@0000`000080020:`0001P0001h0000l00009d0000P0@009@0000`0000000209@0000`000070020
600000`0000000026@0000`0003oool26`00010000000000000001P0000<000000000QT0000<0000
oooo0Q/0000@000000000000000F0000300001P0000B000030000040001D0000E0000180002G0000
8`000;X0000100000736@EEedd62000050400040001<00000000000000000000oooooooooom@0000
<`000180000F000030000000000B000030000080000B000030000080000<00004000000000000000
9@0000`0000500209@0000`000080020:`0001P0001h0000>08009d0001X0P009@0000`000000020
9@0000`000070020600000`0000000026@0000`0003oool26`00010000000000000001P0000<0000
00000QT0000<0000oooo0Q/0000@000000000000000F0000300001P0000B000030000040001D0000
E0000180003O0@008`000082000100000736@EEedd620000G0800040001<00000000000000000000
oooooooooom@0000<0000180000F000030000000000B000030000080000B000030000080000<0000
40000000000000009@0000`0000800209@0000`0000500209@0000`0000=0020:00000`000030000
3P0001@000000000400001@0
\>"], "Graphics",
  ImageSize->{275, 258.75},
  ImageMargins->{{97.3125, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["A More Complicated Set of Equations", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(f\_1\), "=", 
        RowBox[{\(x\ y\), 
          StyleBox["-",
            FontColor->GrayLevel[0]], \(2  y\ z\), " ", "-", " ", "z"}]}], 
      ";", "\n", \(f\_2 = y\^2 - x\^2\ z\  + \ x\ z\), ";", "\n", 
      RowBox[{\(f\_3\), "=", 
        RowBox[{\(z\^2\), 
          StyleBox["-",
            FontColor->GrayLevel[0]], \(y\^2\ x\), " ", "+", " ", "x"}]}], 
      ";", "\n", "\n", \(F\  = \ {f\_1, f\_2, f\_3}\), ";"}]], "Input",
  CellTags->"complicated-equations"],

Cell[CellGroupData[{

Cell[BoxData[
    \({time, G} = GroebnerBasis[F]\  // \ Timing\)], "Input"],

Cell[BoxData[
    \({0.03`\ Second, {z + 4\ z\^3 - 17\ z\^4 + 3\ z\^5 - 45\ z\^6 + 
          60\ z\^7 - 29\ z\^8 + 124\ z\^9 - 48\ z\^10 + 64\ z\^11 - 
          64\ z\^12, \(-22001\)\ z + 14361\ y\ z + 16681\ z\^2 + 
          26380\ z\^3 + 226657\ z\^4 + 11085\ z\^5 - 90346\ z\^6 - 
          472018\ z\^7 - 520424\ z\^8 - 139296\ z\^9 - 150784\ z\^10 + 
          490368\ z\^11, 
        43083\ y\^2 - 11821\ z + 267025\ z\^2 - 583085\ z\^3 + 663460\ z\^4 - 
          2288350\ z\^5 + 2466820\ z\^6 - 3008257\ z\^7 + 4611948\ z\^8 - 
          2592304\ z\^9 + 2672704\ z\^10 - 1686848\ z\^11, 
        43083\ x - 118717\ z + 69484\ z\^2 + 402334\ z\^3 + 409939\ z\^4 + 
          1202033\ z\^5 - 2475608\ z\^6 + 354746\ z\^7 - 6049080\ z\^8 + 
          2269472\ z\^9 - 3106688\ z\^10 + 3442816\ z\^11}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zsolexact1 = Solve[G[\([1]\)] == 0, z]\)], "Input"],

Cell[BoxData[
    \({{z \[Rule] 0}, {z \[Rule] 
          Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 
                60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 
                64\ #1\^11 &, 1]}, {z \[Rule] 
          Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 
                60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 
                64\ #1\^11 &, 2]}, {z \[Rule] 
          Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 
                60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 
                64\ #1\^11 &, 3]}, {z \[Rule] 
          Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 
                60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 
                64\ #1\^11 &, 4]}, {z \[Rule] 
          Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 
                60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 
                64\ #1\^11 &, 5]}, {z \[Rule] 
          Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 
                60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 
                64\ #1\^11 &, 6]}, {z \[Rule] 
          Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 
                60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 
                64\ #1\^11 &, 7]}, {z \[Rule] 
          Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 
                60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 
                64\ #1\^11 &, 8]}, {z \[Rule] 
          Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 
                60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 
                64\ #1\^11 &, 9]}, {z \[Rule] 
          Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 
                60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 
                64\ #1\^11 &, 10]}, {z \[Rule] 
          Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 
                60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 
                64\ #1\^11 &, 11]}}\)], "Output"]
}, Open  ]],

Cell["\<\
One can compute with these \"abstract roots\" like with \"square roots\". For \
example\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(G0 = G\  /. \ zsolexact1[\([2]\)] // Simplify\)], "Input"],

Cell[BoxData[
    \({0, 
      Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 60\ #1\^6 + 
              29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, 
          1]\ \((\(-22001\) + 14361\ y + 
            16681\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 
                    45\ #1\^5 - 60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 
                    48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, 1] + 
            26380\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 \
- 60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^2 + 226657\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^3 + 11085\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 60\
\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^4 - 90346\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 60\
\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^5 - 472018\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^6 - 520424\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^7 - 139296\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^8 - 150784\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^9 + 490368\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^10)\), \(-26357\) + 43083\ y\^2 - 
        11821\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 
                60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 
                64\ #1\^11 &, 1] + 
        161597\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^2 - 135016\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^3 + 584389\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^4 - 1102285\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^5 + 885400\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^6 - 2243904\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^7 + 1343680\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^8 - 1327168\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^9 + 985856\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^10, 53794 + 43083\ x - 
        118717\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 
                60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 
                64\ #1\^11 &, 1] + 
        284660\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^2 - 512164\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^3 + 571321\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^4 - 1218697\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^5 + 752032\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^6 - 1205280\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^7 + 621376\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^8 - 312640\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^9 + 336128\ Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - \
60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 64\ #1\^11 &, \
1]\^10}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(G0 /. {Root[\(-1\) - 4\ #1\^2 + 17\ #1\^3 - 3\ #1\^4 + 45\ #1\^5 - 
                60\ #1\^6 + 29\ #1\^7 - 124\ #1\^8 + 48\ #1\^9 - 64\ #1\^10 + 
                64\ #1\^11 &, 1] \[Rule] \[Alpha]}\)], "Input"],

Cell[BoxData[
    \({0, \[Alpha]\ \((\(-22001\) + 14361\ y + 16681\ \[Alpha] + 
            26380\ \[Alpha]\^2 + 226657\ \[Alpha]\^3 + 11085\ \[Alpha]\^4 - 
            90346\ \[Alpha]\^5 - 472018\ \[Alpha]\^6 - 520424\ \[Alpha]\^7 - 
            139296\ \[Alpha]\^8 - 150784\ \[Alpha]\^9 + 
            490368\ \[Alpha]\^10)\), \(-26357\) + 43083\ y\^2 - 
        11821\ \[Alpha] + 161597\ \[Alpha]\^2 - 135016\ \[Alpha]\^3 + 
        584389\ \[Alpha]\^4 - 1102285\ \[Alpha]\^5 + 885400\ \[Alpha]\^6 - 
        2243904\ \[Alpha]\^7 + 1343680\ \[Alpha]\^8 - 1327168\ \[Alpha]\^9 + 
        985856\ \[Alpha]\^10, 
      53794 + 43083\ x - 118717\ \[Alpha] + 284660\ \[Alpha]\^2 - 
        512164\ \[Alpha]\^3 + 571321\ \[Alpha]\^4 - 1218697\ \[Alpha]\^5 + 
        752032\ \[Alpha]\^6 - 1205280\ \[Alpha]\^7 + 621376\ \[Alpha]\^8 - 
        312640\ \[Alpha]\^9 + 336128\ \[Alpha]\^10}\)], "Output"]
}, Open  ]],

Cell["No more details in this talk!", "Text"],

Cell["Alternatively, compute numerically:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(zsol = NSolve[G[\([1]\)] == 0, z]\)], "Input"],

Cell[BoxData[
    \({{z \[Rule] \(-0.33130430007894435`\) - 
            0.5869344538646171`\ \[ImaginaryI]}, {z \[Rule] \
\(-0.33130430007894435`\) + 
            0.5869344538646171`\ \[ImaginaryI]}, {z \[Rule] \
\(-0.29641346777661987`\) - 
            0.7053287925603559`\ \[ImaginaryI]}, {z \[Rule] \
\(-0.29641346777661987`\) + 
            0.7053287925603559`\ \[ImaginaryI]}, {z \[Rule] \
\(-0.16312357900403873`\) - 
            0.37694017948317526`\ \[ImaginaryI]}, {z \[Rule] \
\(-0.16312357900403873`\) + 0.37694017948317526`\ \[ImaginaryI]}, {z \[Rule] 
          0.`}, {z \[Rule] \(\(0.02489189803936702`\)\(\[InvisibleSpace]\)\) \
- 0.8917802016624394`\ \[ImaginaryI]}, {z \[Rule] \
\(\(0.02489189803936702`\)\(\[InvisibleSpace]\)\) + 
            0.8917802016624394`\ \[ImaginaryI]}, {z \[Rule] 
          0.46885190657576703`}, {z \[Rule] 0.670230792861074`}, {z \[Rule] 
          1.392816198203631`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gsubnum = G\  /. \ zsol[\([1]\)]\)], "Input"],

Cell[BoxData[
    \({6.661338147750939`*^-16 - 
        2.3592239273284576`*^-16\ \[ImaginaryI], \((\(-523.519475855232`\) - 
            4967.646241304129`\ \[ImaginaryI])\) - \((\(\(4757.8610534337195`\
\)\(\[InvisibleSpace]\)\) + 
              8428.965691949767`\ \[ImaginaryI])\)\ y, \
\((\(-7846.896476179476`\) - 8372.055369776837`\ \[ImaginaryI])\) + 
        43083\ y\^2, \((\(-16311.684476871378`\) + 
            16611.000434422152`\ \[ImaginaryI])\) + 43083\ x}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialGCD[Gsubnum[\([2]\)], Gsubnum[\([3]\)]]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ysol = NSolve[\ Gsubnum[\([2]\)] == 0, y]\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(ysol\)\" is similar to \
existing symbol \"\!\(zsol\)\"."\)], "Message"],

Cell[BoxData[
    \({{y \[Rule] \(-0.4735346386353344`\) - 
            0.20518443210789414`\ \[ImaginaryI]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ysol = NSolve[\ Gsubnum[\([3]\)] == 0, y]\)], "Input"],

Cell[BoxData[
    \({{y \[Rule] \(-0.4735346386353328`\) - 
            0.20518443210789467`\ \[ImaginaryI]}, {y \[Rule] \
\(\(0.4735346386353328`\)\(\[InvisibleSpace]\)\) + 
            0.20518443210789467`\ \[ImaginaryI]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Theorem",
    FontWeight->"Bold"],
  " (Roider, Kalkbrener et al.): It suffices to consider the poly in y with \
lowest degree."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xsol = NSolve[\ Gsubnum[\([4]\)] == 0, x]\)], "Input"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(xsol\)\" is similar to \
existing symbols \!\({ysol, zsol}\)."\)], "Message"],

Cell[BoxData[
    \({{x \[Rule] \(\(0.3786106927760689`\)\(\[InvisibleSpace]\)\) - 
            0.38555811885017643`\ \[ImaginaryI]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(F /. zsol[\([1]\)]\) /. ysol[\([1]\)]\) /. xsol[\([1]\)]\)], "Input"],

Cell[BoxData[
    \({1.942890293094024`*^-15 + 
        6.800116025829084`*^-16\ \[ImaginaryI], \(-1.4432899320127035`*^-15\) \
- 7.91033905045424`*^-16\ \[ImaginaryI], 
      2.0539125955565396`*^-15 - 
        4.440892098500626`*^-16\ \[ImaginaryI]}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Application: Invariant Theory", "Subsection"],

Cell[CellGroupData[{

Cell["A Question", "Subsubsection"],

Cell["Can ", "Text",
  CellTags->"algebraic-relations"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h = \(x\_1\^7\) x\_2 - x\_1\ x\_2\^7\)], "Input"],

Cell[BoxData[
    \(x\_1\%7\ x\_2 - x\_1\ x\_2\%7\)], "Output"]
}, Open  ]],

Cell["be expressed as a polynomial in ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(F = {x\_1\^2 + x\_2\^2, \(x\_1\^2\) x\_2\^2, \(x\_1\^3\) x\_2 - 
          x\_1\ x\_2\^3}\)], "Input"],

Cell[BoxData[
    \({x\_1\%2 + x\_2\%2, x\_1\%2\ x\_2\%2, 
      x\_1\%3\ x\_2 - x\_1\ x\_2\%3}\)], "Output"]
}, Open  ]],

Cell["?", "Text"],

Cell[TextData[{
  "Note: These polynomials are fundamental invariants for ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalZ]\_4\)]],
  ", i.e. a set of generators for the ring"
}], "Text"],

Cell[BoxData[
    \(\(\({f \[Element] \[DoubleStruckCapitalC][x\_1, 
              x\_2]\  \[VerticalSeparator] \ f \((x\_1, x\_2)\) = 
        f \((\(-x\_2\), x\_1)\)}\)\(,\)\)\)], "Input"],

Cell["i.e.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({x\_1\^2 + x\_2\^2, \(x\_1\^2\) x\_2\^2, \(x\_1\^3\) x\_2 - 
          x\_1\ x\_2\^3} /. {x\_1 \[Rule] \(-x\_2\), 
        x\_2 \[Rule] x\_1}\)], "Input"],

Cell[BoxData[
    \({x\_1\%2 + x\_2\%2, x\_1\%2\ x\_2\%2, 
      x\_1\%3\ x\_2 - x\_1\ x\_2\%3}\)], "Output"]
}, Open  ]],

Cell["\<\
and all invariants can be expressed as polynomials in these invariants.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reduction to Groebner Bases Computation", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \({time, GB} = 
      GroebnerBasis[{\(-i\_1\) + x\_1\^2 + 
              x\_2\^2, \(-i\_2\) + \(x\_1\^2\) 
                x\_2\^2, \(-i\_3\) + \(x\_1\^3\) x\_2 - 
              x\_1\ x\_2\^3}, {x\_2, x\_1, i\_3, i\_2, i\_1}] // 
        Timing\)], "Input"],

Cell[BoxData[
    \({0.010000000000000009`\ Second, {\(-i\_1\%2\)\ i\_2 + 4\ i\_2\%2 + 
          i\_3\%2, \(-i\_2\) + i\_1\ x\_1\%2 - x\_1\%4, 
        i\_1\%2\ i\_3\ x\_1 - 2\ i\_2\ i\_3\ x\_1 - i\_1\ i\_3\ x\_1\%3 + 
          i\_1\%2\ i\_2\ x\_2 - 4\ i\_2\%2\ x\_2, 
        i\_1\%2\ x\_1 - 2\ i\_2\ x\_1 - i\_1\ x\_1\%3 + 
          i\_3\ x\_2, \(-i\_1\)\ i\_3 + 2\ i\_3\ x\_1\%2 - 
          i\_1\%2\ x\_1\ x\_2 + 4\ i\_2\ x\_1\ x\_2, \(-i\_3\)\ x\_1 - 
          2\ i\_2\ x\_2 + i\_1\ x\_1\%2\ x\_2, \(-i\_3\) - i\_1\ x\_1\ x\_2 + 
          2\ x\_1\%3\ x\_2, \(-i\_1\) + x\_1\%2 + x\_2\%2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialReduce[\(x\_1\^7\) x\_2 - x\_1\ x\_2\^7, 
      GB, {x\_2, x\_1, i\_3, i\_2, i\_1}, 
      MonomialOrder \[Rule] Lexicographic]\)], "Input"],

Cell[BoxData[
    \({{0, \(-i\_3\) - 1\/2\ i\_1\ x\_1\ x\_2 - x\_1\%3\ x\_2, 
        0, \(3\ i\_1\ x\_2\)\/4 - 1\/2\ x\_1\%2\ x\_2 + x\_2\%3\/2, 
        i\_1 - x\_1\%2\/2 + \(3\ x\_2\%2\)\/4, \(3\ i\_1\ x\_1\)\/2 + 
          x\_1\ x\_2\%2, 
        x\_2\%4\/2, \(-\(1\/4\)\)\ i\_1\%2\ x\_1\ x\_2 - 
          1\/2\ i\_1\ x\_1\ x\_2\%3 - x\_1\ x\_2\%5}, 
      i\_1\%2\ i\_3 - i\_2\ i\_3}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Theorem",
    FontWeight->"Bold"],
  " (Sweedler, Sturmfels et al.): h can be represented in terms of I iff \
remainder of h w.r.t. \"Groebner basis of I with slack variables\" is a \
polynomial in the slack variables (which gives the representation)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(i\_1\%2\ i\_3 - i\_2\ i\_3 /. {i\_1 \[Rule] x\_1\^2 + x\_2\^2, 
          i\_2 \[Rule] \(x\_1\^2\) x\_2\^2, 
          i\_3 \[Rule] \(x\_1\^3\) x\_2 - x\_1\ x\_2\^3}\  // 
      Expand\)], "Input"],

Cell[BoxData[
    \(x\_1\%7\ x\_2 - x\_1\ x\_2\%7\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R = 
      PolynomialReduce[\(x\_1\^6\) x\_2 - x\_1\ x\_2\^6, 
        GB, {x\_2, x\_1, i\_3, i\_2, i\_1}, 
        MonomialOrder \[Rule] Lexicographic]\)], "Input"],

Cell[BoxData[
    \({{0, \(i\_1\ x\_1\)\/2 - i\_1\ x\_2 - x\_1\%2\ x\_2, 
        0, \(3\ i\_1\)\/4 - x\_1\%2\/2 + 
          x\_2\%2\/2, \(-\(x\_1\/4\)\) + \(3\ x\_2\)\/4, \(3\ i\_1\)\/4 + 
          x\_1\ x\_2, 
        x\_2\%3\/2, \(-\(1\/4\)\)\ i\_1\%2\ x\_1 - 
          1\/2\ i\_1\ x\_1\ x\_2\%2 - x\_1\ x\_2\%4}, \(-i\_1\%3\)\ x\_1 + 
        2\ i\_1\ i\_2\ x\_1 + 1\/2\ i\_1\ i\_3\ x\_1 + i\_1\%2\ x\_1\%3 - 
        i\_2\ x\_1\%3 + 1\/2\ i\_3\ x\_1\%3 + 
        1\/2\ i\_1\ i\_2\ x\_2}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(\(x\_1\^6\) x\_2 - x\_1\ x\_2\^6\)]],
  " can not be expressed by the fundamental invariants in I. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(x\_1\^6\) x\_2 - x\_1\ x\_2\^6 /. {x\_1 \[Rule] \(-x\_2\), 
        x\_2 \[Rule] x\_1}\)], "Input"],

Cell[BoxData[
    \(x\_1\%6\ x\_2 + x\_1\ x\_2\%6\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Application: Automated (Dis-) Proving in Geometry", "Subsection"],

Cell[CellGroupData[{

Cell["The Method", "Subsubsection"],

Cell["\<\
The following proofs (including the English explanatory texts) are produced \
automatically by the Theorema system, in which the Gr\[ODoubleDot]bner bases \
method is one of the automated proving methods. \
\>", "Text"],

Cell["\<\
Each automated proof generated also contains an explanation of the method of \
reducing the proof problem to the problem of constructing a couple of \
Groebner bases.\
\>", "Text"],

Cell["For  more information on Theorema see", "Text"],

Cell["\<\
B. B., C. Dupre, T. Jebelean, F. Kriftner, K. Nakagawa, D. Vasaru, W. \
Windsteiger.
The Theorema Project: A Progress Report.
In: Symbolic Computation and Automated Reasoning (Proceedings of CALCULEMUS \
2000, Symposium on the Integration of Symbolic Computation and Mechanized \
Reasoning, August 6-7, 2000, St. Andrews, Scotland), M. Kerber and M. \
Kohlhase (eds.), A.K. Peters, Natick, Massachusetts, ISBN 1-56881-145-4, pp. \
98-113.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: Pappus Theorem", "Subsubsection"],

Cell["What does the theorem say geometrically?", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .68242 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0135387 0.00373483 -0.119385 0.00373483 [
[.04248 .35494 -5.8125 0 ]
[.04248 .35494 5.8125 11.1875 ]
[.09851 .13085 -9.21875 0 ]
[.09851 .13085 9.21875 11.1875 ]
[.37862 .46698 -5.75 0 ]
[.37862 .46698 5.75 11.1875 ]
[.45331 .0935 -9.1875 0 ]
[.45331 .0935 9.1875 11.1875 ]
[.97619 .66617 -6.03125 0 ]
[.97619 .66617 6.03125 11.1875 ]
[.93884 .04239 -9.1875 0 ]
[.93884 .04239 9.1875 11.1875 ]
[.20112 .25399 -5.84375 0 ]
[.20112 .25399 5.84375 11.1875 ]
[.31189 .261 -5.8125 0 ]
[.31189 .261 5.8125 11.1875 ]
[.62431 .28078 -6.03125 0 ]
[.62431 .28078 6.03125 11.1875 ]
[ 0 0 0 0 ]
[ 1 .68242 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .32879 m
.35994 .44084 L
s
.02381 .32879 m
.43464 .06736 L
s
.02381 .32879 m
.92017 .01625 L
s
.07983 .1047 m
.35994 .44084 L
s
.07983 .1047 m
.43464 .06736 L
s
.07983 .1047 m
.95752 .64003 L
s
.35994 .44084 m
.92017 .01625 L
s
.43464 .06736 m
.95752 .64003 L
s
.95752 .64003 m
.02381 .32879 L
s
.95752 .64003 m
.35994 .44084 L
s
.92017 .01625 m
.07983 .1047 L
s
.92017 .01625 m
.43464 .06736 L
s
.18245 .22784 m
.02381 .32879 L
s
.18245 .22784 m
.07983 .1047 L
s
.18245 .22784 m
.35994 .44084 L
s
.18245 .22784 m
.43464 .06736 L
s
.29322 .23486 m
.02381 .32879 L
s
.29322 .23486 m
.07983 .1047 L
s
.29322 .23486 m
.95752 .64003 L
s
.29322 .23486 m
.92017 .01625 L
s
gsave
.04248 .35494 -66.8125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 19.1875 translate 1 -1 scale
63.062 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
%%BeginResource: font Courier-BoldOblique-MISO
%%BeginFont: Courier-BoldOblique-MISO
/Courier-BoldOblique /Courier-BoldOblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-BoldOblique-MISO
%%IncludeFont: Courier-BoldOblique-MISO
/Courier-BoldOblique-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.09851 .13085 -70.2188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 19.1875 translate 1 -1 scale
63.062 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
%%BeginResource: font Courier-BoldOblique-MISO
%%BeginFont: Courier-BoldOblique-MISO
/Courier-BoldOblique /Courier-BoldOblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-BoldOblique-MISO
%%IncludeFont: Courier-BoldOblique-MISO
/Courier-BoldOblique-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(A1) show
1.000 setlinewidth
grestore
gsave
.37862 .46698 -66.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
%%BeginResource: font Courier-BoldOblique-MISO
%%BeginFont: Courier-BoldOblique-MISO
/Courier-BoldOblique /Courier-BoldOblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-BoldOblique-MISO
%%IncludeFont: Courier-BoldOblique-MISO
/Courier-BoldOblique-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.45331 .0935 -70.1875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
%%BeginResource: font Courier-BoldOblique-MISO
%%BeginFont: Courier-BoldOblique-MISO
/Courier-BoldOblique /Courier-BoldOblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-BoldOblique-MISO
%%IncludeFont: Courier-BoldOblique-MISO
/Courier-BoldOblique-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(B1) show
1.000 setlinewidth
grestore
gsave
.97619 .66617 -67.0312 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
%%BeginResource: font Courier-BoldOblique-MISO
%%BeginFont: Courier-BoldOblique-MISO
/Courier-BoldOblique /Courier-BoldOblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-BoldOblique-MISO
%%IncludeFont: Courier-BoldOblique-MISO
/Courier-BoldOblique-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(C) show
1.000 setlinewidth
grestore
gsave
.93884 .04239 -70.1875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
%%BeginResource: font Courier-BoldOblique-MISO
%%BeginFont: Courier-BoldOblique-MISO
/Courier-BoldOblique /Courier-BoldOblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-BoldOblique-MISO
%%IncludeFont: Courier-BoldOblique-MISO
/Courier-BoldOblique-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(C1) show
1.000 setlinewidth
grestore
gsave
.20112 .25399 -66.8438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
%%BeginResource: font Courier-BoldOblique-MISO
%%BeginFont: Courier-BoldOblique-MISO
/Courier-BoldOblique /Courier-BoldOblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-BoldOblique-MISO
%%IncludeFont: Courier-BoldOblique-MISO
/Courier-BoldOblique-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(P) show
1.000 setlinewidth
grestore
gsave
.31189 .261 -66.8125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
%%BeginResource: font Courier-BoldOblique-MISO
%%BeginFont: Courier-BoldOblique-MISO
/Courier-BoldOblique /Courier-BoldOblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-BoldOblique-MISO
%%IncludeFont: Courier-BoldOblique-MISO
/Courier-BoldOblique-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(Q) show
1.000 setlinewidth
grestore
gsave
.62431 .28078 -67.0312 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
%%BeginResource: font Courier-BoldOblique-MISO
%%BeginFont: Courier-BoldOblique-MISO
/Courier-BoldOblique /Courier-BoldOblique-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-BoldOblique-MISO
%%IncludeFont: Courier-BoldOblique-MISO
/Courier-BoldOblique-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(S) show
1.000 setlinewidth
grestore
.60563 .25463 m
.35994 .44084 L
s
.60563 .25463 m
.92017 .01625 L
s
.60563 .25463 m
.43464 .06736 L
s
.60563 .25463 m
.95752 .64003 L
s
0 1 0 r
.18245 .22784 m
.29322 .23486 L
s
.18245 .22784 m
.60563 .25463 L
s
.29322 .23486 m
.60563 .25463 L
s
5 Mabswid
.02381 .32879 Mdot
.07983 .1047 Mdot
.35994 .44084 Mdot
.43464 .06736 Mdot
0 0 1 r
.95752 .64003 Mdot
.92017 .01625 Mdot
1 0 0 r
.18245 .22784 Mdot
.29322 .23486 Mdot
.60563 .25463 Mdot
0 0 m
1 0 L
1 .68242 L
0 .68242 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{353, 240.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006i0001;2000`400?l00000o`00003oo`3ooonj
0?ooo`00o`3ooonj0?ooo`00o`3ooonj0?ooo`00o`3ooonj0?ooo`00o`3ooon@0?ooo`80003o:03o
ool00?l0ooooS`3oool40000obL0oooo003o0?ooohh0oooo1P000?lV0?ooo`00o`3ooon=0?ooo`03
000000000?l0003o00@0003o9P3oool00?l0ooooP`3oool<000000@0003o9`3oool00?l0ooooNP3o
ool9000000L0oooo0`0000000`3oool00000000000020000obP0oooo003o0?ooog00oooo2P00000=
0?ooo`<000000`3oool00`000000oooo0?ooo`0Z0?ooo`00o`3ooomW0?ooo`T000005@3oool20000
00D0oooo00<000000?ooo`3oool0:`3oool00?l0ooooG@3oool:000001/0oooo0`0000050?ooo`80
0000;P3oool00?l0ooooE03oool900000280oooo0`0000070?ooo`030000003oool0oooo02h0oooo
003o0?ooodX0oooo2P00000X0?ooo`<000002@3oool00`000000oooo0?ooo`0_0?ooo`00o`3ooom1
0?ooo`X00000;P3oool3000000X0oooo0P00000b0?ooo`00o`3ooolg0?ooo`X00000=@3oool30000
00`0oooo00<000000?ooo`3oool0<P3oool00?l0oooo;P3oool:000003/0oooo0`00000>0?ooo`03
0000003oool0oooo03<0oooo003o0?ooob@0oooo2P0000120?ooo`<000003`3oool2000003H0oooo
003o0?oooa/0oooo2P0000190?ooo`<00000403oool00`000000oooo0?ooo`0f0?ooo`00o`3ooolA
0?ooo`X00000D03oool300000180oooo00<000000?ooo`3oool0=`3oool00?l0oooo203oool:0000
05H0oooo0`00000C0?ooo`800000>P3oool00?d0oooo2P00001M0?ooo`<000005@3oool00`000000
oooo0?ooo`0B0?ooo`030=nLo`000?l0003o0080003o00@0W=oo0?ooo`3oool0okoo1P000?l00`18
W?l0oooo0?ooo`0F0?ooo`00m03oool:000006<0oooo0`00000G0?ooo`030000003oool0oooo0180
oooo00<0gico0000o`18W?l00P3oool00`3ogol0B03o04RLo`040?ooo`030=nLo`000?l0_ooo01X0
oooo003Z0?ooo`X00000JP3oool3000001P0oooo0P00000E0?ooo`0309a8o`00B?l0gooo00<0oooo
00<0okoo0018o`3Oool00`3oool00`3o_ol0003o09cOo`0J0?ooo`00h@3oool:00000700oooo0`00
000J0?ooo`030000003oool0oooo01D0oooo00<0W4So0018o`3Oool02P3oool00`1d0?l0B9co0?oo
o`0I0?ooo`00_`3oool2003o01H0oooo2`00001f0?ooo`@000006`3oool00`000000oooo0?ooo`0F
0?ooo`030=nLo`000?l0_ooo00X0oooo00<0W4So0018o`3Oool06@3oool00;h0oooo1000o`0<0?oo
o`X00000OP3oool3000001`0oooo0P00000J0?ooo`0307@0o`18W?l0oooo00<0oooo00<0W4So04RL
o`3oool00`3oool00`3OW?l0003o0;ooo`0I0?ooo`00_@3oool6003o00030?ooo`000000000000T0
0000Q03oool3000001h0oooo00<000000?ooo`3oool06P3oool00`3ogol0B03o001do`020?ooo`04
0?oOo`180?l004So0=ooo`<0oooo00<0omoo04P0o`1d_ol06@3oool00;/0oooo0P000006003o0080
0000R`3oool300000200oooo00<000000?ooo`3oool07@3oool00`2oM?l0003o0000o`030000o`03
0;ooo`3oool0M03o00<0003o00<007Co0?ooo`3oool05`3oool00;40oooo2`0000020?ooo`@00?l0
R`3oool300000240oooo0P00000Z0?ooo`0407@0o`000?l004So0=oooaP0oooo002X0?ooo`X00000
2`3oool01P000000oooo003o0000o`00oooo000008L0oooo0`00000S0?ooo`800000A`3oool009h0
oooo2`00000B0?ooo`8000001P3oool00`000000oooo0?ooo`210?ooo`<000009@3oool00`000000
oooo0?ooo`170?ooo`00U@3oool:000001X0oooo0P0000090?ooo`030000003oool0oooo07d0oooo
1000000U0?ooo`800000BP3oool008/0oooo2P00000S0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0N@3oool4000002L0oooo0P00001;0?ooo`00PP3oool:000002X0oooo0P00000=
0?ooo`030000003oool0oooo07L0oooo0`00000Y0?ooo`030000003oool0oooo04/0oooo001h0?oo
o`X00000<`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07<0oooo0`00000Z0?oo
o`800000CP3oool006l0oooo2P00000j0?ooo`8000004P3oool00`000000oooo0?ooo`1_0?ooo`<0
0000;03oool2000004l0oooo001U0?ooo`X00000@P3oool2000001D0oooo00<000000?ooo`3oool0
J`3oool3000002h0oooo00<000000?ooo`3oool0C`3oool005`0oooo2P00001:0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0I`3oool3000002l0oooo0P00001B0?ooo`00DP3oool:
00000580oooo0P00000J0?ooo`030000003oool0oooo06<0oooo0`00000a0?ooo`800000D`3oool0
04T0oooo2P00001J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0G`3oool40000
0380oooo00<000000?ooo`3oool0D`3oool002L0oooo0P00o`0F0?ooo`X00000HP3oool2000001l0
oooo00<000000?ooo`3oool0G03oool3000003@0oooo00<000000?ooo`3oool0E03oool002H0oooo
1000o`0<0?ooo`T00000J`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo05P0oooo
0`00000e0?ooo`800000E`3oool002D0oooo1P00o`000`3oool000000000000800000780oooo0P00
000E0?ooo`0307@0o`000?l0003o00@0003o00@007Co0?ooo`3oool0okoo10000?l00`000000003o
04RLo`1D0?ooo`<00000=`3oool00`000000oooo0?ooo`1G0?ooo`009@3oool6003o00030000003o
ool0oooo07P0oooo0P00000H0?ooo`030?noo`000?l0W=oo00<0oooo00<0W4So001do`3oool00`3o
ool0103OW?l0003o0;ooo`00001B0?ooo`<00000>@3oool00`000000oooo0?ooo`1H0?ooo`009P3o
ool4003o07/0oooo00<000000?ooo`3oool06@3oool00`1d0?l0M;oo0?ooo`020?ooo`030=nLo`00
0?l0W=oo00<0oooo00D0okoo0000o`2Lgol0oooo0000001>0?ooo`<00000>P3oool2000005/0oooo
000W0?ooo`800?l00`00001g0?ooo`800000703oool00`2LB?l007Co0?ooo`020?ooo`0307@0o`00
0?l0_ooo00@0oooo00@0M03o04RLo`3oool00000B`3oool3000003`0oooo00<000000?ooo`3oool0
F`3oool002T0oooo0P0000000`3oool000000?ooo`1d0?ooo`030000003oool0oooo01`0oooo00<0
gico0000o`000?l00`000?l00`1d_ol0oooo0?ooo`030?ooo`0509a8o`00B?l0gooo0?ooo`000000
A`3oool4000003d0oooo00<000000?ooo`3oool0G03oool002X0oooo00<000000?ooo`3oool00P00
001a0?ooo`8000007`3oool00`3ogol0B03o07Boo`020?ooo`030;mdo`000?l0W=oo00@0oooo00<0
gico0000o`2oool00P3oool00`000000oooo0?ooo`110?ooo`@00000?P3oool2000005l0oooo000[
0?ooo`040000003oool0oooo0?ooo`800000KP3oool00`000000oooo0?ooo`0P0?ooo`0707@0o`18
W?l0oooo0?ooo`3ogol0B03o04RLo`040?ooo`030?oOo`180?l0M;oo00<0oooo00<000000?ooo`3o
ool0?P3oool300000400oooo00<000000?ooo`3oool0G`3oool002`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1Y0?ooo`8000008@3oool00`3o_ol0003o0000o`040000o`050018
o`3Oool0oooo0?ooo`1d0?l00`000?l00`00M?l0oooo0?ooo`020?ooo`030000003oool0oooo03X0
oooo0`0000120?ooo`030000003oool0oooo0600oooo000]0?ooo`030000003oool0oooo0080oooo
0P00001W0?ooo`800000<03oool0101d0?l0003o0018o`3Oool40?ooo`030000003oool0oooo03H0
oooo0`0000130?ooo`800000H`3oool002h0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0<P3oool3000004D0oooo
0P00001T0?ooo`00;P3oool2000000D0oooo0P00001Q0?ooo`800000?@3oool00`000000oooo0?oo
o`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1T0?ooo`00;`3oool00`000000oooo0?ooo`05
0?ooo`800000GP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo02X0oooo10000017
0?ooo`800000I`3oool00300oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1I0?oo
o`800000@P3oool00`000000oooo0?ooo`0V0?ooo`@00000B@3oool2000006P0oooo000a0?ooo`03
0000003oool0oooo00H0oooo0P00001G0?ooo`800000A@3oool00`000000oooo0?ooo`0R0?ooo`@0
0000B`3oool00`000000oooo0?ooo`1X0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`800000
E03oool00`000000oooo0?ooo`150?ooo`8000008@3oool3000004`0oooo0P00001[0?ooo`00<`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04l0oooo0P0000190?ooo`030000003o
ool0oooo01`0oooo0`00001>0?ooo`800000K03oool002H0oooo00L0gico0000o`000?l0003o0018
o`3Oool0okoo00<0003o00<004So0=noo`000?l01@000?l00`18W?l0oooo0?ooo`040?ooo`800000
CP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo01P0oooo0`00001@0?ooo`030000
003oool0oooo06`0oooo000X0?ooo`0307@0o`00M?l0oooo00<0oooo00<0M03o001do`3oool00`3o
ool00`000=l0003o0;ooo`0:0?ooo`800000BP3oool2000004h0oooo00<000000?ooo`3oool0503o
ool300000540oooo0P00001_0?ooo`00:03oool00`3o_ol0003o0000o`040000o`0307Boo`3oool0
oooo0080oooo00<0okoo0000g`2Lgol0303oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool0403oool400000580oooo0P00001`0?ooo`00:@3oool01`2o
M?l0003o0;ooo`3oool0gico0000o`2Lgol01@3oool00`1d0?l000180?ooo`0<0?ooo`800000A03o
ool2000005<0oooo00<000000?ooo`3oool0303oool4000005@0oooo00<000000?ooo`3oool0L03o
ool002X0oooo00H0W4So04RLo`3oool0_gCo0000o`2oool50?ooo`0309a8o`00B?l0000000h0oooo
0P0000100?ooo`800000EP3oool00`000000oooo0?ooo`080?ooo`@00000E@3oool2000007<0oooo
000Z0?ooo`050?oOo`180?l0_ooo09a8o`00M?l01P3oool0103OW?l0003o0;ooo`00000?0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`040?ooo`@0
0000E`3oool2000007@0oooo000[0?ooo`040?noo`18W?l0M03o04RLo`H0oooo00<0omoo04P0o`1d
_ol00P00000?0?ooo`800000>P3oool2000005/0oooo00@000000?ooo`3oool0oooo0`00001I0?oo
o`030000003oool0oooo07@0oooo000Y0?ooo`030?oOo`180?l0003o0080003o00<0M;oo0?ooo`3o
ool00P3oool01`1d0?l0003o0000o`000?l007Co0?ooo`0000004@3oool2000003L0oooo00<00000
0?ooo`3oool0G03oool3000005X0oooo0P00001g0?ooo`00=@3oool01P1d0?l0003o0018o`3Oool0
oooo00000140oooo0P00000d0?ooo`800000G03oool3000000030?ooo`000000oooo05T0oooo0P00
001h0?ooo`00>`3oool00`000000oooo0?ooo`0@0?ooo`800000<03oool2000005/0oooo10000004
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0N03oool003`0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0/0?ooo`800000F@3oool4000000L0oooo00<000000?oo
o`3oool0E03oool2000007/0oooo000m0?ooo`030000003oool0oooo0140oooo0P00000Z0?ooo`80
0000F03oool4000000/0oooo00<000000?ooo`3oool0DP3oool2000007`0oooo000m0?ooo`800000
503oool2000002L0oooo00<000000?ooo`3oool0E@3oool4000000l0oooo00<000000?ooo`3oool0
D03oool00`000000oooo0?ooo`1l0?ooo`00?P3oool2000001D0oooo00<000000?ooo`3oool08P3o
ool2000005D0oooo1000000C0?ooo`030000003oool0oooo04d0oooo0P00001o0?ooo`00?`3oool0
0`000000oooo0?ooo`0D0?ooo`8000008@3oool00`000000oooo0?ooo`1C0?ooo`<000005`3oool0
0`000000oooo0?ooo`1;0?ooo`800000P03oool00400oooo00<000000?ooo`3oool05@3oool20000
01d0oooo0P00001C0?ooo`<000006`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0800oooo00110?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0603oool200000580
oooo0`00000O0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0P@3oool00480oooo
00<000000?ooo`3oool05P3oool2000001L0oooo00<000000?ooo`3oool0C`3oool400000280oooo
00<000000?ooo`3oool0A03oool2000008@0oooo00120?ooo`8000006@3oool2000001<0oooo0P00
001?0?ooo`@000009P3oool00`000000oooo0?ooo`120?ooo`800000Q@3oool004<0oooo0P00000J
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0C03oool4000002X0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`250?ooo`00A03oool00`000000oooo0?ooo`0I0?oo
o`8000003@3oool2000004`0oooo1000000^0?ooo`030000003oool0oooo03d0oooo0P0000280?oo
o`00A@3oool00`000000oooo0?ooo`0J0?ooo`8000002P3oool00`000000oooo0?ooo`190?ooo`@0
0000<@3oool2000003d0oooo0P0000290?ooo`00AP3oool00`000000oooo0?ooo`0J0?ooo`800000
1`3oool2000004X0oooo0`00000e0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
R@3oool004L0oooo00<000000?ooo`3oool06`3oool2000000<0oooo0P0000190?ooo`<00000>@3o
ool00`000000oooo0?ooo`0g0?ooo`800000S03oool004L0oooo0P00000N0?ooo`<00000B03oool4
000003`0oooo00<000000?ooo`3oool0=@3oool2000008d0oooo00180?ooo`8000007@3oool30000
04D0oooo100000100?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0S@3oool004T0
oooo00<000000?ooo`3oool06P3oool010000000oooo0?ooo`3oool200000400oooo100000140?oo
o`030000003oool0oooo0300oooo0P00002@0?ooo`00BP3oool00`000000oooo0?ooo`0G0?ooo`80
00001P3oool00`000000oooo0?ooo`0j0?ooo`@00000B03oool00`000000oooo0?ooo`0^0?ooo`80
0000T@3oool004/0oooo00<000000?ooo`3oool0503oool2000000T0oooo0P00000g0?ooo`@00000
C03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0940oooo001<0?ooo`030000003o
ool0oooo0180oooo0P00000<0?ooo`800000<P3oool400000500oooo00<000000?ooo`3oool0:@3o
ool2000009@0oooo001<0?ooo`8000004@3oool200000100oooo00<000000?ooo`3oool0;@3oool3
000005@0oooo00<000000?ooo`3oool09`3oool2000009D0oooo001=0?ooo`8000003`3oool00`00
0000oooo0?ooo`0A0?ooo`800000:P3oool4000005L0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`2E0?ooo`00CP3oool00`000000oooo0?ooo`0;0?ooo`8000005P3oool2000002D0
oooo1000001J0?ooo`800000903oool2000009P0oooo001?0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0O0?ooo`@00000GP3oool200000280oooo
0P00002I0?ooo`00D03oool00`000000oooo0?ooo`060?ooo`800000703oool2000001`0oooo1000
001R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0V@3oool00540oooo00@00000
0?ooo`3o0000o`000P3oool200000200oooo0P00000G0?ooo`@00000IP3oool00`000000oooo0?oo
o`0L0?ooo`800000W03oool00540oooo00<000000?l0003o00000P3o00000`000000oooo0?ooo`0Q
0?ooo`8000004`3oool4000006X0oooo00<000000?ooo`3oool06P3oool2000009d0oooo001A0?oo
o`H0o`009@3oool2000000h0oooo1000001^0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0W@3oool00540oooo1P3o0005003o0280oooo0P0000020?ooo`80o`001P3oool400000740
oooo00<000000?ooo`3oool05@3oool200000:00oooo001A0?ooo`030000003o0000o`000080o`00
1P3oool@003o01<0oooo0P0000040?l00080oooo1000001e0?ooo`030000003oool0oooo01<0oooo
0P00002Q0?ooo`00D03oool00`000000oooo0?ooo`020?l000030000003oool0oooo01@0oooo4@00
o`030?ooo`H0o`000P00001i0?ooo`030000003oool0oooo0140oooo0P00002R0?ooo`00CP3oool2
000000H0oooo00<000000?ooo`3oool08`3oool4003o00H0o`001`00o`1e0?ooo`030000003oool0
oooo00h0oooo0P00002T0?ooo`00C03oool2000000P0oooo0P00000V0?ooo`<00000103o00000`00
0000oooo0?ooo`040?oooa800?l0I@3oool00`000000oooo0?ooo`0<0?ooo`800000Y@3oool004/0
oooo00<000000?ooo`3oool02@3oool200000280oooo100000030?ooo`80o`000P3oool2000001D0
oooo4P00o`1E0?ooo`030000003oool0oooo00X0oooo0P00002V0?ooo`00B@3oool2000000d0oooo
0P00000N0?ooo`@00000303oool00`000000oooo0?ooo`0R0?oooa800?l0A@3oool2000000T0oooo
0P00002X0?ooo`00B03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo1000
000@0?ooo`800000<`3ooolB003o03D0oooo00<000000?ooo`3oool01P3oool200000:T0oooo0016
0?ooo`8000004P3oool00`000000oooo0?ooo`0F0?ooo`<000005@3oool200000480oooo4@00o`0V
0?ooo`030000003oool0oooo00@0oooo0P00002Z0?ooo`00A03oool2000001D0oooo00<000000?oo
o`3oool04P3oool4000001T0oooo00<000000?ooo`3oool0D03ooolA003o01H0oooo00@000000?l0
003o0000oooo0P00002/0?ooo`00@`3oool00`000000oooo0?ooo`0E0?ooo`800000403oool40000
01d0oooo0P00001P0?oooa400?l01P3oool40?l000030000003oool0oooo0:/0oooo00110?ooo`80
00006@3oool2000000`0oooo1000000R0?ooo`800000K`3oool5003o00H0o`00[@3oool00400oooo
00<000000?ooo`3oool06P3oool2000000P0oooo1000000W0?ooo`030000003oool0oooo0740oooo
1P3o002]0?ooo`00?P3oool2000001h0oooo00<000000?ooo`3oool00`3oool4000002/0oooo0P00
001a0?ooo`030000003o0000o`000080o`0000<000000?ooo`3oool0Z`3oool003d0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0000000300000300oooo0P00001^0?ooo`80000000<0oooo
0?l0003o00000P3oool00`000000oooo0?ooo`2Z0?ooo`00>`3oool2000001X0oooo00<0W4So0000
o`000?l00P000?l00`2oool0oooo0?ooo`03000003@0oooo0P00001/0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0Z@3oool003T0oooo0P00000M0?ooo`040?oOo`180?l0M;oo0?oo
o`<000000P3oool00`000000oooo0?ooo`0S0?ooo`050=nLo`000?l0W=oo0?ooo`2oM?l00P000?l0
0`2oool0oooo0?ooo`070?ooo`800000J03oool2000000X0oooo00<000000?ooo`3oool0Z03oool0
03P0oooo00<000000?ooo`3oool07P3oool00`000?l00018000000050?ooo`8000009@3oool01`1d
0?l0003o0000o`00B?l0gooo09a8o`00M?l02`3oool2000006D0oooo0P00000;0?ooo`800000Z@3o
ool003H0oooo0P00000N0?ooo`80000000<0001809a8o`000?l00`000?l0101d_ol0oooo0?ooo`3o
ool2000002D0oooo00@0M03o0000o`000?l0B9co3P3oool2000006<0oooo00<000000?ooo`3oool0
303oool200000:P0oooo000e0?ooo`030000003oool0oooo01/0oooo100000020?ooo`070=nLo`00
0?l0_ooo0?ooo`3ogol0B03o001do`030?ooo`030000003oool0oooo0240oooo00<0okoo0000o`18
W?l00P3oool00`2oM?l0003o0;ooo`0>0?ooo`800000G`3oool200000100oooo00<000000?ooo`3o
ool0YP3oool003<0oooo0P00000K0?ooo`@000001@3oool00`3o_ol0003o09cOo`020?ooo`030?no
o`000?l0W=oo00<0oooo00<000000?ooo`3oool0803oool00`2LB?l004So0=ooo`030?ooo`030;md
o`000?l0_ooo00l0oooo0P00001L0?ooo`8000004P3oool00`000000oooo0?ooo`2U0?ooo`00<@3o
ool2000001X0oooo100000080?ooo`030?oOo`180?l0M;oo0080oooo00<0gico0000o`1d_ol0103o
ool00`000000oooo0?ooo`0O0?ooo`0309a8o`00B?l0gooo00<0oooo00<0omoo04P0o`18W?l0403o
ool2000005X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`2T0?ooo`00<03oool0
0`000000oooo0?ooo`0G0?ooo`@000002P3oool00`3OW?l0003o0000o`040000o`0304RLo`3oool0
oooo00@0oooo00<000000?ooo`3oool07P3oool00`2oM?l0003o0;ooo`040?ooo`0309a8o`00M?l0
oooo0140oooo0P00001F0?ooo`8000005`3oool00`000000oooo0?ooo`2S0?ooo`00;P3oool20000
01P0oooo0`00000K0?ooo`8000007`3oool00`3ogol0B03o04RLo`040?ooo`0307@0o`00M?l0oooo
01<0oooo00<000000?ooo`3oool0DP3oool2000001T0oooo00<000000?ooo`3oool0XP3oool002d0
oooo00<000000?ooo`3oool05@3oool3000001l0oooo0P00000O0?ooo`030?noo`000?l0B9co0080
oooo00<0_gCo0000o`1d_ol05@3oool200000540oooo0P00000K0?ooo`030000003oool0oooo0:40
oooo000[0?ooo`8000005@3oool3000002<0oooo0P00000P0?ooo`050;mdo`000?l0003o0000o`1d
_ol0603oool2000004d0oooo0P00000N0?ooo`030000003oool0oooo0:00oooo000Z0?ooo`030000
003oool0oooo0180oooo0`00000W0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
B@3oool200000200oooo00<000000?ooo`3oool0W`3oool002P0oooo0P00000B0?ooo`<00000:`3o
ool00`000000oooo0?ooo`0m0?ooo`800000B03oool2000001L0oooo00<0W4So0000o`000?l00`00
0?l00`2oool0oooo0?ooo`020?ooo`030000003oool0oooo09h0oooo000V0?ooo`8000004@3oool3
000002l0oooo00<000000?ooo`3oool0?P3oool2000004D0oooo00<000000?ooo`3oool05`3oool0
0`2oM?l0003o07Boo`020?ooo`030?noo`000?l0W=oo00@0oooo00<000000?ooo`3oool0W@3oool0
02D0oooo00<000000?ooo`3oool03P3oool400000380oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`100?ooo`8000006P3oool00`3OW?l0003o0;ooo`030?ooo`0307@0o`00M?l0oooo
00<0oooo0P00002N0?ooo`008`3oool2000000h0oooo1000000e0?ooo`800000@@3oool2000003l0
oooo0P00000N0?ooo`0509a8o`000?l0003o0000o`18W?l01@3oool2000009d0oooo000R0?ooo`03
0000003oool0oooo00`0oooo0`00000i0?ooo`800000@P3oool2000003`0oooo00<000000?ooo`3o
ool0703oool00`3o_ol0003o0000o`020000o`0309cOo`3oool0oooo00D0oooo00<000000?ooo`3o
ool0V`3oool00200oooo0P00000<0?ooo`<00000?@3oool00`000000oooo0?ooo`110?ooo`800000
>@3oool2000001l0oooo00<0gico0000o`2Lgol02`3oool00`000000oooo0?ooo`2J0?ooo`007`3o
ool00`000000oooo0?ooo`090?ooo`<00000@@3oool00`000000oooo0?ooo`120?ooo`800000=P3o
ool200000200oooo00<0omoo04P0o`18W?l00P3oool00`3o_ol0003o09cOo`070?ooo`030000003o
ool0oooo09T0oooo000M0?ooo`8000002@3oool3000004D0oooo00<000000?ooo`3oool0@`3oool2
000003<0oooo00<000000?ooo`3oool08P3oool00`2LB?l0003o0000o`020000o`0304RLo`3oool0
oooo00H0oooo00<000000?ooo`3oool0V03oool001/0oooo0P0000080?ooo`<00000B@3oool00`00
0000oooo0?ooo`130?ooo`800000<03oool2000003@0oooo00<000000?ooo`3oool0U`3oool001X0
oooo00<000000?ooo`3oool01@3oool3000004`0oooo0P0000160?ooo`800000;@3oool2000003H0
oooo00<000000?ooo`3oool0UP3oool001P0oooo0P0000050?ooo`<00000D03oool2000004L0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo09D0oooo
000G0?ooo`030000003oool0oooo0080oooo0`00001D0?ooo`030000003oool0oooo04H0oooo0P00
000W0?ooo`800000>`3oool00`000000oooo0?ooo`2D0?ooo`005@3oool2000000<0oooo0`00001G
0?ooo`030000003oool0oooo04L0oooo0P00000T0?ooo`800000?@3oool00`000000oooo0?ooo`2C
0?ooo`003`3oool2003o0080oooo0P0000020?ooo`<00000F`3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2B0?oo
o`003P3oool4003o00030000003oool0000000800000G`3oool00`000000oooo0?ooo`180?ooo`80
00007P3oool200000440oooo0P00002C0?ooo`003@3oool6003o00030000003oool0oooo0640oooo
00<000000?ooo`3oool0B@3oool2000001/0oooo0P0000130?ooo`030000003oool0oooo0940oooo
000=0?ooo`H00?l0I03oool2000004`0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo0900oooo000>0?ooo`@00?l00P00001T0?ooo`800000C03oool2
000001H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`2?0?ooo`003`3oool2003o
00<0oooo0`00001R0?ooo`030000003oool0oooo04`0oooo0P00000B0?ooo`800000BP3oool00`00
0000oooo0?ooo`2>0?ooo`005`3oool300000600oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`0>0?ooo`800000C03oool00`000000oooo0?ooo`2=0?ooo`006P3oool3000005h0oooo
00<000000?ooo`3oool0C@3oool2000000d0oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`2<0?ooo`007@3oool3000005`0oooo00<000000?ooo`3oool0CP3oool2000000T0oooo0P00
001A0?ooo`030000003oool0oooo08/0oooo000P0?ooo`<00000F@3oool200000500oooo0P000007
0?ooo`800000D`3oool00`000000oooo0?ooo`2:0?ooo`008`3oool3000005L0oooo0P00001A0?oo
o`800000103oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo08T0oooo000V0?ooo`<0
0000E@3oool00`000000oooo0?ooo`1A0?ooo`@00000F03oool00`000000oooo0?ooo`280?ooo`00
:@3oool3000005<0oooo00<000000?ooo`3oool0D@3oool2000005X0oooo00<000000?ooo`3oool0
Q`3oool002`0oooo0`00001A0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool00P00
001H0?ooo`800000R03oool002l0oooo0`00001?0?ooo`030000003oool0oooo04`0oooo0P000005
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0QP3oool00380oooo0`00001=0?oo
o`030000003oool0oooo04X0oooo0P0000070?ooo`800000E`3oool00`000000oooo0?ooo`250?oo
o`00=@3oool3000004X0oooo0P00001:0?ooo`030000003oool0oooo00T0oooo0P00001F0?ooo`03
0000003oool0oooo08@0oooo000h0?ooo`<00000B03oool00`000000oooo0?ooo`160?ooo`800000
3P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo08<0oooo000B0?ooo`070=nLo`00
0?l0003o0000o`00B?l0gooo0?noo`030000o`030018o`3Oool0oooo01`0oooo0`0000160?ooo`03
0000003oool0oooo04@0oooo0P00000@0?ooo`800000E@3oool00`000000oooo0?ooo`220?ooo`00
503oool00`1d0?l007Co0?ooo`030?ooo`0307@0o`00M?l0oooo0240oooo0`0000140?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool04P3oool2000005@0oooo00<000000?ooo`3oool0
P@3oool001@0oooo00<0okoo0000o`000?l010000?l00`1d_ol0oooo0?ooo`0S0?ooo`<00000@P3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`200?ooo`005@3oool01`2oM?l0003o0;ooo`3oool0gico0000o`2Lgol0
:03oool300000400oooo00<000000?ooo`3oool0?@3oool2000001T0oooo0P00001C0?ooo`030000
003oool0oooo07l0oooo000F0?ooo`0609a8o`18W?l0oooo0;mdo`000?l0_ooo:`3oool3000003d0
oooo0P00000m0?ooo`030000003oool0oooo01/0oooo0P00001B0?ooo`030000003oool0oooo07h0
oooo000F0?ooo`050?oOo`180?l0_ooo09a8o`00M?l0;`3oool3000003/0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool0O@3oool001L0oooo00@0okoo04RLo`1d0?l0B9co<P3oool3000003T0oooo00<000000?ooo`3o
ool0=`3oool200000280oooo0P00001A0?ooo`030000003oool0oooo07`0oooo000E0?ooo`030?oO
o`180?l0003o0080003o00<0M;oo0?ooo`3oool0<`3oool3000003L0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0T0?ooo`800000C`3oool2000007d0oooo001C0?ooo`<00000=@3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02H0oooo0P00001?0?ooo`030000003o
ool0oooo07/0oooo001F0?ooo`@00000<P3oool00`000000oooo0?ooo`0`0?ooo`800000:`3oool2
000004h0oooo00<000000?ooo`3oool0NP3oool005T0oooo1000000`0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0;@3oool2000004d0oooo00<000000?ooo`3oool0N@3oool005`0
oooo1000000]0?ooo`800000;P3oool00`000000oooo0?ooo`0_0?ooo`800000C@3oool00`000000
oooo0?ooo`1h0?ooo`00G`3oool4000002/0oooo00<000000?ooo`3oool0:P3oool2000003@0oooo
0P00001<0?ooo`030000003oool0oooo07L0oooo001R0?ooo`@00000:@3oool00`000000oooo0?oo
o`0X0?ooo`800000=`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo07H0oooo001U
0?ooo`@000009`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03P0oooo0P00001;
0?ooo`030000003oool0oooo07D0oooo001X0?ooo`@000009@3oool00`000000oooo0?ooo`0S0?oo
o`800000?@3oool2000004X0oooo00<000000?ooo`3oool0M03oool006/0oooo1000000S0?ooo`03
0000003oool0oooo0240oooo0P0000100?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool0L`3oool006h0oooo1000000P0?ooo`8000008@3oool00`000000oooo0?ooo`110?ooo`800000
B@3oool00`000000oooo0?ooo`1b0?ooo`00L@3oool4000001h0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`140?ooo`800000A`3oool2000007<0oooo001e0?ooo`<00000703oool0
0`000000oooo0?ooo`0K0?ooo`800000B@3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo0740oooo001h0?ooo`<000006P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
04X0oooo0P0000160?ooo`030000003oool0oooo0700oooo001k0?ooo`<00000603oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo04d0oooo0P0000150?ooo`030000003oool0oooo06l0
oooo001n0?ooo`<000005P3oool00`000000oooo0?ooo`0D0?ooo`800000DP3oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo06h0oooo00210?ooo`<00000503oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo05<0oooo0P0000140?ooo`030000003oool0oooo06d0oooo0024
0?ooo`<000004@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05H0oooo0P000013
0?ooo`030000003oool0oooo06`0oooo00270?ooo`<000003`3oool00`000000oooo0?ooo`0>0?oo
o`800000FP3oool2000004<0oooo00<000000?ooo`3oool0J`3oool008X0oooo0`00000=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0G03oool200000480oooo00<000000?ooo`3o
ool0JP3oool008d0oooo0`00000;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
G`3oool200000440oooo00<000000?ooo`3oool0J@3oool00900oooo0`0000090?ooo`030000003o
ool0oooo00L0oooo0P00001S0?ooo`800000@@3oool00`000000oooo0?ooo`1X0?ooo`00T`3oool3
000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1U0?ooo`800000@03oool0
0`000000oooo0?ooo`1W0?ooo`00UP3oool3000000@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1X0?ooo`030000003oool0oooo03d0oooo0P00001X0?ooo`00V@3oool300000080
oooo00@00000003o0000o`00oooo0P00001/0?ooo`800000?P3oool00`000000oooo0?ooo`1V0?oo
o`00W03oool2000000@00?l0L03oool2000003d0oooo00<000000?ooo`3oool0I@3oool009d0oooo
1P00o`1a0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0I03oool009d0oooo1P00
o`0200000700oooo0P00000l0?ooo`030000003oool0oooo06<0oooo002N0?ooo`@00?l00`3oool3
000006l0oooo0P00000k0?ooo`030000003oool0oooo0680oooo002O0?ooo`800?l01`3oool30000
06h0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1Q0?ooo`00Z`3oool3000006`0
oooo0P00000j0?ooo`030000003oool0oooo0600oooo002^0?ooo`<00000J`3oool2000003T0oooo
00<000000?ooo`3oool0G`3oool00;40oooo0`00001Z0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0GP3oool00;@0oooo0`00001X0?ooo`800000>03oool00`000000oooo0?ooo`1M
0?ooo`00]`3oool3000006L0oooo0P00000g0?ooo`030000003oool0oooo05`0oooo002j0?ooo`<0
0000I@3oool2000003H0oooo0P00001M0?ooo`00_@3oool3000006@0oooo0P00000e0?ooo`030000
003oool0oooo05/0oooo00300?ooo`<00000H`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo05X0oooo00330?ooo`<00000H@3oool2000003@0oooo00<000000?ooo`3oool0F@3oool0
0<H0oooo0`00001P0?ooo`800000<`3oool00`000000oooo0?ooo`1H0?ooo`00b@3oool3000005l0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1G0?ooo`00X`3oool00`1d0?l0003o
0000o`040000o`03001do`3oool0oooo01l0oooo0`00001M0?ooo`800000<P3oool00`000000oooo
0?ooo`1F0?ooo`00Y03oool00`3o_ol0003o09cOo`030?ooo`0309a8o`00M?l0oooo0280oooo0`00
001L0?ooo`800000<@3oool00`000000oooo0?ooo`1E0?ooo`00Y@3oool00`1d0?l0M;oo0?ooo`02
0?ooo`030=nLo`000?l0W=oo02D0oooo0`00001K0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0E03oool00:D0oooo00<0W4So001do`3oool00P3oool00`1d0?l0003o0;ooo`0X0?oo
o`<00000F@3oool200000300oooo00<000000?ooo`3oool0D`3oool00:D0oooo00<0gico0000o`00
0?l00`000?l00`1d_ol0oooo0?ooo`0Z0?ooo`<00000F03oool2000002l0oooo00<000000?ooo`3o
ool0DP3oool00:D0oooo00<0omoo04P0o`1d_ol00P3oool00`2oM?l0003o09cOo`0^0?ooo`<00000
E`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0540oooo002V0?ooo`0707@0o`18
W?l0oooo0?ooo`3ogol0B03o04RLo`0a0?ooo`<00000E@3oool2000002d0oooo00<000000?ooo`3o
ool0D@3oool00:@0oooo00<0okoo0000o`000?l010000?l00`00B?l0gooo0?ooo`0c0?ooo`<00000
E03oool2000002`0oooo00<000000?ooo`3oool0D03oool00>@0oooo0`00001C0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0C`3oool00>L0oooo0`00001A0?ooo`800000:`3oool0
0`000000oooo0?ooo`1>0?ooo`00jP3oool300000500oooo0P00000Z0?ooo`030000003oool0oooo
04d0oooo003]0?ooo`<00000CP3oool2000002X0oooo00<000000?ooo`3oool0C03oool00?00oooo
0`00001=0?ooo`800000:@3oool00`000000oooo0?ooo`1;0?ooo`00l`3oool3000004`0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`1:0?ooo`00mP3oool3000004X0oooo0P00000X
0?ooo`030000003oool0oooo04T0oooo003i0?ooo`<00000B@3oool2000002L0oooo00<000000?oo
o`3oool0B03oool00?`0oooo0`0000180?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0A`3oool00?l0oooo0`0000160?ooo`8000009@3oool2000004P0oooo003o0?ooo`<0oooo0`00
00150?ooo`800000903oool00`000000oooo0?ooo`160?ooo`00o`3oool60?ooo`<00000A03oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04D0oooo003o0?ooo`T0oooo0`0000120?oo
o`8000008`3oool00`000000oooo0?ooo`140?ooo`00o`3oool<0?ooo`<00000@@3oool200000280
oooo00<000000?ooo`3oool0@`3oool00?l0oooo3`3oool300000400oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`120?ooo`00o`3ooolB0?ooo`<00000?P3oool200000240oooo00<0
00000?ooo`3oool0@@3oool00?l0oooo5@3oool3000003d0oooo0P00000P0?ooo`030000003oool0
oooo0400oooo003o0?oooaP0oooo0`00000l0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0?`3oool00?l0oooo6`3oool3000003X0oooo0P00000O0?ooo`030000003oool0oooo03h0
oooo003o0?oooah0oooo0`00000i0?ooo`8000007P3oool00`000000oooo0?ooo`0m0?ooo`00o`3o
oolQ0?ooo`@00000=P3oool2000001h0oooo00<000000?ooo`3oool0?03oool00?l0oooo903oool4
000003D0oooo0P00000L0?ooo`800000?@3oool00?l0oooo9`3oool4000003@0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0k0?ooo`00o`3ooolZ0?ooo`@00000<P3oool2000001/0
oooo00<000000?ooo`3oool0>P3oool00?l0oooo;@3oool400000340oooo0P00000J0?ooo`030000
003oool0oooo03T0oooo003o0?oooc00oooo1000000`0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0>03oool00?l0oooo<`3oool4000002h0oooo0P00000I0?ooo`030000003oool0
oooo03L0oooo003o0?ooocH0oooo1000000]0?ooo`800000603oool00`000000oooo0?ooo`0f0?oo
o`00o`3oooli0?ooo`@00000;03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03D0
oooo003o0?oooc`0oooo1000000Z0?ooo`8000005`3oool00`000000oooo0?ooo`0d0?ooo`00o`3o
oom00?ooo`<00000:@3oool2000001H0oooo00<000000?ooo`3oool0<`3oool00?l0oooo@`3oool3
000002P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0b0?ooo`00o`3ooom60?oo
o`<000009P3oool2000001D0oooo00<000000?ooo`3oool0<@3oool00?l0ooooB@3oool3000002D0
oooo0P00000C0?ooo`030000003oool0oooo0340oooo003o0?oood`0oooo0`00000T0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0<03oool00?l0ooooC`3oool300000280oooo0P00
000B0?ooo`030000003oool0oooo02l0oooo003o0?oooe80oooo0`00000Q0?ooo`8000004@3oool0
0`000000oooo0?ooo`0^0?ooo`00o`3ooomE0?ooo`<000007`3oool200000140oooo00<000000?oo
o`3oool0;@3oool00?l0ooooF03oool3000001h0oooo0P00000@0?ooo`030000003oool0oooo02`0
oooo003o0?oooe/0oooo0`00000M0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
:`3oool00?l0ooooGP3oool3000001/0oooo0P00000?0?ooo`030000003oool0oooo02X0oooo003o
0?ooof40oooo0`00000J0?ooo`8000003P3oool00`000000oooo0?ooo`0Y0?ooo`00o`3ooomT0?oo
o`<000006@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02P0oooo003o0?ooofL0
oooo0`00000G0?ooo`8000003@3oool00`000000oooo0?ooo`0W0?ooo`00o`3ooomZ0?ooo`<00000
5P3oool2000000`0oooo00<000000?ooo`3oool09P3oool00?l0ooooK@3oool3000001D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?ooo`00o`3ooom`0?ooo`<000004`3oool2
000000X0oooo00<000000?ooo`3oool09@3oool00?l0ooooL`3oool300000180oooo0P0000090?oo
o`030000003oool0oooo02@0oooo003o0?ooogH0oooo0`00000A0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool08`3oool00?l0ooooN@3oool3000000l0oooo0P0000080?ooo`030000
003oool0oooo0280oooo003o0?ooog`0oooo0`00000>0?ooo`8000001`3oool00`000000oooo0?oo
o`0Q0?ooo`00o`3ooomo0?ooo`<000003@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0200oooo003o0?oooh80oooo0`00000;0?ooo`8000001P3oool00`000000oooo0?ooo`0O0?oo
o`00o`3ooon50?ooo`<000002P3oool2000000D0oooo00<000000?ooo`3oool07P3oool00?l0oooo
R03oool3000000P0oooo0P0000050?ooo`030000003oool0oooo01d0oooo003o0?oooh/0oooo0`00
00070?ooo`800000103oool00`000000oooo0?ooo`0L0?ooo`00o`3ooon>0?ooo`<000001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo003o0?oooi40oooo0`0000040?oo
o`8000000P3oool00`000000oooo0?ooo`0K0?ooo`00o`3ooonD0?ooo`<000000`3oool200000003
0?ooo`000000oooo01/0oooo003o0?oooiL0oooo0`0000020?ooo`030000003oool0000001/0oooo
003o0?oooiX0oooo1P0000020000oaP0oooo003o0?oooid0oooo0P0000040000oaL0oooo003o0?oo
oih0oooo1P000?lF0?ooo`00o`3ooonN0?ooo`H0003o5P3oool00?l0ooooW`3oool40000oaL0oooo
003o0?oooj00oooo0P000?lH0?ooo`00o`3ooonj0?ooo`00o`3ooonj0?ooo`00o`3ooonj0?ooo`00
o`3ooonj0?ooo`00o`3ooonj0?ooo`00o`3ooonj0?ooo`00o`3ooonj0?ooo`00o`3ooonj0?ooo`00
o`3ooonj0?ooo`00o`3ooonj0?ooo`00o`3ooonj0?ooo`00o`3ooonj0?ooo`00o`3ooonV0?ooo`03
0=nLo`000?l0003o0080003o00<0W=oo0?ooo`3oool0303oool00?l0ooooY@3oool00`3OW?l0003o
04RLo`020?ooo`030?oOo`180?l0B9co00d0oooo003o0?ooojD0oooo00<0W4So0018o`3Oool00`3o
ool00`3o_ol004So0=ooo`0<0?ooo`00o`3ooonU0?ooo`0309a8o`00B?l0gooo0180oooo003o0?oo
ojD0oooo00<0gico0000o`2oool04P3oool00?l0ooooYP3oool00`1d0?l0B9co0?ooo`030?ooo`03
09a8o`18W?l0oooo00/0oooo003o0?ooojH0oooo00<0omoo04P0o`00M?l00P3oool0103ogol0B03o
0018o`3Oool;0?ooo`00o`3ooonX0?ooo`030;mdo`000?l0003o00<0003o00<0_ooo0?ooo`3oool0
2@3oool00?l0oooo^P3oool00?l0oooo^P3oool00001\
\>"],
  ImageRangeCache->{{{0, 352.188}, {239.688, 0}} -> {0.0425354, 31.9644, \
0.780564, 0.780564}}],

Cell["Textbook formulation:", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "Let A,\[VeryThinSpace]B, \[VeryThinSpace]C and A1,\[VeryThinSpace]B1, \
\[VeryThinSpace]C1 be on two lines and ",
  StyleBox["P\[NonBreakingSpace]=\[NonBreakingSpace]A\[VeryThinSpace]B1\
\[NonBreakingSpace]\[Intersection]\[NonBreakingSpace]A1\[VeryThinSpace]B", 
    "DisplayFormula"],
  ", Q\[NonBreakingSpace]=\[NonBreakingSpace]A\[VeryThinSpace]C1\
\[NonBreakingSpace]\[Intersection]\[NonBreakingSpace]A1\[VeryThinSpace]C, ",
  StyleBox["S\[NonBreakingSpace]=\[NonBreakingSpace]B\[VeryThinSpace]C1\
\[NonBreakingSpace]\[Intersection]\[NonBreakingSpace]B1\[VeryThinSpace]C", 
    "DisplayFormula"],
  ". Then P, Q, and S are collinear."
}], "Text"],

Cell["Input to the system:", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[BoxData[
    \(Proposition["\<Pappus\>", \ any[A, B, A1, B1, C, C1, P, Q, S], 
      point[A, B, A1, B1] \[And] pon[C, line[A, B]] \[And] 
          pon[C1, line[A1, B1]] \[And] 
          inter[P, line[A, B1], line[A1, B]] \[And] 
          inter[Q, line[A, C1], line[A1, C]] \[And] 
          inter[S, line[B, C1], line[B1, C]] \[Implies] 
        collinear[P, Q, S]]\)], "Input",
  CellTags->"Proposition (Pappus)"],

Cell["Input to the system:", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Proposition["\<Pappus\>"], by \[Rule] GeometryProver, 
      ProverOptions \[Rule] {Method -> "\<GroebnerProver\>", 
          Refutation \[Rule] True}]\)], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell["\<\
Notebook generated automatically by the proving algorithm based on Groebner \
basis algorithm:\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]",
  TextAlignment->Left],

Cell["Prove:", "ProofText",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.643137, 0.756863, 1]}],

Cell[TextData[{
  StyleBox["(Proposition (Pappus))", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  "\n   \n",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["A",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox["B",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox["A1",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox["B1",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox["C",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox["C1",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox["P",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox["Q",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox["S",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"point", "[", 
                RowBox[{
                  StyleBox["A",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  StyleBox["B",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  StyleBox["A1",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  StyleBox["B1",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None]}], "]"}], "\[And]", 
              RowBox[{"pon", "[", 
                RowBox[{
                  StyleBox["C",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  RowBox[{"line", "[", 
                    RowBox[{
                      StyleBox["A",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["B",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}]}], "]"}], "\[And]", 
              RowBox[{"pon", "[", 
                RowBox[{
                  StyleBox["C1",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  RowBox[{"line", "[", 
                    RowBox[{
                      StyleBox["A1",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["B1",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}]}], "]"}], "\[And]", 
              RowBox[{"inter", "[", 
                RowBox[{
                  StyleBox["P",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  RowBox[{"line", "[", 
                    RowBox[{
                      StyleBox["A",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["B1",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}], ",", 
                  RowBox[{"line", "[", 
                    RowBox[{
                      StyleBox["A1",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["B",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}]}], "]"}], "\[And]", 
              RowBox[{"inter", "[", 
                RowBox[{
                  StyleBox["Q",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  RowBox[{"line", "[", 
                    RowBox[{
                      StyleBox["A",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["C1",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}], ",", 
                  RowBox[{"line", "[", 
                    RowBox[{
                      StyleBox["A1",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["C",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}]}], "]"}], "\[And]", 
              RowBox[{"inter", "[", 
                RowBox[{
                  StyleBox["S",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  RowBox[{"line", "[", 
                    RowBox[{
                      StyleBox["B",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["C1",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}], ",", 
                  RowBox[{"line", "[", 
                    RowBox[{
                      StyleBox["B1",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["C",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}]}], "]"}]}], "\[Implies]", 
            RowBox[{"collinear", "[", 
              RowBox[{
                StyleBox["P",
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox["Q",
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox["S",
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None]}], "]"}]}], ")"}]}]], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[0.643137, 0.756863, 1]}],
  Cell[" ", "ProofText"]
}], "Conclusion",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.643137, 0.756863, 1]},
  CellTags->"Proposition (Pappus)"],

Cell["with no assumptions.", "ProofText",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.643137, 0.756863, 1]}],

Cell["\<\
To prove the above statement we shall use the Gr\[ODoubleDot]bner basis \
method. First we have to transform the problem into algebraic form. \
\>", "ProofText",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell["Algebraic Form:", "ProofText",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell["\<\
To transform the geometric problem into algebraic form we have to chose first \
an orthogonal coordinate system.\
\>", "ProofText",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell[TextData[{
  "Let's have the origin in point ",
  Cell[BoxData[
      StyleBox["A",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0, 0, 1],
        Background->None]], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  ", and points ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          StyleBox["B",
            FontWeight->"Bold",
            FontSlant->"Italic",
            FontColor->RGBColor[0, 0, 1],
            Background->None], ",", 
          StyleBox["C",
            FontWeight->"Bold",
            FontSlant->"Italic",
            FontColor->RGBColor[0, 0, 1],
            Background->None]}], "}"}]], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " on the two axes."
}], "ProofText",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell["Using this coordinate system we have the following points:", "ProofText",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            StyleBox["A",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["B",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", "0", ",", 
            StyleBox[\(u\_1\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["A1",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(u\_2\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(u\_3\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["B1",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(u\_4\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(u\_5\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["C",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", "0", ",", 
            StyleBox[\(u\_6\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["C1",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(u\_7\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_1\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["P",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_2\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_3\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["Q",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_4\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_5\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["S",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_6\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_7\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}], "}"}]}], "}"}]], "Expression",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell["The algebraic form of the assertion is:", "ProofText",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell[TextData[{
  StyleBox["(1)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  "\n",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox[\(x\_1\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_2\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_3\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_4\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_5\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_6\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_7\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{
                  RowBox[{
                    StyleBox[\(u\_3\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(u\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(u\_5\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(u\_7\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    StyleBox[\(u\_5\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(u\_7\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    StyleBox[\(u\_5\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_3\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_1\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_3\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    StyleBox[\(x\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_7\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_5\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(u\_6\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    StyleBox[\(u\_6\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_5\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(u\_7\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_1\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_6\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    StyleBox[\(x\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_6\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_7\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_7\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(u\_6\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_5\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_6\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    StyleBox[\(u\_6\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_6\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    StyleBox[\(u\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_7\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], "\[Equal]", "0"}]}], 
            "\[Implies]", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[\(x\_3\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], " ", 
                  StyleBox[\(x\_4\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None]}], "+", 
                RowBox[{
                  RowBox[{"-", 
                    StyleBox[\(x\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], " ", 
                  StyleBox[\(x\_5\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None]}], "+", 
                RowBox[{
                  RowBox[{"-", 
                    StyleBox[\(x\_3\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], " ", 
                  StyleBox[\(x\_6\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None]}], "+", 
                RowBox[{
                  StyleBox[\(x\_5\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], " ", 
                  StyleBox[\(x\_6\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None]}], "+", 
                RowBox[{
                  StyleBox[\(x\_2\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], " ", 
                  StyleBox[\(x\_7\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None]}], "+", 
                RowBox[{
                  RowBox[{"-", 
                    StyleBox[\(x\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], " ", 
                  StyleBox[\(x\_7\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None]}]}], "\[Equal]", "0"}]}], ")"}]}]], 
    "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell["", "ProofText"]
}], "Conclusion",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]},
  CellTags->"1"],

Cell["This problem is equivalent to:", "ProofText",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell[TextData[{
  StyleBox["(2)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  "\n",
  Cell[BoxData[
      RowBox[{"\[Not]", 
        RowBox[{"(", 
          RowBox[{
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox[\(x\_1\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox[\(x\_2\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox[\(x\_3\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox[\(x\_4\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox[\(x\_5\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox[\(x\_6\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox[\(x\_7\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    RowBox[{
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(u\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_2\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(u\_5\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_3\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(u\_7\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_5\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(u\_7\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_1\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_4\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_1\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      StyleBox[\(u\_5\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_4\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_1\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_1\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_3\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      StyleBox[\(x\_1\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_7\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_5\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_2\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(u\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_3\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_5\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      StyleBox[\(u\_1\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(u\_7\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_1\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(x\_1\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_7\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_7\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_4\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(u\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_5\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_7\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      StyleBox[\(x\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(x\_2\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_5\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(x\_3\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(x\_5\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(x\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_7\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(x\_4\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_7\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}], "\[NotEqual]", "0"}]}], 
              ")"}]}], ")"}]}]], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell["", "ProofText"]
}], "Conclusion",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]},
  CellTags->"2"],

Cell[TextData[{
  "To remove the last inequality, we use the Rabinowitsch trick: Let ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]],
  Cell[BoxData[
      StyleBox[\(v\_0\),
        FontWeight->"Bold",
        FontSlant->"Italic",
        Background->None]], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]},
    FontColor->RGBColor[1, 0, 0]],
  " be a new variable. Then the problem becomes:"
}], "ProofText",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell[TextData[{
  StyleBox["(3)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  "\n",
  Cell[BoxData[
      RowBox[{"\[Not]", 
        RowBox[{"(", 
          RowBox[{
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox[\(x\_1\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox[\(x\_2\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox[\(x\_3\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox[\(x\_4\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox[\(x\_5\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox[\(x\_6\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox[\(x\_7\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox[\(v\_0\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    RowBox[{
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(u\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_2\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(u\_5\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_3\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(u\_7\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_5\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(u\_7\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_1\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_4\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_1\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      StyleBox[\(u\_5\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_4\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_1\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_1\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_3\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      StyleBox[\(x\_1\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_7\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_5\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_2\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(u\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_3\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_5\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      StyleBox[\(u\_1\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(u\_7\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_1\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(x\_1\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_7\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_7\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_4\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(u\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(u\_5\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None]}], " ", 
                      StyleBox[\(x\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_6\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "+", 
                    RowBox[{
                      StyleBox[\(u\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], " ", 
                      StyleBox[\(x\_7\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
                RowBox[{
                  RowBox[{"1", "+", 
                    RowBox[{
                      RowBox[{"-", 
                        StyleBox[\(v\_0\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[1, 0, 0],
                          Background->None]}], 
                      StyleBox[" ",
                        FontColor->RGBColor[1, 0, 0]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox[\(x\_3\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], " ", 
                            StyleBox[\(x\_4\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}], "+", 
                          RowBox[{
                            RowBox[{"-", 
                              StyleBox[\(x\_2\),
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], " ", 
                            StyleBox[\(x\_5\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}], "+", 
                          RowBox[{
                            RowBox[{"-", 
                              StyleBox[\(x\_3\),
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], " ", 
                            StyleBox[\(x\_6\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}], "+", 
                          RowBox[{
                            StyleBox[\(x\_5\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], " ", 
                            StyleBox[\(x\_6\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}], "+", 
                          RowBox[{
                            StyleBox[\(x\_2\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None], " ", 
                            StyleBox[\(x\_7\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}], "+", 
                          RowBox[{
                            RowBox[{"-", 
                              StyleBox[\(x\_4\),
                                FontWeight->"Bold",
                                FontSlant->"Italic",
                                FontColor->RGBColor[0, 0, 1],
                                Background->None]}], " ", 
                            StyleBox[\(x\_7\),
                              FontWeight->"Bold",
                              FontSlant->"Italic",
                              FontColor->RGBColor[0, 0, 1],
                              Background->None]}]}], ")"}]}]}], "\[Equal]", 
                  "0"}]}], ")"}]}], ")"}]}]], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell["", "ProofText"]
}], "Conclusion",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]},
  CellTags->"3"],

Cell["\<\
This statement is true iff the corresponding Gr\[ODoubleDot]bner basis is \
{1}.\
\>", "ProofText",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell[TextData[{
  "The Gr\[ODoubleDot]bner bases is ",
  Cell[BoxData[
      \(\(\({1}\)\(.\)\)\)], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}]
}], "ProofText",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell["Hence,  the statement and the original assertion is  true.", "ProofText",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell["Statistics:", "ProofText",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell[TextData[{
  "Time needed to compute the Gr\[ODoubleDot]bner bases: ",
  Cell[BoxData[
      \(0.4199999999999946`\ Second\)], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "s."
}], "ProofText",
  CellMargins->{{76.5625, Inherited}, {Inherited, Inherited}},
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: Butterfly Theorem", "Subsubsection"],

Cell["Textbook formulation:", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  StyleBox["A, B, C",
    FontSlant->"Italic"],
  " and ",
  StyleBox["D",
    FontSlant->"Italic"],
  " are four points on circle (",
  StyleBox["O",
    FontSlant->"Italic"],
  "). ",
  StyleBox["E",
    FontSlant->"Italic"],
  " is the intersection of ",
  StyleBox["AC",
    FontSlant->"Italic"],
  " and ",
  StyleBox["BD",
    FontSlant->"Italic"],
  ". Through ",
  StyleBox["E",
    FontSlant->"Italic"],
  " draw a line perpendicular to ",
  StyleBox["OE",
    FontSlant->"Italic"],
  ", meeting ",
  StyleBox["AD",
    FontSlant->"Italic"],
  " at ",
  StyleBox["F",
    FontSlant->"Italic"],
  " and ",
  StyleBox["BC",
    FontSlant->"Italic"],
  " at ",
  StyleBox["G",
    FontSlant->"Italic"],
  ". Show that ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["FE",
            FontSlant->"Italic"], "_"], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["GE",
            FontSlant->"Italic"], "_"], TraditionalForm]]],
  "."
}], "Text"],

Cell["Remark:", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
Using the default coordinate system the algebraic methods are very slow.\
\>", "Subsubsubsection"],

Cell["Input to the system:", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[BoxData[
    \(Proposition["\<Butterfly\>", any[O, A, B, C, D, EE, F, G], 
      point[O, A] \[And] \[IndentingNewLine]pon[C, 
            circle[O, A]] \[And] \[IndentingNewLine]pon[B, 
            circle[O, A]] \[And] \[IndentingNewLine]pon[D, 
            circle[O, A]] \[And] \[IndentingNewLine]inter[EE, line[A, C], 
            line[B, D]] \[And] inter[F, line[D, A], tline[EE, EE, O]] \[And] 
          inter[G, line[B, C], line[EE, F]]\[IndentingNewLine] \[Implies] 
        distequal[EE, F, G, EE]]\)], "Input",
  CellTags->"Proposition (Butterfly)"],

Cell["Input to the system:", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[BoxData[
    \(Simplify[Proposition["\<Butterfly\>"], 
      by -> GraphicSimplifier]\)], "Input"],

Cell["Output generated automatically by the system", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99075 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.628616 0.00205968 0.61959 0.00205968 [
[.32172 .49395 -5.8125 0 ]
[.32172 .49395 5.8125 11.1875 ]
[.51105 .31287 -5.75 0 ]
[.51105 .31287 5.75 11.1875 ]
[.50285 .9559 -6.03125 0 ]
[.50285 .9559 6.03125 11.1875 ]
[.27432 .37305 -9.59375 0 ]
[.27432 .37305 9.59375 11.1875 ]
[.03411 .70604 -6.09375 0 ]
[.03411 .70604 6.09375 11.1875 ]
[.51453 .04007 -6.03125 0 ]
[.51453 .04007 6.03125 11.1875 ]
[.59688 .29104 -5.96875 0 ]
[.59688 .29104 5.96875 11.1875 ]
[.63891 .63607 -5.84375 0 ]
[.63891 .63607 5.84375 11.1875 ]
[ 0 0 0 0 ]
[ 1 .99075 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.62862 .61959 .34757 0 365.73 arc
s
.31142 .47747 m
.49255 .93943 L
s
.50076 .29639 m
.49255 .93943 L
s
.50076 .29639 m
.58658 .27457 L
s
.26402 .35658 m
.31142 .47747 L
s
.26402 .35658 m
.50076 .29639 L
s
.26402 .35658 m
.49255 .93943 L
s
.26402 .35658 m
.02381 .68956 L
s
.26402 .35658 m
.58658 .27457 L
s
.26402 .35658 m
.62862 .61959 L
s
.02381 .68956 m
.31142 .47747 L
s
.02381 .68956 m
.58658 .27457 L
s
.58658 .27457 m
.31142 .47747 L
s
gsave
.32172 .49395 -66.8125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.062 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.51105 .31287 -66.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.50285 .9559 -67.0312 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(C) show
1.000 setlinewidth
grestore
gsave
.27432 .37305 -70.5938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(EE) show
1.000 setlinewidth
grestore
gsave
.03411 .70604 -67.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(F) show
1.000 setlinewidth
grestore
gsave
.51453 .04007 -67.0312 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(G) show
1.000 setlinewidth
grestore
gsave
.59688 .29104 -66.9688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(D) show
1.000 setlinewidth
grestore
gsave
.63891 .63607 -66.8438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(O) show
1.000 setlinewidth
grestore
.50424 .02359 m
.50076 .29639 L
s
.50424 .02359 m
.49255 .93943 L
s
.50424 .02359 m
.26402 .35658 L
s
.50424 .02359 m
.02381 .68956 L
s
0 1 0 r
.26402 .35658 m
.02381 .68956 L
s
.50424 .02359 m
.26402 .35658 L
s
5 Mabswid
.31142 .47747 Mdot
0 0 1 r
.50076 .29639 Mdot
.49255 .93943 Mdot
1 0 0 r
.26402 .35658 Mdot
.02381 .68956 Mdot
.50424 .02359 Mdot
0 0 1 r
.58658 .27457 Mdot
0 1 0 r
.62862 .61959 Mdot
0 0 m
1 0 L
1 .99075 L
0 .99075 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{204.938, 203},
  ImageMargins->{{45, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003<0000bb000`400?l00000o`00003oc03oool0
0<`0oooo003<0?ooo`00I@3oool40?l406<0oooo001U0?ooo`@0o`@0H`3oool006D0oooo103o101S
0?ooo`00I@3oool40?l406<0oooo001U0?ooo`03003o00001000oooo06@0oooo001T0?ooo`03003o
003oool000@006D0oooo001S0?ooo`04003o003oool0oooo000406D0oooo001R0?ooo`05003o003o
ool0oooo0?ooo`001000I@3oool00680oooo00D00?l00?ooo`3oool0oooo0004001U0?ooo`00H@3o
ool00`00o`00oooo0?ooo`020?ooo`04000400001?l000Co0004of80oooo001P0?ooo`03003o003o
ool0oooo0080oooo00<000Co0004003oool00P3oool00`001?l0oooo0?ooo`1O0?ooo`00H03oool0
0`00o`00oooo0?ooo`020?ooo`030004o`001000oooo00@000CoH03oool005l0oooo00<00?l00?oo
o`3oool00`3oool00`001?l000@00?ooo`1T0?ooo`00GP3oool00`00o`00oooo0?ooo`050?ooo`03
0004003oool0oooo0080oooo00<000Co0?ooo`3oool0GP3oool005d0oooo00<00?l00?ooo`3oool0
1P3oool01000100000Co0?ooo`3oool20004of00oooo001M0?ooo`03003o003oool0oooo00H0oooo
00H000@00004o`001?l000Co0?ooo`001?mP0?ooo`00G03oool00`00o`00oooo0?ooo`070?ooo`03
0004003oool0oooo06<0oooo001K0?ooo`03003o003oool0oooo00P0oooo00<000@00?ooo`3oool0
H`3oool005X0oooo00<000@0003o003oool02@3oool00`001000oooo0?ooo`1S0?ooo`00FP3oool0
0`00o`00oooo0?ooo`090?ooo`030004003oool0oooo06<0oooo001I0?ooo`03003o003oool0oooo
00X0oooo00<000@00?ooo`3oool0H`3oool005P0oooo00<00?l00?ooo`3oool02`3oool00`001000
oooo0?ooo`1S0?ooo`00F03oool00`00o`00oooo0?ooo`0;0?ooo`030004003oool0oooo06<0oooo
001G0?ooo`03003o003oool0oooo00`0oooo00<000@00?ooo`3oool0H`3oool005H0oooo00<00?l0
0?ooo`3oool03@3oool00`001000oooo0?ooo`1S0?ooo`00E@3oool00`0010000?l00?ooo`0>0?oo
o`030004003oool0oooo06<0oooo001E0?ooo`03003o003oool0oooo00h0oooo00<000@00?ooo`3o
ool0H`3oool005@0oooo00<00?l00?ooo`3oool03`3oool00`001000oooo0?ooo`1S0?ooo`00D`3o
ool00`00o`00oooo0?ooo`0@0?ooo`030004003oool0oooo06<0oooo001C0?ooo`03003o003oool0
oooo0100oooo00<000@00?ooo`3oool0H`3oool00580oooo00<00?l00?ooo`3oool04@3oool00`00
1000oooo0?ooo`1S0?ooo`00D@3oool00`00o`00oooo0?ooo`0B0?ooo`030004003oool0oooo06<0
oooo001@0?ooo`0300040000o`00oooo01<0oooo00<000@00?ooo`3oool0H`3oool00500oooo00<0
0?l00?ooo`3oool04`3oool00`001000oooo0?ooo`1S0?ooo`00C`3oool00`00o`00oooo0?ooo`0D
0?ooo`030004003oool0oooo06<0oooo001>0?ooo`03003o003oool0oooo01D0oooo00<000@00?oo
o`3oool0H`3oool004d0oooo00<000@0003o003oool05P3oool00`001000oooo0?ooo`1S0?ooo`00
C@3oool00`00o`00oooo0?ooo`0F0?ooo`030004003oool0oooo06<0oooo001<0?ooo`03003o003o
ool0oooo01L0oooo00<000@00?ooo`3oool0H`3oool004/0oooo00<00?l00?ooo`3oool0603oool0
0`001000oooo0?ooo`1S0?ooo`00B`3oool00`00o`00oooo0?ooo`0H0?ooo`030004003oool0oooo
06<0oooo001:0?ooo`03003o003oool0oooo01T0oooo00<000@00?ooo`3oool0H`3oool004T0oooo
00<00?l00?ooo`3oool06P3oool00`001000oooo0?ooo`1S0?ooo`00B03oool00`0010000?l00?oo
o`0K0?ooo`030004003oool0oooo06<0oooo00180?ooo`03003o003oool0oooo01/0oooo00<000@0
0?ooo`3oool0H`3oool004L0oooo00<00?l00?ooo`3oool0703oool00`001000oooo0?ooo`1S0?oo
o`00AP3oool00`00o`00oooo0?ooo`0M0?ooo`030004003oool0oooo06<0oooo00160?ooo`03003o
003oool0oooo01d0oooo00<000@00?ooo`3oool0H`3oool004D0oooo00<00?l00?ooo`3oool07@3o
ool2000406D0oooo00140?ooo`03003o003oool0oooo01h0oooo0P00101U0?ooo`00@`3oool00`00
10000?l00?ooo`0O0?ooo`8000@03`3oool40004oe80oooo00130?ooo`03003o003oool0oooo01l0
oooo0P00100?0?ooo`@000CoDP3oool00480oooo00<00?l00?ooo`3oool0803oool2000400l0oooo
10001?l?000404<0oooo00110?ooo`03003o003oool0oooo0240oooo0P00100:0?ooo`D000@01000
1?l?0?ooo`D000@0?P3oool00400oooo00<000@0003o003oool08P3oool2000400D0oooo1P001002
0?ooo`030004003oool0oooo01L0oooo1@00100i0?ooo`00@03oool00`00o`00oooo0?ooo`0R0?oo
o`@000Co1P0010040?ooo`030004003oool0oooo01d0oooo0`00100f0?ooo`00?`3oool00`00o`00
oooo0?ooo`0S0?ooo`@000Co0`0010050?ooo`8000@08`3oool2000403@0oooo000n0?ooo`030004
0000o`00oooo0240oooo0`0010040004o`L0oooo00<000@00?ooo`3oool09@3oool300040340oooo
000n0?ooo`03003o003oool0oooo01h0oooo1@0010000`3oool000Co0004o`020004o`H0oooo00<0
00@00?ooo`3oool0:@3oool2000402l0oooo000m0?ooo`03003o003oool0oooo01/0oooo1`001003
0?ooo`8000@01P3oool2000400H0oooo1P001?lR0?ooo`<000@0;03oool003`0oooo00<00?l00?oo
o`3oool0603oool5000400030?ooo`00100000@000H0oooo0P0010050?ooo`030004003oool0oooo
00P0oooo00<000Co0?ooo`3oool00P001?lT0?ooo`8000@0:P3oool003/0oooo00<000@0003o003o
ool05@3oool5000400@0oooo00<000@00?ooo`3oool01P3oool2000400@0oooo00<000@00?ooo`3o
ool02@3oool01@001?l0oooo0?ooo`3oool000Co02H0oooo00<000@00?ooo`3oool09`3oool003/0
oooo00<00?l00?ooo`3oool04@3oool5000400L0oooo00<000@00?ooo`3oool01`3oool200040080
oooo0P00100<0?ooo`040004o`3oool0oooo0?ooo`8000Co9P3oool2000402L0oooo000j0?ooo`03
003o003oool0oooo00l0oooo1000100:0?ooo`030004003oool0oooo00P0oooo0P0010000`3oool0
00@00?ooo`0=0?ooo`040004o`3oool0oooo0?ooo`8000Co:03oool00`001000oooo0?ooo`0T0?oo
o`00>@3oool00`0010000?l00?ooo`0<0?ooo`@000@0303oool2000400X0oooo00<000Co00040000
1?l010001?l<0?ooo`040004o`3oool0oooo0?ooo`8000Co:@3oool2000402@0oooo000i0?ooo`03
003o003oool0oooo00P0oooo1000100?0?ooo`030004003oool0oooo00/0oooo00<000@00004o`3o
ool00P3oool20004o`/0oooo1@001?l/0?ooo`030004003oool0oooo0240oooo000h0?ooo`03003o
003oool0oooo00D0oooo1000100A0?ooo`8000@03@3oool2000400040004o`3oool0oooo0?ooo`80
00Co?@3oool00`001000oooo0?ooo`0P0?ooo`00=@3oool40?l400<0oooo1000100D0?ooo`030004
003oool0oooo00/0oooo0P0010000`3oool000@00004o`040004ocl0oooo00<000@00?ooo`3oool0
7`3oool003D0oooo103o1003000401H0oooo0P00100=0?ooo`8000@00P3oool00`00100000Co0?oo
o`020?ooo`8000Co?`3oool2000401l0oooo000e0?ooo`@0o`@0603oool00`001000oooo0?ooo`0<
0?ooo`030004003oool0oooo0080oooo0P0010000`001?l0oooo0?ooo`020004od40oooo00<000@0
0?ooo`3oool0703oool003D0oooo103o100G0?ooo`030004003oool0oooo00/0oooo0P0010050?oo
o`03000400001?l000Co00@000Co@P3oool00`001000oooo0?ooo`0K0?ooo`00=03oool01P001000
0?l00?ooo`001000oooo000401H0oooo00<000@00?ooo`3oool02P3oool2000400H0oooo0P001018
0?ooo`030004003oool0oooo01X0oooo000c0?ooo`0500040000o`00oooo0?ooo`0010000P3oool0
0`001000oooo0?ooo`0B0?ooo`030004003oool0oooo00X0oooo00<000@00?ooo`3oool01P3oool2
000404T0oooo00<000@00?ooo`3oool06@3oool003<0oooo00<00?l00?ooo`3oool00P3oool00`00
1000oooo0?ooo`0200040100oooo0P00100;0?ooo`8000@02@3oool2000404X0oooo00<000@00?oo
o`3oool0603oool00380oooo00<00?l00?ooo`3oool00`3oool00`001000oooo0?ooo`020?ooo`03
0004003oool0oooo00`0oooo00<000@00?ooo`3oool02P3oool2000400X0oooo0P00101;0?ooo`03
0004003oool0oooo01L0oooo000a0?ooo`0300040000o`00oooo00@0oooo00<000@00?ooo`3oool0
0`3oool2000400/0oooo00<000@00?ooo`3oool02P3oool00`001000oooo0?ooo`0:0?ooo`8000@0
C03oool00`001000oooo0?ooo`0F0?ooo`00<@3oool00`00o`0000Co0004o`0;0004o`030?ooo`00
1000oooo00T0oooo00<000@00?ooo`3oool0203oool2000400d0oooo0P00101<0?ooo`030004003o
ool0oooo01H0oooo000`0?ooo`04003o003oool000Co0004o`<0oooo00@000Co0?ooo`001?l000Co
0`3oool010001?l0oooo0?ooo`0010080?ooo`030004003oool0oooo00P0oooo0P00100>0?ooo`80
00@0C@3oool00`001000oooo0?ooo`0E0?ooo`00;`3oool01@00o`00oooo0?ooo`3oool000Co0080
oooo0P001?l20?ooo`030004o`3oool0oooo008000Co0`3oool2000400D0oooo00<000@00?ooo`3o
ool01`3oool200040100oooo0P00101>0?ooo`030004003oool0oooo01@0oooo000^0?ooo`030004
0000o`00oooo0080oooo10001?l30?ooo`@000Co1P3oool01@001000oooo0?ooo`3oool000@000T0
oooo0P00100A0?ooo`8000@0C`3oool00`001000oooo0?ooo`0C0?ooo`00;P3oool00`00o`00oooo
0?ooo`020?ooo`030004o`3oool0oooo00<000Co00@0oooo0004o`001000oooo0`001?l50?ooo`<0
00@02@3oool200040180oooo0P00101@0?ooo`030004003oool0oooo0180oooo000]0?ooo`03003o
003oool0oooo00<0oooo0P001?l30?ooo`040004o`3oool000Co0004o`<0oooo00<000Co0?ooo`3o
ool01@3oool00`001000oooo0?ooo`050?ooo`8000@0503oool200040500oooo00<000@00?ooo`3o
ool04P3oool002`0oooo00<000@0003o003oool00`3oool>0004o`H0oooo00<000@00?ooo`001000
1@3oool2000401D0oooo0P00101A0?ooo`030004003oool0oooo0140oooo000/0?ooo`03003o003o
ool0oooo00d0oooo00<000@00?ooo`3oool01P3oool010001000oooo0?ooo`3oool200040080oooo
0P00100F0?ooo`8000@0DP3oool00`001000oooo0?ooo`0@0?ooo`00:`3oool00`00o`00oooo0?oo
o`0>0?ooo`030004003oool0oooo00H0oooo00<000@00?ooo`3oool00`3oool2000401P0oooo0P00
101B0?ooo`030004003oool0oooo0100oooo000Z0?ooo`03003o003oool0oooo00l0oooo0P001006
0?ooo`030004003oool0oooo00<0oooo1000100G0?ooo`8000@0D`3oool00`001000oooo0?ooo`0?
0?ooo`00:@3oool00`0010000?l00?ooo`0A0?ooo`030004003oool0oooo00<0oooo00<000@00?oo
o`3oool00`3oool2000400<0oooo00<000@00?ooo`3oool0503oool2000405@0oooo00<000@00?oo
o`3oool03P3oool002T0oooo00<00?l00?ooo`3oool04@3oool00`001000oooo0?ooo`030?ooo`04
0004003oool0oooo0?ooo`8000@01P3oool00`001000oooo0?ooo`0C0?ooo`8000@0E03oool00`00
1000oooo0?ooo`0>0?ooo`00:03oool00`00o`00oooo0?ooo`0C0?ooo`050004003oool0oooo0?oo
o`0010000`3oool2000400P0oooo0P00100C0?ooo`8000@0E@3oool00`001000oooo0?ooo`0=0?oo
o`009`3oool00`00o`00oooo0?ooo`0D0?ooo`060004003oool0oooo0?ooo`001000oooo0`00100;
0?ooo`030004003oool0oooo0100oooo0P00101E0?ooo`030004003oool0oooo00d0oooo000V0?oo
o`0300040000o`00oooo01D0oooo0P0010000`3oool000@00?ooo`02000400h0oooo0P00100@0?oo
o`030004003oool0oooo05D0oooo00<000@00?ooo`3oool0303oool002H0oooo00<00?l00?ooo`3o
ool05P3oool4003o00030004003oool0oooo00l0oooo00<000@00?ooo`3oool03@3oool00`001000
oooo0?ooo`1F0?ooo`030004003oool0oooo00/0oooo000U0?ooo`03003o003oool0oooo01L0oooo
1000o`0C0?ooo`030004003oool0oooo00`0oooo00<000@00?ooo`3oool0EP3oool00`001000oooo
0?ooo`0;0?ooo`00903oool00`0010000?l00?ooo`0H0?ooo`@00?l0503oool2000400`0oooo00<0
00@00?ooo`3oool0EP3oool00`001000oooo0?ooo`0;0?ooo`00903oool00`00o`00oooo0?ooo`0G
0?ooo`0300040000o`000?l000800?l05P3oool00`001000oooo0?ooo`090?ooo`030004003oool0
oooo05L0oooo00<000@00?ooo`3oool02P3oool002<0oooo00<00?l00?ooo`3oool05P3oool20004
00040?ooo`00100000@0000401P0oooo0P0010090?ooo`030004003oool0oooo05L0oooo00<000@0
0?ooo`3oool02P3oool00280oooo00<00?l00?ooo`3oool05P3oool200040080oooo00<000@00?oo
o`0010006P3oool00`001000oooo0?ooo`060?ooo`030004003oool0oooo05P0oooo00<000@00?oo
o`3oool02@3oool00240oooo00<000@0003o003oool05P3oool200040080oooo00<000@00?ooo`3o
ool00P00100J0?ooo`8000@01P3oool00`001000oooo0?ooo`1H0?ooo`030004003oool0oooo00T0
oooo000Q0?ooo`03003o003oool0oooo01@0oooo0P0010040?ooo`030004003oool0oooo008000@0
703oool00`001000oooo0?ooo`030?ooo`030004003oool0oooo05P0oooo00<000@00?ooo`3oool0
2@3oool00200oooo00<00?l00?ooo`3oool0503oool2000400@0oooo00<000@00?ooo`3oool00P3o
ool00`001000oooo0?ooo`0K0?ooo`030004003oool0oooo0080oooo00<000@00?ooo`3oool0F@3o
ool00`001000oooo0?ooo`080?ooo`007`3oool00`00o`00oooo0?ooo`0C0?ooo`<000@01@3oool0
1P00100000Co0004o`001?l0oooo000400<000Co6`3oool200040080oooo00<000@00?ooo`3oool0
F@3oool00`001000oooo0?ooo`080?ooo`007`3oool00`00o`00oooo0?ooo`0B0?ooo`8000@01`3o
ool010001000oooo0004o`001?l20?ooo`03000400001?l0oooo01d0oooo00<000@00?ooo`001000
F`3oool00`001000oooo0?ooo`080?ooo`007P3oool00`00o`00oooo0?ooo`0B0?ooo`8000@01`3o
ool010001000oooo0?ooo`3oool50004oal0oooo0P00101L0?ooo`030004003oool0oooo00L0oooo
000M0?ooo`03003o003oool0oooo0140oooo0P0010090?ooo`030004003oool0oooo0080oooo00@0
00Co0?ooo`00100000Co803oool2000405/0oooo00<000@00?ooo`3oool01`3oool001`0oooo00<0
00@0003o003oool04@3oool2000400X0oooo00<000@00?ooo`3oool00P3oool010001?l0oooo0004
o`001?lP0?ooo`030004003oool000@005X0oooo00<000@00?ooo`3oool01`3oool001`0oooo00<0
0?l00?ooo`3oool0403oool2000400/0oooo00<000@00?ooo`3oool00`3oool20004o`8000@07`3o
ool00`001000oooo0?ooo`02000405P0oooo00<000@00?ooo`3oool01`3oool001/0oooo00<00?l0
0?ooo`3oool03`3oool2000400d0oooo00<000@00?ooo`3oool00P3oool30004o`030?ooo`001000
oooo01h0oooo00<000@00?ooo`3oool00P3oool00`001000oooo0?ooo`1F0?ooo`030004003oool0
oooo00H0oooo000J0?ooo`03003o003oool0oooo00l0oooo0P00100=0?ooo`030004003oool0oooo
00L0oooo00<000@00?ooo`3oool07@3oool00`001000oooo0?ooo`030?ooo`8000@0EP3oool00`00
1000oooo0?ooo`060?ooo`006@3oool00`0010000?l00?ooo`0?0?ooo`030004003oool0oooo00d0
oooo00<000@00?ooo`3oool01`3oool2000401h0oooo00<000@00?ooo`3oool01@3oool00`001000
oooo0?ooo`1C0?ooo`030004003oool0oooo00H0oooo000I0?ooo`03003o003oool0oooo00d0oooo
0P00100@0?ooo`030004003oool0oooo00P0oooo00<000@00?ooo`3oool0703oool00`001000oooo
0?ooo`060?ooo`030004003oool0oooo0580oooo00<000@00?ooo`3oool01P3oool001P0oooo00<0
0?l00?ooo`3oool03@3oool200040140oooo00<000@00?ooo`3oool0203oool2000401d0oooo00<0
00@00?ooo`3oool01`3oool200040580oooo00<000@00?ooo`3oool01P3oool001L0oooo00<00?l0
0?ooo`3oool0303oool2000401<0oooo00<000@00?ooo`3oool02@3oool00`001000oooo0?ooo`0K
0?ooo`030004003oool0oooo00T0oooo00<000@00?ooo`3oool0D03oool00`001000oooo0?ooo`05
0?ooo`005`3oool00`00o`00oooo0?ooo`0;0?ooo`8000@0503oool00`001000oooo0?ooo`090?oo
o`030004003oool0oooo01/0oooo00<000@00?ooo`3oool02P3oool200040500oooo00<000@00?oo
o`3oool01@3oool001H0oooo00<00?l00?ooo`3oool02`3oool2000401@0oooo00<000@00?ooo`3o
ool02P3oool2000401`0oooo00<000@00?ooo`3oool0303oool00`001000oooo0?ooo`1=0?ooo`03
0004003oool0oooo00D0oooo000E0?ooo`03003o003oool0oooo00X0oooo0P00100F0?ooo`030004
003oool0oooo00/0oooo00<000@00?ooo`3oool06P3oool00`001000oooo0?ooo`0=0?ooo`030004
003oool0oooo04`0oooo00<000@00?ooo`3oool01@3oool001@0oooo00<000@0003o003oool02P3o
ool2000401L0oooo00<000@00?ooo`3oool02`3oool2000401/0oooo00<000@00?ooo`3oool03P3o
ool2000404`0oooo00<000@00?ooo`3oool01@3oool001@0oooo00<00?l00?ooo`3oool02@3oool0
0`001000oooo0?ooo`0G0?ooo`030004003oool0oooo00`0oooo00<000@00?ooo`3oool06@3oool0
0`001000oooo0?ooo`0@0?ooo`030004003oool0oooo04T0oooo00<000@00?ooo`3oool01@3oool0
01<0oooo00<00?l00?ooo`3oool0203oool2000401X0oooo00<000@00?ooo`3oool0303oool00`00
1000oooo0?ooo`0I0?ooo`030004003oool0oooo0140oooo0P0010190?ooo`030004003oool0oooo
00D0oooo000B0?ooo`03003o003oool0oooo00P0oooo0P00100K0?ooo`030004003oool0oooo00`0
oooo0P00100J0?ooo`030004003oool0oooo01<0oooo00<000@00?ooo`3oool0AP3oool00`001000
oooo0?ooo`050?ooo`004P3oool00`00o`00oooo0?ooo`070?ooo`030004003oool0oooo01/0oooo
00<000@00?ooo`3oool03@3oool00`001000oooo0?ooo`0H0?ooo`030004003oool0oooo01@0oooo
00<000@00?ooo`00o`000`00o`130?ooo`030004003oool0oooo00@0oooo000A0?ooo`03003o003o
ool0oooo00H0oooo0P00100N0?ooo`030004003oool0oooo00d0oooo0P00100I0?ooo`030004003o
ool0oooo01D0oooo00<000@0003o0000o`000P00o`130?ooo`030004003oool0oooo00@0oooo000@
0?ooo`03003o003oool0oooo00H0oooo0P00100O0?ooo`030004003oool0oooo00h0oooo00<000@0
0?ooo`3oool05`3oool00`001000oooo0?ooo`0F0?ooo`@00?l0@`3oool00`001000oooo0?ooo`04
0?ooo`003`3oool00`00o`00oooo0?ooo`060?ooo`030004003oool0oooo01l0oooo00<000@00?oo
o`3oool03P3oool00`001000oooo0?ooo`0G0?ooo`030004003oool0oooo01H0oooo1000o`130?oo
o`030004003oool0oooo00@0oooo000?0?ooo`03003o003oool0oooo00@0oooo0P00100R0?ooo`03
0004003oool0oooo00h0oooo0P00100H0?ooo`030004003oool0oooo05d0oooo00<000@00?ooo`3o
ool0103oool000h0oooo00<00?l00?ooo`3oool0103oool00`001000oooo0?ooo`0R0?ooo`030004
003oool0oooo00l0oooo00<000@00?ooo`3oool05P3oool00`001000oooo0?ooo`1M0?ooo`030004
003oool0oooo00@0oooo000=0?ooo`03003o003oool0oooo00<0oooo0P00100U0?ooo`030004003o
ool0oooo00l0oooo0P00100G0?ooo`030004003oool0oooo05`0oooo00<000@00?ooo`3oool01@3o
ool000`0oooo00<000@0003o003oool00`3oool2000402H0oooo00<000@00?ooo`3oool0403oool0
0`001000oooo0?ooo`0E0?ooo`030004003oool0oooo05`0oooo00<000@00?ooo`3oool01@3oool0
00`0oooo00<00?l00?ooo`3oool00P3oool00`001000oooo0?ooo`0V0?ooo`030004003oool0oooo
0100oooo00<000@00?ooo`3oool05@3oool00`001000oooo0?ooo`1L0?ooo`030004003oool0oooo
00D0oooo000;0?ooo`04003o003oool0oooo0?ooo`8000@0:@3oool00`001000oooo0?ooo`0@0?oo
o`8000@05P3oool00`001000oooo0?ooo`0G0?ooo`@000Co@@3oool00`001000oooo0?ooo`050?oo
o`002P3oool01@00o`00oooo0?ooo`3oool000@002/0oooo00<000@00?ooo`3oool04@3oool00`00
1000oooo0?ooo`0D0?ooo`030004003oool0oooo01H0oooo0P001?l20?ooo`8000Co@03oool00`00
1000oooo0?ooo`050?ooo`002P3oool01000o`00oooo0?ooo`00100/0?ooo`030004003oool0oooo
0140oooo00<000@00?ooo`3oool0503oool00`001000oooo0?ooo`0F0?ooo`8000Co0`3oool00`00
1?l0oooo0?ooo`0n0?ooo`030004003oool0oooo00D0oooo00090?ooo`04003o003oool000@00004
02d0oooo00<000@00?ooo`3oool04P3oool00`001000oooo0?ooo`0C0?ooo`030004003oool0oooo
01H0oooo0P001?l30?ooo`8000Co?`3oool00`001000oooo0?ooo`050?ooo`00203oool00`00o`00
oooo0004000`0?ooo`030004003oool0oooo0140oooo00<000@00?ooo`3oool04`3oool00`001000
oooo0?ooo`0F0?ooo`8000Co0`3oool20004ocl0oooo00<000@00?ooo`3oool01@3oool000D0oooo
103o10000`001000oooo0?ooo`0_0?ooo`030004003oool0oooo0140oooo0P00100D0?ooo`030004
003oool0oooo01L0oooo0P001?l20?ooo`8000Co?P3oool00`001000oooo0?ooo`060?ooo`001@3o
ool40?l40380oooo00<000@00?ooo`3oool04P3oool00`001000oooo0?ooo`0B0?ooo`030004003o
ool0oooo01P0oooo10001?lo0?ooo`030004003oool0oooo00H0oooo00050?ooo`@0o`@0<P3oool0
0`001000oooo0?ooo`0B0?ooo`030004003oool0oooo0180oooo00<000@00?ooo`3oool0F`3oool0
0`001000oooo0?ooo`060?ooo`001@3oool40?l40380oooo00<000@00?ooo`3oool04`3oool00`00
1000oooo0?ooo`0A0?ooo`030004003oool0oooo05/0oooo00<000@00?ooo`3oool01P3oool003`0
oooo00<000@00?ooo`3oool04P3oool00`001000oooo0?ooo`0A0?ooo`030004003oool0oooo05/0
oooo00<000@00?ooo`3oool01P3oool003`0oooo00<000@00?ooo`3oool04P3oool200040180oooo
00<000@00?ooo`3oool0FP3oool00`001000oooo0?ooo`070?ooo`00?03oool00`001000oooo0?oo
o`0C0?ooo`030004003oool0oooo0100oooo00<000@00?ooo`3oool0FP3oool00`001000oooo0?oo
o`070?ooo`00?03oool00`001000oooo0?ooo`0C0?ooo`030004003oool0oooo00l0oooo0P00101L
0?ooo`030004003oool0oooo00L0oooo000l0?ooo`030004003oool0oooo01@0oooo00<000@00?oo
o`3oool03P3oool2000405`0oooo00<000@00?ooo`3oool01`3oool000D0oooo10001?ld0?ooo`03
0004003oool0oooo01<0oooo00<000@00?ooo`3oool03P3oool2000405/0oooo00<000@00?ooo`3o
ool0203oool000H0oooo00<000Co0?ooo`3oool0=03oool00`001000oooo0?ooo`0C0?ooo`8000@0
3`3oool2000405/0oooo00<000@00?ooo`3oool0203oool000L0oooo00<000Co0?ooo`001?l0<`3o
ool00`001000oooo0?ooo`0D0?ooo`030004003oool0oooo00d0oooo0P00101K0?ooo`030004003o
ool0oooo00P0oooo00070?ooo`@000Co<`3oool00`001000oooo0?ooo`0C0?ooo`030004003oool0
oooo00d0oooo0P00101J0?ooo`030004003oool0oooo00T0oooo00070?ooo`030004o`3oool0oooo
00<000Co<@3oool00`001000oooo0?ooo`0D0?ooo`030004003oool0oooo00`0oooo0P00101J0?oo
o`030004003oool0oooo00T0oooo00070?ooo`8000Co0`3oool00`001?l0oooo0?ooo`0`0?ooo`03
0004003oool0oooo01<0oooo00<000@00?ooo`3oool0303oool2000405X0oooo00<000@00?ooo`3o
ool02@3oool000H0oooo1`001?lb0?ooo`030004003oool0oooo01<0oooo0P00100=0?ooo`8000@0
F@3oool00`001000oooo0?ooo`0:0?ooo`00?`3oool00`001000oooo0?ooo`0D0?ooo`030004003o
ool0oooo00/0oooo0P00101I0?ooo`030004003oool0oooo00X0oooo00100?ooo`030004003oool0
oooo01<0oooo00<000@00?ooo`3oool02`3oool2000405P0oooo00<000@00?ooo`3oool02`3oool0
0440oooo00<000@00?ooo`3oool04`3oool00`001000oooo0?ooo`0:0?ooo`8000@0F03oool00`00
1000oooo0?ooo`0;0?ooo`00@@3oool00`001000oooo0?ooo`0C0?ooo`030004003oool0oooo00X0
oooo0P00101H0?ooo`030004003oool0oooo00/0oooo00110?ooo`030004003oool0oooo01<0oooo
00<000@00?ooo`3oool02P3oool2000405L0oooo00<000@00?ooo`3oool0303oool00480oooo00<0
00@00?ooo`3oool04`3oool00`001000oooo0?ooo`090?ooo`030004003oool0oooo05D0oooo00<0
00@00?ooo`3oool03@3oool004<0oooo00<000@00?ooo`3oool04P3oool00`001000oooo0?ooo`09
0?ooo`030004003oool0oooo05@0oooo00<000@00?ooo`3oool03P3oool004<0oooo00<000@00?oo
o`3oool04P3oool2000400X0oooo00<000@00?ooo`3oool0E03oool00`001000oooo0?ooo`0>0?oo
o`00A03oool00`001000oooo0?ooo`0B0?ooo`030004003oool0oooo00P0oooo00<000@00?ooo`3o
ool0D`3oool00`001000oooo0?ooo`0?0?ooo`00A@3oool00`001000oooo0?ooo`0A0?ooo`030004
003oool0oooo00P0oooo00<000@00?ooo`3oool0DP3oool00`001000oooo0?ooo`0@0?ooo`00A@3o
ool00`001000oooo0?ooo`0B0?ooo`030004003oool0oooo00L0oooo00<000@00?ooo`3oool0DP3o
ool00`001000oooo0?ooo`0@0?ooo`00AP3oool00`001000oooo0?ooo`0A0?ooo`030004003oool0
oooo00L0oooo00<000@00?ooo`3oool0D@3oool00`001000oooo0?ooo`0A0?ooo`00A`3oool00`00
1000oooo0?ooo`0@0?ooo`8000@0203oool00`001000oooo0?ooo`1@0?ooo`030004003oool0oooo
0180oooo00170?ooo`030004003oool0oooo0140oooo00<000@00?ooo`3oool01P3oool00`001000
oooo0?ooo`1@0?ooo`030004003oool0oooo0180oooo00180?ooo`030004003oool0oooo0100oooo
00<000@00?ooo`3oool01P3oool00`001000oooo0?ooo`1?0?ooo`030004003oool0oooo01<0oooo
00190?ooo`030004003oool0oooo0100oooo00<000@00?ooo`3oool01@3oool00`001000oooo0?oo
o`1>0?ooo`030004003oool0oooo01@0oooo00190?ooo`030004003oool0oooo0100oooo00<000@0
0?ooo`3oool01@3oool00`001000oooo0?ooo`1>0?ooo`030004003oool0oooo01@0oooo001:0?oo
o`030004003oool0oooo00l0oooo0P0010060?ooo`030004003oool0oooo04d0oooo00<000@00?oo
o`3oool05@3oool004/0oooo00<000@00?ooo`3oool03`3oool00`001000oooo0?ooo`040?ooo`03
0004003oool0oooo04`0oooo00<000@00?ooo`3oool05P3oool004`0oooo00<000@00?ooo`3oool0
3P3oool00`001000oooo0?ooo`040?ooo`030004003oool0oooo04/0oooo00<000@00?ooo`3oool0
5`3oool004d0oooo00<000@00?ooo`3oool03P3oool00`001000oooo0?ooo`030?ooo`030004003o
ool0oooo04X0oooo00<000@00?ooo`3oool0603oool004h0oooo00<000@00?ooo`3oool03@3oool0
0`001000oooo0?ooo`030?ooo`030004003oool0oooo04X0oooo00<000@00?ooo`3oool0603oool0
04l0oooo00<000@00?ooo`3oool0303oool2000400@0oooo00<000@00?ooo`3oool0B@3oool00`00
1000oooo0?ooo`0I0?ooo`00D03oool00`001000oooo0?ooo`0<0?ooo`030004003oool0oooo0080
oooo00<000@00?ooo`3oool0A`3oool2000401`0oooo001A0?ooo`030004003oool0oooo00/0oooo
00<000@00?ooo`3oool00P3oool00`001000oooo0?ooo`160?ooo`030004003oool0oooo01`0oooo
001B0?ooo`8000@0303oool01@001000oooo0?ooo`3oool000@004H0oooo0P00100O0?ooo`00E03o
ool00`001000oooo0?ooo`090?ooo`050004003oool0oooo0?ooo`001000A@3oool00`001000oooo
0?ooo`0O0?ooo`00E@3oool00`001000oooo0?ooo`080?ooo`050004003oool0oooo0?ooo`001000
A03oool00`001000oooo0?ooo`0P0?ooo`00EP3oool00`001000oooo0?ooo`080?ooo`040004003o
ool0oooo000404@0oooo00<000@00?ooo`3oool0803oool005L0oooo00<000@00?ooo`3oool01`3o
ool010001000oooo0?ooo`0010120?ooo`8000@08`3oool005P0oooo0P0010080?ooo`030004003o
ool000@00400oooo0P00100U0?ooo`00FP3oool2000400H0oooo00<000@00?ooo`001000?P3oool2
000402L0oooo001L0?ooo`030004003oool0oooo00<0oooo00<000@00?ooo`001000?@3oool00`00
1000oooo0?ooo`0W0?ooo`00G@3oool2000400@0oooo0P00100k0?ooo`8000@0:P3oool005l0oooo
00@000@00?ooo`3oool0oooo10001?lg0?ooo`8000@0;03oool00600oooo0`0010040004oc@0oooo
0`00100^0?ooo`00H`3oool40004oc80oooo0P00100a0?ooo`00H`3oool40004o`030004003oool0
oooo02`0oooo0`00100c0?ooo`00J03oool4000402L0oooo0`00100f0?ooo`00K03oool300040240
oooo0`00100i0?ooo`00K`3oool3000401X0oooo1000100l0?ooo`00LP3oool;000400D0oooo2P00
10100?ooo`00O@3oool5000404X0oooo001T0?ooo`D000CoH`3oool006<0oooo0P001?l30?ooo`03
0004o`3oool0oooo0640oooo001S0?ooo`8000CoI`3oool006<0oooo0P001?mW0?ooo`00H`3oool2
0004o`@0oooo00<000Co0?ooo`3oool0H03oool006@0oooo0P001?l20?ooo`8000CoHP3oool006D0
oooo0`001?l00`3oool000Co0?ooo`1Q0?ooo`00c03oool00001\
\>"],
  ImageRangeCache->{{{118.375, 281.313}, {556.813, 395.438}} -> {-670.932, \
903.213, 2.43585, 2.43585}}],

Cell[TextData[{
  "|",
  Cell[BoxData[
      StyleBox["EE",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0, 0, 1],
        Background->None]], "Expression"],
  Cell[BoxData[
      StyleBox["F",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0, 0, 1],
        Background->None]], "Expression"],
  "| \[TildeFullEqual] |",
  Cell[BoxData[
      StyleBox["G",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0, 0, 1],
        Background->None]], "Expression"],
  Cell[BoxData[
      StyleBox["EE",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0, 0, 1],
        Background->None]], "Expression"],
  "| for this configuration of the points"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["End of output", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["Input to the system:", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[BoxData[
    \(KnowledgeBase["\<Butterfly_g\>", 
      any[O, A, B, C, 
        D], {{\[VeryThinSpace]O, {100, 100}}, {A, {0, 100}}, {B, {55, 
            190}}, {C, {171, 170}}, {D, {60, 10}}}]\)], "Input",
  CellTags->"KnowledgeBase (Butterfly_g)"],

Cell["Input to the system:", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[BoxData[
    \(Simplify[Proposition["\<Butterfly\>"], by -> GraphicSimplifier, 
      using \[Rule] KnowledgeBase["\<Butterfly_g\>"]]\)], "Input"],

Cell["Output generated automatically by the system", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.0238095 0.0047619 [
[.0381 .51905 -5.8125 0 ]
[.0381 .51905 5.8125 11.1875 ]
[.30133 .94497 -5.75 0 ]
[.30133 .94497 5.75 11.1875 ]
[.85338 .85337 -6.03125 0 ]
[.85338 .85337 6.03125 11.1875 ]
[.30848 .62992 -9.59375 0 ]
[.30848 .62992 9.59375 11.1875 ]
[.15327 .34182 -6.09375 0 ]
[.15327 .34182 6.09375 11.1875 ]
[.4637 .91802 -6.03125 0 ]
[.4637 .91802 6.03125 11.1875 ]
[.32089 .0839 -5.96875 0 ]
[.32089 .0839 5.96875 11.1875 ]
[.51429 .51905 -5.84375 0 ]
[.51429 .51905 5.84375 11.1875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .47619 0 365.73 arc
s
.02381 .5 m
.8391 .83432 L
s
.28704 .92592 m
.8391 .83432 L
s
.28704 .92592 m
.3066 .06485 L
s
.2942 .61088 m
.02381 .5 L
s
.2942 .61088 m
.28704 .92592 L
s
.2942 .61088 m
.8391 .83432 L
s
.2942 .61088 m
.13898 .32278 L
s
.2942 .61088 m
.3066 .06485 L
s
.2942 .61088 m
.5 .5 L
s
.13898 .32278 m
.02381 .5 L
s
.13898 .32278 m
.3066 .06485 L
s
.3066 .06485 m
.02381 .5 L
s
gsave
.0381 .51905 -66.8125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.062 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.30133 .94497 -66.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.85338 .85337 -67.0312 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(C) show
1.000 setlinewidth
grestore
gsave
.30848 .62992 -70.5938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(EE) show
1.000 setlinewidth
grestore
gsave
.15327 .34182 -67.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(F) show
1.000 setlinewidth
grestore
gsave
.4637 .91802 -67.0312 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(G) show
1.000 setlinewidth
grestore
gsave
.32089 .0839 -66.9688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(D) show
1.000 setlinewidth
grestore
gsave
.51429 .51905 -66.8438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.1875 translate 1 -1 scale
63.000 12.500 moveto
%%IncludeResource: font Courier-BoldOblique
%%IncludeFont: Courier-BoldOblique
/Courier-BoldOblique findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(O) show
1.000 setlinewidth
grestore
.44941 .89898 m
.28704 .92592 L
s
.44941 .89898 m
.8391 .83432 L
s
.44941 .89898 m
.2942 .61088 L
s
.44941 .89898 m
.13898 .32278 L
s
0 1 0 r
.2942 .61088 m
.13898 .32278 L
s
.44941 .89898 m
.2942 .61088 L
s
5 Mabswid
.02381 .5 Mdot
0 0 1 r
.28704 .92592 Mdot
.8391 .83432 Mdot
1 0 0 r
.2942 .61088 Mdot
.13898 .32278 Mdot
.44941 .89898 Mdot
0 0 1 r
.3066 .06485 Mdot
0 1 0 r
.5 .5 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{402.375, 402.375},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007f0001mR000`400?l00000o`00003oo`3oooog
0?ooo`00o`3oooog0?ooo`00o`3oooog0?ooo`00o`3oooog0?ooo`00o`3oooog0?ooo`00o`3oooog
0?ooo`00o`3oooog0?ooo`00o`3oooog0?ooo`00o`3oooog0?ooo`00o`3oooog0?ooo`00o`3oooog
0?ooo`00o`3oooog0?ooo`00i@3oool/00000>D0oooo003L0?ooo`T00000;03oool900000=`0oooo
003F0?ooo`H00000?P3oool600000=H0oooo003@0?ooo`H00000BP3oool600000=00oooo003:0?oo
o`H00000EP3oool600000<X0oooo00340?ooo`H00000HP3oool300000<L0oooo00320?ooo`800000
J`3oool600000<40oooo002o0?ooo`<00000L`3oool200000;l0oooo002i0?ooo`H00000N03oool6
00000;T0oooo002f0?ooo`<00000Q03oool300000;H0oooo002c0?ooo`<00000RP3oool300000;<0
oooo002`0?ooo`<00000T03oool300000;00oooo002^0?ooo`800000UP3oool300000:d0oooo002[
0?ooo`<00000V`3oool200000:/0oooo002X0?ooo`<00000X03oool300000:P0oooo002U0?ooo`<0
0000YP3oool300000:D0oooo002R0?ooo`<00000[03oool300000:80oooo002P0?ooo`800000/P3o
ool3000009l0oooo002I0?ooo`80003o0P3oool300000;L0oooo0P00002M0?ooo`00V03oool40000
o`030000003oool0oooo0;X0oooo0P00002K0?ooo`00U`3oool60000okh0oooo0P00002I0?ooo`00
U`3oool60000ol00oooo0P00002G0?ooo`00U@3oool2000000030?ooo`000?l0003o0080003o``3o
ool3000009@0oooo002B0?ooo`<000000P3oool010000000oooo0000o`000?o70?ooo`030000003o
ool0oooo0940oooo002@0?ooo`800000103oool010000000oooo0?ooo`0000390?ooo`800000T@3o
ool008h0oooo0P0000060?ooo`040000003oool0oooo00000</0oooo0P00002?0?ooo`00S@3oool0
0`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000c@3oool3000008`0oooo002;
0?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0<h0oooo00<00000
0?ooo`3oool0R@3oool008T0oooo0P0000090?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0c`3oool2000008T0oooo00280?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3A0?ooo`800000Q`3oool008H0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`240?ooo`00Q03o
ool2000000`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3D0?ooo`800000Q03o
ool00880oooo0P00000=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0eP3oool2
00000880oooo00200?ooo`8000003`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0=P0oooo0P0000200?ooo`00O`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01`000?oC0?ooo`030000003oool0oooo07d0oooo001m0?ooo`800000
403oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`80003o103oool00`000?l0
oooo0?ooo`3A0?ooo`800000O@3oool007/0oooo0P00000B0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool20000o`<0oooo0P000?oD0?ooo`800000N`3oool007X0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo0P00
0?l40?ooo`80003oe@3oool00`000000oooo0?ooo`1h0?ooo`00N03oool2000001<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`80003o103oool20000omH0oooo0P00001h
0?ooo`00MP3oool2000001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?oo
o`80003o103oool20000omP0oooo0P00001f0?ooo`00M@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool20000o`80oooo0`000?oJ0?ooo`03
0000003oool0oooo07<0oooo001d0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`020?ooo`L0003og03oool00`000000oooo0?ooo`1b0?ooo`00LP3o
ool2000001L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3V0?ooo`800000LP3o
ool00740oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0;0?ooo`800000jP3oool2
00000700oooo001_0?ooo`800000603oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0>/0oooo00<000000?ooo`3oool0K@3oool006h0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool0K03oool006d0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0>d0oooo
00<000000?ooo`3oool0J`3oool006/0oooo0P00000J0?ooo`8000003`3oool00`000000oooo0?oo
o`3^0?ooo`800000J`3oool006X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0?00oooo00<000000?ooo`3oool0J03oool006T0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?40oooo00<000000?oo
o`3oool0I`3oool006P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0?80oooo00<000000?ooo`3oool0IP3oool006H0oooo0P00000M0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0l`3oool2000006H0oooo001U0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3e0?ooo`030000003o
ool0oooo06<0oooo001T0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`3f0?ooo`030000003oool0oooo0680oooo001S0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3g0?ooo`800000HP3oool00640
oooo0P00000O0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0n@3oool00`000000
oooo0?ooo`1O0?ooo`00H03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0nP3oool00`000000oooo0?ooo`1N0?ooo`00G`3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0n`3oool00`000000oooo0?oo
o`1M0?ooo`00G@3oool200000240oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3l
0?ooo`800000G@3oool005`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0?h0oooo00<000000?ooo`3oool0FP3oool005/0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3o
ool0F@3oool005X0oooo00<000000?ooo`3oool08@3oool2000001P0oooo00<000000?ooo`3oool0
o`3oool10?ooo`030000003oool0oooo05P0oooo001I0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool0E`3o
ool005P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0?l0oooo0`3oool00`000000oooo0?ooo`1F0?ooo`00E`3oool00`000000oooo0?ooo`0R0?oo
o`8000006P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo00<000000?ooo`3oool0E@3oool005H0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0
oooo1@3oool00`000000oooo0?ooo`1D0?ooo`00E@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo05<0oooo
001D0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`3o0?ooo`L0oooo00<000000?ooo`3oool0DP3oool00580oooo0P00000V0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0o`3oool80?ooo`030000003oool0oooo0540oooo001A0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?oo
o`T0oooo00<000000?ooo`3oool0D03oool00500oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`1?0?ooo`00
D03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
o`3oool;0?ooo`030000003oool0oooo04h0oooo001?0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`3o0?ooo``0oooo00<000000?ooo`3oool0C@3o
ool004h0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo0?l0oooo3@3oool00`000000oooo0?ooo`1<0?ooo`00C@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3oool>0?ooo`030000003oool0oooo
04/0oooo001<0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool0BP3oool004/0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`190?ooo`00BP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0o`3ooolA0?ooo`030000003oool0oooo04P0oooo00190?ooo`030000003oool0
oooo02L0oooo0P00000S0?ooo`030000003oool0oooo0?l0oooo4P3oool00`000000oooo0?ooo`17
0?ooo`00B03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0o`3ooolC0?ooo`030000003oool0oooo04H0oooo00170?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3o0?oooa@0oooo00<000000?ooo`3o
ool0A@3oool004H0oooo00<000000?ooo`3oool0:03oool2000002D0oooo00<000000?ooo`3oool0
o`3ooolE0?ooo`030000003oool0oooo04@0oooo00160?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?oooaD0oooo00<000000?ooo`3oool0A03o
ool004D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo0?l0oooo5P3oool00`000000oooo0?ooo`130?ooo`00A03oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`030000003oool0oooo
0480oooo00130?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`3o0?oooaP0oooo00<000000?ooo`3oool0@@3oool00480oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo
0?ooo`100?ooo`00@@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o0?oooaX0oooo00<00000
0?ooo`3oool0?`3oool00400oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0X0?oo
o`800000o`3ooolM0?ooo`030000003oool0oooo03h0oooo000o0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0:03oool200000?l0oooo7@3oool00`000000oooo0?ooo`0n0?ooo`00
?`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02T0oooo0P00003o0?oooah0oooo
00<000000?ooo`3oool0?@3oool003h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo0?l0oooo7P3oool00`000000oooo0?ooo`0l0?ooo`00?@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooolO
0?ooo`030000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`3o0?ooob00oooo00<000000?ooo`3oool0>P3oool003/0
oooo00<000000?ooo`3oool0:P3oool2000002d0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`03
0000003oool0oooo03T0oooo000k0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`3o0?ooob40oooo00<000000?ooo`3oool0>@3oool003X0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0oooo8P3o
ool00`000000oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo0?ooo`0Z0?ooo`800000;`3oool0
0`000000oooo0?ooo`3o0?ooob<0oooo00<000000?ooo`3oool0=`3oool003P0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0oooo903oool00`00
0000oooo0?ooo`0f0?ooo`00=`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo03H0oooo000g0?ooo`030000
003oool0oooo02X0oooo0P00000a0?ooo`030000003oool0oooo0?l0oooo9@3oool00`000000oooo
0?ooo`0e0?ooo`00=P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0o`3ooolV0?ooo`030000003oool0oooo03@0oooo000f0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo0?l0oooo9`3oool00`000000oooo0?ooo`0c0?ooo`00=03oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0o`3ooolX0?ooo`03
0000003oool0oooo0380oooo000c0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`3o0?ooobT0oooo00<000000?ooo`3oool0<@3oool003<0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0oooo:@3o
ool00`000000oooo0?ooo`0a0?ooo`00<P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`030000003oool0oooo0300oooo000b0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3o0?oo
obX0oooo00<000000?ooo`3oool0<03oool00340oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000oooo0?ooo`0_0?ooo`00
<03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
o`3oool/0?ooo`030000003oool0oooo02h0oooo000`0?ooo`030000003oool0oooo02X0oooo0P00
000h0?ooo`030000003oool0oooo0?l0oooo;03oool00`000000oooo0?ooo`0^0?ooo`00;`3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0o`3oool]
0?ooo`030000003oool0oooo02d0oooo000_0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool0;@3oool002h0
oooo00<000000?ooo`3oool0:P3oool2000003X0oooo00<000000?ooo`3oool0o`3oool^0?ooo`03
0000003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool0;03oool002`0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0oooo;`3o
ool00`000000oooo0?ooo`0[0?ooo`00;03oool00`000000oooo0?ooo`0Z0?ooo`800000?03oool0
0`000000oooo0?ooo`3o0?ooobl0oooo00<000000?ooo`3oool0:`3oool002/0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0oooo<03oool00`00
0000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool0o`3ooola0?ooo`030000003oool0oooo02T0oooo000Z0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3o0?oooc40oooo
00<000000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo0?l0oooo<P3oool00`000000oooo0?ooo`0X0?ooo`00:@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3ooolb
0?ooo`030000003oool0oooo02P0oooo000Y0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`3o0?oooc<0oooo00<000000?ooo`3oool09`3oool002P0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0
oooo=03oool00`000000oooo0?ooo`0V0?ooo`00:03oool00`000000oooo0?ooo`0Y0?ooo`800000
@@3oool00`000000oooo0?ooo`3o0?oooc@0oooo00<000000?ooo`3oool09P3oool002L0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0?l0oooo=@3o
ool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0o`3ooole0?ooo`030000003oool0oooo02D0oooo000V0?oo
o`030000003oool0oooo02T0oooo0P0000130?ooo`030000003oool0oooo0?l0oooo=P3oool00`00
0000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool0o`3ooolf0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?ooocL0oooo
00<000000?ooo`3oool08`3oool002@0oooo00<000000?ooo`3oool0:@3oool2000004D0oooo00<0
00000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo0280oooo000T0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3o0?ooocP0oooo00<00000
0?ooo`3oool08P3oool002<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo0?l0oooo>@3oool00`000000oooo0?ooo`0Q0?ooo`008`3oool00`000000
oooo0?ooo`0X0?ooo`800000AP3oool200000?l0oooo>`3oool00`000000oooo0?ooo`0Q0?ooo`00
8P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04D0oooo0P00003o0?oooc/0oooo
00<000000?ooo`3oool08@3oool00280oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`160?ooo`800000o`3oooll0?ooo`030000003oool0oooo0200oooo000R0?ooo`030000003oool0
oooo02L0oooo0P0000180?ooo`800000o`3oooll0?ooo`030000003oool0oooo0200oooo000Q0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0A`3oool200000?l0oooo?03oool00`00
0000oooo0?ooo`0P0?ooo`008@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0o`3oooll0?ooo`030000003oool0oooo01l0oooo000P0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`3o0?ooocd0oooo
00<000000?ooo`3oool07P3oool00200oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo0?l0oooo?@3oool00`000000oooo0?ooo`0N0?ooo`007`3oool0
0`000000oooo0?ooo`0W0?ooo`800000B`3oool00`000000oooo0?ooo`3o0?oooch0oooo00<00000
0?ooo`3oool07@3oool001l0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo0?l0oooo?P3oool00`000000oooo0?ooo`0M0?ooo`007P3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`03
0000003oool0oooo01`0oooo000N0?ooo`030000003oool0oooo02H0oooo0P00001=0?ooo`030000
003oool0oooo0?l0oooo?`3oool00`000000oooo0?ooo`0L0?ooo`007@3oool00`000000oooo0?oo
o`0U0?ooo`80o`0000<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooocl0oooo00<0
00000?ooo`3oool0703oool001d0oooo00<000000?ooo`3oool0903oool40?l004h0oooo00<00000
0?ooo`3oool0o`3ooom00?ooo`030000003oool0oooo01/0oooo000M0?ooo`030000003oool0oooo
02<0oooo1P3o001=0?ooo`030000003oool0oooo0?l0oooo@03oool00`000000oooo0?ooo`0K0?oo
o`00703oool00`000000oooo0?ooo`0T0?ooo`H0o`00C@3oool00`000000oooo0?ooo`3o0?oood40
oooo00<000000?ooo`3oool06P3oool001`0oooo00<000000?ooo`3oool09@3oool40?l004h0oooo
00<000000?ooo`3oool0o`3ooom10?ooo`030000003oool0oooo01X0oooo000L0?ooo`030000003o
ool0oooo02@0oooo0P0000020?l004l0oooo00<000000?ooo`3oool0o`3ooom10?ooo`030000003o
ool0oooo01X0oooo000K0?ooo`030000003oool0oooo02D0oooo00D000000?ooo`3oool0oooo003o
001>0?ooo`030000003oool0oooo0?l0oooo@P3oool00`000000oooo0?ooo`0I0?ooo`006`3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<00?l00?ooo`3oool0C03oool0
0`000000oooo0?ooo`3o0?oood80oooo00<000000?ooo`3oool06@3oool001/0oooo00<000000?oo
o`3oool08`3oool2000000D0oooo00<00?l00?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?oo
od80oooo00<000000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`040?ooo`03003o003oool0oooo04/0oooo00<000000?ooo`3oool0o`3ooom30?ooo`03
0000003oool0oooo01P0oooo000J0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
1P3oool00`00o`00oooo0?ooo`1:0?ooo`030000003oool0oooo0?l0oooo@`3oool00`000000oooo
0?ooo`0H0?ooo`006P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00H0oooo00<0
0?l00?ooo`3oool0BP3oool00`000000oooo0?ooo`3o0?oood<0oooo00<000000?ooo`3oool0603o
ool001T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`03003o003oool0
oooo04T0oooo00<000000?ooo`3oool0o`3ooom40?ooo`030000003oool0oooo01L0oooo000I0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool02@3oool00`00o`00oooo0?ooo`190?oo
o`030000003oool0oooo0?l0ooooA03oool00`000000oooo0?ooo`0G0?ooo`00603oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00X0oooo00<00?l00?ooo`3oool0B03oool00`000000
oooo0?ooo`3o0?oood@0oooo00<000000?ooo`3oool05`3oool001P0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0;0?ooo`0300000000o`00oooo04P0oooo00<000000?ooo`3oool0
o`3ooom50?ooo`030000003oool0oooo01H0oooo000H0?ooo`030000003oool0oooo0240oooo0P00
000>0?ooo`03003o003oool0oooo04L0oooo00<000000?ooo`3oool0o`3ooom50?ooo`030000003o
ool0oooo01H0oooo000G0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02@3oool5
0000o`03003o003oool0oooo04H0oooo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0
oooo01D0oooo000G0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02`3oool20000
o`80oooo00<00?l00?ooo`3oool0AP3oool00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?oo
o`3oool05@3oool001L0oooo00<000000?ooo`3oool0803oool2000000h0oooo0P000?l20?ooo`03
003o003oool0oooo04D0oooo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo01D0
oooo000F0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool03@3oool20000o`030?oo
o`000?l00?l004L0oooo00<000000?ooo`3oool0o`3ooom70?ooo`030000003oool0oooo01@0oooo
000F0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool03P3oool40000o`030?ooo`00
o`00oooo04D0oooo00<000000?ooo`3oool0o`3ooom70?ooo`030000003oool0oooo01@0oooo000F
0?ooo`030000003oool0oooo01l0oooo0P00000@0?ooo`80003o00@0oooo0000o`3oool00?l0AP3o
ool00`000000oooo0?ooo`3o0?ooodL0oooo00<000000?ooo`3oool0503oool001D0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0@0?ooo`80003o0P3oool00`000?l00?l00?ooo`14
0?ooo`030000003oool0oooo0?l0ooooB03oool00`000000oooo0?ooo`0C0?ooo`005@3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo0100oooo1P000?l00`00o`00oooo0?ooo`130?oo
o`030000003oool0oooo0?l0ooooB03oool00`000000oooo0?ooo`0C0?ooo`005@3oool00`000000
oooo0?ooo`0N0?ooo`8000006@3oool00`00o`00oooo0?ooo`120?ooo`030000003oool0oooo0?l0
ooooB03oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo01P0oooo00<00?l00?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?ooodT0oooo
00<000000?ooo`3oool04P3oool001@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0J0?ooo`03003o003oool0oooo0440oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003o
ool0oooo0180oooo000D0?ooo`030000003oool0oooo01d0oooo0P00000L0?ooo`0300000000o`00
oooo0440oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo0180oooo000D0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`00o`00oooo0?ooo`100?oo
o`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0B0?ooo`00503oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01h0oooo00<00?l00?ooo`3oool0?`3oool00`000000
oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool04P3oool001@0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0N0?ooo`03003o003oool0oooo03l0oooo00<000000?ooo`3oool0
o`3ooom90?ooo`030000003oool0oooo0180oooo000C0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0803oool00`00o`00oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0ooooBP3o
ool00`000000oooo0?ooo`0A0?ooo`004`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo0240oooo00<00?l00?ooo`3oool0?@3oool200000?l0ooooC03oool00`000000oooo0?ooo`0A
0?ooo`004P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0280oooo00<00?l00?oo
o`3oool0?03oool200000?l0ooooC03oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo02<0oooo00<00?l00?ooo`3oool0?03oool200000?l0
ooooC@3oool00`000000oooo0?ooo`0@0?ooo`004P3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo02D0oooo00<00?l00?ooo`3oool0>`3oool200000?l0ooooC@3oool00`000000oooo
0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02D0oooo00<0
0?l00?ooo`3oool0>`3oool200000?l0ooooC@3oool00`000000oooo0?ooo`0@0?ooo`004@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02L0oooo00<00?l00?ooo`3oool0>P3oool2
00000?l0ooooCP3oool00`000000oooo0?ooo`0?0?ooo`004@3oool00`000000oooo0?ooo`0I0?oo
o`800000:@3oool00`0000000?l00?ooo`0j0?ooo`800000o`3ooom>0?ooo`030000003oool0oooo
00l0oooo000A0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0:@3oool00`00o`00
oooo0?ooo`0i0?ooo`800000o`3ooom>0?ooo`030000003oool0oooo00l0oooo000A0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0:`3oool00`00o`00oooo0?ooo`0h0?ooo`030000
003oool0oooo0?l0ooooC@3oool00`000000oooo0?ooo`0?0?ooo`004@3oool00`000000oooo0?oo
o`0G0?ooo`800000;@3oool00`00o`00oooo0?ooo`0h0?ooo`030000003oool0oooo0?l0ooooC@3o
ool00`000000oooo0?ooo`0?0?ooo`00403oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo02d0oooo00<00?l00?ooo`3oool0=`3oool00`000000oooo0?ooo`3o0?ooodh0oooo00<00000
0?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0^0?oo
o`03003o003oool0oooo03L0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo
00h0oooo000@0?ooo`030000003oool0oooo01H0oooo0P00000a0?ooo`03003o003oool0oooo03H0
oooo00<000000?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0<03oool00`00o`00oooo0?ooo`0f0?ooo`030000
003oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`0>0?ooo`00403oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0380oooo00<00?l00?ooo`3oool0=@3oool00`000000oooo0?oo
o`3o0?ooodh0oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0b0?ooo`03003o003oool0oooo03D0oooo00<000000?ooo`3oool0o`3ooom>
0?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0=03oool00`00o`00oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0ooooC`3oool00`00
0000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03D0
oooo00<00?l00?ooo`3oool0=03oool00`000000oooo0?ooo`3o0?ooodl0oooo00<000000?ooo`3o
ool03@3oool000l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0f0?ooo`03003o
003oool0oooo03<0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`030000003oool0oooo00d0oooo
000?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0=`3oool00`0000000?l00?oo
o`0c0?ooo`030000003oool0oooo0?l0ooooC`3oool00`000000oooo0?ooo`0=0?ooo`003`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03T0oooo00<00?l00?ooo`3oool0<P3oool0
0`000000oooo0?ooo`3o0?ooodl0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0j0?ooo`03003o003oool0oooo0340oooo00<000000?oo
o`3oool0o`3ooom?0?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0>`3oool00`00o`00oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0
ooooD03oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo03d0oooo00<00?l00?ooo`3oool0<03oool00`000000oooo0?ooo`3o0?oooe00oooo
00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0m0?ooo`03003o003oool0oooo0300oooo00<000000?ooo`3oool0o`3ooom@0?ooo`030000003o
ool0oooo00`0oooo000>0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0?`3oool0
0`00o`00oooo0?ooo`0_0?ooo`030000003oool0oooo0?l0ooooD03oool00`000000oooo0?ooo`0<
0?ooo`003P3oool00`000000oooo0?ooo`0?0?ooo`800000@@3oool00`00o`00oooo0?ooo`0_0?oo
o`030000003oool0oooo0?l0ooooD03oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0440oooo00<00?l00?ooo`3oool0;P3oool00`000000
oooo0?ooo`3o0?oooe00oooo00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`120?ooo`03003o003oool0oooo02h0oooo00<000000?ooo`3oool0
o`3ooomA0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo00h0oooo0P00
00150?ooo`03003o003oool0oooo02d0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`030000003o
ool0oooo00/0oooo000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0A03oool0
0`0000000?l00?ooo`0]0?ooo`030000003oool0oooo0?l0ooooD@3oool00`000000oooo0?ooo`0;
0?ooo`003@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04H0oooo00<00?l00?oo
o`3oool0;03oool00`000000oooo0?ooo`3o0?oooe40oooo00<000000?ooo`3oool02`3oool000d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`160?ooo`0300000000o`00oooo02`0
oooo00<000000?ooo`3oool0o`3ooomA0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0B03oool00`00o`00oooo0?ooo`0[0?ooo`030000
003oool0oooo0?l0ooooD@3oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo04X0oooo00<00?l00?ooo`3oool0:P3oool00`000000oooo0?oo
o`3o0?oooe40oooo00<000000?ooo`3oool02`3oool000d0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`1:0?ooo`03003o003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooomA
0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0C03oool00`00o`00oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0ooooD@3oool00`00
0000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04d0
oooo00<00?l00?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oooe80oooo00<000000?ooo`3o
ool02P3oool000`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1>0?ooo`03003o
003oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`030000003oool0oooo00X0oooo
000<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0C`3oool00`00o`00oooo0?oo
o`0X0?ooo`030000003oool0oooo0?l0ooooDP3oool00`000000oooo0?ooo`0:0?ooo`00303oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0540oooo00<00?l00?ooo`3oool09`3oool0
0`000000oooo0?ooo`3o0?oooe80oooo00<000000?ooo`3oool02P3oool000`0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`1A0?ooo`03003o003oool0oooo02L0oooo00<000000?oo
o`3oool0o`3ooomB0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0D`3oool00`00o`00oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0
ooooDP3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo05@0oooo00<00000003o003oool09P3oool00`000000oooo0?ooo`3o0?oooe80oooo
00<000000?ooo`3oool02P3oool000`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`1E0?ooo`03003o003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`030000003o
ool0oooo00X0oooo000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0EP3oool0
0`0000000?l00?ooo`0U0?ooo`030000003oool0oooo0?l0ooooDP3oool00`000000oooo0?ooo`0:
0?ooo`00303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05P0oooo00<00?l00?oo
o`3oool08`3oool200000?l0ooooE03oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo05T0oooo00<00?l00?ooo`3oool08P3oool200000?l0
ooooE03oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo05X0oooo00<00?l00?ooo`3oool08P3oool200000?l0ooooE03oool00`000000oooo
0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`020?ooo`800000G@3oool00`00o`00oooo0?oo
o`0Q0?ooo`800000o`3ooomD0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0G03oool00`00o`00oooo0?ooo`0Q0?ooo`800000o`3ooomD
0?ooo`030000003oool0oooo00X0oooo000<0?ooo`050000003oool0oooo0?ooo`000000H03oool0
0`00o`00oooo0?ooo`0P0?ooo`800000o`3ooomD0?ooo`030000003oool0oooo00X0oooo000<0?oo
o`050000003oool0oooo0?ooo`000000H03oool00`00o`00oooo0?ooo`0P0?ooo`800000o`3ooomD
0?ooo`030000003oool0oooo00X0oooo000<0?ooo`040000003oool0oooo00000680oooo00<00?l0
0?ooo`3oool07`3oool200000?l0ooooE03oool00`000000oooo0?ooo`0:0?ooo`00303oool00`00
0000oooo0000001S0?ooo`0300000000o`00oooo01l0oooo0P00003o0?oooe@0oooo00<000000?oo
o`3oool02P3oool000/0oooo00@000000?ooo`3oool00000I03oool00`00o`00oooo0?ooo`0N0?oo
o`800000o`3ooomD0?ooo`030000003oool0oooo00X0oooo000;0?ooo`800?l000<000000?ooo`3o
ool0H`3oool00`0000000?l00?ooo`0N0?ooo`030000003oool0oooo06<0oooo0P00o`3]0?ooo`03
0000003oool0oooo00X0oooo000:0?ooo`@00?l0IP3oool00`00o`00oooo0?ooo`0M0?ooo`030000
003oool0oooo0680oooo1000o`3/0?ooo`030000003oool0oooo00X0oooo00090?ooo`H00?l0IP3o
ool00`00o`00oooo0?ooo`0L0?ooo`030000003oool0oooo0640oooo1P00o`3[0?ooo`030000003o
ool0oooo00X0oooo00090?ooo`H00?l0IP3oool00`00o`00oooo0?ooo`0L0?ooo`030000003oool0
oooo0640oooo1P00o`3[0?ooo`030000003oool0oooo00X0oooo000:0?ooo`@00?l000<000000?oo
o`3oool0I@3oool00`00o`00oooo0?ooo`0K0?ooo`030000003oool0oooo0640oooo00<00000003o
0000o`000P00o`3/0?ooo`030000003oool0oooo00X0oooo000;0?ooo`800?l00P3oool3000006@0
oooo00<00?l00?ooo`3oool06`3oool00`000000oooo0?ooo`1O0?ooo`8000000P3oool2003o0>d0
oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool0103oool2000006<0oooo
00<00?l00?ooo`3oool06P3oool00`000000oooo0?ooo`1M0?ooo`800000l`3oool00`000000oooo
0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`050?ooo`<00000H03oool00`00o`00oooo0?oo
o`0J0?ooo`030000003oool0oooo05/0oooo0P00003e0?ooo`030000003oool0oooo00X0oooo000<
0?ooo`030000003oool0oooo00P0oooo0P00001O0?ooo`03003o003oool0oooo01T0oooo00<00000
0?ooo`3oool0F@3oool200000?L0oooo00<000000?ooo`3oool02P3oool000`0oooo00<000000?oo
o`3oool02P3oool3000005`0oooo00<00?l00?ooo`3oool06@3oool00`000000oooo0?ooo`1G0?oo
o`800000n@3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`0<0?ooo`<0
0000F`3oool00`00o`00oooo0?ooo`0H0?ooo`030000003oool0oooo05D0oooo0P00003k0?ooo`03
0000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo00l0oooo0`00001H0?ooo`030000
0000o`00oooo01P0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3k0?ooo`030000
003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0140oooo0`00001G0?ooo`03003o003o
ool0oooo01L0oooo00<000000?ooo`3oool0DP3oool200000?h0oooo00<000000?ooo`3oool02P3o
ool000`0oooo00<000000?ooo`3oool0503oool2000005D0oooo00<00000003o003oool05`3oool0
0`000000oooo0?ooo`1@0?ooo`800000o`3oool10?ooo`030000003oool0oooo00X0oooo000<0?oo
o`030000003oool0oooo01H0oooo0`00001C0?ooo`03003o003oool0oooo01H0oooo00<000000?oo
o`3oool0CP3oool200000?l0oooo0`3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000
oooo0?ooo`0I0?ooo`800000DP3oool00`00o`00oooo0?ooo`0E0?ooo`030000003oool0oooo04`0
oooo0P00003o0?ooo`D0oooo00<000000?ooo`3oool02P3oool000`0oooo00<000000000o`000?l0
0P000?l30?ooo`@0003o4P3oool3000004l0oooo00<00?l00?ooo`3oool05@3oool00`000000oooo
0?ooo`1:0?ooo`8000007@3oool40000onD0oooo00<000000?ooo`3oool02P3oool000`0oooo00@0
00000?ooo`000?l0003o1@3oool20000oaH0oooo0P00001>0?ooo`03003o003oool0oooo01@0oooo
00<000000?ooo`3oool0B03oool2000001d0oooo0`000?l20?ooo`80003oi03oool00`000000oooo
0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`070000oaT0oooo0`00001;0?ooo`03003o003o
ool0oooo01@0oooo00<000000?ooo`3oool0AP3oool2000001l0oooo0P000?l40?ooo`80003oh`3o
ool00`000000oooo0?ooo`0:0?ooo`00303oool010000000oooo0?ooo`3oool20000o`80oooo0P00
0?lL0?ooo`800000BP3oool00`00o`00oooo0?ooo`0C0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool07`3oool20000o`D0oooo0P000?oR0?ooo`030000003oool0oooo00X0oooo000<
0?ooo`040000003oool0oooo0?ooo`<0003o00<0oooo0000o`000?l07P3oool3000004L0oooo00<0
0?l00?ooo`3oool04`3oool00`000000oooo0?ooo`130?ooo`8000008P3oool20000o`D0oooo0P00
0?oR0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0080oooo0P000?l0
0`3oool0003o0000o`0P0?ooo`<00000AP3oool00`00o`00oooo0?ooo`0B0?ooo`030000003oool0
oooo0440oooo0P00000U0?ooo`80003o103oool20000on80oooo00<000000?ooo`3oool02P3oool0
00`0oooo00<000000?ooo`3oool00`3oool30000ob@0oooo0`0000130?ooo`0300000000o`00oooo
0180oooo00<000000?ooo`3oool0?`3oool2000002P0oooo0P000?l20?ooo`<0003ohP3oool00`00
0000oooo0?ooo`0:0?ooo`00303oool010000000oooo0?ooo`3oool50000obH0oooo0`0000120?oo
o`03003o003oool0oooo0140oooo00<000000?ooo`3oool0?@3oool2000002/0oooo1@000?oS0?oo
o`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo02l0oooo0`00000o0?ooo`03
00000000o`00oooo0140oooo00<000000?ooo`3oool0>`3oool200000?l0oooo5P3oool00`000000
oooo0?ooo`0:0?ooo`003@3oool00`000000oooo0?ooo`0`0?ooo`<00000?P3oool00`00o`00oooo
0?ooo`0@0?ooo`030000003oool0oooo03T0oooo0P00003o0?oooaL0oooo00<000000?ooo`3oool0
2`3oool000d0oooo00<000000?ooo`3oool0<`3oool3000003/0oooo00<00000003o003oool0403o
ool00`000000oooo0?ooo`0g0?ooo`800000o`3ooolI0?ooo`030000003oool0oooo00/0oooo000=
0?ooo`030000003oool0oooo03D0oooo0`00000j0?ooo`03003o003oool0oooo00l0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?oooaT0oooo00<000000?ooo`3oool02`3oool0
00d0oooo00<000000?ooo`3oool0>03oool3000003P0oooo00<00?l00?ooo`3oool03P3oool00`00
0000oooo0?ooo`0d0?ooo`800000o`3ooolL0?ooo`030000003oool0oooo00/0oooo000=0?ooo`03
0000003oool0oooo03X0oooo0`00000f0?ooo`03003o003oool0oooo00h0oooo00<000000?ooo`3o
ool0<P3oool200000?l0oooo7P3oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo
0?ooo`0m0?ooo`800000=@3oool00`00o`00oooo0?ooo`0=0?ooo`030000003oool0oooo0300oooo
0P00003o0?ooob00oooo00<000000?ooo`3oool02`3oool000d0oooo00<000000?ooo`3oool0?`3o
ool300000380oooo00<00?l00?ooo`3oool03@3oool00`000000oooo0?ooo`0^0?ooo`800000o`3o
oolR0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0440oooo0`00000a
0?ooo`03003o003oool0oooo00`0oooo00<000000?ooo`3oool0;03oool200000?l0oooo903oool0
0`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`140?ooo`<00000;P3oool00`00
o`00oooo0?ooo`0<0?ooo`030000003oool0oooo02X0oooo0P00003o0?ooobH0oooo00<000000?oo
o`3oool02`3oool000h0oooo00<000000?ooo`3oool0A@3oool3000002d0oooo00<00?l00?ooo`3o
ool02`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo9@3oool00`000000
oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`180?ooo`<00000:P3oool00`0000000?l0
0?ooo`0;0?ooo`030000003oool0oooo02L0oooo0P00003o0?ooobP0oooo00<000000?ooo`3oool0
303oool000h0oooo00<000000?ooo`3oool0BP3oool3000002T0oooo00<00?l00?ooo`3oool02@3o
ool2000002L0oooo0P00003o0?ooobX0oooo00<000000?ooo`3oool0303oool000h0oooo00<00000
0?ooo`3oool0C@3oool3000002H0oooo00<00000003o003oool02@3oool2000002D0oooo0P00003o
0?ooob`0oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool0C`3oool30000
02D0oooo00<00?l00?ooo`3oool0203oool2000002<0oooo0P00003o0?ooobh0oooo00<000000?oo
o`3oool0303oool000h0oooo00<000000?ooo`3oool0DP3oool300000280oooo00<00000003o003o
ool0203oool200000240oooo0P00003o0?oooc00oooo00<000000?ooo`3oool0303oool000l0oooo
00<000000?ooo`3oool0D`3oool300000240oooo00<00?l00?ooo`3oool01`3oool2000001l0oooo
0P00003o0?oooc40oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool0EP3o
ool3000001l0oooo00<00?l00?ooo`3oool01P3oool2000001d0oooo0P00003o0?oooc<0oooo00<0
00000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool0F03oool3000001d0oooo00<00?l0
0?ooo`3oool01P3oool2000001`0oooo00<000000?ooo`3oool0o`3ooolc0?ooo`030000003oool0
oooo00d0oooo000?0?ooo`030000003oool0oooo05X0oooo1000000K0?ooo`03003o003oool0oooo
00D0oooo0P00000J0?ooo`800000o`3ooolf0?ooo`030000003oool0oooo00d0oooo000?0?ooo`03
0000003oool0oooo05d0oooo0`00000I0?ooo`03003o003oool0oooo00D0oooo0P00000H0?ooo`80
0000o`3ooolh0?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo05l0oooo
1000000G0?ooo`03003o003oool0oooo00@0oooo0P00000F0?ooo`800000o`3ooolj0?ooo`030000
003oool0oooo00d0oooo000@0?ooo`030000003oool0oooo0640oooo0`00000E0?ooo`0300000000
o`00oooo00@0oooo0P00000D0?ooo`800000o`3ooolk0?ooo`030000003oool0oooo00h0oooo000@
0?ooo`030000003oool0oooo06<0oooo1000000C0?ooo`03003o003oool0oooo00<0oooo0P00000B
0?ooo`800000o`3ooolm0?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000003oool0oooo
06H0oooo0`00000A0?ooo`0300000000o`00oooo00<0oooo00<000000?ooo`3oool03`3oool20000
0?l0oooo?`3oool00`000000oooo0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`1X0?ooo`<0
0000403oool00`00o`00oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo0P00003o0?oood40
oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool0J`3oool3000000d0oooo
00<00000003o003oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo
@@3oool00`000000oooo0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`1]0?ooo`<00000303o
ool01@00o`00oooo0?ooo`3oool0000000`0oooo0P00003o0?oood@0oooo00<000000?ooo`3oool0
3P3oool00140oooo00<000000?ooo`3oool0K`3oool3000000T0oooo00D00000003o003oool0oooo
0000000:0?ooo`800000o`3ooom50?ooo`030000003oool0oooo00l0oooo000A0?ooo`030000003o
ool0oooo0740oooo0`0000080?ooo`04003o003oool0oooo000000P0oooo0P00003o0?ooodL0oooo
00<000000?ooo`3oool03`3oool00140oooo00<000000?ooo`3oool0L`3oool4000000H0oooo00<0
0?l00?ooo`0000001P3oool200000?l0ooooB@3oool00`000000oooo0?ooo`0?0?ooo`004@3oool0
0`000000oooo0?ooo`1f0?ooo`<00000103oool00`00o`00oooo000000040?ooo`800000o`3ooom:
0?ooo`030000003oool0oooo0100oooo000A0?ooo`030000003oool0oooo07P0oooo100000020?oo
o`04003o003o0000o`000?ooo`800000o`3ooom<0?ooo`030000003oool0oooo0100oooo000A0?oo
o`030000003oool0oooo07/0oooo0`0000040?l00?l0ooooCP3oool00`000000oooo0?ooo`0@0?oo
o`004P3oool00`000000oooo0?ooo`1l0?ooo`H0o`00o`3ooom=0?ooo`030000003oool0oooo0100
oooo000B0?ooo`030000003oool0oooo07`0oooo1P3o003o0?ooodd0oooo00<000000?ooo`3oool0
403oool001<0oooo00<000000?ooo`3oool0O03oool40?l000@00000o`3ooom:0?ooo`030000003o
ool0oooo0100oooo000C0?ooo`030000003oool0oooo07d0oooo0P3o00001000o`00oooo0?ooo`3o
ool300000?l0ooooA`3oool00`000000oooo0?ooo`0A0?ooo`004`3oool00`000000oooo0?ooo`1m
0?ooo`030000003oool00?l000D0oooo1000003o0?oood@0oooo00<000000?ooo`3oool04@3oool0
01@0oooo00<000000?ooo`3oool0O03oool010000000oooo00000000o`070?ooo`<00000o`3ooom2
0?ooo`030000003oool0oooo0140oooo000D0?ooo`030000003oool0oooo07`0oooo00@000000?oo
o`3oool00?l02@3oool300000?l0oooo?`3oool00`000000oooo0?ooo`0B0?ooo`00503oool00`00
0000oooo0?ooo`1l0?ooo`050000003oool0oooo0?ooo`00o`002P3oool400000?l0oooo?03oool0
0`000000oooo0?ooo`0B0?ooo`00503oool00`000000oooo0?ooo`1l0?ooo`050000003oool0oooo
0?ooo`00o`003@3oool300000?l0oooo>P3oool00`000000oooo0?ooo`0B0?ooo`00503oool00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo0080oooo00<00?l00?ooo`3oool0303oool40000
0?l0oooo=`3oool00`000000oooo0?ooo`0B0?ooo`00503oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo0080oooo00<00?l00?ooo`3oool03`3oool300000?l0oooo=@3oool00`000000
oooo0?ooo`0B0?ooo`005@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00<0oooo
00<00?l00?ooo`3oool0403oool400000?l0oooo<@3oool00`000000oooo0?ooo`0C0?ooo`005@3o
ool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00<0oooo00<00?l00?ooo`3oool04`3o
ool300000?l0oooo;`3oool00`000000oooo0?ooo`0C0?ooo`005@3oool00`000000oooo0?ooo`1k
0?ooo`030000003oool0oooo00@0oooo00<00?l00?ooo`3oool0503oool400000?l0oooo;03oool0
0`000000oooo0?ooo`0C0?ooo`005P3oool00`000000oooo0?ooo`1h0?ooo`P0003o00<0oooo0000
0000o`001P000?lB0?ooo`<00000o`3ooolY0?ooo`030000003oool0oooo01@0oooo000F0?ooo`03
0000003oool0oooo07T0oooo0P000?l50?ooo`040000o`3oool00?l00000o`D0oooo00<0003o0?oo
o`3oool04@3oool300000?l0oooo9`3oool00`000000oooo0?ooo`0D0?ooo`005P3oool00`000000
oooo0?ooo`1j0?ooo`80003o00<0oooo0000o`3oool00`3oool01@0000000?l00000o`3oool0003o
01T0oooo0`00003o0?ooob@0oooo00<000000?ooo`3oool0503oool001L0oooo00<000000?ooo`3o
ool0N@3oool20000o`030?ooo`000?l0oooo00@0oooo00@00?l00000o`3oool0003o6`3oool30000
0?l0oooo8@3oool00`000000oooo0?ooo`0E0?ooo`005`3oool00`000000oooo0?ooo`1i0?ooo`D0
003o103oool00`0000000?l00000o`020000oa`0oooo1000003o0?oooah0oooo00<000000?ooo`3o
ool05@3oool001L0oooo00<000000?ooo`3oool0N@3oool20000o`80oooo00<0003o0?ooo`3oool0
0P3oool01@000?l00?l00?ooo`3oool0003o01l0oooo0`00003o0?oooa`0oooo00<000000?ooo`3o
ool05@3oool001P0oooo00<000000?ooo`3oool0N03oool00`000000003o0000o`030?ooo`060000
o`3oool0oooo0?ooo`000?l00?l00`3oool00`000?l0oooo0?ooo`0M0?ooo`@00000o`3ooolH0?oo
o`030000003oool0oooo01H0oooo000H0?ooo`030000003oool0oooo07P0oooo20000?l0103oool0
003o0000o`00o`050000ob40oooo0`00003o0?oooaH0oooo00<000000?ooo`3oool05P3oool001T0
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`090?ooo`03003o003oool0oooo02D0
oooo1000003o0?oooa<0oooo00<000000?ooo`3oool05P3oool001T0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`090?ooo`03003o003oool0oooo02P0oooo0`00003o0?oooa00oooo
00<000000?ooo`3oool05`3oool001T0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`0:0?ooo`03003o003oool0oooo02T0oooo0`00003o0?ooo`h0oooo00<000000?ooo`3oool05`3o
ool001X0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0:0?ooo`03003o003oool0
oooo02`0oooo0`00003o0?ooo`X0oooo00<000000?ooo`3oool0603oool001X0oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`0;0?ooo`03003o003oool0oooo02d0oooo0`00003o0?oo
o`P0oooo00<000000?ooo`3oool0603oool001X0oooo00<000000?ooo`3oool0M@3oool2000000d0
oooo00<00000003o003oool0<03oool300000?l0oooo1@3oool00`000000oooo0?ooo`0H0?ooo`00
6`3oool00`000000oooo0?ooo`1d0?ooo`8000003P3oool00`00o`00oooo0?ooo`0a0?ooo`<00000
o`3oool20?ooo`030000003oool0oooo01T0oooo000K0?ooo`030000003oool0oooo07@0oooo0P00
000>0?ooo`0300000000o`00oooo03@0oooo0`00003n0?ooo`030000003oool0oooo01T0oooo000K
0?ooo`030000003oool0oooo07@0oooo0P00000?0?ooo`03003o003oool0oooo03D0oooo0`00003l
0?ooo`030000003oool0oooo01T0oooo000L0?ooo`030000003oool0oooo07<0oooo0P00000?0?oo
o`0300000000o`00oooo03L0oooo1000003h0?ooo`030000003oool0oooo01X0oooo000L0?ooo`03
0000003oool0oooo07<0oooo0P00000@0?ooo`03003o003oool0oooo03T0oooo0`00003f0?ooo`03
0000003oool0oooo01X0oooo000L0?ooo`030000003oool0oooo07<0oooo0P00000A0?ooo`03003o
003oool0oooo03X0oooo0`00003d0?ooo`030000003oool0oooo01X0oooo000M0?ooo`030000003o
ool0oooo0780oooo0P00000A0?ooo`03003o003oool0oooo03d0oooo0`00003`0?ooo`030000003o
ool0oooo01/0oooo000M0?ooo`030000003oool0oooo0780oooo0P00000B0?ooo`03003o003oool0
oooo03h0oooo0`00003^0?ooo`030000003oool0oooo01/0oooo000N0?ooo`030000003oool0oooo
0740oooo0P00000B0?ooo`03003o003oool0oooo0440oooo0`00003[0?ooo`030000003oool0oooo
01/0oooo000N0?ooo`030000003oool0oooo0740oooo0P00000C0?ooo`03003o003oool0oooo0480
oooo0`00003X0?ooo`030000003oool0oooo01`0oooo000N0?ooo`030000003oool0oooo0740oooo
00<000000?ooo`3oool04P3oool00`00o`00oooo0?ooo`150?ooo`<00000i@3oool00`000000oooo
0?ooo`0L0?ooo`007`3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo01<0oooo00<0
0?l00?ooo`3oool0AP3oool300000>80oooo00<000000?ooo`3oool07@3oool001l0oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`0C0?ooo`0300000000o`00oooo04T0oooo0`00003O
0?ooo`030000003oool0oooo01d0oooo000P0?ooo`030000003oool0oooo06l0oooo00<000000?oo
o`3oool0503oool00`00o`00oooo0?ooo`1:0?ooo`<00000g03oool00`000000oooo0?ooo`0N0?oo
o`00803oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo01@0oooo00<00000003o003o
ool0C03oool300000=X0oooo00<000000?ooo`3oool07P3oool00240oooo00<000000?ooo`3oool0
KP3oool00`000000oooo0?ooo`0E0?ooo`03003o003oool0oooo04h0oooo0`00003F0?ooo`030000
003oool0oooo01l0oooo000Q0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool05@3o
ool00`0000000?l00?ooo`1@0?ooo`<00000e03oool00`000000oooo0?ooo`0O0?ooo`008P3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo01H0oooo00<00?l00?ooo`3oool0DP3oool3
00000=00oooo00<000000?ooo`3oool0803oool00280oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`0G0?ooo`03003o003oool0oooo05<0oooo0`00003>0?ooo`030000003oool0oooo
0200oooo000S0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool05`3oool00`00o`00
oooo0?ooo`1F0?ooo`<00000b`3oool00`000000oooo0?ooo`0P0?ooo`008`3oool00`000000oooo
0?ooo`1/0?ooo`030000003oool0oooo01P0oooo00<00?l00?ooo`3oool0E`3oool300000<P0oooo
00<000000?ooo`3oool08@3oool002<0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?oo
o`0H0?ooo`03003o003oool0oooo05X0oooo0`0000350?ooo`030000003oool0oooo0240oooo000T
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool06@3oool00`00o`00oooo0?ooo`1K
0?ooo`<00000`P3oool00`000000oooo0?ooo`0R0?ooo`00903oool00`000000oooo0?ooo`1[0?oo
o`030000003oool0oooo01T0oooo00<00?l00?ooo`3oool0GP3oool200000<00oooo00<000000?oo
o`3oool08P3oool002D0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0J0?ooo`03
003o003oool0oooo05l0oooo0`00002l0?ooo`030000003oool0oooo02<0oooo000U0?ooo`030000
003oool0oooo06X0oooo00<000000?ooo`3oool06P3oool00`0000000?l00?ooo`1Q0?ooo`<00000
^P3oool00`000000oooo0?ooo`0S0?ooo`009P3oool00`000000oooo0?ooo`1Y0?ooo`030000003o
ool0oooo01/0oooo00<00?l00?ooo`3oool0H`3oool300000;H0oooo00<000000?ooo`3oool0903o
ool002L0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0K0?ooo`0300000000o`00
oooo06D0oooo0`00002d0?ooo`030000003oool0oooo02@0oooo000W0?ooo`030000003oool0oooo
06P0oooo00<000000?ooo`3oool0703oool00`00o`00oooo0?ooo`1W0?ooo`<00000/03oool00`00
0000oooo0?ooo`0U0?ooo`00:03oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01`0
oooo00<00000003o003oool0J@3oool300000:d0oooo00<000000?ooo`3oool09P3oool002P0oooo
00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0M0?ooo`03003o003oool0oooo06/0oooo
0`00002Z0?ooo`030000003oool0oooo02H0oooo000Y0?ooo`030000003oool0oooo06H0oooo00<0
00000?ooo`3oool07P3oool00`00o`00oooo0?ooo`1/0?ooo`<00000Y`3oool00`000000oooo0?oo
o`0W0?ooo`00:P3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo01h0oooo00<00?l0
0?ooo`3oool0K`3oool300000:@0oooo00<000000?ooo`3oool09`3oool002X0oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`0O0?ooo`03003o003oool0oooo0700oooo0`00002Q0?oo
o`030000003oool0oooo02P0oooo000Z0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3o
ool07`3oool00`00o`00oooo0?ooo`1c0?ooo`800000WP3oool00`000000oooo0?ooo`0Y0?ooo`00
:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0200oooo00<00?l00?ooo`3oool0
M03oool3000009/0oooo00<000000?ooo`3oool0:@3oool002/0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`0P0?ooo`03003o003oool0oooo07H0oooo0`00002H0?ooo`030000003o
ool0oooo02X0oooo000/0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool08@3oool0
0`00o`00oooo0?ooo`1h0?ooo`<00000U@3oool00`000000oooo0?ooo`0Z0?ooo`00;03oool00`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo0240oooo00<00000003o003oool0NP3oool30000
0980oooo00<000000?ooo`3oool0:`3oool002d0oooo00<000000?ooo`3oool0HP3oool00`000000
oooo0?ooo`0R0?ooo`03003o003oool0oooo07`0oooo0`00002?0?ooo`030000003oool0oooo02/0
oooo000^0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool08P3oool00`0000000?l0
0?ooo`1n0?ooo`<00000S03oool00`000000oooo0?ooo`0/0?ooo`00;`3oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo02<0oooo00<00?l00?ooo`3oool0P03oool3000008P0oooo00<0
00000?ooo`3oool0;@3oool002l0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0T
0?ooo`03003o003oool0oooo0840oooo0`0000260?ooo`030000003oool0oooo02d0oooo000`0?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool0903oool00`00o`00oooo0?ooo`240?oo
o`800000P`3oool00`000000oooo0?ooo`0^0?ooo`00<03oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo02D0oooo00<00?l00?ooo`3oool0Q@3oool300000800oooo00<000000?ooo`3o
ool0;P3oool00340oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0U0?ooo`03003o
003oool0oooo08P0oooo0P00001m0?ooo`030000003oool0oooo02l0oooo000b0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool09P3oool00`00o`00oooo0?ooo`290?ooo`<00000N@3o
ool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo02H0oooo00<00?l00?ooo`3oool0R`3oool3000007L0oooo00<000000?ooo`3oool0<03oool0
03<0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0W0?ooo`03003o003oool0oooo
08d0oooo0`00001c0?ooo`030000003oool0oooo0340oooo000c0?ooo`030000003oool0oooo05`0
oooo00<000000?ooo`3oool09`3oool00`00o`00oooo0?ooo`2?0?ooo`<00000L@3oool00`000000
oooo0?ooo`0a0?ooo`00=03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo02P0oooo
00<00?l00?ooo`3oool0T@3oool3000006d0oooo00<000000?ooo`3oool0<P3oool003D0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`0X0?ooo`03003o003oool0oooo09<0oooo0`00
001Z0?ooo`030000003oool0oooo03<0oooo000f0?ooo`030000003oool0oooo05P0oooo0P00000[
0?ooo`03003o003oool0oooo09D0oooo0P00001W0?ooo`030000003oool0oooo03@0oooo000f0?oo
o`030000003oool0oooo05P0oooo0P00000[0?ooo`0300000000o`00oooo09L0oooo0`00001T0?oo
o`030000003oool0oooo03@0oooo000g0?ooo`030000003oool0oooo05L0oooo0P00000/0?ooo`03
003o003oool0oooo09T0oooo0P00001Q0?ooo`030000003oool0oooo03D0oooo000h0?ooo`030000
003oool0oooo05H0oooo0P00000]0?ooo`03003o003oool0oooo09X0oooo0`00001N0?ooo`030000
003oool0oooo03D0oooo000h0?ooo`030000003oool0oooo05H0oooo0P00000]0?ooo`03003o003o
ool0oooo09d0oooo0P00001K0?ooo`030000003oool0oooo03H0oooo000i0?ooo`030000003oool0
oooo05D0oooo0P00000^0?ooo`03003o003oool0oooo09h0oooo0`00001G0?ooo`030000003oool0
oooo03L0oooo000j0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0;@3oool00`00
o`00oooo0?ooo`2P0?ooo`<00000E03oool00`000000oooo0?ooo`0h0?ooo`00>`3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo02h0oooo00<00?l00?ooo`3oool0XP3oool300000500
oooo00<000000?ooo`3oool0>@3oool003/0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`0^0?ooo`03003o003oool0oooo0:@0oooo0`00001>0?ooo`030000003oool0oooo03T0oooo
000l0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0;`3oool00`00o`00oooo0?oo
o`2V0?ooo`800000B`3oool00`000000oooo0?ooo`0j0?ooo`00?@3oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo02l0oooo00<00?l00?ooo`3oool0Z03oool3000004L0oooo00<00000
0?ooo`3oool0>`3oool003h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0`0?oo
o`03003o003oool0oooo0:X0oooo0P0000140?ooo`030000003oool0oooo03`0oooo000o0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0<03oool00`00o`00oooo0?ooo`2/0?ooo`<0
0000@03oool00`000000oooo0?ooo`0m0?ooo`00?`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0340oooo00<00?l00?ooo`3oool0[P3oool2000003h0oooo00<000000?ooo`3oool0
?@3oool00400oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0a0?ooo`0300000000
o`00oooo0;00oooo0`00000j0?ooo`030000003oool0oooo03h0oooo00110?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0<P3oool00`00o`00oooo0?ooo`2b0?ooo`800000=`3oool0
0`000000oooo0?ooo`0o0?ooo`00@@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
03<0oooo00<00?l00?ooo`3oool0/`3oool3000003<0oooo00<000000?ooo`3oool0@03oool00480
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0c0?ooo`03003o003oool0oooo0;D0
oooo0`00000a0?ooo`030000003oool0oooo0400oooo00130?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0=03oool00`00o`00oooo0?ooo`2g0?ooo`800000;P3oool00`000000oooo
0?ooo`110?ooo`00A03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo03@0oooo00<0
0?l00?ooo`3oool0^@3oool3000002X0oooo00<000000?ooo`3oool0@P3oool004D0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0e0?ooo`03003o003oool0oooo0;/0oooo0P00000W
0?ooo`030000003oool0oooo04<0oooo00160?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0=@3oool00`00o`00oooo0?ooo`2m0?ooo`<000008`3oool00`000000oooo0?ooo`140?oo
o`00AP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03H0oooo00<00?l00?ooo`3o
ool0_`3oool200000240oooo00<000000?ooo`3oool0A03oool004L0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0f0?ooo`03003o003oool0oooo0<40oooo0`00000M0?ooo`030000
003oool0oooo04D0oooo00180?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0=`3o
ool00`00o`00oooo0?ooo`330?ooo`8000006P3oool00`000000oooo0?ooo`160?ooo`00B@3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo03L0oooo00<00?l00?ooo`3oool0a@3oool3
000001H0oooo00<000000?ooo`3oool0A`3oool004X0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0h0?ooo`03003o003oool0oooo0<L0oooo0P00000C0?ooo`030000003oool0oooo
04P0oooo001;0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0>03oool00`000000
0?l00?ooo`390?ooo`800000403oool00`000000oooo0?ooo`190?ooo`00C03oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo03T0oooo00<00?l00?ooo`3oool0bP3oool3000000`0oooo
00<000000?ooo`3oool0BP3oool004d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0j0?ooo`03003o003oool0oooo0<`0oooo0P0000090?ooo`030000003oool0oooo04/0oooo001>
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0>P3oool00`00o`00oooo0?ooo`3>
0?ooo`<000000P3oool20000o`030?ooo`000000oooo04d0oooo001?0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0>`3oool00`00o`00oooo0?ooo`3@0?ooo`03000000000?l0003o
0080003oC`3oool00500oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0k0?ooo`03
003o003oool0oooo0=00oooo1P000?m>0?ooo`00D03oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo03`0oooo00<00?l00?ooo`3oool0b@3oool6000000H0003oCP3oool00540oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`0l0?ooo`03003o003oool0oooo0<<0oooo1`00
00060?ooo`@0003oC`3oool00580oooo0P00000m0?ooo`030000003oool0oooo03d0oooo00<00?l0
0?ooo`3oool0_03oool7000000/0oooo00@000000?ooo`000?l0003oD03oool005@0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0m0?ooo`03003o003oool0oooo0;H0oooo1`00000@
0?ooo`030000003oool0oooo0580oooo001E0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool0?P3oool00`00o`00oooo0?ooo`2_0?ooo`L000005@3oool00`000000oooo0?ooo`1C0?oo
o`00EP3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03h0oooo00<00?l00?ooo`3o
ool0Z@3oool7000001X0oooo00<000000?ooo`3oool0E03oool005L0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0o0?ooo`03003o003oool0oooo0:80oooo1`00000O0?ooo`030000
003oool0oooo05D0oooo001H0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0@03o
ool00`00o`00oooo0?ooo`2K0?ooo`L00000903oool00`000000oooo0?ooo`1F0?ooo`00F@3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0400oooo00<00?l00?ooo`3oool0U@3oool7
000002T0oooo00<000000?ooo`3oool0E`3oool005X0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`110?ooo`03003o003oool0oooo08h0oooo1`00000^0?ooo`030000003oool0oooo
05P0oooo001K0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0@@3oool00`00o`00
oooo0?ooo`280?ooo`L00000<`3oool00`000000oooo0?ooo`1I0?ooo`00G03oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0480oooo00<00?l00?ooo`3oool0P@3oool7000003P0oooo
00<000000?ooo`3oool0FP3oool005d0oooo0P00000b0?ooo`030000003oool0oooo0480oooo00<0
0?l00?ooo`3oool0N`3oool7000003`0oooo0P00001M0?ooo`00G`3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo00<00?l00?ooo`3oool0M03oool700000440oooo00<00000
0?ooo`3oool0403oool50000odP0oooo001P0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0@`3oool00`00o`00oooo0?ooo`1^0?ooo`L00000AP3oool00`000000oooo0?ooo`0@0?oo
o`<0003o0`3oool20000odH0oooo001Q0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0A03oool00`00o`00oooo0?ooo`1W0?ooo`L00000B`3oool00`000000oooo0?ooo`0A0?ooo`80
003o1@3oool00`000?l0oooo0?ooo`140?ooo`00HP3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo04@0oooo00<00?l00?ooo`3oool0H@3oool8000004l0oooo00<000000?ooo`3oool0
4P3oool20000od`0oooo001S0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0A@3o
ool00`00o`00oooo0?ooo`1J0?ooo`P00000D`3oool2000001D0oooo0P000?m<0?ooo`00I03oool2
000002/0oooo00<000000?ooo`3oool0A@3oool00`00o`00oooo0?ooo`1D0?ooo`P00000E`3oool2
000001P0oooo0P000?l40?ooo`030000o`3oool0oooo04@0oooo001V0?ooo`800000:03oool20000
04P0oooo00<00?l00?ooo`3oool0C@3oool8000005`0oooo00<000000?ooo`3oool06@3oool20000
o`80oooo0P000?m60?ooo`00J03oool00`000000oooo0?ooo`0U0?ooo`800000B@3oool00`00o`00
oooo0?ooo`160?ooo`P00000H@3oool00`000000oooo0?ooo`0K0?ooo`<0003o00<0oooo0000o`3o
ool0A@3oool006T0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`180?ooo`03003o
003oool0oooo0400oooo2000001V0?ooo`030000003oool0oooo06L0oooo001Z0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0B@3oool00`00o`00oooo0?ooo`0i0?ooo`P00000J`3o
ool00`000000oooo0?ooo`1X0?ooo`00J`3oool2000002<0oooo00<000000?ooo`3oool0B@3oool0
0`00o`00oooo0?ooo`0c0?ooo`P00000K`3oool2000006/0oooo001]0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0BP3oool00`00o`00oooo0?ooo`0/0?ooo`P00000M03oool00`00
0000oooo0?ooo`1[0?ooo`00KP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04X0
oooo00<00?l00?ooo`3oool09P3oool8000007T0oooo00<000000?ooo`3oool0K03oool006l0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1;0?ooo`03003o003oool0oooo01l0oooo
2000001m0?ooo`800000K`3oool00700oooo0P00000N0?ooo`030000003oool0oooo04/0oooo00<0
0?l00?ooo`3oool06@3oool800000880oooo00<000000?ooo`3oool0K`3oool00780oooo0P00000L
0?ooo`030000003oool0oooo04`0oooo00<00?l00?ooo`3oool04P3oool8000008H0oooo0P00001b
0?ooo`00M03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04`0oooo00<00?l00?l0
003o0000303oool8000008/0oooo00<000000?ooo`3oool0LP3oool007D0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`1<0?ooo`@0o`001@3oool800000900oooo00<000000?ooo`3o
ool0L`3oool007H0oooo0P00000H0?ooo`030000003oool0oooo04/0oooo1P3o0006000009@0oooo
0P00001f0?ooo`00N03oool2000001H0oooo00<000000?ooo`3oool0B@3oool2000000H0o`00V03o
ool2000007P0oooo001j0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@`3oool8
000000030?ooo`3o0000o`000080o`00V03oool00`000000oooo0?ooo`1h0?ooo`00N`3oool20000
01<0oooo00<000000?ooo`3oool0?@3oool8000000P0oooo0P3o002G0?ooo`800000N`3oool007d0
oooo0P00000A0?ooo`030000003oool0oooo03L0oooo2000002U0?ooo`800000O@3oool007l0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0a0?ooo`P00000ZP3oool00`000000oooo
0?ooo`1m0?ooo`00P03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02/0oooo1`00
002`0?ooo`030000003oool0oooo07h0oooo00210?ooo`8000003@3oool00`000000oooo0?ooo`0U
0?ooo`L00000]03oool200000840oooo00230?ooo`8000002`3oool00`000000oooo0?ooo`0O0?oo
o`L00000^03oool2000008<0oooo00250?ooo`8000002@3oool00`000000oooo0?ooo`0I0?ooo`L0
0000^`3oool3000008D0oooo00270?ooo`8000001`3oool00`000000oooo0?ooo`0C0?ooo`L00000
`03oool00`000000oooo0?ooo`260?ooo`00R@3oool2000000D0oooo00<000000?ooo`3oool03@3o
ool600000<D0oooo0P0000290?ooo`00R`3oool010000000oooo0?ooo`3oool20000o`T0oooo1P00
00390?ooo`800000R`3oool008`0oooo0P0000040000o`80oooo1P00003>0?ooo`030000003oool0
oooo08/0oooo002=0?ooo`H0003o00<000000?ooo`3oool0d03oool2000008h0oooo002=0?ooo`H0
003oDP3oool70000ogP0oooo0P00002@0?ooo`00SP3oool40000o`800000D03oool20000o`@0oooo
0P000?me0?ooo`<00000TP3oool008l0oooo0P000?l30?ooo`<00000C@3oool20000o`@0oooo0P00
0?mb0?ooo`<00000U@3oool009L0oooo0P00001;0?ooo`80003o0`3oool40000og00oooo00<00000
0?ooo`3oool0UP3oool009T0oooo0P0000190?ooo`80003oM@3oool2000009T0oooo002K0?ooo`80
0000B03oool20000o`D0oooo00<0003o0?ooo`3oool0JP3oool2000009/0oooo002M0?ooo`800000
A`3oool20000o`@0oooo00<0003o0?ooo`3oool0I`3oool3000009d0oooo002O0?ooo`<00000AP3o
ool50000ofL0oooo0P00002P0?ooo`00XP3oool300000:`0oooo0`00002R0?ooo`00Y@3oool30000
0:H0oooo0`00002U0?ooo`00Z03oool300000:00oooo0`00002X0?ooo`00Z`3oool2000009/0oooo
0`00002[0?ooo`00[@3oool3000009H0oooo0P00002^0?ooo`00TP3oool70000oaL0oooo0`00002@
0?ooo`<00000/03oool009<0oooo0P000?l30?ooo`80003o6@3oool3000008X0oooo0`00002c0?oo
o`00U03oool20000o`<0oooo0P000?lK0?ooo`<00000Q03oool300000;H0oooo002D0?ooo`80003o
0`3oool20000oah0oooo1@00001i0?ooo`H00000^@3oool009@0oooo1P000?lT0?ooo`<00000L`3o
ool300000;l0oooo002D0?ooo`80003o0`3oool20000obH0oooo0`00001^0?ooo`800000`P3oool0
09D0oooo0P000?l20?ooo`80003o:@3oool600000680oooo1P0000340?ooo`00U03oool60000oc00
oooo1P00001F0?ooo`H00000bP3oool00=00oooo1P00001:0?ooo`H00000d03oool00=H0oooo1P00
000n0?ooo`H00000eP3oool00=`0oooo2@00000/0?ooo`T00000g03oool00>D0oooo4@0000090?oo
oa800000i@3oool00?H0oooo2@00003g0?ooo`00o`3oooog0?ooo`00o`3oooog0?ooo`00o`3oooog
0?ooo`00o`3oooog0?ooo`00o`3oooog0?ooo`00o`3oooog0?ooo`00o`3oooog0?ooo`00o`3oooog
0?ooo`00o`3oooog0?ooo`00o`3oooog0?ooo`00o`3oooog0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 501.938}, {501.938, 0}} -> {-5.00105, -5.00105, \
0.522979, 0.522979}}],

Cell[TextData[{
  "|",
  Cell[BoxData[
      StyleBox["EE",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0, 0, 1],
        Background->None]], "Expression"],
  Cell[BoxData[
      StyleBox["F",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0, 0, 1],
        Background->None]], "Expression"],
  "| \[TildeFullEqual] |",
  Cell[BoxData[
      StyleBox["G",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0, 0, 1],
        Background->None]], "Expression"],
  Cell[BoxData[
      StyleBox["EE",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0, 0, 1],
        Background->None]], "Expression"],
  "| for this configuration of the points"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["End of output", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["Input to the system:", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Proposition["\<Butterfly\>"], by \[Rule] GeometryProver, 
      ProverOptions \[Rule] {Method -> "\<GroebnerProver\>", 
          Refutation \[Rule] False}]\)], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell["Inserted notebook generated automatically by the system", "Text",
  CellDingbat->"\[FilledSmallCircle]",
  TextAlignment->Left],

Cell["Prove:", "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.643137, 0.756863, 1]}],

Cell[TextData[{
  StyleBox["(Proposition (Butterfly))", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  "\n   \n",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["O",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox["A",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox["B",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox["C",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox["D",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox["EE",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox["F",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox["G",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"point", "[", 
                RowBox[{
                  StyleBox["O",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  StyleBox["A",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None]}], "]"}], "\[And]", 
              RowBox[{"pon", "[", 
                RowBox[{
                  StyleBox["C",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  RowBox[{"circle", "[", 
                    RowBox[{
                      StyleBox["O",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["A",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}]}], "]"}], "\[And]", 
              RowBox[{"pon", "[", 
                RowBox[{
                  StyleBox["B",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  RowBox[{"circle", "[", 
                    RowBox[{
                      StyleBox["O",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["A",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}]}], "]"}], "\[And]", 
              RowBox[{"pon", "[", 
                RowBox[{
                  StyleBox["D",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  RowBox[{"circle", "[", 
                    RowBox[{
                      StyleBox["O",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["A",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}]}], "]"}], "\[And]", 
              RowBox[{"inter", "[", 
                RowBox[{
                  StyleBox["EE",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  RowBox[{"line", "[", 
                    RowBox[{
                      StyleBox["A",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["C",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}], ",", 
                  RowBox[{"line", "[", 
                    RowBox[{
                      StyleBox["B",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["D",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}]}], "]"}], "\[And]", 
              RowBox[{"inter", "[", 
                RowBox[{
                  StyleBox["F",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  RowBox[{"line", "[", 
                    RowBox[{
                      StyleBox["D",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["A",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}], ",", 
                  RowBox[{"tline", "[", 
                    RowBox[{
                      StyleBox["EE",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["EE",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["O",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}]}], "]"}], "\[And]", 
              RowBox[{"inter", "[", 
                RowBox[{
                  StyleBox["G",
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], ",", 
                  RowBox[{"line", "[", 
                    RowBox[{
                      StyleBox["B",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["C",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}], ",", 
                  RowBox[{"line", "[", 
                    RowBox[{
                      StyleBox["EE",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], ",", 
                      StyleBox["F",
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], "]"}]}], "]"}]}], "\[Implies]", 
            RowBox[{"distequal", "[", 
              RowBox[{
                StyleBox["EE",
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox["F",
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox["G",
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], ",", 
                StyleBox["EE",
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None]}], "]"}]}], ")"}]}]], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[0.643137, 0.756863, 1]}],
  Cell[" ", "ProofText"]
}], "Conclusion",
  CellBracketOptions->{"Color"->RGBColor[0.643137, 0.756863, 1]},
  CellTags->"Proposition (Butterfly)"],

Cell["with no assumptions.", "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.643137, 0.756863, 1]}],

Cell["\<\
To prove the above statement we shall use the Gr\[ODoubleDot]bner bases \
method. First we have to transform the problem into algebraic form. \
\>", "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell["Algebraic Form:", "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell["\<\
To transform the geometric problem into algebraic form we have to chose first \
an orthogonal coordinate system.\
\>", "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell[TextData[{
  "Let's have the origin in point ",
  Cell[BoxData[
      StyleBox["EE",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0, 0, 1],
        Background->None]], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  ", and points ",
  Cell[BoxData[
      RowBox[{"{", 
        StyleBox["O",
          FontWeight->"Bold",
          FontSlant->"Italic",
          FontColor->RGBColor[0, 0, 1],
          Background->None], "}"}]], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " and ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          StyleBox["F",
            FontWeight->"Bold",
            FontSlant->"Italic",
            FontColor->RGBColor[0, 0, 1],
            Background->None], ",", 
          StyleBox["G",
            FontWeight->"Bold",
            FontSlant->"Italic",
            FontColor->RGBColor[0, 0, 1],
            Background->None]}], "}"}]], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " on the two axes."
}], "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell["Using this coordinate system we have the following points:", "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            StyleBox["EE",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["O",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(u\_1\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["A",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(u\_2\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(u\_3\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["B",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(u\_4\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_1\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["F",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", "0", ",", 
            StyleBox[\(x\_2\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["G",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", "0", ",", 
            StyleBox[\(x\_3\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["C",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_4\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_5\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["D",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_6\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_7\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}], "}"}]}], "}"}]], "Expression",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell["The algebraic form of the given construction is:", "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell[TextData[{
  StyleBox["(1)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  "\n   \n",
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox[\(v\_1\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(v\_2\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_1\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_2\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_3\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_4\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_5\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_6\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None], ",", 
            StyleBox[\(x\_7\),
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0, 0, 1],
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{\((\(-1\))\), "+", 
                  RowBox[{
                    StyleBox[\(u\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(v\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(v\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_6\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
              RowBox[{
                RowBox[{\((\(-1\))\), "+", 
                  RowBox[{
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(v\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(v\_1\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
              RowBox[{
                RowBox[{
                  RowBox[{"2", " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{"-", 
                    SuperscriptBox[
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  RowBox[{"-", 
                    SuperscriptBox[
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  RowBox[{\(-2\), " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  SuperscriptBox[
                    StyleBox[\(x\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "2"], "+", 
                  SuperscriptBox[
                    StyleBox[\(x\_5\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "2"]}], "\[Equal]", "0"}], "\[And]", 
              
              RowBox[{
                RowBox[{
                  RowBox[{"2", " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{"-", 
                    SuperscriptBox[
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  RowBox[{"-", 
                    SuperscriptBox[
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  RowBox[{\(-2\), " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(u\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  SuperscriptBox[
                    StyleBox[\(u\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "2"], "+", 
                  SuperscriptBox[
                    StyleBox[\(x\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "2"]}], "\[Equal]", "0"}], "\[And]", 
              
              RowBox[{
                RowBox[{
                  RowBox[{"2", " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{"-", 
                    SuperscriptBox[
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  RowBox[{"-", 
                    SuperscriptBox[
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  RowBox[{\(-2\), " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_6\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  SuperscriptBox[
                    StyleBox[\(x\_6\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "2"], "+", 
                  SuperscriptBox[
                    StyleBox[\(x\_7\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "2"]}], "\[Equal]", "0"}], "\[And]", 
              
              RowBox[{
                RowBox[{
                  RowBox[{
                    StyleBox[\(u\_3\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_5\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    StyleBox[\(x\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_6\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_7\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_6\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    StyleBox[\(x\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_6\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_7\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], "\[Equal]", "0"}], "\[And]", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    StyleBox[\(u\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_3\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    StyleBox[\(x\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(x\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(x\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    StyleBox[\(x\_5\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], "\[Equal]", "0"}]}], 
            "\[Implies]", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(x\_2\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "2"], "+", 
                RowBox[{"-", 
                  SuperscriptBox[
                    StyleBox[\(x\_3\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "2"]}]}], "\[Equal]", "0"}]}], 
          ")"}]}]], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell["", "ProofText"]
}], "Conclusion",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]},
  CellTags->"1"],

Cell["\<\
We have to compute the Gr\[ODoubleDot]bner bases of the hypothesis \
polynomials (GB).\
\>", "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell[TextData[{
  "The polynomials of the Gr\[ODoubleDot]bner bases are: \n",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              SuperscriptBox[
                StyleBox[\(u\_2\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], "2"]}], "+", 
            RowBox[{"-", 
              SuperscriptBox[
                StyleBox[\(u\_3\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], "2"]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-2\), " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    SuperscriptBox[
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  RowBox[{"2", " ", 
                    SuperscriptBox[
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "3"]}], "+", 
                  RowBox[{"2", " ", 
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    SuperscriptBox[
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}]}], ")"}], " ", 
              StyleBox[\(v\_1\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}]}], ",", 
          RowBox[{
            RowBox[{\(-2\), " ", 
              StyleBox[\(u\_1\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_2\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            SuperscriptBox[
              StyleBox[\(u\_2\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], "2"], "+", 
            SuperscriptBox[
              StyleBox[\(u\_3\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], "2"], "+", 
            RowBox[{"2", " ", 
              StyleBox[\(u\_1\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_4\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"4", " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(u\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{\(-2\), " ", 
                    SuperscriptBox[
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"], " ", 
                    StyleBox[\(u\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{\(-2\), " ", 
                    SuperscriptBox[
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"], " ", 
                    StyleBox[\(u\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{\(-2\), " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    SuperscriptBox[
                      StyleBox[\(u\_4\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}]}], ")"}], " ", 
              StyleBox[\(v\_2\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}]}], ",", 
          RowBox[{
            RowBox[{\(-2\), " ", 
              StyleBox[\(u\_1\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_2\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_3\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_4\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(u\_2\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], "2"], " ", 
              StyleBox[\(u\_3\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_4\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(u\_3\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], "3"], " ", 
              StyleBox[\(u\_4\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    SuperscriptBox[
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  RowBox[{"-", 
                    SuperscriptBox[
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "3"]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    SuperscriptBox[
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}]}], ")"}], " ", 
              StyleBox[\(x\_1\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    SuperscriptBox[
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  RowBox[{"-", 
                    SuperscriptBox[
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "3"]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    SuperscriptBox[
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      SuperscriptBox[
                        StyleBox[\(u\_2\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "2"]}], " ", 
                    StyleBox[\(u\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      SuperscriptBox[
                        StyleBox[\(u\_3\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "2"]}], " ", 
                    StyleBox[\(u\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], ")"}], " ", 
              StyleBox[\(x\_2\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}]}], ",", 
          RowBox[{
            RowBox[{"2", " ", 
              StyleBox[\(u\_1\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_2\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_3\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_4\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"-", 
                SuperscriptBox[
                  StyleBox[\(u\_2\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "2"]}], " ", 
              StyleBox[\(u\_3\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_4\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"-", 
                SuperscriptBox[
                  StyleBox[\(u\_3\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "3"]}], " ", 
              StyleBox[\(u\_4\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-2\), " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    SuperscriptBox[
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  SuperscriptBox[
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "3"], "+", 
                  RowBox[{
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    SuperscriptBox[
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}]}], ")"}], " ", 
              StyleBox[\(x\_1\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    SuperscriptBox[
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  RowBox[{"-", 
                    SuperscriptBox[
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "3"]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None]}], " ", 
                    SuperscriptBox[
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      SuperscriptBox[
                        StyleBox[\(u\_2\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "2"]}], " ", 
                    StyleBox[\(u\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"-", 
                      SuperscriptBox[
                        StyleBox[\(u\_3\),
                          FontWeight->"Bold",
                          FontSlant->"Italic",
                          FontColor->RGBColor[0, 0, 1],
                          Background->None], "2"]}], " ", 
                    StyleBox[\(u\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], ")"}], " ", 
              StyleBox[\(x\_3\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}]}], ",", 
          RowBox[{
            RowBox[{\(-2\), " ", 
              StyleBox[\(u\_1\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              SuperscriptBox[
                StyleBox[\(u\_2\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], "2"]}], "+", 
            SuperscriptBox[
              StyleBox[\(u\_2\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], "3"], "+", 
            RowBox[{
              StyleBox[\(u\_2\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              SuperscriptBox[
                StyleBox[\(u\_3\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], "2"]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "2"], "+", 
                  SuperscriptBox[
                    StyleBox[\(u\_3\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "2"]}], ")"}], " ", 
              StyleBox[\(x\_4\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}]}], ",", 
          RowBox[{
            RowBox[{"2", " ", 
              StyleBox[\(u\_1\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_2\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_3\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"-", 
                SuperscriptBox[
                  StyleBox[\(u\_2\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "2"]}], " ", 
              StyleBox[\(u\_3\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{"-", 
              SuperscriptBox[
                StyleBox[\(u\_3\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], "3"]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  RowBox[{"-", 
                    SuperscriptBox[
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}]}], ")"}], " ", 
              StyleBox[\(x\_5\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}]}], ",", 
          RowBox[{
            RowBox[{"2", " ", 
              StyleBox[\(u\_1\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_2\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_4\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"-", 
                SuperscriptBox[
                  StyleBox[\(u\_2\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "2"]}], " ", 
              StyleBox[\(u\_4\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"-", 
                SuperscriptBox[
                  StyleBox[\(u\_3\),
                    FontWeight->"Bold",
                    FontSlant->"Italic",
                    FontColor->RGBColor[0, 0, 1],
                    Background->None], "2"]}], " ", 
              StyleBox[\(u\_4\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  RowBox[{"-", 
                    SuperscriptBox[
                      StyleBox[\(u\_2\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  RowBox[{"-", 
                    SuperscriptBox[
                      StyleBox[\(u\_3\),
                        FontWeight->"Bold",
                        FontSlant->"Italic",
                        FontColor->RGBColor[0, 0, 1],
                        Background->None], "2"]}], "+", 
                  RowBox[{\(-2\), " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(u\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], ")"}], " ", 
              StyleBox[\(x\_6\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}]}], ",", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-2\), " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  SuperscriptBox[
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "2"], "+", 
                  SuperscriptBox[
                    StyleBox[\(u\_3\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "2"]}], ")"}], " ", 
              StyleBox[\(x\_1\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(-2\), " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}], "+", 
                  SuperscriptBox[
                    StyleBox[\(u\_2\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "2"], "+", 
                  SuperscriptBox[
                    StyleBox[\(u\_3\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], "2"], "+", 
                  RowBox[{"2", " ", 
                    StyleBox[\(u\_1\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None], " ", 
                    StyleBox[\(u\_4\),
                      FontWeight->"Bold",
                      FontSlant->"Italic",
                      FontColor->RGBColor[0, 0, 1],
                      Background->None]}]}], ")"}], " ", 
              StyleBox[\(x\_7\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}]}], ",", 
          RowBox[{
            RowBox[{"2", " ", 
              StyleBox[\(u\_1\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_2\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            RowBox[{"-", 
              SuperscriptBox[
                StyleBox[\(u\_2\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], "2"]}], "+", 
            RowBox[{"-", 
              SuperscriptBox[
                StyleBox[\(u\_3\),
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0, 0, 1],
                  Background->None], "2"]}], "+", 
            RowBox[{\(-2\), " ", 
              StyleBox[\(u\_1\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], " ", 
              StyleBox[\(u\_4\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None]}], "+", 
            SuperscriptBox[
              StyleBox[\(u\_4\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], "2"], "+", 
            SuperscriptBox[
              StyleBox[\(x\_1\),
                FontWeight->"Bold",
                FontSlant->"Italic",
                FontColor->RGBColor[0, 0, 1],
                Background->None], "2"]}]}], "}"}]], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}]
}], "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell["\<\
We compute the normal form of the conclusion polynomial modulo GB. \
\>", "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell[TextData[{
  "The normal form is: ",
  Cell[BoxData[
      \(0\)], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}]
}], "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell["\<\
As the obtained normal form equals to 0 the statement is generically true.\
\>", "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell["Statistics:", "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell[TextData[{
  "The length of the Gr\[ODoubleDot]bner bases is ",
  Cell[BoxData[
      \(9\)], ".",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}]
}], "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell[TextData[{
  "Time needed to compute the Gr\[ODoubleDot]bner bases: ",
  Cell[BoxData[
      \(0.269999999999996`\ Second\)], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "s."
}], "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell[TextData[{
  "Time needed to compute the normal form of the conclusion polynomial modulo \
GB:  ",
  Cell[BoxData[
      \(0.3200000000000074`\ Second\)], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "s."
}], "ProofText",
  CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],

Cell["\[EmptySquare]", "ProofText",
  CellMargins->{{Inherited, Inherited}, {Inherited, 0}},
  CellBracketOptions->{"Color"->RGBColor[0.643137, 0.756863, 1]},
  TextAlignment->Right],

Cell["End of inserted notebook", "Text",
  CellDingbat->"\[FilledSmallCircle]"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example: The Correctness of Origami Constructions (jointly with T. Ida)\
\>", "Subsubsection"],

Cell[TextData[{
  StyleBox["Example of an Origami Construction Problem:",
    FontWeight->"Bold"],
  " Starting from a square A, B, C, D, find a sequence of origami steps such \
that, finally, we arrive at an equilateral triangle. "
}], "Text"],

Cell[TextData[{
  "A first solution (does not yield maximum edge length; other solution and \
more complicated examples see ",
  StyleBox["T. Ida, BB, J. Robu et al. 2003 and 2004",
    FontWeight->"Bold"],
  "): "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.81745 .81745 m .18255 .81745 L .18255 .18255 L p 0 .4 1 r
F P
0 g
s
1 0 0 r
.02 w
.18255 .81745 Mdot
.5 .81745 Mdot
.18255 .81745 Mdot
.5 .81745 Mdot
.5 Mabswid
.18255 .18255 m .81745 .18255 L .81745 .81745 L p 0 .4 1 r
F P
0 g
s
.2 1 0 r
.5 .18255 m
.5 .81745 L
s
.18255 .18255 m
.18255 .81745 L
s
1 0 0 r
.02 w
.81745 .81745 Mdot
.18255 .18255 Mdot
.81745 .81745 Mdot
.18255 .18255 Mdot
.81745 .18255 Mdot
.5 .18255 Mdot
.81745 .18255 Mdot
.5 .18255 Mdot
0 g
gsave
.18255 .18255 -72.875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.875 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81745 .18255 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81745 .81745 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18255 .81745 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .81745 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .18255 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18255 .18255 -72.875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.875 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81745 .18255 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81745 .81745 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18255 .81745 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .81745 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .18255 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .5 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{186.625, 186.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004G00015b000`400?l00000o`00003oo`3ooolH
0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH
0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH
0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH
0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH
0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH
0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH
0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH
0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH
0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`00o`3ooolH
0?ooo`00o`3ooolH0?ooo`00o`3ooolH0?ooo`008`3oool0203oScD00000000000000000000e08oo
o`3oool0ohle0`0000000`0001@0GlCo0?ooo`1=0?ooo`030?n?=@00000000000080000000<0000D
05o4o`3oool0D03oool00`3oScD000000000000500000003000eS`3oool0oooo03H0oooo000T0?oo
o`030?ooS`0e0000=Hoo00D0oooo00<0a5lD000DG`3oool00P3oool30?l004/0oooo00<0oon?03D0
=@2?ool0203oool30?l004X0oooo00<0oon?03D0501Oa?l0103oool0101O500003F?0?ooo`3oool3
0?l00380oooo000U0?ooo`0308le0000=Hl0oooo00@0oooo00@0Ga@001AOa03oool0oooo1@3o001D
000000D0o`00D`0000050?l00340oooo000U0?ooo`030?o4G`0D0000000000@0000000@0000e08oo
o`3oool0oooo1@3o001:001Vo`03001VS`0003D006Ko00L006Ko1@3o0019001Vo`03001VS`0001@0
04ko00@006Ko00<004iO0000=@00I_l01@3o000a0?ooo`009P3oool00`1O500055o40?ooo`020?oo
o`0308le0000=Hl0oooo0080oooo1@3o001:001Vo`06001VS`0003D006Ko001Vo`005P0003Wo1000
I_l50?l004T006Ko00<006J?00005000C_l00`00I_l01000CUl00000000Va000I_l50?l00340oooo
000V0?ooo`070?n?=@0003D0Sooo0?ooo`3oohl0=@0003F?o`040?ooo`<0o`00B`00I_l00`00IXl0
00000000000200000003000Va000I_l006Ko00<006Ko0`3o001:001Vo`03001VS`000000000000<0
000000<0000D001>o`00I_l00P00I_l30?l00380oooo000V0?ooo`060?ooS`0e0000=Hoo0?ooo`34
Ga@001AO1P3oool00`0co`0006Ko001Vo`1:001Vo`06001VS`0003D006Ko001Vo`005P0002K41P00
I_l00`0co`0006Ko001Vo`19001Vo`03001VS`0001@004ko00<006Ko00<002HD0008G`00I_l01000
I_l00`000000oooo0?ooo`0`0?ooo`009`3oool01@34Ga@001AO0?ooo`1O500055o400H0oooo00<0
<ol0001Vo`00I_l0BP00I_l00`00IXl0000e001Vo`04001Vo`03000V50009/@006Ko008006Ko00<0
<ol0001Vo`00I_l0B@00I_l00`00IXl0000D001>o`04001Vo`0300080000>Ol006Ko00<006Ko00<0
00000?ooo`3oool0<03oool002L0oooo00D0olAO01@0501OSel0500D05o4o`060?ooo`0303?o0000
I_l006Ko04X006Ko00<006J?0000=@00I_l01000I_l00`009Q@002K4001Vo`02001Vo`0303?o0000
I_l006Ko04T006Ko00<006J?00005000C_l00`00I_l00`009Q@0000e001Vo`04001Vo`030000003o
ool0oooo0300oooo000U0?ooo`0308le0000000000000080000000<001AO0?ooo`3oool01@3oool0
0`0co`0006Ko001Vo`19001Vo`03000i=@000000000000H0000000D002K4001Vo`00I_l006Ko03?o
001:001Vo`03000i=@000000000000@0000000<0000D001>o`00I_l01000I_l00`000000oooo0?oo
o`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<00000
0?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001V
o`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00
I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o
0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00
I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l0
06Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0c
o`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380
oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300
oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo
0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<0
00000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F
001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001V
o`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`03
03?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0
EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000
I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool0
0`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool0
0380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo
0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000
oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko
00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001V
o`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0
001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001V
o`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00
I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o
0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3o
ool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03o
ool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0
oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`00
0000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H0
06Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko
001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0
<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F
001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001V
o`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`03
03?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00
<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0
<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003o
ool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l0
0`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko
05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`00
06Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko
00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001V
o`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0
001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?oo
o`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?oo
o`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3o
ool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000
003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00
I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l0
06Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0c
o`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H0
06Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko
001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0
<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b
0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`
0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?oo
o`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`03
0000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0
EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000
I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l0
0`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko
05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`00
06Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo
00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo
000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?oo
o`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<00000
0?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001V
o`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00
I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o
0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00
I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l0
06Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0c
o`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380
oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300
oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo
0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<0
00000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F
001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001V
o`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`03
03?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0
EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000
I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool0
0`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool0
0380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo
0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000
oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1B001Vo`03001V_`000000000000D00000
00<004co001Vo`00I_l0DP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001V
o`1E001Vo`03001V_`0G000005[o05L006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0
001Vo`00I_l0E@00I_l00`00I[l05`00001Jo`1G001Vo`030000003oool0oooo0300oooo000b0?oo
o`0303?o0000I_l006Ko05D006Ko00<006Jo01L00000F_l0E`00I_l00`000000oooo0?ooo`0`0?oo
o`00<P3oool00`0co`0006Ko001Vo`1E001Vo`03001V_`0G000005[o05L006Ko00<000000?ooo`3o
ool0<03oool00380oooo00<0<ol0001Vo`00I_l0E@00I_l00`00I[l05`00001Jo`1G001Vo`030000
003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05D006Ko00<006Jo01L00000F_l0E`00
I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1E001Vo`03001V_`0G0000
05[o05L006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0E@00I_l00`00
I[l05`00001Jo`1G001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko0580
06Ko00H005ZL00000000000003nL01L00000F_mG001Vo`030000003oool0oooo0300oooo000b0?oo
o`0303?o0000I_l006Ko05D006Ko00<001d000000000F_l0E`00I_l00`000000oooo0?ooo`0`0?oo
o`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3o
ool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000
003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00
I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l0
06Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0c
o`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H0
06Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko
001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0
<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b
0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`
0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?oo
o`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`03
0000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0
EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000
I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l0
0`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko
05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`00
06Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo
00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo
000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?oo
o`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<00000
0?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001V
o`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00
I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o
0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00
I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l0
06Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0c
o`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380
oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300
oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo
0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<0
00000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F
001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001V
o`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`03
03?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0
EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000
I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool0
0`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool0
0380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo
0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000
oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko
00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001V
o`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0
001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001V
o`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00
I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o
0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3o
ool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03o
ool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0
oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`00
0000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H0
06Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko
001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0
<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F
001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001V
o`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`03
03?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00
<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0
<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003o
ool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l0
0`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko
05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`00
06Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko
00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001V
o`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0
001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?oo
o`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?oo
o`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3o
ool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000
003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00
I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l0
06Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0c
o`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H0
06Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko
001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0
<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b
0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`
0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?oo
o`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`03
0000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0
EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`0006Ko001Vo`1F001Vo`0303?o0000
I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo00<0<ol0001Vo`00I_l0EP00I_l0
0`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo000b0?ooo`0303?o0000I_l006Ko
05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?ooo`0`0?ooo`00<P3oool00`0co`00
06Ko001Vo`1F001Vo`0303?o0000I_l006Ko05H006Ko00<000000?ooo`3oool0<03oool00380oooo
00<0<ol0001Vo`00I_l0EP00I_l00`0co`0006Ko001Vo`1F001Vo`030000003oool0oooo0300oooo
000b0?ooo`0303?o0000I_l006Ko05H006Ko00<0<ol0001Vo`00I_l0EP00I_l00`000000oooo0?oo
o`0`0?ooo`009@3oool00`3oohl0=@00000000050000000303F?o`3oool0oooo0080oooo00<0<ol0
001Vo`00I_l0B000I_l00`00>CD000000000000600000003000Va000I_l006Ko008006Ko00<0<ol0
001Vo`00I_l0B`00I_l01@005P000000000000000000000e00H006Ko00<000000?ooo`3oool0<03o
ool002L0oooo00<0ScD001AOa03oool00P3oool00`3oohl0=@0003F?o`020?ooo`030?l0000co`00
o`0004X006Ko00<006J?00005000C_l01000I_l00`009Q@002K4001Vo`02001Vo`030?l0000co`00
o`0004/006Ko00<001H0000FS`00I_l00P00I_l00`00>CD00000000io`02001Vo`<0o`00<P3oool0
02L0oooo00<0ScD001AOa03oool00`3oool00`3oa5l0500e08ooo`020?l0000303?o003o0000o`00
04T006Ko00<006J?00005000C_l01000I_l010009Q@002K4001Vo`00I_l20?l0000303?o003o0000
o`0004T006Ko00<002HD000FS`00I_l01000I_l00`00CUl0000e001Vo`050?l00340oooo000W0?oo
o`0308le000DGl@0oooo00@0oooo00D0Ga@003F?o`3o0000o`0003?o00020?l005@000000P3o0000
0`0co`00o`000?l0001C000000D0o`00<@3oool002L0oooo00<0ScD001AOa03oool0103oool00`2?
=@0055o40?l000040?l004T0oooo00H0oon?03D0501Oa?l0oooo08le000DGl@50?ooo`D0o`00B03o
ool00`3oohl0=@0e08ooo`080?ooo`D0o`00<@3oool002L0oooo00<0ScD001AOa03oool0103oool0
0`2?=@0055o40?ooo`030?l004X0oooo00<0oon?03D0000000000P0000000`0DGl@0oooo0?ooo`04
0?ooo`<0o`00B@3oool00`3oohl0=@0e08ooo`090?ooo`<0o`00<P3oool002L0oooo00<0ScD001AO
a03oool0103oool00`1O5000=Hoo0?ooo`1=0?ooo`060?ooS`0e01@0GlCo0?ooo`2?=@0055o4DP3o
ool00`3oohl0=@0D05o4o`0n0?ooo`009`3oool00`2?=@0055o40?ooo`030?ooo`030?o4G`0D03D0
Sooo04h0oooo00<0oon?03D0501Oa?l0103oool00`1O51@0GlCo0?ooo`1?0?ooo`030<AO500eSol0
oooo00@0oooo00<0a5lD000DG`3oool0=P3oool002L0oooo00<0ScD001AOa03oool00P3oool00`3o
ScD0000003F?o`1?0?ooo`030?ooS`0e01@0GlCo00@0oooo00<0Ga@D05o4o`3oool0C`3oool00`3o
ohl0=@00000eS`030?ooo`0308le000051@051AO03L0oooo000U0?ooo`030?ooS`0e0000000000@0
000000<0000e08ooo`3oool0CP3oool00`3oScD0000000000005000000030000501Oa?l0oooo0540
oooo00L0ScD00000000000000000000eS`3oa5l051AO03L0oooo003o0?oooaP0oooo003o0?oooaP0
oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0
oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0
oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0
oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0
oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0
oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0
oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0
oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0oooo003o0?oooaP0
oooo003o0?oooaP0oooo003o0?oooaP0oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 239.813}, {382.188, 233.938}} -> {-0.617633, \
1.578, 0.00539634, 0.00539634}}],

Cell["\<\
Then we fix the point A and fold so that point D will lie on line EF. (This \
is a legal origami operation.)\
\>", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.83671 .16329 m .83671 .83671 L .34373 .83671 L p 0 .4 1 r
F P
0 g
s
1 0 0 r
.02 w
.83671 .83671 Mdot
.5 .83671 Mdot
.83671 .83671 Mdot
.5 .83671 Mdot
.5 Mabswid
.34373 .83671 m .16329 .16329 L .83671 .16329 L p 0 .4 1 r
F P
0 g
s
1 0 0 r
.02 w
.83671 .16329 Mdot
.83671 .16329 Mdot
.16329 .16329 Mdot
.5 .16329 Mdot
.16329 .16329 Mdot
.5 .16329 Mdot
.5 Mabswid
.16329 .16329 m .34373 .83671 L .5 .74649 L closepath p .2 1 0 r
F P
0 g
s
1 0 0 r
.02 w
.16329 .16329 Mdot
.5 .74649 Mdot
.16329 .16329 Mdot
.5 .74649 Mdot
.34373 .83671 Mdot
0 g
gsave
.16329 .16329 -72.875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.875 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83671 .16329 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83671 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .16329 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16329 .16329 -72.875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.875 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83671 .16329 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83671 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .16329 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34373 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16329 .16329 -72.875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.875 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .74649 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16329 .16329 -72.875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.875 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .74649 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34373 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.33567 .58216 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{187.313, 187.313},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H000162000`400?l00000o`00003oo`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`007P3oool0203oD0/00000000000000000000;053oo`3oool0oe0;1000
00000`0SUol0oooo0?ooo`1B0?ooo`030?n?=@00000000000080000000<0000D05o4o`3oool0E@3o
ool00`3oScD000000000000500000003000eS`3oool0oooo0340oooo000O0?ooo`030?ooD00;0000
2e3o00D0oooo00<0Ub<000008`3oool0EP3oool00`3oohl0=@0e08ooo`1J0?ooo`030?ooS`0e01@0
GlCo00@0oooo00<0Ga@0000eS`3oool0<@3oool00200oooo00<0D0/0000;D03oool0103oool00`0S
000002>G0?ooo`020?ooo`<0o`00D@3oool00`3oohl0=@0e08ooo`070?ooo`<0o`00D03oool00`3o
ohl0=@0D05o4o`040?ooo`040?ooS`0e03D0Sooo0?ooo`<0o`00;@3oool00200oooo00<0oiLS0000
0000000010000000100000/0D?oo0?ooo`3oool50?l005T000001@3o001I000000D0o`00;03oool0
0240oooo00<08`00000SU`3oool00P3oool00`1@2`0000]@0?ooo`020?ooo`D0o`00D000I_l01P00
IXl0000e001Vo`00I_l001H0000io`<006Ko1@3o001?001Vo`03001VS`0001@004ko00<006Ko00@0
04iO000000009/@006Ko1@3o000/0?ooo`008@3oool01`3oD0/0000;053oo`3oool0oom@00/0000;
D?l00`3oool50?l0050006Ko00<006J?0000000000000P00000010009/@006Ko001Vo`00I_l50?l0
04l006Ko00<006J?0000000000000`000000100001@004ko001Vo`00I_l50?l002`0oooo000Q0?oo
o`060?ooD00;00002e3o0?ooo`2G8`00000S1@3oool30?l0000300000000I_l006Ko04h006Ko00H0
06J?0000=@00I_l006Ko000F00009/@4001Vo`<0o`00D000I_l00`00IXl0000D001>o`03001Vo`03
000V500025l006Ko008006Ko0`3o000]0?ooo`008P3oool01@2G8`00000S0?ooo`0S000002>G00L0
oooo0P00001@001Vo`03001VS`0003D006Ko00@006Ko00<002HD000Va000I_l0D`00I_l00`00IXl0
000D001>o`04001Vo`0300080000>Ol006Ko00<006Ko00<000000?ooo`3oool0:`3oool00280oooo
00D0oiLS0000000SD2<0000002>Go`070?ooo`030000000co`00000004l006Ko00<006J?0000=@00
I_l01000I_l00`009Q@002K4001Vo`1C001Vo`03001VS`0001@004ko00<006Ko00<002HD0000=@00
I_l01000I_l00`000000oooo0?ooo`0[0?ooo`00803oool00`1@2`00000000000002000000030000
8`3oool0oooo00L0oooo0P00001>001Vo`03000i=@000000000000H0000000<002K4001Vo`00I_l0
D@00I_l00`00>CD00000000000040000000300005000C_l006Ko00@006Ko00<000000?ooo`3oool0
:`3oool002l0oooo00<0000003?o00000000^000I_l00`000000oooo0?ooo`0[0?ooo`00;`3oool0
10000000<ol003?o0000002g001Vo`030000003oool0oooo02/0oooo000_0?ooo`040000000co`00
<ol000000;L006Ko00<000000?ooo`3oool0:`3oool00300oooo00@0000003?o000co`000000]P00
I_l00`000000oooo0?ooo`0[0?ooo`00<03oool010000000<ol003?o0000002f001Vo`030000003o
ool0oooo02/0oooo000`0?ooo`050000000co`00<ol003?o00000000]@00I_l00`000000oooo0?oo
o`0[0?ooo`00<@3oool010000000<ol003?o0000002e001Vo`030000003oool0oooo02/0oooo000a
0?ooo`050000000co`00<ol003?o00000000]000I_l00`000000oooo0?ooo`0[0?ooo`00<@3oool0
0`000000<ol003?o000203?o000300000000I_l006Ko0;4006Ko00<000000?ooo`3oool0:`3oool0
0340oooo00<0000003?o000co`000P0co`000`00000006Ko001Vo`2a001Vo`030000003oool0oooo
02/0oooo000b0?ooo`030000000co`00<ol00080<ol000<00000001Vo`00I_l0/000I_l00`000000
oooo0?ooo`0[0?ooo`00<P3oool00`000000<ol003?o000203?o000300000000I_l006Ko0;0006Ko
00<000000?ooo`3oool0:`3oool00380oooo00<0000003?o000co`000`0co`000`00000006Ko001V
o`2_001Vo`030000003oool0oooo02/0oooo000b0?ooo`030000000co`00<ol000<0<ol000<00000
001Vo`00I_l0[`00I_l00`000000oooo0?ooo`0[0?ooo`00<`3oool00`000000<ol003?o000303?o
000300000000I_l006Ko0:h006Ko00<000000?ooo`3oool0:`3oool003<0oooo00<0000003?o000c
o`00100co`000`00000006Ko001Vo`2]001Vo`030000003oool0oooo02/0oooo000c0?ooo`030000
000co`00<ol000@0<ol000<00000001Vo`00I_l0[@00I_l00`000000oooo0?ooo`0[0?ooo`00<`3o
ool00`000000<ol003?o000503?o000300000000I_l006Ko0:`006Ko00<000000?ooo`3oool0:`3o
ool003@0oooo00<0000003?o000co`00100co`000`00000006Ko001Vo`2/001Vo`030000003oool0
oooo02/0oooo000d0?ooo`030000000co`00<ol000D0<ol000<00000001Vo`00I_l0Z`00I_l00`00
0000oooo0?ooo`0[0?ooo`00=03oool00`000000<ol003?o000503?o000300000000I_l006Ko0:/0
06Ko00<000000?ooo`3oool0:`3oool003D0oooo00<0000003?o000co`001@0co`000`00000006Ko
001Vo`2Z001Vo`030000003oool0oooo02/0oooo000e0?ooo`030000000co`00<ol000H0<ol000<0
0000001Vo`00I_l0Z@00I_l00`000000oooo0?ooo`0[0?ooo`00=@3oool00`000000<ol003?o0006
03?o000300000000I_l006Ko0:T006Ko00<000000?ooo`3oool0:`3oool003D0oooo00<0000003?o
000co`001`0co`000`00000006Ko001Vo`2X001Vo`030000003oool0oooo02/0oooo000f0?ooo`03
0000000co`00<ol000H0<ol000<00000001Vo`00I_l0Z000I_l00`000000oooo0?ooo`0[0?ooo`00
=P3oool00`000000<ol003?o000703?o000300000000I_l006Ko0:L006Ko00<000000?ooo`3oool0
:`3oool003H0oooo00<0000003?o000co`001`0co`000`00000006Ko001Vo`2W001Vo`030000003o
ool0oooo02/0oooo000f0?ooo`030000000co`00<ol000P0<ol000<00000001Vo`00I_l0YP00I_l0
0`000000oooo0?ooo`0[0?ooo`00=`3oool00`000000<ol003?o000803?o000300000000I_l006Ko
0:D006Ko00<000000?ooo`3oool0:`3oool003L0oooo00<0000003?o000co`00200co`000`000000
06Ko001Vo`2U001Vo`030000003oool0oooo02/0oooo000g0?ooo`030000000co`00<ol000T0<ol0
00<00000001Vo`00I_l0Y000I_l00`000000oooo0?ooo`0[0?ooo`00>03oool00`000000<ol003?o
000803?o000300000000I_l006Ko0:@006Ko00<000000?ooo`3oool0:`3oool003P0oooo00<00000
03?o000co`002@0co`000`00000006Ko001Vo`2S001Vo`030000003oool0oooo02/0oooo000h0?oo
o`030000000co`00<ol000X0<ol000<00000001Vo`00I_l0XP00I_l00`000000oooo0?ooo`0[0?oo
o`00>03oool00`000000<ol003?o000:03?o000300000000I_l006Ko0:8006Ko00<000000?ooo`3o
ool0:`3oool003T0oooo00<0000003?o000co`002P0co`000`00000006Ko001Vo`2Q001Vo`030000
003oool0oooo02/0oooo000i0?ooo`030000000co`00<ol000X0<ol000<00000001Vo`00I_l0X@00
I_l00`000000oooo0?ooo`0[0?ooo`00>@3oool00`000000<ol003?o000;03?o000300000000I_l0
06Ko0:0006Ko00<000000?ooo`3oool0:`3oool003T0oooo00<0000003?o000co`002`0co`000`00
000006Ko001Vo`2P001Vo`030000003oool0oooo02/0oooo000j0?ooo`030000000co`00<ol000/0
<ol000<00000001Vo`00I_l0W`00I_l00`000000oooo0?ooo`0[0?ooo`00>P3oool00`000000<ol0
03?o000<03?o000300000000I_l006Ko09h006Ko00<000000?ooo`3oool0:`3oool003X0oooo00<0
000003?o000co`00300co`000`00000006Ko001Vo`2N001Vo`030000003oool0oooo02/0oooo000j
0?ooo`030000000co`00<ol000d0<ol000<00000001Vo`00I_l0W@00I_l00`000000oooo0?ooo`0[
0?ooo`00>`3oool00`000000<ol003?o000<03?o000300000000I_l006Ko09d006Ko00<000000?oo
o`3oool0:`3oool003/0oooo00<0000003?o000co`003@0co`000`00000006Ko001Vo`2L001Vo`03
0000003oool0oooo02/0oooo000k0?ooo`030000000co`00<ol000d0<ol000<00000001Vo`00I_l0
W000I_l00`000000oooo0?ooo`0[0?ooo`00?03oool00`000000<ol003?o000=03?o000300000000
I_l006Ko09/006Ko00<000000?ooo`3oool0:`3oool003`0oooo00<0000003?o000co`003P0co`00
0`00000006Ko001Vo`2J001Vo`030000003oool0oooo02/0oooo000l0?ooo`030000000co`00<ol0
00h0<ol000<00000001Vo`00I_l0VP00I_l00`000000oooo0?ooo`0[0?ooo`00?03oool00`000000
<ol003?o000?03?o000300000000I_l006Ko09T006Ko00<000000?ooo`3oool0:`3oool003d0oooo
00<0000003?o000co`003P0co`000`00000006Ko001Vo`2I001Vo`030000003oool0oooo02/0oooo
000m0?ooo`030000000co`00<ol000l0<ol000<00000001Vo`00I_l0V000I_l00`000000oooo0?oo
o`0[0?ooo`00?@3oool00`000000<ol003?o000?03?o000300000000I_l006Ko09P006Ko00<00000
0?ooo`3oool0:`3oool003d0oooo00<0000003?o000co`00400co`000`00000006Ko001Vo`2G001V
o`030000003oool0oooo02/0oooo000n0?ooo`030000000co`00<ol00100<ol000<00000001Vo`00
I_l0UP00I_l00`000000oooo0?ooo`0[0?ooo`00?P3oool00`000000<ol003?o000@03?o00030000
0000I_l006Ko09H006Ko00<000000?ooo`3oool0:`3oool003h0oooo00<0000003?o000co`004@0c
o`000`00000006Ko001Vo`2E001Vo`030000003oool0oooo02/0oooo000o0?ooo`030000000co`00
<ol00100<ol000<00000001Vo`00I_l0U@00I_l00`000000oooo0?ooo`0[0?ooo`00?`3oool00`00
0000<ol003?o000A03?o000300000000I_l006Ko09@006Ko00<000000?ooo`3oool0:`3oool003l0
oooo00<0000003?o000co`004@0co`000`00000006Ko001Vo`2D001Vo`030000003oool0oooo02/0
oooo000o0?ooo`030000000co`00<ol00180<ol000<00000001Vo`00I_l0T`00I_l00`000000oooo
0?ooo`0[0?ooo`00@03oool00`000000<ol003?o000B03?o000300000000I_l006Ko098006Ko00<0
00000?ooo`3oool0:`3oool00400oooo00<0000003?o000co`004P0co`000`00000006Ko001Vo`2B
001Vo`030000003oool0oooo02/0oooo00100?ooo`030000000co`00<ol001<0<ol000<00000001V
o`00I_l0T@00I_l00`000000oooo0?ooo`0[0?ooo`00@03oool00`000000<ol003?o000C03?o0003
00000000I_l006Ko094006Ko00<000000?ooo`3oool0:`3oool00440oooo00<0000003?o000co`00
4`0co`000`00000006Ko001Vo`2@001Vo`030000003oool0oooo02/0oooo00110?ooo`030000000c
o`00<ol001<0<ol000<00000001Vo`00I_l0T000I_l00`000000oooo0?ooo`0[0?ooo`00@@3oool0
0`000000<ol003?o000D03?o000300000000I_l006Ko08l006Ko00<000000?ooo`3oool0:`3oool0
0480oooo00<0000003?o000co`00500co`000`00000006Ko001Vo`2>001Vo`030000003oool0oooo
02/0oooo00120?ooo`030000000co`00<ol001@0<ol000<00000001Vo`00I_l0SP00I_l00`000000
oooo0?ooo`0[0?ooo`00@P3oool00`000000<ol003?o000E03?o000300000000I_l006Ko08d006Ko
00<000000?ooo`3oool0:`3oool00480oooo00<0000003?o000co`005@0co`000`00000006Ko001V
o`2=001Vo`030000003oool0oooo02/0oooo00130?ooo`030000000co`00<ol001D0<ol000<00000
001Vo`00I_l0S000I_l00`000000oooo0?ooo`0[0?ooo`00@`3oool00`000000<ol003?o000E03?o
000300000000I_l006Ko08`006Ko00<000000?ooo`3oool0:`3oool004<0oooo00<0000003?o000c
o`005P0co`000`00000006Ko001Vo`2;001Vo`030000003oool0oooo02/0oooo00130?ooo`030000
000co`00<ol001L0<ol000<00000001Vo`00I_l0RP00I_l00`000000oooo0?ooo`0[0?ooo`00A03o
ool00`000000<ol003?o000F03?o000300000000I_l006Ko08X006Ko00<000000?ooo`3oool0:`3o
ool004@0oooo00<0000003?o000co`005`0co`000`00000006Ko001Vo`29001Vo`030000003oool0
oooo02/0oooo00140?ooo`030000000co`00<ol001L0<ol000<00000001Vo`00I_l0R@00I_l00`00
0000oooo0?ooo`0[0?ooo`00A03oool00`000000<ol003?o000H03?o000300000000I_l006Ko08P0
06Ko00<000000?ooo`3oool0:`3oool004D0oooo00<0000003?o000co`005`0co`000`00000006Ko
001Vo`28001Vo`030000003oool0oooo02/0oooo00150?ooo`030000000co`00<ol001P0<ol000<0
0000001Vo`00I_l0Q`00I_l00`000000oooo0?ooo`0[0?ooo`00A@3oool00`000000<ol003?o000I
03?o000300000000I_l006Ko08H006Ko00<000000?ooo`3oool0:`3oool004H0oooo00<0000003?o
000co`00600co`000`00000006Ko001Vo`26001Vo`030000003oool0oooo02/0oooo00160?ooo`03
0000000co`00<ol001T0<ol000<00000001Vo`00I_l0Q@00I_l00`000000oooo0?ooo`0[0?ooo`00
AP3oool00`000000<ol003?o000I03?o000300000000I_l006Ko08D006Ko00<000000?ooo`3oool0
:`3oool004H0oooo00<0000003?o000co`006P0co`000`00000006Ko001Vo`24001Vo`030000003o
ool0oooo02/0oooo00170?ooo`030000000co`00<ol001T0<ol000<00000001Vo`00I_l0Q000I_l0
0`000000oooo0?ooo`0[0?ooo`00A`3oool00`000000<ol003?o000J03?o000300000000I_l006Ko
08<006Ko00<000000?ooo`3oool0:`3oool004L0oooo00<0000003?o000co`006`0co`000`000000
06Ko001Vo`22001Vo`030000003oool0oooo02/0oooo00170?ooo`030000000co`00<ol001/0<ol0
00<00000001Vo`00I_l0PP00I_l00`000000oooo0?ooo`0[0?ooo`00B03oool00`000000<ol003?o
000K03?o000300000000I_l006Ko084006Ko00<000000?ooo`3oool0:`3oool004P0oooo00<00000
03?o000co`006`0co`000`00000006Ko001Vo`21001Vo`030000003oool0oooo02/0oooo00180?oo
o`030000000co`00<ol001`0<ol000<00000001Vo`00I_l0P000I_l00`000000oooo0?ooo`0[0?oo
o`00B@3oool00`000000<ol003?o000K03?o000300000000I_l006Ko080006Ko00<000000?ooo`3o
ool0:`3oool004T0oooo00<0000003?o000co`00700co`000`00000006Ko001Vo`1o001Vo`030000
003oool0oooo02/0oooo00190?ooo`030000000co`00<ol001d0<ol000<00000001Vo`00I_l0OP00
I_l00`000000oooo0?ooo`0[0?ooo`00B@3oool00`000000<ol003?o000M03?o000300000000I_l0
06Ko07h006Ko00<000000?ooo`3oool0:`3oool004X0oooo00<0000003?o000co`007@0co`000`00
000006Ko001Vo`1m001Vo`030000003oool0oooo02/0oooo001:0?ooo`030000000co`00<ol001d0
<ol000<00000001Vo`00I_l0O@00I_l00`000000oooo0?ooo`0[0?ooo`00BP3oool00`000000<ol0
03?o000N03?o000300000000I_l006Ko07`006Ko00<000000?ooo`3oool0:`3oool004X0oooo00<0
000003?o000co`007P0co`000`00000006Ko001Vo`1l001Vo`030000003oool0oooo02/0oooo001;
0?ooo`030000000co`00<ol001h0<ol000<00000001Vo`00I_l0N`00I_l00`000000oooo0?ooo`0[
0?ooo`00B`3oool00`000000<ol003?o000O03?o000300000000I_l006Ko07X006Ko00<000000?oo
o`3oool0:`3oool004/0oooo00<0000003?o000co`007`0co`000`00000006Ko001Vo`1j001Vo`03
0000003oool0oooo02/0oooo001;0?ooo`030000000co`00<ol00200<ol000<00000001Vo`00I_l0
N@00I_l00`000000oooo0?ooo`0[0?ooo`00C03oool00`000000<ol003?o000O03?o000300000000
I_l006Ko07T006Ko00<000000?ooo`3oool0:`3oool004`0oooo00<0000003?o000co`002`0co`00
0`0cg`003`000000000200000003001d000co`00<ol000d0<ol000<00000001Vo`00I_l0N000I_l0
0`000000oooo0?ooo`0[0?ooo`00C03oool00`000000<ol003?o000:03?o000303>o000000008=l0
00<0<ol000<084P00018000co`003@0co`000`00000006Ko001Vo`1h001Vo`030000003oool0oooo
02/0oooo001=0?ooo`030000000co`00<ol00100<ol000<084P001No000co`003@0co`000`000000
06Ko001Vo`1g001Vo`030000003oool0oooo02/0oooo001=0?ooo`030000000co`00<ol00100<ol0
00<084P0023O000co`003P0co`000`00000006Ko001Vo`1f001Vo`030000003oool0oooo02/0oooo
001=0?ooo`030000000co`00<ol000l0<ol000<05`00001d000co`003`0co`000`00000006Ko001V
o`1f001Vo`030000003oool0oooo02/0oooo001=0?ooo`030000000co`00<ol000`0<ol000@09W@0
0000000000003i`04P0co`000`00000006Ko001Vo`1e001Vo`030000003oool0oooo02/0oooo001>
0?ooo`030000000co`00<ol000h0<ol000<05`0000nL000co`00400co`000`00000006Ko001Vo`1e
001Vo`030000003oool0oooo02/0oooo001>0?ooo`030000000co`00<ol000h0<ol000<0<ml000m8
000co`004@0co`000`00000006Ko001Vo`1d001Vo`030000003oool0oooo02/0oooo001>0?ooo`03
0000000co`00<ol000h0<ol000<0<ml000m8000co`004P0co`000`00000006Ko001Vo`1c001Vo`03
0000003oool0oooo02/0oooo001>0?ooo`030000000co`00<ol000T0<ol000<05`00001d000co`00
0P0co`000`0G00003i`003?o000B03?o000300000000I_l006Ko07<006Ko00<000000?ooo`3oool0
:`3oool004l0oooo00<0000003?o000co`002@0co`001@0VM00000000000000000003i`001D0<ol0
00<00000001Vo`00I_l0LP00I_l00`000000oooo0?ooo`0[0?ooo`00C`3oool00`000000<ol003?o
000S03?o000300000000I_l006Ko078006Ko00<000000?ooo`3oool0:`3oool004l0oooo00<00000
03?o000co`00900co`000`00000006Ko001Vo`1a001Vo`030000003oool0oooo02/0oooo001@0?oo
o`030000000co`00<ol002<0<ol000<00000001Vo`00I_l0L@00I_l00`000000oooo0?ooo`0[0?oo
o`00D03oool00`000000<ol003?o000T03?o000300000000I_l006Ko070006Ko00<000000?ooo`3o
ool0:`3oool00500oooo00<0000003?o000co`009@0co`000`00000006Ko001Vo`1_001Vo`030000
003oool0oooo02/0oooo001@0?ooo`030000000co`00<ol002D0<ol000<00000001Vo`00I_l0K`00
I_l00`000000oooo0?ooo`0[0?ooo`00D@3oool00`000000<ol003?o000U03?o000300000000I_l0
06Ko06h006Ko00<000000?ooo`3oool0:`3oool00540oooo00<0000003?o000co`009@0co`000`00
000006Ko001Vo`1^001Vo`030000003oool0oooo02/0oooo001A0?ooo`030000000co`00<ol002H0
<ol000<00000001Vo`00I_l0K@00I_l00`000000oooo0?ooo`0[0?ooo`00D@3oool00`000000<ol0
03?o000V03?o000300000000I_l006Ko06d006Ko00<000000?ooo`3oool0:`3oool00580oooo00<0
000003?o000co`009P0co`000`00000006Ko001Vo`1/001Vo`030000003oool0oooo02/0oooo001B
0?ooo`030000000co`00<ol002L0<ol000<00000001Vo`00I_l0J`00I_l00`000000oooo0?ooo`0[
0?ooo`00DP3oool00`000000<ol003?o000W03?o000300000000I_l006Ko06/006Ko00<000000?oo
o`3oool0:`3oool005<0oooo00<0000003?o000co`009`0co`000`00000006Ko001Vo`1Z001Vo`03
0000003oool0oooo02/0oooo001C0?ooo`030000000co`00<ol002L0<ol000<00000001Vo`00I_l0
JP00I_l00`000000oooo0?ooo`0[0?ooo`00D`3oool00`000000<ol003?o000X03?o000300000000
I_l006Ko06T006Ko00<000000?ooo`3oool0:`3oool005<0oooo00<0000003?o000co`00:00co`00
0`00000006Ko001Vo`1Y001Vo`030000003oool0oooo02/0oooo001D0?ooo`030000000co`00<ol0
02P0<ol000<00000001Vo`00I_l0J000I_l00`000000oooo0?ooo`0[0?ooo`00E03oool00`000000
<ol003?o000Y03?o000300000000I_l006Ko06L006Ko00<000000?ooo`3oool0:`3oool005@0oooo
00<0000003?o000co`00:@0co`000`00000006Ko001Vo`1W001Vo`030000003oool0oooo02/0oooo
001D0?ooo`030000000co`00<ol002X0<ol000<00000001Vo`00I_l0IP00I_l00`000000oooo0?oo
o`0[0?ooo`00E@3oool00`000000<ol003?o000Y03?o000300000000I_l006Ko06H006Ko00<00000
0?ooo`3oool0:`3oool005D0oooo00<0000003?o000co`00:P0co`000`00000006Ko001Vo`1U001V
o`030000003oool0oooo02/0oooo001E0?ooo`030000000co`00<ol002X0<ol000<00000001Vo`00
I_l0I@00I_l00`000000oooo0?ooo`0[0?ooo`00E@3oool00`000000<ol003?o000[03?o00030000
0000I_l006Ko06@006Ko00<000000?ooo`3oool0:`3oool005H0oooo00<0000003?o000co`00:`0c
o`000`00000006Ko001Vo`1S001Vo`030000003oool0oooo02/0oooo001F0?ooo`030000000co`00
<ol002/0<ol000<00000001Vo`00I_l0H`00I_l00`000000oooo0?ooo`0[0?ooo`00EP3oool00`00
0000<ol003?o000/03?o000300000000I_l006Ko068006Ko00<000000?ooo`3oool0:`3oool005L0
oooo00<0000003?o000co`00:`0co`000`00000006Ko001Vo`1R001Vo`030000003oool0oooo02/0
oooo001G0?ooo`030000000co`00<ol002`0<ol000<00000001Vo`00I_l0H@00I_l00`000000oooo
0?ooo`0[0?ooo`00E`3oool00`000000<ol003?o000/03?o000300000000I_l006Ko064006Ko00<0
00000?ooo`3oool0:`3oool005L0oooo00<0000003?o000co`00;@0co`000`00000006Ko001Vo`1P
001Vo`030000003oool0oooo02/0oooo001H0?ooo`030000000co`00<ol002d0<ol000<00000001V
o`00I_l0G`00I_l00`000000oooo0?ooo`0[0?ooo`00F03oool00`000000<ol003?o000]03?o0003
00000000I_l006Ko05l006Ko00<000000?ooo`3oool0:`3oool005P0oooo00<0000003?o000co`00
;P0co`000`00000006Ko001Vo`1N001Vo`030000003oool0oooo02/0oooo001H0?ooo`030000000c
o`00<ol002@0<ol000<02`0000000000000010000000100;S`00<ol003?o0000001P001Vo`030000
003oool0oooo02/0oooo001I0?ooo`030000000co`00<ol002@0<ol000<07CD000EO000co`000`0c
o`00100;00002hl003?o000co`030?l005d006Ko00<000000?ooo`3oool0:`3oool005T0oooo00<0
000003?o000co`00900co`000`0M=@001El003?o000303?o000303?4000500007Ol000D0o`00G000
I_l00`000000oooo0?ooo`0[0?ooo`00F@3oool00`000000<ol003?o000T03?o000301de0005G`00
<ol000@0<ol000<051@000^?003o0000103o001L001Vo`030000003oool0oooo02/0oooo001J0?oo
o`030000000co`00<ol002<0<ol000<07CD000EO000co`00100co`000`0M=@001El00?l000040?l0
05`006Ko00<000000?ooo`3oool0:`3oool005X0oooo00<0000003?o000co`008`0co`000`0M=@00
1El003?o000403?o0080000000@006Ko0?l0003o0000o`00G@00I_l00`000000oooo0?ooo`0[0?oo
o`00FP3oool00`000000<ol003?o000S03?o000301de0005G`00<ol00080<ol00P0000000`002000
03Wo001Vo`1P001Vo`030000003oool0oooo02/0oooo001J0?ooo`030000000co`00<ol002<0<ol0
00P07CD000EO000co`00<ol000000000I_l004iO0000=F8006Ko00<000000?ooo`3oool0:`3oool0
05/0oooo00<0000003?o000co`008P0co`00200M=@001El000000000000006Ko000i=@00000003Wo
HP00I_l00`000000oooo0?ooo`0[0?ooo`00F`3oool00`000000<ol003?o000Q03?o000300/00000
0000000000<0000000<0000e001Vo`00I_l0HP00I_l00`000000oooo0?ooo`0[0?ooo`00F`3oool0
0`000000<ol003?o000Q03?o000300000000I_l006Ko06P006Ko00<000000?ooo`3oool0:`3oool0
05/0oooo00<0000003?o000co`007`0co`02000006/006Ko00<000000?ooo`3oool0:`3oool005`0
oooo00<0000003?o000co`00700co`02000006d006Ko00<000000?ooo`3oool0:`3oool005`0oooo
00<0000003?o000co`006P0co`02000006l006Ko00<000000?ooo`3oool0:`3oool005`0oooo00<0
000003?o000co`006@0co`000`00000006Ko001Vo`1_001Vo`030000003oool0oooo02/0oooo001L
0?ooo`030000000co`00<ol001L0<ol00P00001b001Vo`030000003oool0oooo02/0oooo001M0?oo
o`030000000co`00<ol001@0<ol00P00001d001Vo`030000003oool0oooo02/0oooo001M0?ooo`03
0000000co`00<ol001<0<ol000<00000001Vo`00I_l0M000I_l00`000000oooo0?ooo`0[0?ooo`00
G@3oool00`000000<ol003?o000A03?o00800000M`00I_l00`000000oooo0?ooo`0[0?ooo`00GP3o
ool00`000000<ol003?o000>03?o00800000N@00I_l00`000000oooo0?ooo`0[0?ooo`00GP3oool0
0`000000<ol003?o000<03?o00800000N`00I_l00`000000oooo0?ooo`0[0?ooo`00GP3oool00`00
0000<ol003?o000;03?o000300000000I_l006Ko07/006Ko00<000000?ooo`3oool0:`3oool005h0
oooo00<0000003?o000co`002@0co`02000007h006Ko00<000000?ooo`3oool0:`3oool005l0oooo
00<0000003?o000co`001P0co`020000080006Ko00<000000?ooo`3oool0:`3oool005l0oooo00<0
000003?o000co`001@0co`000`00000006Ko001Vo`20001Vo`030000003oool0oooo02/0oooo001D
0?ooo`030?ooS`0e0000000000<0000000<001AO0?ooo`3oool00P3oool00`000000<ol003?o0003
03?o008000005`00I_l00`00>CD000000000000600000003000Va000I_l006Ko05D006Ko00D001H0
00000000000000000000=@06001Vo`030000003oool0oooo02/0oooo001C0?ooo`030?ooS`0e0000
=Hoo00@0oooo00@0a5lD000DG`3oool0oooo0`3o000203?o008000006P00I_l00`00IXl0000D001>
o`04001Vo`04000V50009/@006Ko001Vo`<0o`00D@00I_l00`005P0001J?001Vo`02001Vo`03000i
=@00000003Wo008006Ko0`3o000]0?ooo`00D`3oool00`2?=@0055o40?ooo`040?ooo`030?n?=@00
55l0oooo00D0o`0000<00000001Vo`00I_l06P00I_l00`00IXl0000D001>o`04001Vo`03000V5000
9/@006Ko00D0o`00C`00I_l00`009Q@001J?001Vo`04001Vo`03001>G`0003D006Ko00D0o`00;03o
ool00580oooo00<0oon?03D0501Oa?l01@3oool00`3oScD001AO0?ooo`050?l002L000001@3o001I
000000D0o`00;03oool00580oooo00<0oon?03D0=@2?ool00P3oool00`34Ga@00000000000020000
000301AOa03o0000o`0000<0o`007@3oool01P3oohl0=@0D05o4o`3oool0ScD001AOa0@0oooo1@3o
001>0?ooo`030?ooS`0e03D0Sooo00P0oooo1@3o000/0?ooo`00DP3oool00`3oohl0=@0e08ooo`09
0?ooo`<0o`007P3oool00`3oohl0=@00000000020000000301AOa03oool0oooo00<0oooo0`3o001?
0?ooo`030?ooS`0e03D0Sooo00T0oooo0`3o000]0?ooo`00D`3oool00`1O51@0GlCo0?ooo`0Y0?oo
o`060?ooS`0e01@0GlCo0?ooo`2?=@0055o4E`3oool00`3oohl0=@0D05o4o`0i0?ooo`00D`3oool0
0`34Ga@055o40?ooo`040?ooo`030?n?=@0055l0oooo0280oooo00<0oon?03D0501Oa?l0103oool0
0`1O51@0GlCo0?ooo`1D0?ooo`030<AO500eSol0oooo00@0oooo00<0a5lD000DG`3oool0<@3oool0
05@0oooo00<0Ga@0000eS`3oool00P3oool00`34Ga@00000000DG`0S0?ooo`030?ooS`0e01@0GlCo
00@0oooo00<0Ga@D05o4o`3oool0E03oool00`3oohl0=@00000eS`030?ooo`0308le000051@051AO
0380oooo001E0?ooo`0708le0000000000000000000055l0ohle000DG`0R0?ooo`030?n?=@000000
000000D0000000<0000D05o4o`3oool0EP3oool01`2?=@00000000000000000003F?0?o4G`0D55l0
<P3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00001\
\>"],
  ImageRangeCache->{{{91.5625, 240.375}, {562.563, 413.75}} -> {-0.615299, \
2.78037, 0.00537595, 0.00537595}}],

Cell["\<\
Now we can do the analogous step with corner C, fixing B and bringing C onto \
the current position of D.  \
\>", "Text"],

Cell[TextData[{
  "An Origami Proof Problem: ",
  "Prove that, for all squares ABCD, ",
  Cell[BoxData[
      \(TraditionalForm\`GD\&_\)]],
  " = 2 ",
  Cell[BoxData[
      \(TraditionalForm\`ED\&_\)]],
  "."
}], "Text"],

Cell[TextData[StyleBox["The Translation into a Prove Problem on Equalities:",
  FontWeight->"Bold"]], "Text"],

Cell[TextData[{
  "First, note that ",
  Cell[BoxData[
      \(TraditionalForm\`AB\&_\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`BC\&_\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`CD\&_\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`DA\&_\)]],
  ", since we start from a square. Hence, whenever the length of one of these \
four edges occurs, we replace it by ",
  Cell[BoxData[
      \(TraditionalForm\`AB\&_\)]],
  "."
}], "Text"],

Cell["Now observe that", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DF\&_\^2 = \(AD\&_\^2 - AF\&_\^2 = \(AB\&_\^2 - \((AB\&_/2)\)\^2 = 
          3/4 \(\( AB\&_\^2\)\(.\)\)\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.83671 .16329 m .83671 .83671 L .34373 .83671 L p 0 .4 1 r
F P
0 g
s
1 0 0 r
.02 w
.83671 .83671 Mdot
.5 .83671 Mdot
.83671 .83671 Mdot
.5 .83671 Mdot
.5 Mabswid
.34373 .83671 m .16329 .16329 L .83671 .16329 L p 0 .4 1 r
F P
0 g
s
1 0 0 r
.02 w
.83671 .16329 Mdot
.83671 .16329 Mdot
.16329 .16329 Mdot
.5 .16329 Mdot
.16329 .16329 Mdot
.5 .16329 Mdot
.5 Mabswid
.16329 .16329 m .34373 .83671 L .5 .74649 L closepath p .2 1 0 r
F P
0 g
s
1 0 0 r
.02 w
.16329 .16329 Mdot
.5 .74649 Mdot
.16329 .16329 Mdot
.5 .74649 Mdot
.34373 .83671 Mdot
0 g
gsave
.16329 .16329 -72.875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.875 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83671 .16329 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83671 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .16329 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16329 .16329 -72.875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.875 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83671 .16329 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83671 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .16329 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34373 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16329 .16329 -72.875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.875 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .74649 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16329 .16329 -72.875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.875 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .74649 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34373 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.33567 .58216 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{187.313, 187.313},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H000162000`400?l00000o`00003oo`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`007P3oool0203oD0/00000000000000000000;053oo`3oool0oe0;1000
00000`0SUol0oooo0?ooo`1B0?ooo`030?n?=@00000000000080000000<0000D05o4o`3oool0E@3o
ool00`3oScD000000000000500000003000eS`3oool0oooo0340oooo000O0?ooo`030?ooD00;0000
2e3o00D0oooo00<0Ub<000008`3oool0EP3oool00`3oohl0=@0e08ooo`1J0?ooo`030?ooS`0e01@0
GlCo00@0oooo00<0Ga@0000eS`3oool0<@3oool00200oooo00<0D0/0000;D03oool0103oool00`0S
000002>G0?ooo`020?ooo`<0o`00D@3oool00`3oohl0=@0e08ooo`070?ooo`<0o`00D03oool00`3o
ohl0=@0D05o4o`040?ooo`040?ooS`0e03D0Sooo0?ooo`<0o`00;@3oool00200oooo00<0oiLS0000
0000000010000000100000/0D?oo0?ooo`3oool50?l005T000001@3o001I000000D0o`00;03oool0
0240oooo00<08`00000SU`3oool00P3oool00`1@2`0000]@0?ooo`020?ooo`D0o`00D000I_l01P00
IXl0000e001Vo`00I_l001H0000io`<006Ko1@3o001?001Vo`03001VS`0001@004ko00<006Ko00@0
04iO000000009/@006Ko1@3o000/0?ooo`008@3oool01`3oD0/0000;053oo`3oool0oom@00/0000;
D?l00`3oool50?l0050006Ko00<006J?0000000000000P00000010009/@006Ko001Vo`00I_l50?l0
04l006Ko00<006J?0000000000000`000000100001@004ko001Vo`00I_l50?l002`0oooo000Q0?oo
o`060?ooD00;00002e3o0?ooo`2G8`00000S1@3oool30?l0000300000000I_l006Ko04h006Ko00H0
06J?0000=@00I_l006Ko000F00009/@4001Vo`<0o`00D000I_l00`00IXl0000D001>o`03001Vo`03
000V500025l006Ko008006Ko0`3o000]0?ooo`008P3oool01@2G8`00000S0?ooo`0S000002>G00L0
oooo0P00001@001Vo`03001VS`0003D006Ko00@006Ko00<002HD000Va000I_l0D`00I_l00`00IXl0
000D001>o`04001Vo`0300080000>Ol006Ko00<006Ko00<000000?ooo`3oool0:`3oool00280oooo
00D0oiLS0000000SD2<0000002>Go`070?ooo`030000000co`00000004l006Ko00<006J?0000=@00
I_l01000I_l00`009Q@002K4001Vo`1C001Vo`03001VS`0001@004ko00<006Ko00<002HD0000=@00
I_l01000I_l00`000000oooo0?ooo`0[0?ooo`00803oool00`1@2`00000000000002000000030000
8`3oool0oooo00L0oooo0P00001>001Vo`03000i=@000000000000H0000000<002K4001Vo`00I_l0
D@00I_l00`00>CD00000000000040000000300005000C_l006Ko00@006Ko00<000000?ooo`3oool0
:`3oool002l0oooo00<0000003?o00000000^000I_l00`000000oooo0?ooo`0[0?ooo`00;`3oool0
10000000<ol003?o0000002g001Vo`030000003oool0oooo02/0oooo000_0?ooo`040000000co`00
<ol000000;L006Ko00<000000?ooo`3oool0:`3oool00300oooo00@0000003?o000co`000000]P00
I_l00`000000oooo0?ooo`0[0?ooo`00<03oool010000000<ol003?o0000002f001Vo`030000003o
ool0oooo02/0oooo000`0?ooo`050000000co`00<ol003?o00000000]@00I_l00`000000oooo0?oo
o`0[0?ooo`00<@3oool010000000<ol003?o0000002e001Vo`030000003oool0oooo02/0oooo000a
0?ooo`050000000co`00<ol003?o00000000]000I_l00`000000oooo0?ooo`0[0?ooo`00<@3oool0
0`000000<ol003?o000203?o000300000000I_l006Ko0;4006Ko00<000000?ooo`3oool0:`3oool0
0340oooo00<0000003?o000co`000P0co`000`00000006Ko001Vo`2a001Vo`030000003oool0oooo
02/0oooo000b0?ooo`030000000co`00<ol00080<ol000<00000001Vo`00I_l0/000I_l00`000000
oooo0?ooo`0[0?ooo`00<P3oool00`000000<ol003?o000203?o000300000000I_l006Ko0;0006Ko
00<000000?ooo`3oool0:`3oool00380oooo00<0000003?o000co`000`0co`000`00000006Ko001V
o`2_001Vo`030000003oool0oooo02/0oooo000b0?ooo`030000000co`00<ol000<0<ol000<00000
001Vo`00I_l0[`00I_l00`000000oooo0?ooo`0[0?ooo`00<`3oool00`000000<ol003?o000303?o
000300000000I_l006Ko0:h006Ko00<000000?ooo`3oool0:`3oool003<0oooo00<0000003?o000c
o`00100co`000`00000006Ko001Vo`2]001Vo`030000003oool0oooo02/0oooo000c0?ooo`030000
000co`00<ol000@0<ol000<00000001Vo`00I_l0[@00I_l00`000000oooo0?ooo`0[0?ooo`00<`3o
ool00`000000<ol003?o000503?o000300000000I_l006Ko0:`006Ko00<000000?ooo`3oool0:`3o
ool003@0oooo00<0000003?o000co`00100co`000`00000006Ko001Vo`2/001Vo`030000003oool0
oooo02/0oooo000d0?ooo`030000000co`00<ol000D0<ol000<00000001Vo`00I_l0Z`00I_l00`00
0000oooo0?ooo`0[0?ooo`00=03oool00`000000<ol003?o000503?o000300000000I_l006Ko0:/0
06Ko00<000000?ooo`3oool0:`3oool003D0oooo00<0000003?o000co`001@0co`000`00000006Ko
001Vo`2Z001Vo`030000003oool0oooo02/0oooo000e0?ooo`030000000co`00<ol000H0<ol000<0
0000001Vo`00I_l0Z@00I_l00`000000oooo0?ooo`0[0?ooo`00=@3oool00`000000<ol003?o0006
03?o000300000000I_l006Ko0:T006Ko00<000000?ooo`3oool0:`3oool003D0oooo00<0000003?o
000co`001`0co`000`00000006Ko001Vo`2X001Vo`030000003oool0oooo02/0oooo000f0?ooo`03
0000000co`00<ol000H0<ol000<00000001Vo`00I_l0Z000I_l00`000000oooo0?ooo`0[0?ooo`00
=P3oool00`000000<ol003?o000703?o000300000000I_l006Ko0:L006Ko00<000000?ooo`3oool0
:`3oool003H0oooo00<0000003?o000co`001`0co`000`00000006Ko001Vo`2W001Vo`030000003o
ool0oooo02/0oooo000f0?ooo`030000000co`00<ol000P0<ol000<00000001Vo`00I_l0YP00I_l0
0`000000oooo0?ooo`0[0?ooo`00=`3oool00`000000<ol003?o000803?o000300000000I_l006Ko
0:D006Ko00<000000?ooo`3oool0:`3oool003L0oooo00<0000003?o000co`00200co`000`000000
06Ko001Vo`2U001Vo`030000003oool0oooo02/0oooo000g0?ooo`030000000co`00<ol000T0<ol0
00<00000001Vo`00I_l0Y000I_l00`000000oooo0?ooo`0[0?ooo`00>03oool00`000000<ol003?o
000803?o000300000000I_l006Ko0:@006Ko00<000000?ooo`3oool0:`3oool003P0oooo00<00000
03?o000co`002@0co`000`00000006Ko001Vo`2S001Vo`030000003oool0oooo02/0oooo000h0?oo
o`030000000co`00<ol000X0<ol000<00000001Vo`00I_l0XP00I_l00`000000oooo0?ooo`0[0?oo
o`00>03oool00`000000<ol003?o000:03?o000300000000I_l006Ko0:8006Ko00<000000?ooo`3o
ool0:`3oool003T0oooo00<0000003?o000co`002P0co`000`00000006Ko001Vo`2Q001Vo`030000
003oool0oooo02/0oooo000i0?ooo`030000000co`00<ol000X0<ol000<00000001Vo`00I_l0X@00
I_l00`000000oooo0?ooo`0[0?ooo`00>@3oool00`000000<ol003?o000;03?o000300000000I_l0
06Ko0:0006Ko00<000000?ooo`3oool0:`3oool003T0oooo00<0000003?o000co`002`0co`000`00
000006Ko001Vo`2P001Vo`030000003oool0oooo02/0oooo000j0?ooo`030000000co`00<ol000/0
<ol000<00000001Vo`00I_l0W`00I_l00`000000oooo0?ooo`0[0?ooo`00>P3oool00`000000<ol0
03?o000<03?o000300000000I_l006Ko09h006Ko00<000000?ooo`3oool0:`3oool003X0oooo00<0
000003?o000co`00300co`000`00000006Ko001Vo`2N001Vo`030000003oool0oooo02/0oooo000j
0?ooo`030000000co`00<ol000d0<ol000<00000001Vo`00I_l0W@00I_l00`000000oooo0?ooo`0[
0?ooo`00>`3oool00`000000<ol003?o000<03?o000300000000I_l006Ko09d006Ko00<000000?oo
o`3oool0:`3oool003/0oooo00<0000003?o000co`003@0co`000`00000006Ko001Vo`2L001Vo`03
0000003oool0oooo02/0oooo000k0?ooo`030000000co`00<ol000d0<ol000<00000001Vo`00I_l0
W000I_l00`000000oooo0?ooo`0[0?ooo`00?03oool00`000000<ol003?o000=03?o000300000000
I_l006Ko09/006Ko00<000000?ooo`3oool0:`3oool003`0oooo00<0000003?o000co`003P0co`00
0`00000006Ko001Vo`2J001Vo`030000003oool0oooo02/0oooo000l0?ooo`030000000co`00<ol0
00h0<ol000<00000001Vo`00I_l0VP00I_l00`000000oooo0?ooo`0[0?ooo`00?03oool00`000000
<ol003?o000?03?o000300000000I_l006Ko09T006Ko00<000000?ooo`3oool0:`3oool003d0oooo
00<0000003?o000co`003P0co`000`00000006Ko001Vo`2I001Vo`030000003oool0oooo02/0oooo
000m0?ooo`030000000co`00<ol000l0<ol000<00000001Vo`00I_l0V000I_l00`000000oooo0?oo
o`0[0?ooo`00?@3oool00`000000<ol003?o000?03?o000300000000I_l006Ko09P006Ko00<00000
0?ooo`3oool0:`3oool003d0oooo00<0000003?o000co`00400co`000`00000006Ko001Vo`2G001V
o`030000003oool0oooo02/0oooo000n0?ooo`030000000co`00<ol00100<ol000<00000001Vo`00
I_l0UP00I_l00`000000oooo0?ooo`0[0?ooo`00?P3oool00`000000<ol003?o000@03?o00030000
0000I_l006Ko09H006Ko00<000000?ooo`3oool0:`3oool003h0oooo00<0000003?o000co`004@0c
o`000`00000006Ko001Vo`2E001Vo`030000003oool0oooo02/0oooo000o0?ooo`030000000co`00
<ol00100<ol000<00000001Vo`00I_l0U@00I_l00`000000oooo0?ooo`0[0?ooo`00?`3oool00`00
0000<ol003?o000A03?o000300000000I_l006Ko09@006Ko00<000000?ooo`3oool0:`3oool003l0
oooo00<0000003?o000co`004@0co`000`00000006Ko001Vo`2D001Vo`030000003oool0oooo02/0
oooo000o0?ooo`030000000co`00<ol00180<ol000<00000001Vo`00I_l0T`00I_l00`000000oooo
0?ooo`0[0?ooo`00@03oool00`000000<ol003?o000B03?o000300000000I_l006Ko098006Ko00<0
00000?ooo`3oool0:`3oool00400oooo00<0000003?o000co`004P0co`000`00000006Ko001Vo`2B
001Vo`030000003oool0oooo02/0oooo00100?ooo`030000000co`00<ol001<0<ol000<00000001V
o`00I_l0T@00I_l00`000000oooo0?ooo`0[0?ooo`00@03oool00`000000<ol003?o000C03?o0003
00000000I_l006Ko094006Ko00<000000?ooo`3oool0:`3oool00440oooo00<0000003?o000co`00
4`0co`000`00000006Ko001Vo`2@001Vo`030000003oool0oooo02/0oooo00110?ooo`030000000c
o`00<ol001<0<ol000<00000001Vo`00I_l0T000I_l00`000000oooo0?ooo`0[0?ooo`00@@3oool0
0`000000<ol003?o000D03?o000300000000I_l006Ko08l006Ko00<000000?ooo`3oool0:`3oool0
0480oooo00<0000003?o000co`00500co`000`00000006Ko001Vo`2>001Vo`030000003oool0oooo
02/0oooo00120?ooo`030000000co`00<ol001@0<ol000<00000001Vo`00I_l0SP00I_l00`000000
oooo0?ooo`0[0?ooo`00@P3oool00`000000<ol003?o000E03?o000300000000I_l006Ko08d006Ko
00<000000?ooo`3oool0:`3oool00480oooo00<0000003?o000co`005@0co`000`00000006Ko001V
o`2=001Vo`030000003oool0oooo02/0oooo00130?ooo`030000000co`00<ol001D0<ol000<00000
001Vo`00I_l0S000I_l00`000000oooo0?ooo`0[0?ooo`00@`3oool00`000000<ol003?o000E03?o
000300000000I_l006Ko08`006Ko00<000000?ooo`3oool0:`3oool004<0oooo00<0000003?o000c
o`005P0co`000`00000006Ko001Vo`2;001Vo`030000003oool0oooo02/0oooo00130?ooo`030000
000co`00<ol001L0<ol000<00000001Vo`00I_l0RP00I_l00`000000oooo0?ooo`0[0?ooo`00A03o
ool00`000000<ol003?o000F03?o000300000000I_l006Ko08X006Ko00<000000?ooo`3oool0:`3o
ool004@0oooo00<0000003?o000co`005`0co`000`00000006Ko001Vo`29001Vo`030000003oool0
oooo02/0oooo00140?ooo`030000000co`00<ol001L0<ol000<00000001Vo`00I_l0R@00I_l00`00
0000oooo0?ooo`0[0?ooo`00A03oool00`000000<ol003?o000H03?o000300000000I_l006Ko08P0
06Ko00<000000?ooo`3oool0:`3oool004D0oooo00<0000003?o000co`005`0co`000`00000006Ko
001Vo`28001Vo`030000003oool0oooo02/0oooo00150?ooo`030000000co`00<ol001P0<ol000<0
0000001Vo`00I_l0Q`00I_l00`000000oooo0?ooo`0[0?ooo`00A@3oool00`000000<ol003?o000I
03?o000300000000I_l006Ko08H006Ko00<000000?ooo`3oool0:`3oool004H0oooo00<0000003?o
000co`00600co`000`00000006Ko001Vo`26001Vo`030000003oool0oooo02/0oooo00160?ooo`03
0000000co`00<ol001T0<ol000<00000001Vo`00I_l0Q@00I_l00`000000oooo0?ooo`0[0?ooo`00
AP3oool00`000000<ol003?o000I03?o000300000000I_l006Ko08D006Ko00<000000?ooo`3oool0
:`3oool004H0oooo00<0000003?o000co`006P0co`000`00000006Ko001Vo`24001Vo`030000003o
ool0oooo02/0oooo00170?ooo`030000000co`00<ol001T0<ol000<00000001Vo`00I_l0Q000I_l0
0`000000oooo0?ooo`0[0?ooo`00A`3oool00`000000<ol003?o000J03?o000300000000I_l006Ko
08<006Ko00<000000?ooo`3oool0:`3oool004L0oooo00<0000003?o000co`006`0co`000`000000
06Ko001Vo`22001Vo`030000003oool0oooo02/0oooo00170?ooo`030000000co`00<ol001/0<ol0
00<00000001Vo`00I_l0PP00I_l00`000000oooo0?ooo`0[0?ooo`00B03oool00`000000<ol003?o
000K03?o000300000000I_l006Ko084006Ko00<000000?ooo`3oool0:`3oool004P0oooo00<00000
03?o000co`006`0co`000`00000006Ko001Vo`21001Vo`030000003oool0oooo02/0oooo00180?oo
o`030000000co`00<ol001`0<ol000<00000001Vo`00I_l0P000I_l00`000000oooo0?ooo`0[0?oo
o`00B@3oool00`000000<ol003?o000K03?o000300000000I_l006Ko080006Ko00<000000?ooo`3o
ool0:`3oool004T0oooo00<0000003?o000co`00700co`000`00000006Ko001Vo`1o001Vo`030000
003oool0oooo02/0oooo00190?ooo`030000000co`00<ol001d0<ol000<00000001Vo`00I_l0OP00
I_l00`000000oooo0?ooo`0[0?ooo`00B@3oool00`000000<ol003?o000M03?o000300000000I_l0
06Ko07h006Ko00<000000?ooo`3oool0:`3oool004X0oooo00<0000003?o000co`007@0co`000`00
000006Ko001Vo`1m001Vo`030000003oool0oooo02/0oooo001:0?ooo`030000000co`00<ol001d0
<ol000<00000001Vo`00I_l0O@00I_l00`000000oooo0?ooo`0[0?ooo`00BP3oool00`000000<ol0
03?o000N03?o000300000000I_l006Ko07`006Ko00<000000?ooo`3oool0:`3oool004X0oooo00<0
000003?o000co`007P0co`000`00000006Ko001Vo`1l001Vo`030000003oool0oooo02/0oooo001;
0?ooo`030000000co`00<ol001h0<ol000<00000001Vo`00I_l0N`00I_l00`000000oooo0?ooo`0[
0?ooo`00B`3oool00`000000<ol003?o000O03?o000300000000I_l006Ko07X006Ko00<000000?oo
o`3oool0:`3oool004/0oooo00<0000003?o000co`007`0co`000`00000006Ko001Vo`1j001Vo`03
0000003oool0oooo02/0oooo001;0?ooo`030000000co`00<ol00200<ol000<00000001Vo`00I_l0
N@00I_l00`000000oooo0?ooo`0[0?ooo`00C03oool00`000000<ol003?o000O03?o000300000000
I_l006Ko07T006Ko00<000000?ooo`3oool0:`3oool004`0oooo00<0000003?o000co`002`0co`00
0`0cg`003`000000000200000003001d000co`00<ol000d0<ol000<00000001Vo`00I_l0N000I_l0
0`000000oooo0?ooo`0[0?ooo`00C03oool00`000000<ol003?o000:03?o000303>o000000008=l0
00<0<ol000<084P00018000co`003@0co`000`00000006Ko001Vo`1h001Vo`030000003oool0oooo
02/0oooo001=0?ooo`030000000co`00<ol00100<ol000<084P001No000co`003@0co`000`000000
06Ko001Vo`1g001Vo`030000003oool0oooo02/0oooo001=0?ooo`030000000co`00<ol00100<ol0
00<084P0023O000co`003P0co`000`00000006Ko001Vo`1f001Vo`030000003oool0oooo02/0oooo
001=0?ooo`030000000co`00<ol000l0<ol000<05`00001d000co`003`0co`000`00000006Ko001V
o`1f001Vo`030000003oool0oooo02/0oooo001=0?ooo`030000000co`00<ol000`0<ol000@09W@0
0000000000003i`04P0co`000`00000006Ko001Vo`1e001Vo`030000003oool0oooo02/0oooo001>
0?ooo`030000000co`00<ol000h0<ol000<05`0000nL000co`00400co`000`00000006Ko001Vo`1e
001Vo`030000003oool0oooo02/0oooo001>0?ooo`030000000co`00<ol000h0<ol000<0<ml000m8
000co`004@0co`000`00000006Ko001Vo`1d001Vo`030000003oool0oooo02/0oooo001>0?ooo`03
0000000co`00<ol000h0<ol000<0<ml000m8000co`004P0co`000`00000006Ko001Vo`1c001Vo`03
0000003oool0oooo02/0oooo001>0?ooo`030000000co`00<ol000T0<ol000<05`00001d000co`00
0P0co`000`0G00003i`003?o000B03?o000300000000I_l006Ko07<006Ko00<000000?ooo`3oool0
:`3oool004l0oooo00<0000003?o000co`002@0co`001@0VM00000000000000000003i`001D0<ol0
00<00000001Vo`00I_l0LP00I_l00`000000oooo0?ooo`0[0?ooo`00C`3oool00`000000<ol003?o
000S03?o000300000000I_l006Ko078006Ko00<000000?ooo`3oool0:`3oool004l0oooo00<00000
03?o000co`00900co`000`00000006Ko001Vo`1a001Vo`030000003oool0oooo02/0oooo001@0?oo
o`030000000co`00<ol002<0<ol000<00000001Vo`00I_l0L@00I_l00`000000oooo0?ooo`0[0?oo
o`00D03oool00`000000<ol003?o000T03?o000300000000I_l006Ko070006Ko00<000000?ooo`3o
ool0:`3oool00500oooo00<0000003?o000co`009@0co`000`00000006Ko001Vo`1_001Vo`030000
003oool0oooo02/0oooo001@0?ooo`030000000co`00<ol002D0<ol000<00000001Vo`00I_l0K`00
I_l00`000000oooo0?ooo`0[0?ooo`00D@3oool00`000000<ol003?o000U03?o000300000000I_l0
06Ko06h006Ko00<000000?ooo`3oool0:`3oool00540oooo00<0000003?o000co`009@0co`000`00
000006Ko001Vo`1^001Vo`030000003oool0oooo02/0oooo001A0?ooo`030000000co`00<ol002H0
<ol000<00000001Vo`00I_l0K@00I_l00`000000oooo0?ooo`0[0?ooo`00D@3oool00`000000<ol0
03?o000V03?o000300000000I_l006Ko06d006Ko00<000000?ooo`3oool0:`3oool00580oooo00<0
000003?o000co`009P0co`000`00000006Ko001Vo`1/001Vo`030000003oool0oooo02/0oooo001B
0?ooo`030000000co`00<ol002L0<ol000<00000001Vo`00I_l0J`00I_l00`000000oooo0?ooo`0[
0?ooo`00DP3oool00`000000<ol003?o000W03?o000300000000I_l006Ko06/006Ko00<000000?oo
o`3oool0:`3oool005<0oooo00<0000003?o000co`009`0co`000`00000006Ko001Vo`1Z001Vo`03
0000003oool0oooo02/0oooo001C0?ooo`030000000co`00<ol002L0<ol000<00000001Vo`00I_l0
JP00I_l00`000000oooo0?ooo`0[0?ooo`00D`3oool00`000000<ol003?o000X03?o000300000000
I_l006Ko06T006Ko00<000000?ooo`3oool0:`3oool005<0oooo00<0000003?o000co`00:00co`00
0`00000006Ko001Vo`1Y001Vo`030000003oool0oooo02/0oooo001D0?ooo`030000000co`00<ol0
02P0<ol000<00000001Vo`00I_l0J000I_l00`000000oooo0?ooo`0[0?ooo`00E03oool00`000000
<ol003?o000Y03?o000300000000I_l006Ko06L006Ko00<000000?ooo`3oool0:`3oool005@0oooo
00<0000003?o000co`00:@0co`000`00000006Ko001Vo`1W001Vo`030000003oool0oooo02/0oooo
001D0?ooo`030000000co`00<ol002X0<ol000<00000001Vo`00I_l0IP00I_l00`000000oooo0?oo
o`0[0?ooo`00E@3oool00`000000<ol003?o000Y03?o000300000000I_l006Ko06H006Ko00<00000
0?ooo`3oool0:`3oool005D0oooo00<0000003?o000co`00:P0co`000`00000006Ko001Vo`1U001V
o`030000003oool0oooo02/0oooo001E0?ooo`030000000co`00<ol002X0<ol000<00000001Vo`00
I_l0I@00I_l00`000000oooo0?ooo`0[0?ooo`00E@3oool00`000000<ol003?o000[03?o00030000
0000I_l006Ko06@006Ko00<000000?ooo`3oool0:`3oool005H0oooo00<0000003?o000co`00:`0c
o`000`00000006Ko001Vo`1S001Vo`030000003oool0oooo02/0oooo001F0?ooo`030000000co`00
<ol002/0<ol000<00000001Vo`00I_l0H`00I_l00`000000oooo0?ooo`0[0?ooo`00EP3oool00`00
0000<ol003?o000/03?o000300000000I_l006Ko068006Ko00<000000?ooo`3oool0:`3oool005L0
oooo00<0000003?o000co`00:`0co`000`00000006Ko001Vo`1R001Vo`030000003oool0oooo02/0
oooo001G0?ooo`030000000co`00<ol002`0<ol000<00000001Vo`00I_l0H@00I_l00`000000oooo
0?ooo`0[0?ooo`00E`3oool00`000000<ol003?o000/03?o000300000000I_l006Ko064006Ko00<0
00000?ooo`3oool0:`3oool005L0oooo00<0000003?o000co`00;@0co`000`00000006Ko001Vo`1P
001Vo`030000003oool0oooo02/0oooo001H0?ooo`030000000co`00<ol002d0<ol000<00000001V
o`00I_l0G`00I_l00`000000oooo0?ooo`0[0?ooo`00F03oool00`000000<ol003?o000]03?o0003
00000000I_l006Ko05l006Ko00<000000?ooo`3oool0:`3oool005P0oooo00<0000003?o000co`00
;P0co`000`00000006Ko001Vo`1N001Vo`030000003oool0oooo02/0oooo001H0?ooo`030000000c
o`00<ol002@0<ol000<02`0000000000000010000000100;S`00<ol003?o0000001P001Vo`030000
003oool0oooo02/0oooo001I0?ooo`030000000co`00<ol002@0<ol000<07CD000EO000co`000`0c
o`00100;00002hl003?o000co`030?l005d006Ko00<000000?ooo`3oool0:`3oool005T0oooo00<0
000003?o000co`00900co`000`0M=@001El003?o000303?o000303?4000500007Ol000D0o`00G000
I_l00`000000oooo0?ooo`0[0?ooo`00F@3oool00`000000<ol003?o000T03?o000301de0005G`00
<ol000@0<ol000<051@000^?003o0000103o001L001Vo`030000003oool0oooo02/0oooo001J0?oo
o`030000000co`00<ol002<0<ol000<07CD000EO000co`00100co`000`0M=@001El00?l000040?l0
05`006Ko00<000000?ooo`3oool0:`3oool005X0oooo00<0000003?o000co`008`0co`000`0M=@00
1El003?o000403?o0080000000@006Ko0?l0003o0000o`00G@00I_l00`000000oooo0?ooo`0[0?oo
o`00FP3oool00`000000<ol003?o000S03?o000301de0005G`00<ol00080<ol00P0000000`002000
03Wo001Vo`1P001Vo`030000003oool0oooo02/0oooo001J0?ooo`030000000co`00<ol002<0<ol0
00P07CD000EO000co`00<ol000000000I_l004iO0000=F8006Ko00<000000?ooo`3oool0:`3oool0
05/0oooo00<0000003?o000co`008P0co`00200M=@001El000000000000006Ko000i=@00000003Wo
HP00I_l00`000000oooo0?ooo`0[0?ooo`00F`3oool00`000000<ol003?o000Q03?o000300/00000
0000000000<0000000<0000e001Vo`00I_l0HP00I_l00`000000oooo0?ooo`0[0?ooo`00F`3oool0
0`000000<ol003?o000Q03?o000300000000I_l006Ko06P006Ko00<000000?ooo`3oool0:`3oool0
05/0oooo00<0000003?o000co`007`0co`02000006/006Ko00<000000?ooo`3oool0:`3oool005`0
oooo00<0000003?o000co`00700co`02000006d006Ko00<000000?ooo`3oool0:`3oool005`0oooo
00<0000003?o000co`006P0co`02000006l006Ko00<000000?ooo`3oool0:`3oool005`0oooo00<0
000003?o000co`006@0co`000`00000006Ko001Vo`1_001Vo`030000003oool0oooo02/0oooo001L
0?ooo`030000000co`00<ol001L0<ol00P00001b001Vo`030000003oool0oooo02/0oooo001M0?oo
o`030000000co`00<ol001@0<ol00P00001d001Vo`030000003oool0oooo02/0oooo001M0?ooo`03
0000000co`00<ol001<0<ol000<00000001Vo`00I_l0M000I_l00`000000oooo0?ooo`0[0?ooo`00
G@3oool00`000000<ol003?o000A03?o00800000M`00I_l00`000000oooo0?ooo`0[0?ooo`00GP3o
ool00`000000<ol003?o000>03?o00800000N@00I_l00`000000oooo0?ooo`0[0?ooo`00GP3oool0
0`000000<ol003?o000<03?o00800000N`00I_l00`000000oooo0?ooo`0[0?ooo`00GP3oool00`00
0000<ol003?o000;03?o000300000000I_l006Ko07/006Ko00<000000?ooo`3oool0:`3oool005h0
oooo00<0000003?o000co`002@0co`02000007h006Ko00<000000?ooo`3oool0:`3oool005l0oooo
00<0000003?o000co`001P0co`020000080006Ko00<000000?ooo`3oool0:`3oool005l0oooo00<0
000003?o000co`001@0co`000`00000006Ko001Vo`20001Vo`030000003oool0oooo02/0oooo001D
0?ooo`030?ooS`0e0000000000<0000000<001AO0?ooo`3oool00P3oool00`000000<ol003?o0003
03?o008000005`00I_l00`00>CD000000000000600000003000Va000I_l006Ko05D006Ko00D001H0
00000000000000000000=@06001Vo`030000003oool0oooo02/0oooo001C0?ooo`030?ooS`0e0000
=Hoo00@0oooo00@0a5lD000DG`3oool0oooo0`3o000203?o008000006P00I_l00`00IXl0000D001>
o`04001Vo`04000V50009/@006Ko001Vo`<0o`00D@00I_l00`005P0001J?001Vo`02001Vo`03000i
=@00000003Wo008006Ko0`3o000]0?ooo`00D`3oool00`2?=@0055o40?ooo`040?ooo`030?n?=@00
55l0oooo00D0o`0000<00000001Vo`00I_l06P00I_l00`00IXl0000D001>o`04001Vo`03000V5000
9/@006Ko00D0o`00C`00I_l00`009Q@001J?001Vo`04001Vo`03001>G`0003D006Ko00D0o`00;03o
ool00580oooo00<0oon?03D0501Oa?l01@3oool00`3oScD001AO0?ooo`050?l002L000001@3o001I
000000D0o`00;03oool00580oooo00<0oon?03D0=@2?ool00P3oool00`34Ga@00000000000020000
000301AOa03o0000o`0000<0o`007@3oool01P3oohl0=@0D05o4o`3oool0ScD001AOa0@0oooo1@3o
001>0?ooo`030?ooS`0e03D0Sooo00P0oooo1@3o000/0?ooo`00DP3oool00`3oohl0=@0e08ooo`09
0?ooo`<0o`007P3oool00`3oohl0=@00000000020000000301AOa03oool0oooo00<0oooo0`3o001?
0?ooo`030?ooS`0e03D0Sooo00T0oooo0`3o000]0?ooo`00D`3oool00`1O51@0GlCo0?ooo`0Y0?oo
o`060?ooS`0e01@0GlCo0?ooo`2?=@0055o4E`3oool00`3oohl0=@0D05o4o`0i0?ooo`00D`3oool0
0`34Ga@055o40?ooo`040?ooo`030?n?=@0055l0oooo0280oooo00<0oon?03D0501Oa?l0103oool0
0`1O51@0GlCo0?ooo`1D0?ooo`030<AO500eSol0oooo00@0oooo00<0a5lD000DG`3oool0<@3oool0
05@0oooo00<0Ga@0000eS`3oool00P3oool00`34Ga@00000000DG`0S0?ooo`030?ooS`0e01@0GlCo
00@0oooo00<0Ga@D05o4o`3oool0E03oool00`3oohl0=@00000eS`030?ooo`0308le000051@051AO
0380oooo001E0?ooo`0708le0000000000000000000055l0ohle000DG`0R0?ooo`030?n?=@000000
000000D0000000<0000D05o4o`3oool0EP3oool01`2?=@00000000000000000003F?0?o4G`0D55l0
<P3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00001\
\>"],
  ImageRangeCache->{{{91.5625, 240.375}, {562.563, 413.75}} -> {-0.615299, \
2.78037, 0.00537595, 0.00537595}}]
}, Open  ]],

Cell["and", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GD\&_\^2 = \(GE\&_\^2 + 
          ED\&_\^2 = \(\((DC\&_/2 - GD\&_)\)\^2 + \((EF\&_ - DF\&_)\)\^2 = \
\((AB\&_/2 - GD\&_)\)\^2 + \(\(\((AB\&_ - DF\&_)\)\^2\)\(.\)\)\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.83671 .16329 m .83671 .83671 L .34373 .83671 L p 0 .4 1 r
F P
0 g
s
1 0 0 r
.02 w
.83671 .83671 Mdot
.5 .83671 Mdot
.83671 .83671 Mdot
.5 .83671 Mdot
.5 Mabswid
.34373 .83671 m .16329 .16329 L .83671 .16329 L p 0 .4 1 r
F P
0 g
s
1 0 0 r
.02 w
.83671 .16329 Mdot
.83671 .16329 Mdot
.16329 .16329 Mdot
.5 .16329 Mdot
.16329 .16329 Mdot
.5 .16329 Mdot
.5 Mabswid
.16329 .16329 m .34373 .83671 L .5 .74649 L closepath p .2 1 0 r
F P
0 g
s
1 0 0 r
.02 w
.16329 .16329 Mdot
.5 .74649 Mdot
.16329 .16329 Mdot
.5 .74649 Mdot
.34373 .83671 Mdot
0 g
gsave
.16329 .16329 -72.875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.875 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83671 .16329 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83671 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .16329 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16329 .16329 -72.875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.875 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83671 .16329 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83671 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .16329 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34373 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16329 .16329 -72.875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.875 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .74649 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16329 .16329 -72.875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
70.875 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .74649 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34373 .83671 -72.1875 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(G) show
70.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.33567 .58216 -66.5938 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{187.313, 187.313},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H000162000`400?l00000o`00003oo`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI0?ooo`00o`3ooolI
0?ooo`00o`3ooolI0?ooo`007P3oool0203oD0/00000000000000000000;053oo`3oool0oe0;1000
00000`0SUol0oooo0?ooo`1B0?ooo`030?n?=@00000000000080000000<0000D05o4o`3oool0E@3o
ool00`3oScD000000000000500000003000eS`3oool0oooo0340oooo000O0?ooo`030?ooD00;0000
2e3o00D0oooo00<0Ub<000008`3oool0EP3oool00`3oohl0=@0e08ooo`1J0?ooo`030?ooS`0e01@0
GlCo00@0oooo00<0Ga@0000eS`3oool0<@3oool00200oooo00<0D0/0000;D03oool0103oool00`0S
000002>G0?ooo`020?ooo`<0o`00D@3oool00`3oohl0=@0e08ooo`070?ooo`<0o`00D03oool00`3o
ohl0=@0D05o4o`040?ooo`040?ooS`0e03D0Sooo0?ooo`<0o`00;@3oool00200oooo00<0oiLS0000
0000000010000000100000/0D?oo0?ooo`3oool50?l005T000001@3o001I000000D0o`00;03oool0
0240oooo00<08`00000SU`3oool00P3oool00`1@2`0000]@0?ooo`020?ooo`D0o`00D000I_l01P00
IXl0000e001Vo`00I_l001H0000io`<006Ko1@3o001?001Vo`03001VS`0001@004ko00<006Ko00@0
04iO000000009/@006Ko1@3o000/0?ooo`008@3oool01`3oD0/0000;053oo`3oool0oom@00/0000;
D?l00`3oool50?l0050006Ko00<006J?0000000000000P00000010009/@006Ko001Vo`00I_l50?l0
04l006Ko00<006J?0000000000000`000000100001@004ko001Vo`00I_l50?l002`0oooo000Q0?oo
o`060?ooD00;00002e3o0?ooo`2G8`00000S1@3oool30?l0000300000000I_l006Ko04h006Ko00H0
06J?0000=@00I_l006Ko000F00009/@4001Vo`<0o`00D000I_l00`00IXl0000D001>o`03001Vo`03
000V500025l006Ko008006Ko0`3o000]0?ooo`008P3oool01@2G8`00000S0?ooo`0S000002>G00L0
oooo0P00001@001Vo`03001VS`0003D006Ko00@006Ko00<002HD000Va000I_l0D`00I_l00`00IXl0
000D001>o`04001Vo`0300080000>Ol006Ko00<006Ko00<000000?ooo`3oool0:`3oool00280oooo
00D0oiLS0000000SD2<0000002>Go`070?ooo`030000000co`00000004l006Ko00<006J?0000=@00
I_l01000I_l00`009Q@002K4001Vo`1C001Vo`03001VS`0001@004ko00<006Ko00<002HD0000=@00
I_l01000I_l00`000000oooo0?ooo`0[0?ooo`00803oool00`1@2`00000000000002000000030000
8`3oool0oooo00L0oooo0P00001>001Vo`03000i=@000000000000H0000000<002K4001Vo`00I_l0
D@00I_l00`00>CD00000000000040000000300005000C_l006Ko00@006Ko00<000000?ooo`3oool0
:`3oool002l0oooo00<0000003?o00000000^000I_l00`000000oooo0?ooo`0[0?ooo`00;`3oool0
10000000<ol003?o0000002g001Vo`030000003oool0oooo02/0oooo000_0?ooo`040000000co`00
<ol000000;L006Ko00<000000?ooo`3oool0:`3oool00300oooo00@0000003?o000co`000000]P00
I_l00`000000oooo0?ooo`0[0?ooo`00<03oool010000000<ol003?o0000002f001Vo`030000003o
ool0oooo02/0oooo000`0?ooo`050000000co`00<ol003?o00000000]@00I_l00`000000oooo0?oo
o`0[0?ooo`00<@3oool010000000<ol003?o0000002e001Vo`030000003oool0oooo02/0oooo000a
0?ooo`050000000co`00<ol003?o00000000]000I_l00`000000oooo0?ooo`0[0?ooo`00<@3oool0
0`000000<ol003?o000203?o000300000000I_l006Ko0;4006Ko00<000000?ooo`3oool0:`3oool0
0340oooo00<0000003?o000co`000P0co`000`00000006Ko001Vo`2a001Vo`030000003oool0oooo
02/0oooo000b0?ooo`030000000co`00<ol00080<ol000<00000001Vo`00I_l0/000I_l00`000000
oooo0?ooo`0[0?ooo`00<P3oool00`000000<ol003?o000203?o000300000000I_l006Ko0;0006Ko
00<000000?ooo`3oool0:`3oool00380oooo00<0000003?o000co`000`0co`000`00000006Ko001V
o`2_001Vo`030000003oool0oooo02/0oooo000b0?ooo`030000000co`00<ol000<0<ol000<00000
001Vo`00I_l0[`00I_l00`000000oooo0?ooo`0[0?ooo`00<`3oool00`000000<ol003?o000303?o
000300000000I_l006Ko0:h006Ko00<000000?ooo`3oool0:`3oool003<0oooo00<0000003?o000c
o`00100co`000`00000006Ko001Vo`2]001Vo`030000003oool0oooo02/0oooo000c0?ooo`030000
000co`00<ol000@0<ol000<00000001Vo`00I_l0[@00I_l00`000000oooo0?ooo`0[0?ooo`00<`3o
ool00`000000<ol003?o000503?o000300000000I_l006Ko0:`006Ko00<000000?ooo`3oool0:`3o
ool003@0oooo00<0000003?o000co`00100co`000`00000006Ko001Vo`2/001Vo`030000003oool0
oooo02/0oooo000d0?ooo`030000000co`00<ol000D0<ol000<00000001Vo`00I_l0Z`00I_l00`00
0000oooo0?ooo`0[0?ooo`00=03oool00`000000<ol003?o000503?o000300000000I_l006Ko0:/0
06Ko00<000000?ooo`3oool0:`3oool003D0oooo00<0000003?o000co`001@0co`000`00000006Ko
001Vo`2Z001Vo`030000003oool0oooo02/0oooo000e0?ooo`030000000co`00<ol000H0<ol000<0
0000001Vo`00I_l0Z@00I_l00`000000oooo0?ooo`0[0?ooo`00=@3oool00`000000<ol003?o0006
03?o000300000000I_l006Ko0:T006Ko00<000000?ooo`3oool0:`3oool003D0oooo00<0000003?o
000co`001`0co`000`00000006Ko001Vo`2X001Vo`030000003oool0oooo02/0oooo000f0?ooo`03
0000000co`00<ol000H0<ol000<00000001Vo`00I_l0Z000I_l00`000000oooo0?ooo`0[0?ooo`00
=P3oool00`000000<ol003?o000703?o000300000000I_l006Ko0:L006Ko00<000000?ooo`3oool0
:`3oool003H0oooo00<0000003?o000co`001`0co`000`00000006Ko001Vo`2W001Vo`030000003o
ool0oooo02/0oooo000f0?ooo`030000000co`00<ol000P0<ol000<00000001Vo`00I_l0YP00I_l0
0`000000oooo0?ooo`0[0?ooo`00=`3oool00`000000<ol003?o000803?o000300000000I_l006Ko
0:D006Ko00<000000?ooo`3oool0:`3oool003L0oooo00<0000003?o000co`00200co`000`000000
06Ko001Vo`2U001Vo`030000003oool0oooo02/0oooo000g0?ooo`030000000co`00<ol000T0<ol0
00<00000001Vo`00I_l0Y000I_l00`000000oooo0?ooo`0[0?ooo`00>03oool00`000000<ol003?o
000803?o000300000000I_l006Ko0:@006Ko00<000000?ooo`3oool0:`3oool003P0oooo00<00000
03?o000co`002@0co`000`00000006Ko001Vo`2S001Vo`030000003oool0oooo02/0oooo000h0?oo
o`030000000co`00<ol000X0<ol000<00000001Vo`00I_l0XP00I_l00`000000oooo0?ooo`0[0?oo
o`00>03oool00`000000<ol003?o000:03?o000300000000I_l006Ko0:8006Ko00<000000?ooo`3o
ool0:`3oool003T0oooo00<0000003?o000co`002P0co`000`00000006Ko001Vo`2Q001Vo`030000
003oool0oooo02/0oooo000i0?ooo`030000000co`00<ol000X0<ol000<00000001Vo`00I_l0X@00
I_l00`000000oooo0?ooo`0[0?ooo`00>@3oool00`000000<ol003?o000;03?o000300000000I_l0
06Ko0:0006Ko00<000000?ooo`3oool0:`3oool003T0oooo00<0000003?o000co`002`0co`000`00
000006Ko001Vo`2P001Vo`030000003oool0oooo02/0oooo000j0?ooo`030000000co`00<ol000/0
<ol000<00000001Vo`00I_l0W`00I_l00`000000oooo0?ooo`0[0?ooo`00>P3oool00`000000<ol0
03?o000<03?o000300000000I_l006Ko09h006Ko00<000000?ooo`3oool0:`3oool003X0oooo00<0
000003?o000co`00300co`000`00000006Ko001Vo`2N001Vo`030000003oool0oooo02/0oooo000j
0?ooo`030000000co`00<ol000d0<ol000<00000001Vo`00I_l0W@00I_l00`000000oooo0?ooo`0[
0?ooo`00>`3oool00`000000<ol003?o000<03?o000300000000I_l006Ko09d006Ko00<000000?oo
o`3oool0:`3oool003/0oooo00<0000003?o000co`003@0co`000`00000006Ko001Vo`2L001Vo`03
0000003oool0oooo02/0oooo000k0?ooo`030000000co`00<ol000d0<ol000<00000001Vo`00I_l0
W000I_l00`000000oooo0?ooo`0[0?ooo`00?03oool00`000000<ol003?o000=03?o000300000000
I_l006Ko09/006Ko00<000000?ooo`3oool0:`3oool003`0oooo00<0000003?o000co`003P0co`00
0`00000006Ko001Vo`2J001Vo`030000003oool0oooo02/0oooo000l0?ooo`030000000co`00<ol0
00h0<ol000<00000001Vo`00I_l0VP00I_l00`000000oooo0?ooo`0[0?ooo`00?03oool00`000000
<ol003?o000?03?o000300000000I_l006Ko09T006Ko00<000000?ooo`3oool0:`3oool003d0oooo
00<0000003?o000co`003P0co`000`00000006Ko001Vo`2I001Vo`030000003oool0oooo02/0oooo
000m0?ooo`030000000co`00<ol000l0<ol000<00000001Vo`00I_l0V000I_l00`000000oooo0?oo
o`0[0?ooo`00?@3oool00`000000<ol003?o000?03?o000300000000I_l006Ko09P006Ko00<00000
0?ooo`3oool0:`3oool003d0oooo00<0000003?o000co`00400co`000`00000006Ko001Vo`2G001V
o`030000003oool0oooo02/0oooo000n0?ooo`030000000co`00<ol00100<ol000<00000001Vo`00
I_l0UP00I_l00`000000oooo0?ooo`0[0?ooo`00?P3oool00`000000<ol003?o000@03?o00030000
0000I_l006Ko09H006Ko00<000000?ooo`3oool0:`3oool003h0oooo00<0000003?o000co`004@0c
o`000`00000006Ko001Vo`2E001Vo`030000003oool0oooo02/0oooo000o0?ooo`030000000co`00
<ol00100<ol000<00000001Vo`00I_l0U@00I_l00`000000oooo0?ooo`0[0?ooo`00?`3oool00`00
0000<ol003?o000A03?o000300000000I_l006Ko09@006Ko00<000000?ooo`3oool0:`3oool003l0
oooo00<0000003?o000co`004@0co`000`00000006Ko001Vo`2D001Vo`030000003oool0oooo02/0
oooo000o0?ooo`030000000co`00<ol00180<ol000<00000001Vo`00I_l0T`00I_l00`000000oooo
0?ooo`0[0?ooo`00@03oool00`000000<ol003?o000B03?o000300000000I_l006Ko098006Ko00<0
00000?ooo`3oool0:`3oool00400oooo00<0000003?o000co`004P0co`000`00000006Ko001Vo`2B
001Vo`030000003oool0oooo02/0oooo00100?ooo`030000000co`00<ol001<0<ol000<00000001V
o`00I_l0T@00I_l00`000000oooo0?ooo`0[0?ooo`00@03oool00`000000<ol003?o000C03?o0003
00000000I_l006Ko094006Ko00<000000?ooo`3oool0:`3oool00440oooo00<0000003?o000co`00
4`0co`000`00000006Ko001Vo`2@001Vo`030000003oool0oooo02/0oooo00110?ooo`030000000c
o`00<ol001<0<ol000<00000001Vo`00I_l0T000I_l00`000000oooo0?ooo`0[0?ooo`00@@3oool0
0`000000<ol003?o000D03?o000300000000I_l006Ko08l006Ko00<000000?ooo`3oool0:`3oool0
0480oooo00<0000003?o000co`00500co`000`00000006Ko001Vo`2>001Vo`030000003oool0oooo
02/0oooo00120?ooo`030000000co`00<ol001@0<ol000<00000001Vo`00I_l0SP00I_l00`000000
oooo0?ooo`0[0?ooo`00@P3oool00`000000<ol003?o000E03?o000300000000I_l006Ko08d006Ko
00<000000?ooo`3oool0:`3oool00480oooo00<0000003?o000co`005@0co`000`00000006Ko001V
o`2=001Vo`030000003oool0oooo02/0oooo00130?ooo`030000000co`00<ol001D0<ol000<00000
001Vo`00I_l0S000I_l00`000000oooo0?ooo`0[0?ooo`00@`3oool00`000000<ol003?o000E03?o
000300000000I_l006Ko08`006Ko00<000000?ooo`3oool0:`3oool004<0oooo00<0000003?o000c
o`005P0co`000`00000006Ko001Vo`2;001Vo`030000003oool0oooo02/0oooo00130?ooo`030000
000co`00<ol001L0<ol000<00000001Vo`00I_l0RP00I_l00`000000oooo0?ooo`0[0?ooo`00A03o
ool00`000000<ol003?o000F03?o000300000000I_l006Ko08X006Ko00<000000?ooo`3oool0:`3o
ool004@0oooo00<0000003?o000co`005`0co`000`00000006Ko001Vo`29001Vo`030000003oool0
oooo02/0oooo00140?ooo`030000000co`00<ol001L0<ol000<00000001Vo`00I_l0R@00I_l00`00
0000oooo0?ooo`0[0?ooo`00A03oool00`000000<ol003?o000H03?o000300000000I_l006Ko08P0
06Ko00<000000?ooo`3oool0:`3oool004D0oooo00<0000003?o000co`005`0co`000`00000006Ko
001Vo`28001Vo`030000003oool0oooo02/0oooo00150?ooo`030000000co`00<ol001P0<ol000<0
0000001Vo`00I_l0Q`00I_l00`000000oooo0?ooo`0[0?ooo`00A@3oool00`000000<ol003?o000I
03?o000300000000I_l006Ko08H006Ko00<000000?ooo`3oool0:`3oool004H0oooo00<0000003?o
000co`00600co`000`00000006Ko001Vo`26001Vo`030000003oool0oooo02/0oooo00160?ooo`03
0000000co`00<ol001T0<ol000<00000001Vo`00I_l0Q@00I_l00`000000oooo0?ooo`0[0?ooo`00
AP3oool00`000000<ol003?o000I03?o000300000000I_l006Ko08D006Ko00<000000?ooo`3oool0
:`3oool004H0oooo00<0000003?o000co`006P0co`000`00000006Ko001Vo`24001Vo`030000003o
ool0oooo02/0oooo00170?ooo`030000000co`00<ol001T0<ol000<00000001Vo`00I_l0Q000I_l0
0`000000oooo0?ooo`0[0?ooo`00A`3oool00`000000<ol003?o000J03?o000300000000I_l006Ko
08<006Ko00<000000?ooo`3oool0:`3oool004L0oooo00<0000003?o000co`006`0co`000`000000
06Ko001Vo`22001Vo`030000003oool0oooo02/0oooo00170?ooo`030000000co`00<ol001/0<ol0
00<00000001Vo`00I_l0PP00I_l00`000000oooo0?ooo`0[0?ooo`00B03oool00`000000<ol003?o
000K03?o000300000000I_l006Ko084006Ko00<000000?ooo`3oool0:`3oool004P0oooo00<00000
03?o000co`006`0co`000`00000006Ko001Vo`21001Vo`030000003oool0oooo02/0oooo00180?oo
o`030000000co`00<ol001`0<ol000<00000001Vo`00I_l0P000I_l00`000000oooo0?ooo`0[0?oo
o`00B@3oool00`000000<ol003?o000K03?o000300000000I_l006Ko080006Ko00<000000?ooo`3o
ool0:`3oool004T0oooo00<0000003?o000co`00700co`000`00000006Ko001Vo`1o001Vo`030000
003oool0oooo02/0oooo00190?ooo`030000000co`00<ol001d0<ol000<00000001Vo`00I_l0OP00
I_l00`000000oooo0?ooo`0[0?ooo`00B@3oool00`000000<ol003?o000M03?o000300000000I_l0
06Ko07h006Ko00<000000?ooo`3oool0:`3oool004X0oooo00<0000003?o000co`007@0co`000`00
000006Ko001Vo`1m001Vo`030000003oool0oooo02/0oooo001:0?ooo`030000000co`00<ol001d0
<ol000<00000001Vo`00I_l0O@00I_l00`000000oooo0?ooo`0[0?ooo`00BP3oool00`000000<ol0
03?o000N03?o000300000000I_l006Ko07`006Ko00<000000?ooo`3oool0:`3oool004X0oooo00<0
000003?o000co`007P0co`000`00000006Ko001Vo`1l001Vo`030000003oool0oooo02/0oooo001;
0?ooo`030000000co`00<ol001h0<ol000<00000001Vo`00I_l0N`00I_l00`000000oooo0?ooo`0[
0?ooo`00B`3oool00`000000<ol003?o000O03?o000300000000I_l006Ko07X006Ko00<000000?oo
o`3oool0:`3oool004/0oooo00<0000003?o000co`007`0co`000`00000006Ko001Vo`1j001Vo`03
0000003oool0oooo02/0oooo001;0?ooo`030000000co`00<ol00200<ol000<00000001Vo`00I_l0
N@00I_l00`000000oooo0?ooo`0[0?ooo`00C03oool00`000000<ol003?o000O03?o000300000000
I_l006Ko07T006Ko00<000000?ooo`3oool0:`3oool004`0oooo00<0000003?o000co`002`0co`00
0`0cg`003`000000000200000003001d000co`00<ol000d0<ol000<00000001Vo`00I_l0N000I_l0
0`000000oooo0?ooo`0[0?ooo`00C03oool00`000000<ol003?o000:03?o000303>o000000008=l0
00<0<ol000<084P00018000co`003@0co`000`00000006Ko001Vo`1h001Vo`030000003oool0oooo
02/0oooo001=0?ooo`030000000co`00<ol00100<ol000<084P001No000co`003@0co`000`000000
06Ko001Vo`1g001Vo`030000003oool0oooo02/0oooo001=0?ooo`030000000co`00<ol00100<ol0
00<084P0023O000co`003P0co`000`00000006Ko001Vo`1f001Vo`030000003oool0oooo02/0oooo
001=0?ooo`030000000co`00<ol000l0<ol000<05`00001d000co`003`0co`000`00000006Ko001V
o`1f001Vo`030000003oool0oooo02/0oooo001=0?ooo`030000000co`00<ol000`0<ol000@09W@0
0000000000003i`04P0co`000`00000006Ko001Vo`1e001Vo`030000003oool0oooo02/0oooo001>
0?ooo`030000000co`00<ol000h0<ol000<05`0000nL000co`00400co`000`00000006Ko001Vo`1e
001Vo`030000003oool0oooo02/0oooo001>0?ooo`030000000co`00<ol000h0<ol000<0<ml000m8
000co`004@0co`000`00000006Ko001Vo`1d001Vo`030000003oool0oooo02/0oooo001>0?ooo`03
0000000co`00<ol000h0<ol000<0<ml000m8000co`004P0co`000`00000006Ko001Vo`1c001Vo`03
0000003oool0oooo02/0oooo001>0?ooo`030000000co`00<ol000T0<ol000<05`00001d000co`00
0P0co`000`0G00003i`003?o000B03?o000300000000I_l006Ko07<006Ko00<000000?ooo`3oool0
:`3oool004l0oooo00<0000003?o000co`002@0co`001@0VM00000000000000000003i`001D0<ol0
00<00000001Vo`00I_l0LP00I_l00`000000oooo0?ooo`0[0?ooo`00C`3oool00`000000<ol003?o
000S03?o000300000000I_l006Ko078006Ko00<000000?ooo`3oool0:`3oool004l0oooo00<00000
03?o000co`00900co`000`00000006Ko001Vo`1a001Vo`030000003oool0oooo02/0oooo001@0?oo
o`030000000co`00<ol002<0<ol000<00000001Vo`00I_l0L@00I_l00`000000oooo0?ooo`0[0?oo
o`00D03oool00`000000<ol003?o000T03?o000300000000I_l006Ko070006Ko00<000000?ooo`3o
ool0:`3oool00500oooo00<0000003?o000co`009@0co`000`00000006Ko001Vo`1_001Vo`030000
003oool0oooo02/0oooo001@0?ooo`030000000co`00<ol002D0<ol000<00000001Vo`00I_l0K`00
I_l00`000000oooo0?ooo`0[0?ooo`00D@3oool00`000000<ol003?o000U03?o000300000000I_l0
06Ko06h006Ko00<000000?ooo`3oool0:`3oool00540oooo00<0000003?o000co`009@0co`000`00
000006Ko001Vo`1^001Vo`030000003oool0oooo02/0oooo001A0?ooo`030000000co`00<ol002H0
<ol000<00000001Vo`00I_l0K@00I_l00`000000oooo0?ooo`0[0?ooo`00D@3oool00`000000<ol0
03?o000V03?o000300000000I_l006Ko06d006Ko00<000000?ooo`3oool0:`3oool00580oooo00<0
000003?o000co`009P0co`000`00000006Ko001Vo`1/001Vo`030000003oool0oooo02/0oooo001B
0?ooo`030000000co`00<ol002L0<ol000<00000001Vo`00I_l0J`00I_l00`000000oooo0?ooo`0[
0?ooo`00DP3oool00`000000<ol003?o000W03?o000300000000I_l006Ko06/006Ko00<000000?oo
o`3oool0:`3oool005<0oooo00<0000003?o000co`009`0co`000`00000006Ko001Vo`1Z001Vo`03
0000003oool0oooo02/0oooo001C0?ooo`030000000co`00<ol002L0<ol000<00000001Vo`00I_l0
JP00I_l00`000000oooo0?ooo`0[0?ooo`00D`3oool00`000000<ol003?o000X03?o000300000000
I_l006Ko06T006Ko00<000000?ooo`3oool0:`3oool005<0oooo00<0000003?o000co`00:00co`00
0`00000006Ko001Vo`1Y001Vo`030000003oool0oooo02/0oooo001D0?ooo`030000000co`00<ol0
02P0<ol000<00000001Vo`00I_l0J000I_l00`000000oooo0?ooo`0[0?ooo`00E03oool00`000000
<ol003?o000Y03?o000300000000I_l006Ko06L006Ko00<000000?ooo`3oool0:`3oool005@0oooo
00<0000003?o000co`00:@0co`000`00000006Ko001Vo`1W001Vo`030000003oool0oooo02/0oooo
001D0?ooo`030000000co`00<ol002X0<ol000<00000001Vo`00I_l0IP00I_l00`000000oooo0?oo
o`0[0?ooo`00E@3oool00`000000<ol003?o000Y03?o000300000000I_l006Ko06H006Ko00<00000
0?ooo`3oool0:`3oool005D0oooo00<0000003?o000co`00:P0co`000`00000006Ko001Vo`1U001V
o`030000003oool0oooo02/0oooo001E0?ooo`030000000co`00<ol002X0<ol000<00000001Vo`00
I_l0I@00I_l00`000000oooo0?ooo`0[0?ooo`00E@3oool00`000000<ol003?o000[03?o00030000
0000I_l006Ko06@006Ko00<000000?ooo`3oool0:`3oool005H0oooo00<0000003?o000co`00:`0c
o`000`00000006Ko001Vo`1S001Vo`030000003oool0oooo02/0oooo001F0?ooo`030000000co`00
<ol002/0<ol000<00000001Vo`00I_l0H`00I_l00`000000oooo0?ooo`0[0?ooo`00EP3oool00`00
0000<ol003?o000/03?o000300000000I_l006Ko068006Ko00<000000?ooo`3oool0:`3oool005L0
oooo00<0000003?o000co`00:`0co`000`00000006Ko001Vo`1R001Vo`030000003oool0oooo02/0
oooo001G0?ooo`030000000co`00<ol002`0<ol000<00000001Vo`00I_l0H@00I_l00`000000oooo
0?ooo`0[0?ooo`00E`3oool00`000000<ol003?o000/03?o000300000000I_l006Ko064006Ko00<0
00000?ooo`3oool0:`3oool005L0oooo00<0000003?o000co`00;@0co`000`00000006Ko001Vo`1P
001Vo`030000003oool0oooo02/0oooo001H0?ooo`030000000co`00<ol002d0<ol000<00000001V
o`00I_l0G`00I_l00`000000oooo0?ooo`0[0?ooo`00F03oool00`000000<ol003?o000]03?o0003
00000000I_l006Ko05l006Ko00<000000?ooo`3oool0:`3oool005P0oooo00<0000003?o000co`00
;P0co`000`00000006Ko001Vo`1N001Vo`030000003oool0oooo02/0oooo001H0?ooo`030000000c
o`00<ol002@0<ol000<02`0000000000000010000000100;S`00<ol003?o0000001P001Vo`030000
003oool0oooo02/0oooo001I0?ooo`030000000co`00<ol002@0<ol000<07CD000EO000co`000`0c
o`00100;00002hl003?o000co`030?l005d006Ko00<000000?ooo`3oool0:`3oool005T0oooo00<0
000003?o000co`00900co`000`0M=@001El003?o000303?o000303?4000500007Ol000D0o`00G000
I_l00`000000oooo0?ooo`0[0?ooo`00F@3oool00`000000<ol003?o000T03?o000301de0005G`00
<ol000@0<ol000<051@000^?003o0000103o001L001Vo`030000003oool0oooo02/0oooo001J0?oo
o`030000000co`00<ol002<0<ol000<07CD000EO000co`00100co`000`0M=@001El00?l000040?l0
05`006Ko00<000000?ooo`3oool0:`3oool005X0oooo00<0000003?o000co`008`0co`000`0M=@00
1El003?o000403?o0080000000@006Ko0?l0003o0000o`00G@00I_l00`000000oooo0?ooo`0[0?oo
o`00FP3oool00`000000<ol003?o000S03?o000301de0005G`00<ol00080<ol00P0000000`002000
03Wo001Vo`1P001Vo`030000003oool0oooo02/0oooo001J0?ooo`030000000co`00<ol002<0<ol0
00P07CD000EO000co`00<ol000000000I_l004iO0000=F8006Ko00<000000?ooo`3oool0:`3oool0
05/0oooo00<0000003?o000co`008P0co`00200M=@001El000000000000006Ko000i=@00000003Wo
HP00I_l00`000000oooo0?ooo`0[0?ooo`00F`3oool00`000000<ol003?o000Q03?o000300/00000
0000000000<0000000<0000e001Vo`00I_l0HP00I_l00`000000oooo0?ooo`0[0?ooo`00F`3oool0
0`000000<ol003?o000Q03?o000300000000I_l006Ko06P006Ko00<000000?ooo`3oool0:`3oool0
05/0oooo00<0000003?o000co`007`0co`02000006/006Ko00<000000?ooo`3oool0:`3oool005`0
oooo00<0000003?o000co`00700co`02000006d006Ko00<000000?ooo`3oool0:`3oool005`0oooo
00<0000003?o000co`006P0co`02000006l006Ko00<000000?ooo`3oool0:`3oool005`0oooo00<0
000003?o000co`006@0co`000`00000006Ko001Vo`1_001Vo`030000003oool0oooo02/0oooo001L
0?ooo`030000000co`00<ol001L0<ol00P00001b001Vo`030000003oool0oooo02/0oooo001M0?oo
o`030000000co`00<ol001@0<ol00P00001d001Vo`030000003oool0oooo02/0oooo001M0?ooo`03
0000000co`00<ol001<0<ol000<00000001Vo`00I_l0M000I_l00`000000oooo0?ooo`0[0?ooo`00
G@3oool00`000000<ol003?o000A03?o00800000M`00I_l00`000000oooo0?ooo`0[0?ooo`00GP3o
ool00`000000<ol003?o000>03?o00800000N@00I_l00`000000oooo0?ooo`0[0?ooo`00GP3oool0
0`000000<ol003?o000<03?o00800000N`00I_l00`000000oooo0?ooo`0[0?ooo`00GP3oool00`00
0000<ol003?o000;03?o000300000000I_l006Ko07/006Ko00<000000?ooo`3oool0:`3oool005h0
oooo00<0000003?o000co`002@0co`02000007h006Ko00<000000?ooo`3oool0:`3oool005l0oooo
00<0000003?o000co`001P0co`020000080006Ko00<000000?ooo`3oool0:`3oool005l0oooo00<0
000003?o000co`001@0co`000`00000006Ko001Vo`20001Vo`030000003oool0oooo02/0oooo001D
0?ooo`030?ooS`0e0000000000<0000000<001AO0?ooo`3oool00P3oool00`000000<ol003?o0003
03?o008000005`00I_l00`00>CD000000000000600000003000Va000I_l006Ko05D006Ko00D001H0
00000000000000000000=@06001Vo`030000003oool0oooo02/0oooo001C0?ooo`030?ooS`0e0000
=Hoo00@0oooo00@0a5lD000DG`3oool0oooo0`3o000203?o008000006P00I_l00`00IXl0000D001>
o`04001Vo`04000V50009/@006Ko001Vo`<0o`00D@00I_l00`005P0001J?001Vo`02001Vo`03000i
=@00000003Wo008006Ko0`3o000]0?ooo`00D`3oool00`2?=@0055o40?ooo`040?ooo`030?n?=@00
55l0oooo00D0o`0000<00000001Vo`00I_l06P00I_l00`00IXl0000D001>o`04001Vo`03000V5000
9/@006Ko00D0o`00C`00I_l00`009Q@001J?001Vo`04001Vo`03001>G`0003D006Ko00D0o`00;03o
ool00580oooo00<0oon?03D0501Oa?l01@3oool00`3oScD001AO0?ooo`050?l002L000001@3o001I
000000D0o`00;03oool00580oooo00<0oon?03D0=@2?ool00P3oool00`34Ga@00000000000020000
000301AOa03o0000o`0000<0o`007@3oool01P3oohl0=@0D05o4o`3oool0ScD001AOa0@0oooo1@3o
001>0?ooo`030?ooS`0e03D0Sooo00P0oooo1@3o000/0?ooo`00DP3oool00`3oohl0=@0e08ooo`09
0?ooo`<0o`007P3oool00`3oohl0=@00000000020000000301AOa03oool0oooo00<0oooo0`3o001?
0?ooo`030?ooS`0e03D0Sooo00T0oooo0`3o000]0?ooo`00D`3oool00`1O51@0GlCo0?ooo`0Y0?oo
o`060?ooS`0e01@0GlCo0?ooo`2?=@0055o4E`3oool00`3oohl0=@0D05o4o`0i0?ooo`00D`3oool0
0`34Ga@055o40?ooo`040?ooo`030?n?=@0055l0oooo0280oooo00<0oon?03D0501Oa?l0103oool0
0`1O51@0GlCo0?ooo`1D0?ooo`030<AO500eSol0oooo00@0oooo00<0a5lD000DG`3oool0<@3oool0
05@0oooo00<0Ga@0000eS`3oool00P3oool00`34Ga@00000000DG`0S0?ooo`030?ooS`0e01@0GlCo
00@0oooo00<0Ga@D05o4o`3oool0E03oool00`3oohl0=@00000eS`030?ooo`0308le000051@051AO
0380oooo001E0?ooo`0708le0000000000000000000055l0ohle000DG`0R0?ooo`030?n?=@000000
000000D0000000<0000D05o4o`3oool0EP3oool01`2?=@00000000000000000003F?0?o4G`0D55l0
<P3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo
6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00?l0oooo6@3oool00001\
\>"],
  ImageRangeCache->{{{91.5625, 240.375}, {562.563, 413.75}} -> {-0.615299, \
2.78037, 0.00537595, 0.00537595}}]
}, Open  ]],

Cell["We want to decide whether, under these assumptions, ", "Text"],

Cell[BoxData[
    \(TraditionalForm\`GD\&_ = \(2  ED\&_ = \(2 \((EF\&_ - DF\&_)\) = 
          2 \(\((AB\&_ - DF\&_)\)\(.\)\)\)\)\)], "Input",
  FormatType->StandardForm],

Cell["For abbreviation, let's write", "Text"],

Cell[BoxData[
    \(a = AB\&_, \ b = GD\&_, f = \(\(DF\&_\)\(.\)\)\)], "Input"],

Cell["Then, what we want to prove is that", "Text"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+\(a \[NotEqual] 0, f, b\)\), 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            StyleBox["{",
              SpanMaxSize->Infinity], GridBox[{
                {\(f\^2 = 3/4  a\^2\)},
                {\(b\^2 = \((a/2 - b)\)\^2 + \((a - f)\)\^2\)}
                },
              ColumnAlignments->{Left}], 
            StyleBox["}",
              ShowContents->False]}], "\[Implies]", \((b = 2 \((a - f)\))\)}],
         ")"}]}]], "Input"],

Cell["The Transformation to a Groebner Basis Construction Problem:", "Text",
  FontWeight->"Bold"],

Cell["This is equivalent to", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\(\[Not] \[Exists] \)\+\(a, f, b\)\), 
        RowBox[{"(", 
          RowBox[{
            StyleBox["{",
              SpanMaxSize->Infinity], GridBox[{
                {\(a \[NotEqual] 0\)},
                {\(f\^2 = 3/4  a\^2\)},
                {\(b\^2 = \((a/2 - b)\)\^2 + \((a - f)\)\^2\)},
                {\(b \[NotEqual] 2 \((a - f)\)\)}
                },
              ColumnAlignments->{Left}], 
            StyleBox["}",
              ShowContents->False]}], ")"}]}], ","}]], "Input"],

Cell["which is equivalent to", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\(\[Not] \[Exists] \)\+\(a, f, b, \[Xi], \[Eta]\)\), 
        RowBox[{"(", 
          RowBox[{
            StyleBox["{",
              SpanMaxSize->Infinity], GridBox[{
                {\(a\ \[Eta] = 1\)},
                {\(f\^2 = 3/4  a\^2\)},
                {\(b\^2 = \((a/2 - b)\)\^2 + \((a - f)\)\^2\)},
                {\(\((b - 2 \((a - f)\))\) \[Xi] = 1\)}
                },
              ColumnAlignments->{Left}], 
            StyleBox["}",
              ShowContents->False]}], ")"}]}], ","}]], "Input"],

Cell["\<\
This question can be decided by computing the (reduced) Gr\[ODoubleDot]bner \
basis\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(J = 
      GroebnerBasis[{a\ \[Eta] - 1, f\^2 - 3/4  a\^2, 
          b\^2 - \((a/2 - b)\)\^2 - \((a - f)\)\^2, \((b - 
                  2 \((a - f)\))\) \[Xi] - 1}, {\[Xi], \[Eta], b, f, 
          a}]\)], "Input"],

Cell[BoxData[
    \({1}\)], "Output"]
}, Open  ]],

Cell["\<\
and to check whether or not this Gr\[ODoubleDot]bner basis is equal to {1}. \
Since this is the case, we know that the restricted version of the theorem is \
true.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Application: Graph Coloring", "Subsection"],

Cell[CellGroupData[{

Cell["The Problem", "Subsubsection"],

Cell["\<\
Find all admissible colorings in k colors of a graph with n vertices and \
edges E:\
\>", "Text"],

Cell["\<\
An admissible coloring in 3 colors of a graph with 4 vertices and edges \
{1,2}, {1,3}, {2,3}, {3,4}:\
\>", "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0000c/0@0006`000000000000003P100100@00
00000000002;7P00B2400215CDH00040k0`0090000040000000000000000000000@00003003n0000
b`000000000000000000033P0`3h60<02P00010000080@00l00000T0000@0000>P400481000D0000
300000d0000W00006000004000000000o`000000000U000030000040000V00007000008000000000
0@000000000000029@0000`000020000:P0001P0000@0@00l00004P1000X0@009@0000`000000020
:00000`0000100009@0000`000070020:00000`000020000DP000701000200000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000001P00004000100P00@0800010002@QaT0dPdQijQ4nGLN0000
:0`E00005@2P]aL0g>LC0040000TjQ<0l8SjMg0hmGOoooooZ4CiMg1mmGLjR_Eg000005/1003ooooo
L>cP06cgh00h`:P10000000000000000J7_:000000000000000000000000;@00X000008000101QD0
0000000000000000@00005H100000000`>[P05bgh0000:P1V;bX0E3W4`1@jA<0P>TC0;cY4`1`N/X0
iP00000000000000O;GP0:2eh000jA<0G[bB<80000010000I7H02000000U000030000080000H0000
30000000008I000030000?ooo`8K00004000000000000000DP00070100010000h?ooo`0000000000
0000090100000000040005@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^00000000000000000000
00000000000000000000000000000<X0[>4C031ebP3mL@<`000009Q00c0?00000P0002aebP000000
@>8C0=/o0c0/MLX000000>1bbP10hQ<0Zd@3<4l;0G`M?0<`9C`3<60000180000H00004P0001/ha<0
H00004P0001P0000B00004El0S070000H0000000000dhQ<0TS/3<0L00028ha<0Nj2<<2aebP1P0000
B000060000180000;7G:0;cS4`0<>`<`K><C0040000001<0Q;l9OTl;0Gb0hQ<0i0@0013T4`000000
0R2><4l;0Gb0hQ<00@00013T4`0@LLX0M>@C0000000]0000I7H02000000U000030000040000X0000
30000080000H000030000000008I000030000?ooo`8K000040000000000000005P0000`0000H0000
4P0000`000010000E00005@0000L00002`0002/0000^00000@00001`aT5EMM=1904001L100010000
C00000000000000000000?ooooooooooD0000340000@00005P0000`0000000004P0000`000020000
4P0000`0000200003000010000000000000002L0000H00000P000000003oo`00000002D0000<0000
0P0002H0000L00000`0000000001000000000000008U0000300000<0000Z0000600000P2003`0@00
@08002P2000U000030000000080X000030000080000U0000300000L0080X0000300000<0000H0000
30000000008I000030000?ooo`8K00004000000000000000600000`0000000026@0000`0003oool2
6`00010000000000000001H0000<000060000180000<00000@0005@0001D0000504000/1000S0@00
;P4000400000L<I1EGGC@A`2000G0P000@0004`00000000000000000003ooooooooooe00000d0000
400001H0000<000000000180000<00000P000180000<00000P0000`0000@000000000000000W0000
600000<000000000003o0000000U0000300000<0000V000070000080000000000@00000000000002
9@0000`000020000:P0001P000080@00n0400401000`0P009@0000`000000020:00000`000030000
9@0000`000070020:00000`000020000600000`0000000026@0000`0003oool26`00010000000000
000001P0000<000000000QT0000<0000oooo0Q/0000@000000000000000F0000300001P0000B0000
30000040001D0000E00001@0000C0@008`0003H1000100000736@EEedd4L0@007`800040001<0000
0000000000000000oooooooooom@0000<`000100000F000030000000000B000030000080000B0000
30000080000<000040000000000000009`0001P00002000000000?oo000000009@0000`000020000
9P0001`000030000000000400000000000000RD0000<00000`0002X0000H000020800?P000100P00
<04002D0000<00000000P2P0000<00000P0002D0000<00001`00P2P0000<00000`0001P0000<0000
00000QT0000<0000oooo0Q/0000@000000000000000H000030000000008I000030000?ooo`8K0000
40000000000000005P0000`0000H00004P0000`000010000E00005@0000D0@004`0002<1000f0000
0@00001`aT5EMM=1708001l100010000C00000000000000000000?ooooooooooD0000380000@0000
5P0000`0000000004P0000`0000200004P0000`0000200003000010000000000000002L0000H0000
0`0000000000c9T0000002D0000<00000`0002H0000L00000P0000000001000000000000008U0000
30000080000[0000600004P100080@0040800101000U000030000000080X0000300000<0000U0000
300000L0080X000030000080000<000040000000000000009`0001P0000200000000003<V@000000
9@0000`0000200009P0001`000030000000000400000000000000RD0000<00000`0002/0000H0000
804002P1000X0@00008002D0000<00000000P2P0000<00000P0002D0000<00001`00P2P0000<0000
0`0000`0000@000000000000000W0000600000<0000000000<bI0000000U0000300000<0000V0000
70000080000000000@000000000000029@0000`000020000:`0001P000100@0060800102000P0P00
9@0000`000000020:00000`0000300009@0000`000070020:00000`0000200003000010000000000
000004H0000X0000700004M4BD<20000>`4001T1000>0P0040800000001O0000>0000080000h0000
000003P00000000000010040000000000000000000000000000002D0000<00000P0002L0000H0000
0`0000000000c9T0000002D0000<00000`0005H0000/0000<P0002P000060@00804000@0000l0@P2
@P4>0P`280460QX19@0000`000070020:00000`0000200009@0000`000000020:00000`000030000
AP0001@000080000AdA9@`<0000<000040000000000000009@0000`0000800209@0000`000050020
9@0000`0000=0020:00000`0000100003P0001@000000000400001@0
\>"], "Graphics",
  ImageSize->{165.313, 169.5},
  ImageMargins->{{147, 0}, {0, 3}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Not an admissible coloring in 3 colors of the same graph:", "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0000c/0@0006`000000000000003P100100@00
00000000002;7P00B2400215CDH00040k0`0090000040000000000000000000000@00003003n0000
b`000000000000000000033P0`3h60<02P00010000080@00l00000T0000@0000>P400481000D0000
300000d0000W00006000004000000000o`000000000U000030000040000V00007000008000000000
0@000000000000029@0000`000020000:P0001P0000@0@00l00004P1000X0@009@0000`000000020
:00000`0000100009@0000`000070020:00000`000020000DP000701000200000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000001P00004000100P00@0800010002@QaT0AQHQQZQ4nGLN0000
:0`E00005@2P]aL0g>LC0040000TjQ<0l8SjMg0hmGOoooooZ4CiMg1mmGLjR_Eg000005/1003ooooo
<;CP0<c/h00h]jP10000000000000000J7_:000000000000000000000000;@00X000008000101QD0
0000000000000000@00005H100000000J>kP0:RRh0000:P19;fX0E3W4`1@jA<0P>TC0;cY4`1`N/X0
iP00000000000000N:3P09bPh000jA<0G[bB<80000010000I7H02000000U000030000080000H0000
30000000008I000030000?ooo`8K00004000000000000000DP00070100010000h?ooo`0000000000
0000090100000000040005@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^00000000000000000000
00000000000000000000000000000<X0[>4C031ebP3mL@<`000009Q00c0?00000P0002aebP000000
@>8C0=/o0c0/MLX0000008AabP10hQ<0Zd@3<4l;0G`M?0<`9C`3<60000180000H00004P0001/ha<0
H00004P0001P0000B00004El0S070000H0000000000dhQ<0TS/3<0L00028ha<0Nj2<<2aebP1P0000
B000060000180000;7G:0;cS4`0<>`<`K><C0040000001<0Q;l9OTl;0Gb0hQ<0i0@0013T4`000000
0R2><4l;0Gb0hQ<00@00013T4`3PL/X0M>@C0000000]0000I7H02000000U000030000040000X0000
30000080000H000030000000008I000030000?ooo`8K000040000000000000005P0000`0000H0000
4P0000`000010000E00005@0000L00002`0002/0000^00000@00001`aT5EMM=1904001L100010000
C00000000000000000000?ooooooooooD0000340000@00005P0000`0000000004P0000`000020000
4P0000`0000200003000010000000000000002L0000H00000P000000000c<l`0000002D0000<0000
0P0002H0000L00000`0000000001000000000000008U0000300000<0000Z0000600000P2003`0@00
@08002P2000U000030000000080X000030000080000U0000300000L0080X0000300000<0000H0000
30000000008I000030000?ooo`8K00004000000000000000600000`0000000026@0000`0003oool2
6`00010000000000000001H0000<000060000180000<00000@0005@0001D0000504000/1000S0@00
;P4000400000L<I1EGGC@A`2000G0P000@0004`00000000000000000003ooooooooooe00000d0000
400001H0000<000000000180000<00000P000180000<00000P0000`0000@000000000000000W0000
600000<000000000o`000000000U0000300000<0000V000070000080000000000@00000000000002
9@0000`000020000:P0001P000080@00n0400401000`0P009@0000`000000020:00000`000030000
9@0000`000070020:00000`000020000600000`0000000026@0000`0003oool26`00010000000000
000001P0000<000000000QT0000<0000oooo0Q/0000@000000000000000F0000300001P0000B0000
30000040001D0000E00001@0000C0@008`0003H1000100000736@EEedd4L0@007`800040001<0000
0000000000000000oooooooooom@0000<`000100000F000030000000000B000030000080000B0000
30000080000<000040000000000000009`0001P00002000000000?oo000000009@0000`000020000
9P0001`000030000000000400000000000000RD0000<00000`0002X0000H000020800?P000100P00
<04002D0000<00000000P2P0000<00000P0002D0000<00001`00P2P0000<00000`0001P0000<0000
00000QT0000<0000oooo0Q/0000@000000000000000H000030000000008I000030000?ooo`8K0000
40000000000000005P0000`0000H00004P0000`000010000E00005@0000D0@004`0002<1000f0000
0@00001`aT5EMM=1708001l100010000C00000000000000000000?ooooooooooD0000380000@0000
5P0000`0000000004P0000`0000200004P0000`0000200003000010000000000000002L0000H0000
0`0000000000c9T0000002D0000<00000`0002H0000L00000P0000000001000000000000008U0000
30000080000[0000600004P100080@0040800101000U000030000000080X0000300000<0000U0000
300000L0080X000030000080000<000040000000000000009`0001P0000200000000003<V@000000
9@0000`0000200009P0001`000030000000000400000000000000RD0000<00000`0002/0000H0000
804002P1000X0@00008002D0000<00000000P2P0000<00000P0002D0000<00001`00P2P0000<0000
0`0000`0000@000000000000000W0000600000<0000000000<bI0000000U0000300000<0000V0000
70000080000000000@000000000000029@0000`000020000:`0001P000100@0060800102000P0P00
9@0000`000000020:00000`0000300009@0000`000070020:00000`0000200003000010000000000
000004H0000X0000700004M4BD<20000>`4001T1000>0P0040800000001O0000>0000080000h0000
000003P00000000000010040000000000000000000000000000002D0000<00000P0002L0000H0000
0`0000000000c9T0000002D0000<00000`0005H0000/0000<P0002P000060@00804000@0000l0@P2
@P4>0P`280460QX19@0000`000070020:00000`0000200009@0000`000000020:00000`000030000
AP0001@000080000AdA9@`<0000<000040000000000000009@0000`0000800209@0000`000050020
9@0000`0000=0020:00000`0000100003P0001@000000000400001@0
\>"], "Graphics",
  ImageSize->{165.25, 169.5},
  ImageMargins->{{146, 0}, {0, 35}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The Translation into a Groebner Bases Problem\
\>", "Subsubsection"],

Cell[TextData[{
  StyleBox["Theorem",
    FontWeight->"Bold"],
  ": The possible colorings of the above graph correspond 1-1 to the common \
solutions of the following set of polynomials:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((x\_1\^2 + x\_1\ x\_2 + x\_2\^2)\) \((x\_1 - x\_2)\) // 
      Expand\)], "Input"],

Cell[BoxData[
    \(x\_1\%3 - x\_2\%3\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \({\ \(-1\) + 
        x\_1\^3, \ \ \ \ \ \(\(...\)\(\ \ \)\(at\)\(\ \)\(vertex\)\(\ \)\(1\)\
\(\ \)\(color\)\(\ \)\(is\)\(\ \)\(a\)\(\ \)\(3\)\) - 
        ary\ root\ of\ 1\[IndentingNewLine] - 1 + 
        x\_2\^3, \ \ \ \(\(...\)\(\ \ \)\(at\)\(\ \)\(vertex\)\(\ \)\(2\)\(\ \
\)\(color\)\(\ \)\(is\)\(\ \)\(a\)\(\ \)\(3\)\) - 
        ary\ root\ of\ 1\[IndentingNewLine] - 1 + 
        x\_3\^3, \[IndentingNewLine]\(-1\) + 
        x\_4\^3, \[IndentingNewLine]x\_1\^2 + x\_1\ x\_2 + 
        x\_2\^2, \ \ \(\(...\)\(\ \)\(the\)\(\ \)\(colors\)\(\ \)\(at\)\(\ \)\
\(1\)\(\ \)\(and\)\(\ \)\(2\)\(\ \)\(must\)\(\ \)\(be\)\(\ \)\(different\)\), \
\[IndentingNewLine]x\_1\^2 + x\_1\ x\_3 + 
        x\_3\^2, \[IndentingNewLine]x\_2\^2 + x\_2\ x\_3 + 
        x\_3\^2, \[IndentingNewLine]x\_3\^2 + x\_3\ x\_4 + 
        x\_4\^2}\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution by Groebner Bases", "Subsubsection"],

Cell["\<\
Compute a Groebner basis of this polynomial set and compute all solutions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GB = 
      GroebnerBasis[{\(-1\) + x\_1\%3, \(-1\) + x\_2\%3, \(-1\) + 
            x\_3\%3, \(-1\) + x\_4\%3, x\_1\%2 + x\_1\ x\_2 + x\_2\%2, 
          x\_1\%2 + x\_1\ x\_3 + x\_3\%2, x\_2\%2 + x\_2\ x\_3 + x\_3\%2, 
          x\_3\%2 + x\_3\ x\_4 + x\_4\%2}, \[IndentingNewLine]{x\_4, x\_3, 
          x\_2, x\_1}]\)], "Input"],

Cell[BoxData[
    \({\(-1\) + x\_1\%3, 
      x\_1\%2 + x\_1\ x\_2 + x\_2\%2, \(-x\_1\) - x\_2 - 
        x\_3, \(-x\_1\)\ x\_2 + x\_1\ x\_4 + x\_2\ x\_4 - 
        x\_4\%2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[{\(-1\) + x\_1\%3 == 0, \(-1\) + x\_2\%3 == 0, \(-1\) + x\_3\%3 == 
          0, \(-1\) + x\_4\%3 == 0, x\_1\%2 + x\_1\ x\_2 + x\_2\%2 == 0, 
        x\_1\%2 + x\_1\ x\_3 + x\_3\%2 == 0, 
        x\_2\%2 + x\_2\ x\_3 + x\_3\%2 == 0, 
        x\_3\%2 + x\_3\ x\_4 + x\_4\%2 == 0}, \[IndentingNewLine]{x\_4, x\_3, 
        x\_2, x\_1}]\)], "Input"],

Cell[BoxData[
    \({{x\_4 \[Rule] 1, x\_1 \[Rule] 1, 
        x\_2 \[Rule] \(-1\) + \((\(-1\))\)\^\(1/3\), 
        x\_3 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\)}, {x\_4 \[Rule] 1, 
        x\_1 \[Rule] 1, x\_2 \[Rule] \(-1\) - \((\(-1\))\)\^\(2/3\), 
        x\_3 \[Rule] \((\(-1\))\)\^\(2/3\)}, {x\_4 \[Rule] 1, x\_2 \[Rule] 1, 
        x\_1 \[Rule] \(-1\) + \((\(-1\))\)\^\(1/3\), 
        x\_3 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\)}, {x\_4 \[Rule] 1, 
        x\_2 \[Rule] 1, x\_1 \[Rule] \(-1\) - \((\(-1\))\)\^\(2/3\), 
        x\_3 \[Rule] \((\(-1\))\)\^\(2/3\)}, {x\_4 \[Rule] \
\(-\((\(-1\))\)\^\(1/3\)\), x\_2 \[Rule] \(-1\) + \((\(-1\))\)\^\(1/3\), 
        x\_1 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\), 
        x\_3 \[Rule] 1}, {x\_4 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\), 
        x\_2 \[Rule] \(-1\) - \((\(-1\))\)\^\(2/3\), 
        x\_1 \[Rule] \((\(-1\))\)\^\(2/3\), 
        x\_3 \[Rule] 1}, {x\_4 \[Rule] \((\(-1\))\)\^\(2/3\), 
        x\_2 \[Rule] \(-1\) + \((\(-1\))\)\^\(1/3\), 
        x\_1 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\), 
        x\_3 \[Rule] 1}, {x\_4 \[Rule] \((\(-1\))\)\^\(2/3\), 
        x\_2 \[Rule] \(-1\) - \((\(-1\))\)\^\(2/3\), 
        x\_1 \[Rule] \((\(-1\))\)\^\(2/3\), 
        x\_3 \[Rule] 1}, {x\_4 \[Rule] \(-1\) + \((\(-1\))\)\^\(1/3\), 
        x\_1 \[Rule] 1, x\_2 \[Rule] \(-1\) + \((\(-1\))\)\^\(1/3\), 
        x\_3 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\)}, {x\_4 \[Rule] \(-1\) + \
\((\(-1\))\)\^\(1/3\), x\_2 \[Rule] 1, 
        x\_1 \[Rule] \(-1\) + \((\(-1\))\)\^\(1/3\), 
        x\_3 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\)}, {x\_4 \[Rule] \(-1\) - \
\((\(-1\))\)\^\(2/3\), x\_1 \[Rule] 1, 
        x\_2 \[Rule] \(-1\) - \((\(-1\))\)\^\(2/3\), 
        x\_3 \[Rule] \((\(-1\))\)\^\(2/3\)}, {x\_4 \[Rule] \(-1\) - \
\((\(-1\))\)\^\(2/3\), x\_2 \[Rule] 1, 
        x\_1 \[Rule] \(-1\) - \((\(-1\))\)\^\(2/3\), 
        x\_3 \[Rule] \((\(-1\))\)\^\(2/3\)}}\)], "Output"]
}, Open  ]],

Cell["Slightly re-organized output:", "Text"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\({x\_1 \[Rule] 1, x\_2 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\), 
          x\_3 \[Rule] \(-1\) + \((\(-1\))\)\^\(1/3\), x\_4 \[Rule] 1}\), ",",
         
        RowBox[{"{", 
          RowBox[{
            StyleBox[\(x\_1 \[Rule] 1\),
              FontColor->RGBColor[1, 0, 0]], ",", 
            StyleBox[\(x\_2 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\)\),
              FontColor->RGBColor[1, 1, 0]], ",", 
            StyleBox[\(x\_3 \[Rule] \(-1\) + \((\(-1\))\)\^\(1/3\)\),
              FontColor->RGBColor[0, 0, 1]], ",", 
            StyleBox[\(x\_4 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\)\),
              FontColor->RGBColor[1, 1, 0]]}], "}"}], 
        ",", \({x\_1 \[Rule] 1, x\_2 \[Rule] \((\(-1\))\)\^\(2/3\), 
          x\_3 \[Rule] \(-1\) - \((\(-1\))\)\^\(2/3\), x\_4 \[Rule] 1}\), 
        ",", \({x\_1 \[Rule] 1, x\_2 \[Rule] \((\(-1\))\)\^\(2/3\), 
          x\_3 \[Rule] \(-1\) - \((\(-1\))\)\^\(2/3\), 
          x\_4 \[Rule] \((\(-1\))\)\^\(2/3\)}\), 
        ",", \({x\_1 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\), x\_2 \[Rule] 1, 
          x\_3 \[Rule] \(-1\) + \((\(-1\))\)\^\(1/3\), x\_4 \[Rule] 1}\), 
        ",", \({x\_1 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\), x\_2 \[Rule] 1, 
          x\_3 \[Rule] \(-1\) + \((\(-1\))\)\^\(1/3\), 
          x\_4 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\)}\), 
        ",", \({x\_1 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\), 
          x\_2 \[Rule] \(-1\) + \((\(-1\))\)\^\(1/3\), x\_3 \[Rule] 1, 
          x\_4 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\)}\), 
        ",", \({x\_1 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\), 
          x\_2 \[Rule] \(-1\) + \((\(-1\))\)\^\(1/3\), x\_3 \[Rule] 1, 
          x\_4 \[Rule] \(-1\) + \((\(-1\))\)\^\(1/3\)}\), 
        ",", \({x\_1 \[Rule] \((\(-1\))\)\^\(2/3\), x\_2 \[Rule] 1, 
          x\_3 \[Rule] \(-1\) - \((\(-1\))\)\^\(2/3\), x\_4 \[Rule] 1}\), 
        ",", \({x\_1 \[Rule] \((\(-1\))\)\^\(2/3\), x\_2 \[Rule] 1, 
          x\_3 \[Rule] \(-1\) - \((\(-1\))\)\^\(2/3\), 
          x\_4 \[Rule] \((\(-1\))\)\^\(2/3\)}\), 
        ",", \({x\_1 \[Rule] \((\(-1\))\)\^\(2/3\), 
          x\_2 \[Rule] \(-1\) - \((\(-1\))\)\^\(2/3\), x\_3 \[Rule] 1, 
          x\_4 \[Rule] \((\(-1\))\)\^\(2/3\)}\), 
        ",", \({x\_1 \[Rule] \((\(-1\))\)\^\(2/3\), 
          x\_2 \[Rule] \(-1\) - \((\(-1\))\)\^\(2/3\), x\_3 \[Rule] 1, 
          x\_4 \[Rule] \(-1\) - \((\(-1\))\)\^\(2/3\)}\)}], "}"}]], "Input",
  Background->GrayLevel[0.666667]],

Cell[TextData[{
  "For example, ",
  Cell[BoxData[
      \({x\_1 \[Rule] 1, x\_2 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\), 
        x\_3 \[Rule] \(-1\) + \((\(-1\))\)\^\(1/3\), 
        x\_4 \[Rule] \(-\((\(-1\))\)\^\(1/3\)\)}\)]],
  "corresponds to "
}], "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0000c/0@0006`000000000000003P100100@00
00000000002;7P00B2400215CDH00040k0`0090000040000000000000000000000@00003003n0000
b`000000000000000000033P0`3h60<02P00010000080@00l00000T0000@0000>P400481000D0000
300000d0000W00006000004000000000o`000000000U000030000040000V00007000008000000000
0@000000000000029@0000`000020000:P0001P0000@0@00l00004P1000X0@009@0000`000000020
:00000`0000100009@0000`000070020:00000`000020000DP000701000200000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000001P00004000100P00@0800010002@QaT0dPdQijQ4nGLN0000
:0`E00005@2P]aL0g>LC0040000TjQ<0l8SjMg0hmGOoooooZ4CiMg1mmGLjR_Eg000005/1003ooooo
L>cP06cgh00h`:P10000000000000000J7_:000000000000000000000000;@00X000008000101QD0
0000000000000000@00005H100000000`>[P05bgh0000:P1V;bX0E3W4`1@jA<0P>TC0;cY4`1`N/X0
iP00000000000000O;GP0:2eh000jA<0G[bB<80000010000I7H02000000U000030000080000H0000
30000000008I000030000?ooo`8K00004000000000000000DP00070100010000h?ooo`0000000000
0000090100000000040005@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^00000000000000000000
00000000000000000000000000000<X0[>4C031ebP3mL@<`000009Q00c0?00000P0002aebP000000
@>8C0=/o0c0/MLX000000>1bbP10hQ<0Zd@3<4l;0G`M?0<`9C`3<60000180000H00004P0001/ha<0
H00004P0001P0000B00004El0S070000H0000000000dhQ<0TS/3<0L00028ha<0Nj2<<2aebP1P0000
B000060000180000;7G:0;cS4`0<>`<`K><C0040000001<0Q;l9OTl;0Gb0hQ<0i0@0013T4`000000
0R2><4l;0Gb0hQ<00@00013T4`0@LLX0M>@C0000000]0000I7H02000000U000030000040000X0000
30000080000H000030000000008I000030000?ooo`8K000040000000000000005P0000`0000H0000
4P0000`000010000E00005@0000L00002`0002/0000^00000@00001`aT5EMM=1904001L100010000
C00000000000000000000?ooooooooooD0000340000@00005P0000`0000000004P0000`000020000
4P0000`0000200003000010000000000000002L0000H00000P000000003oo`00000002D0000<0000
0P0002H0000L00000`0000000001000000000000008U0000300000<0000Z0000600000P2003`0@00
@08002P2000U000030000000080X000030000080000U0000300000L0080X0000300000<0000H0000
30000000008I000030000?ooo`8K00004000000000000000600000`0000000026@0000`0003oool2
6`00010000000000000001H0000<000060000180000<00000@0005@0001D0000504000/1000S0@00
;P4000400000L<I1EGGC@A`2000G0P000@0004`00000000000000000003ooooooooooe00000d0000
400001H0000<000000000180000<00000P000180000<00000P0000`0000@000000000000000W0000
600000<000000000003o0000000U0000300000<0000V000070000080000000000@00000000000002
9@0000`000020000:P0001P000080@00n0400401000`0P009@0000`000000020:00000`000030000
9@0000`000070020:00000`000020000600000`0000000026@0000`0003oool26`00010000000000
000001P0000<000000000QT0000<0000oooo0Q/0000@000000000000000F0000300001P0000B0000
30000040001D0000E00001@0000C0@008`0003H1000100000736@EEedd4L0@007`800040001<0000
0000000000000000oooooooooom@0000<`000100000F000030000000000B000030000080000B0000
30000080000<000040000000000000009`0001P00002000000000?oo000000009@0000`000020000
9P0001`000030000000000400000000000000RD0000<00000`0002X0000H000020800?P000100P00
<04002D0000<00000000P2P0000<00000P0002D0000<00001`00P2P0000<00000`0001P0000<0000
00000QT0000<0000oooo0Q/0000@000000000000000H000030000000008I000030000?ooo`8K0000
40000000000000005P0000`0000H00004P0000`000010000E00005@0000D0@004`0002<1000f0000
0@00001`aT5EMM=1708001l100010000C00000000000000000000?ooooooooooD0000380000@0000
5P0000`0000000004P0000`0000200004P0000`0000200003000010000000000000002L0000H0000
0`0000000000c9T0000002D0000<00000`0002H0000L00000P0000000001000000000000008U0000
30000080000[0000600004P100080@0040800101000U000030000000080X0000300000<0000U0000
300000L0080X000030000080000<000040000000000000009`0001P0000200000000003<V@000000
9@0000`0000200009P0001`000030000000000400000000000000RD0000<00000`0002/0000H0000
804002P1000X0@00008002D0000<00000000P2P0000<00000P0002D0000<00001`00P2P0000<0000
0`0000`0000@000000000000000W0000600000<0000000000<bI0000000U0000300000<0000V0000
70000080000000000@000000000000029@0000`000020000:`0001P000100@0060800102000P0P00
9@0000`000000020:00000`0000300009@0000`000070020:00000`0000200003000010000000000
000004H0000X0000700004M4BD<20000>`4001T1000>0P0040800000001O0000>0000080000h0000
000003P00000000000010040000000000000000000000000000002D0000<00000P0002L0000H0000
0`0000000000c9T0000002D0000<00000`0005H0000/0000<P0002P000060@00804000@0000l0@P2
@P4>0P`280460QX19@0000`000070020:00000`0000200009@0000`000000020:00000`000030000
AP0001@000080000AdA9@`<0000<000040000000000000009@0000`0000800209@0000`000050020
9@0000`0000=0020:00000`0000100003P0001@000000000400001@0
\>"], "Graphics",
  ImageSize->{190.625, 195.5},
  ImageMargins->{{144.25, 0}, {0, 0.25}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discussion", "Section"],

Cell[CellGroupData[{

Cell["How Difficult is the Construction of Gr\[ODoubleDot]bner Bases?", \
"Subsection",
  CellTags->"very-easy"],

Cell[CellGroupData[{

Cell["Very Easy", "Subsubsection",
  CellTags->"very-easy"],

Cell["\<\
The structure of the algorithm is easy. The operations needed in the \
algorithm are elementary. \"Every high-school student can execute the \
algorithm.\" (See palm-top TI-98.)    \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Very Difficult", "Subsubsection",
  CellTags->"very-difficult"],

Cell[TextData[{
  "The inherent complexity of the problems that can be solved by the GB \
method (e.g. graph colorings) is \"exponential\". Hence, the worst-case \
complexity of the GB algorithm ",
  StyleBox["must",
    FontSlant->"Italic"],
  " be high.   "
}], "Text",
  CellTags->"difficult"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sometimes Easy", "Subsubsection",
  CellTags->"sometimes-easy"],

Cell["\<\
Mathematically interesting examples often have a lot of \"structure\" and, in \
concrete examples, GB computations can be reasonably, even surprisingly, \
fast. \
\>", "Text",
  CellTags->"sometimes-easy"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Enormous Potential for Improvement", "Subsubsection"],

Cell[TextData[{
  "More ",
  StyleBox["mathematical ",
    FontSlant->"Italic"],
  "theorems can lead to drastic speed-up:"
}], "Text",
  CellTags->"improvements"],

Cell["\<\
The use of \"criteria\" for eliminating the consideration of certain \
S-polynomials.\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{65.5625, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  StyleBox["p",
    FontSlant->"Italic"],
  "-adic approaches and floating point approaches."
}], "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{65.5625, Inherited}, {Inherited, Inherited}}],

Cell["The \"Gr\[ODoubleDot]bner Walk\" approach.", "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{65.5625, Inherited}, {Inherited, Inherited}}],

Cell["\<\
The \"linear algebra\" approach. (Generalized Sylvester matrices.)  \
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{65.5625, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Practically, ",
  StyleBox["tuning",
    FontSlant->"Italic"],
  " of the algorithm is also important: "
}], "Text"],

Cell["\<\
Heuristics, strategies for choosing orderings, selecting S-polynomials etc.\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{68.75, Inherited}, {Inherited, Inherited}},
  CellTags->"tuning"],

Cell["Good implementation techniques.", "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{68.75, Inherited}, {Inherited, Inherited}}],

Cell[" A huge literature.", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Why \"Gr\[ODoubleDot]bner\" Bases?", "Subsection"],

Cell[TextData[{
  "Professor ",
  StyleBox[" Wolfgang Gr\[ODoubleDot]bner",
    FontColor->RGBColor[1, 0, 0]],
  " (1899-1980) was my PhD thesis supervisor."
}], "Text",
  CellTags->"Groebner-bases-name"],

Cell["\<\
He gave me the problem of finding \"the uncovered points if the black points \
are given\".\
\>", "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0001d`0@0006`0000:000000000742003Z0@00
00000000003g?@00GS<00215CDH00040<1d007/100040000000000000000000000@00003003n0000
b`000000000000000000033P0`3h60<02P000100001`0000`00000T0000@0000O@800?41000D0000
300000d0000W000060000040000000000<bI0000000U000030000040000V00007000008000000000
0@000000000000029@0000`000020000:`0001P0003@0000`0000=P0001`0P009@0000`000000020
:00000`0000100009@0000`000070020:00000`0000200003000010000000000000002L0000H0000
0P0000000000c9T0000002D0000<00000P0002H0000L00000@0000000001000000000000008U0000
30000040000[0000600002P200380000<08007P2000U000030000000080X000030000080000U0000
300000L0080X000030000040000<000040000000000000009`0001P0000100000000003<V@000000
9@0000`0000100009P0001`000020000000000400000000000000RD0000<00000P0002/0000H0000
>0400=0000100@00P08002D0000<00000000P2P0000<00000@0002D0000<00001`00P2P0000<0000
0P0000`0000@000000000000000W000060000080000000000<bI0000000U000030000080000V0000
70000040000000000@000000000000029@0000`000010000:`0001P0002X0@00b0000;01001h0P00
9@0000`000000020:00000`0000200009@0000`000070020:00000`0000100003000010000000000
000002L0000H00000@0000000000c9T0000002D0000<00000@0002H0000L00000P00000000010000
00000000008U000030000080000[000060000:P000180P00Z0800502000U000030000000080X0000
30000040000U0000300000L0080X000030000080000<000040000000000000009`0001P000020000
0000003<V@0000009@0000`0000200009P0001`000010000000000400000000000000RD0000<0000
0@0002/0000H0000Z0000>01002X0P00j04002D0000<00000000P2P0000<00000P0002D0000<0000
1`00P2P0000<00000@0000`0000@000000000000000W000060000040000000000<bI0000000U0000
30000040000V000070000080000000000@000000000000029@0000`000020000:`0001P0002P0000
L0400:02001h0@009@0000`000000020:00000`0000100009@0000`000070020:00000`000020000
3000010000000000000002L0000H00000P0000000000c9T0000002D0000<00000P0002H0000L0000
0@0000000001000000000000008U000030000040000[000060000:P000000@00Z08000P1000U0000
30000000080X000030000080000U0000300000L0080X000030000040000<00004000000000000000
9`0001P00001000000000000000000009@0000`0000100009P0001`0000200000000004000000000
00000RD0000<00000P0002X0000H0000^0000601003X0000T04002D0000<00000000P2P0000<0000
0@0002D0000<00001`00P2P0000<00000P0000`0000@000000000000000W00006000008000000000
ool00000000U000030000080000V000070000040000000000@000000000000029@0000`000010000
:P0001P0000X0@00b04005P1003h0@009@0000`000000020:00000`0000200009@0000`000070020
:00000`0000100003000010000000000000002L0000H00000@00000000000000000002D0000<0000
0@0002H0000L00000P0000000001000000000000008U000030000080000Z0000600001P2000h0P00
B08006P2000U000030000000080X000030000040000U0000300000L0080X000030000080000<0000
40000000000000009@0000`0000500209@0000`000080020:`0001P000300P00:0800>/2001[0P00
9@0000`0000000209@0000`000070020DP0007010002000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000001P00004000100P00@0800010003PQ1L0L0/QTjQ4nGLN0000:0`E00005@2P<aX0
g>LC0040000TjQ<0l8SjMg0hmGOoooooZ4CiMg1mmGLjR_Eg000005/1003oooooL9mQ0J2<H@6LPk<1
00000000000000007938000000000000000000000000;@00Z`00008000101QD00000000000000000
@00005H100000000j9UQ0J2<H@400;<1K8Bc0E3W4`1@jA<0P>TC0;cY4`0TSlP0iP00000000000000
289Q0Bb2H@40jA<0G[bB<80000010000I7H02000000U000030000080000H000030000000008I0000
30000?ooo`8K00004000000000000000DP00070100010000d?ooo`00000000000000090100000000
04008T40LP1Y0640K000000000000000000000000000000000000000000000000000000000000000
0000000000000<P0[>4C0>B9b03mL@<`000009Q00c0?00000P000>29b0000000@>8C0=/o0c3PRLP0
000009B7b010hQ<0Zd@3<2h@0DPM?0<`9C`3<60000180000H00004P0001/ha<0H00004P0001P0000
B00004El0S070000H0000000000dhQ<0TS/3<0L00028ha<0Nj2<<>29b01P0000B000060000180000
h8W80;cS4`0<>`<`K><C0040000001<0Q;l9ORh@0DR0hQ<0i0@0013T4`0000000R2><2h@0DR0hQ<0
0@00013T4`2/Q/P0M>@C0000000]0000I7H02000000U000030000040000X000030000080000H0000
30000000008I000030000?ooo`8K000040000000000000005P0000`0000H00004P0000`000010000
E00005@0001J0P00K`400742002U0@000@00001`aT5EMM=1bP8005`200010000C000000000000000
00000?ooooooooooD00007P0000H00005P0000`0000000004P0000`0000200004P0000`000020000
3000010000000000000002L0000H00000P000000003o0000000002D0000<00000P0002H0000L0000
0`0000000001000000000000008U0000300000<0000Z0000600009P1003X0000b04001P1000U0000
30000000080X000030000080000U0000300000L0080X0000300000<0000<00004000000000000000
9`0001P00003000000000?l0000000009@0000`0000300009P0001`0000200000000004000000000
00000RD0000<00000P0002X0000H0000T04005P100300@00R04002D0000<00000000P2P0000<0000
0`0002D0000<00001`00P2P0000<00000P0000`0000@000000000000000W00006000008000000000
o`000000000U000030000080000V0000700000<0000000000@000000000000029@0000`000030000
:P0001P0000@0P00b0400402003h0@009@0000`000000020:00000`0000200009@0000`000070020
:00000`0000300003000010000000000000002L0000H00000`000000003o0000000002D0000<0000
0`0002H0000L00000P0000000001000000000000008U000030000080000Z0000600001P2001H0@00
B08008P1000U000030000000080X0000300000<0000U0000300000L0080X000030000080000<0000
40000000000000009`0001P00002000000000?l0000000009@0000`0000200009P0001`000030000
000000400000000000000RD0000<00000`0002X0000H000060800?0000180P00804002D0000<0000
0000P2P0000<00000P0002D0000<00001`00P2P0000<00000`0000`0000@000000000000000W0000
600000<000000000o`000000000U0000300000<0000V000070000080000000000@00000000000002
9@0000`000020000:P0001P0000X0@00F04005P100280@009@0000`000000020:00000`000030000
9@0000`000070020:00000`0000200003000010000000000000002L0000H00000P000000003o0000
000002D0000<00000P0002H0000L00000`0000000001000000000000008U0000300000<0000Z0000
60000<00003`0000l0000201000U000030000000080X000030000080000U0000300000L0080X0000
300000<0000<000040000000000000009`0001P00003000000000?l0000000009@0000`000030000
9P0001`000020000000000400000000000000RD0000<00000P0002X0000H0000<0400?00001P0@00
804002D0000<00000000P2P0000<00000`0002D0000<00001`00P2P0000<00000P0000`0000@0000
00000000000W00006000008000000000o`000000000U000030000080000V0000700000<000000000
0@000000000000029@0000`000030000:P0001P0002@0@00b0400<01003h0@009@0000`000000020
:00000`0000200009@0000`000070020:00000`0000300003000010000000000000002D0000<0000
1@00P2D0000<00002000P2/0000H0000b00007P2003]0000Z08002D0000<00000000P2D0000<0000
1`00P1P0000<000000000QT0000<0000oooo0Q/0000@000000000000001B0000L04000<0003Poooo
0000000000000000T04000000000@00R@@1b06T0H@1/000000000000000000000000000000000000
0000000000000000000000000000000000000000b02/hA<0i8W80?ea0c000000V403<0l000020000
h8W800000010hQ<0fcl3<>29b0000000[8K8043R4`2[A0<`;Q01B1dl0c0U?0<`H00004P0001P0000
B00006cS4`1P0000B000060000180000AG`2<0L0001P0000000003CR4`2B>`<`1`0008SS4`1kX8``
h8W8060000180000H00004P0003PRLP0_><C00`k0c1/ha<00@0000004`24_`Un;Q01B83R4`3T1000
4>@C0000000288h`;Q01B83R4`0100004>@C09B7b01di1<0000002d0001TMP08000002D0000<0000
0`0002P0000<00000@0001P0000<000000000QT0000<0000oooo0Q/0000@000000000000000F0000
300001P0000B000030000040001D0000E0000680002o0@00L`000>81000100000736@EEedd7B0000
W0800040001<00000000000000000000oooooooooom@0000<0000180000F000030000000000B0000
30000080000B000030000080000<000040000000000000009@0000`0000500209@0000`000080020
:`0001P0000X0@00P08004d1002`0P009@0000`0000000209@0000`000070020600000`000000002
6@0000`0003oool26`00010000000000000001P0000<000000000QT0000<0000oooo0Q/0000@0000
00000000000F0000300001P0000B000030000040001D0000E0000<8000370@00d`000>X100010000
0736@EEedd4b0@00Y0800040001<00000000000000000000oooooooooom@0000<@000180000F0000
30000000000B000030000080000B000030000080000<000040000000000000009@0000`000050020
9@0000`000080020:`0001P0000@0P00N08003D2002X0P009@0000`0000000209@0000`000070020
600000`0000000026@0000`0003oool26`00010000000000000001P0000<000000000QT0000<0000
oooo0Q/0000@000000000000000F0000300001P0000B000030000040001D0000E0000:X1002o0@00
^`400>81000100000736@EEedd4J0P00W0800040001<00000000000000000000oooooooooom@0000
<`000180000F000030000000000B000030000080000B000030000080000<00004000000000000000
9@0000`0000500209@0000`000080020:`0001P0002@0@00P0800;D1002`0P009@0000`000000020
9@0000`000070020600000`0000000026@0000`0003oool26`00010000000000000001P0000<0000
00000QT0000<0000oooo0Q/0000@000000000000000F0000300001P0000B000030000040001D0000
E00002X100370@00>`400>X1000100000736@EEedd6J0@00Y0800040001<00000000000000000000
oooooooooom@0000<P000180000F000030000000000B000030000080000B000030000080000<0000
40000000000000009@0000`0000500209@0000`000080020:`0001P0001h0000d04009d000000P00
9@0000`0000000209@0000`000070020600000`0000000026@0000`0003oool26`00010000000000
000001P0000<000000000QT0000<0000oooo0Q/0000@000000000000000F0000300001P0000B0000
30000040001D0000E0000180000G0@008`0003X1000100000736@EEedd620000m0400040001<0000
0000000000000000oooooooooom@0000<@000180000F000030000000000B000030000080000B0000
30000080000<000040000000000000009@0000`0000500209@0000`000080020:`0001P0001`0000
J04009D0002H0@009@0000`0000000209@0000`000070020600000`0000000026@0000`0003oool2
6`00010000000000000001P0000<000000000QT0000<0000oooo0Q/0000@000000000000000F0000
300001P0000B000030000040001D0000E00000X0002_00006`000=80000100000736@EEedd5j0000
S0400040001<00000000000000000000oooooooooom@0000<P000180000F000030000000000B0000
30000080000B000030000080000<000040000000000000009@0000`0000500209@0000`000080020
:`0001P0001h0000l00009d0000P0@009@0000`0000000209@0000`000070020600000`000000002
6@0000`0003oool26`00010000000000000001P0000<000000000QT0000<0000oooo0Q/0000@0000
00000000000F0000300001P0000B000030000040001D0000E0000180000g00008`0005X000010000
0736@EEedd62000050400040001<00000000000000000000oooooooooom@0000<`000180000F0000
30000000000B000030000080000B000030000080000<000040000000000000009@0000`000050020
9@0000`000080020:`0001P0001h0000>08009d0001X0P009@0000`0000000209@0000`000070020
600000`0000000026@0000`0003oool26`00010000000000000001P0000<000000000QT0000<0000
oooo0Q/0000@000000000000000F0000300001P0000B000030000040001D0000E0000180001o0@00
8`000:81000100000736@EEedd620000G0800040001<00000000000000000000oooooooooom@0000
<0000180000F000030000000000B000030000080000B000030000080000<00004000000000000000
9@0000`0000800209@0000`0000500209@0000`0000=0020:00000`0000300003P0001@000000000
400001@0
\>"], "Graphics",
  ImageSize->{235, 187.125},
  ImageMargins->{{120.625, 0}, {0, 7.3125}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
In my thesis (1965) and journal publication  (1970) I introduced:\
\>", "Text"],

Cell["\<\
* the concept of Gr\[ODoubleDot]bner bases and reduced Gr\[ODoubleDot]bner \
bases
* the S-polynomials
* the main theorem with proof
* the algorithm with termination and correctness proof
* the uniqueness of Gr\[ODoubleDot]bner bases
* first applications (computing in residue rings, Hilbert function, algebraic \
systems)
* the technique of base-change w.r.t. to different orderings
* a complete computer implementation 
* first complexity considerations.\
\>", "Text",
  CellMargins->{{73.5625, Inherited}, {Inherited, Inherited}}],

Cell["\<\
However, in the thesis, I did not use the name \"Gr\[ODoubleDot]bner bases\". \
I introduced this name only in 1976, for honoring Gr\[ODoubleDot]bner, when \
people started to become interested in my work.   \
\>", "Text"],

Cell["My later contributions:", "Text"],

Cell["\<\
* the technique of criteria for eliminating unnecessary reductions
* an abstract characterization of \"Gr\[ODoubleDot]bner bases rings\".\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More Info on Gr\[ODoubleDot]bner Bases?", "Subsection"],

Cell[CellGroupData[{

Cell["Gr\[ODoubleDot]bner Bases 98 Conference", "Subsubsection",
  CellTags->"right-conference"],

Cell[TextData[{
  "B. B., F. Winkler. Gr\[ODoubleDot]bner",
  StyleBox[" Bases: Theory and Applications. ",
    FontSlant->"Italic"],
  "Cambridge University Press, 1998. 560 pages."
}], "Text",
  CellDingbat->None,
  CellMargins->{{37.5, Inherited}, {Inherited, Inherited}}],

Cell["This book contains tutorials and original papers.", "Text"],

Cell["This book contains also:", "Text"],

Cell[TextData[{
  "B. B. ",
  StyleBox["Introduction to Gr\[ODoubleDot]bner Bases",
    FontSlant->"Italic"],
  ", pp. 3-31."
}], "Text",
  CellDingbat->None,
  CellMargins->{{38.5, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "B. B. ",
  StyleBox["An Algorithmic Criterion for the Solvability of Systems of \
Algebraic Equations, pp. 540-560. ",
    FontSlant->"Italic"],
  "(English translation of the original paper from 1970, in which Gr\
\[ODoubleDot]bner bases were introduced.)"
}], "Text",
  CellDingbat->None,
  CellMargins->{{40.5, Inherited}, {Inherited, Inherited}}],

Cell["\<\
A continuation of this book is the special issue of the JSC  on Gr\
\[ODoubleDot]bner bases edited by Q.N. Tran and F. Winkler, 2000.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["On Your Desk", "Subsubsection",
  CellTags->"desk"],

Cell[TextData[{
  "GB implementations are contained in all the current math software systems \
like ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "(see demo), Maple, Magma, Macsyma, Axiom, Derive, Reduce, Mupad, ..."
}], "Text"],

Cell[TextData[{
  "Software systems specialized on Gr\[ODoubleDot]bner bases: ",
  StyleBox["RISA-ASIR (M. Noro, K. Yokoyama)",
    FontColor->RGBColor[0, 0, 1]],
  ", CoCoA, Macaulay, Singular, ..."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["In Your Palm", "Subsubsection"],

Cell["\<\
Gr\[ODoubleDot]bner bases are now availabe on the TI-92 (implemented in \
Derive).\
\>", "Text",
  CellTags->"TI-92"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Textbooks", "Subsubsection"],

Cell[TextData[{
  "T. Kreuzer, L. Robbiano: ",
  StyleBox["Algorithmic Commutative Algebra I.",
    FontSlant->"Italic"],
  " Springer, Heidelber, 2000: Contains a list of all other, approx. 10, \
textbooks on GB."
}], "Text"],

Cell[TextData[{
  "W.W.Adams, P. Loustenau. ",
  StyleBox["Introduction to ",
    FontSlant->"Italic"],
  "Gr\[ODoubleDot]bner",
  StyleBox[" Bases",
    FontSlant->"Italic"],
  ". Graduate Studies in Mathematics: Amer. Math. Soc., Providence, R.I., \
1994."
}], "Text"],

Cell[TextData[{
  "T.Becker, V.Weispfenning. ",
  "Gr\[ODoubleDot]bner",
  StyleBox[" Bases: A Computational Approach to Commutative Algebra.",
    FontSlant->"Italic"],
  " Springer, New York, 1993."
}], "Text"],

Cell[TextData[{
  "D.Cox, J.Little, D.O'Shea. ",
  StyleBox[
  "Ideals, Varieties, and Algorithms: An Introduction to Computational \
Algebraic Geometry and Commutative Algebra.",
    FontSlant->"Italic"],
  " Springer, New York, 1992."
}], "Text"],

Cell["....", "Text"],

Cell["M. Maruyama. Gr\[ODoubleDot]bner Bases and Applications. 2002.", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell["\<\
M. Noro, K. Yokoyama. Computational Fundamentals of Gr\[ODoubleDot]bner \
Bases.
University of Tokyo Press, 2003.\
\>", "Text",
  FontColor->RGBColor[0, 0, 1]]
}, Open  ]],

Cell[CellGroupData[{

Cell["On the Web", "Subsubsection"],

Cell["\<\
Search. E.g. in the Research Index you obtain ~ 3000 citations.\
\>", "Text",
  CellTags->"Web"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Original Publications", "Subsubsection"],

Cell["\<\
Approximately 600 papers appeared meanwhile on Gr\[ODoubleDot]bner bases.\
\>", "Text"],

Cell["J of Symbolic Computation, in particular, special issues.", "Text"],

Cell["ISSAC Conferences.", "Text"],

Cell["Mega Conferences.", "Text"],

Cell["ACA Conferences.", "Text"],

Cell["...", "Text"],

Cell["The essential  additional original ideas in the literature:", "Text"],

Cell[TextData[{
  "Gr\[ODoubleDot]bner bases can be constructed w.r.t. arbitrary \"",
  StyleBox["admissible",
    FontColor->RGBColor[0, 0, 1]],
  "\" orderings (W. Trinks 1978)"
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{75, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Gr\[ODoubleDot]bner bases w.r.t. to \"lexical\" orderings have the ",
  StyleBox["elimination property ",
    FontColor->RGBColor[0, 0, 1]],
  "(W. Trinks 1978)"
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{75, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Gr\[ODoubleDot]bner bases can be used for computing ",
  StyleBox["syzygies",
    FontColor->RGBColor[0, 0, 1]],
  " and the S-polys generate the module of syzygies (G. Zacharias 1978)"
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{75, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "A given ",
  StyleBox["F",
    FontSlant->"Italic"],
  ", w.r.t. the ",
  StyleBox["infinitely",
    FontSlant->"Italic"],
  " many admissible orderings, has ",
  StyleBox["only ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["finitely ",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["many Gr\[ODoubleDot]bner bases ",
    FontColor->RGBColor[0, 0, 1]],
  "and, hence, we can construct a \"universal\" Gr\[ODoubleDot]bner bases for \
",
  StyleBox["F",
    FontSlant->"Italic"],
  " (L. Robbiano, V. Weispfenning, T. Schwarz 1988)"
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{75, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Starting from a Gr\[ODoubleDot]bner bases for ",
  StyleBox["F",
    FontSlant->"Italic"],
  " for ordering ",
  Cell[BoxData[
      \(TraditionalForm\`O\_1\)]],
  " one can ",
  StyleBox["\"walk\", by changing the basis only slightly, to a basis for a \
\"nearby\"",
    FontColor->RGBColor[0, 0, 1]],
  " ordering ",
  Cell[BoxData[
      \(TraditionalForm\`O\_2\)]],
  "  and so on ... until one arrives at a Gr\[ODoubleDot]bner bases for a \
desired ordering ",
  Cell[BoxData[
      \(TraditionalForm\`O\_k\)]],
  " (Kalkbrener, Mall 1995, Nam 2000)."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{75, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Use ",
  StyleBox["arbitrary linear algebra algorithms ",
    FontColor->RGBColor[0, 0, 1]],
  "for the reduction (remaindering) process: (Faug\[EGrave]re 1997)."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{75, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "... numerours ",
  StyleBox["applications",
    FontColor->RGBColor[0, 0, 1]],
  ","
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{75, Inherited}, {Inherited, Inherited}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conclusions", "Section"],

Cell["Research topics:", "Text"],

Cell["\<\
the inner structure of Groebner bases: generalized Sylvester matrices\
\>", "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{68.625, Inherited}, {Inherited, Inherited}}],

Cell["the numerics of GB computations", "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{68.625, Inherited}, {Inherited, Inherited}}],

Cell["axiomatic characterization of Groebner rings", "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{68.625, Inherited}, {Inherited, Inherited}}],

Cell["generalizations (e.g. non-commutative poly-rings)", "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{68.625, Inherited}, {Inherited, Inherited}}],

Cell["speeding up the computation", "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{68.625, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Groebner bases for particular classes of ideals (avoid computation)\
\>", "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{68.625, Inherited}, {Inherited, Inherited}}],

Cell["the study of admissible orderings", "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{68.625, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "applications (problem reductions, e.g. functional analysis, BV problems, \
",
  StyleBox["Rosenkranz 2003",
    FontWeight->"Bold"],
  ")"
}], "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{68.625, Inherited}, {Inherited, Inherited}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Presentation",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section",
    FontFamily->"Arial"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Arial",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Arial",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Arial",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Arial",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Arial",
    FontSize->14,
    FontWeight->"Bold",
    Background->GrayLevel[0.666667]],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Arial",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    FontFamily->"Arial"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Arial"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Arial",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names. \
Some attributes for these styles are actually set in FormatType Styles (in \
the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Open  ]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9,
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "division-reduction"->{
    Cell[2747, 96, 96, 1, 87, "Subsubsection",
      CellTags->"division-reduction"]},
  "application-theory"->{
    Cell[7406, 279, 96, 2, 67, "Text",
      CellTags->"application-theory"],
    Cell[7505, 283, 376, 7, 170, "Text",
      CellTags->"application-theory"]},
  "power"->{
    Cell[9061, 335, 159, 5, 89, "Text",
      CellTags->"power"]},
  "reduction-not-unique"->{
    Cell[12144, 476, 97, 2, 81, "Input",
      CellTags->"reduction-not-unique"],
    Cell[12363, 486, 107, 2, 81, "Input",
      CellTags->"reduction-not-unique"]},
  "Groebner-bases-construction"->{
    Cell[15021, 617, 79, 1, 87, "Subsubsection",
      CellTags->"Groebner-bases-construction"]},
  "algorithm"->{
    Cell[16638, 686, 144, 4, 100, "Text",
      CellTags->"algorithm"]},
  "termination"->{
    Cell[17615, 728, 80, 1, 87, "Subsubsection",
      CellTags->"termination"]},
  "Gauss-algorithm"->{
    Cell[17848, 738, 417, 12, 205, "Text",
      CellTags->"Gauss-algorithm"]},
  "simple-equations"->{
    Cell[20405, 853, 85, 1, 87, "Subsubsection",
      CellTags->"simple-equations"]},
  "complicated-equations"->{
    Cell[33669, 1099, 516, 12, 221, "Input",
      CellTags->"complicated-equations"]},
  "algebraic-relations"->{
    Cell[47811, 1407, 55, 1, 65, "Text",
      CellTags->"algebraic-relations"]},
  "Proposition (Pappus)"->{
    Cell[96316, 2494, 423, 8, 217, "Input",
      CellTags->"Proposition (Pappus)"],
    Cell[97482, 2529, 9451, 232, 244, "Conclusion",
      CellTags->"Proposition (Pappus)"]},
  "1"->{
    Cell[114132, 2961, 18224, 438, 256, "Conclusion",
      CellTags->"1"],
    Cell[286236, 6460, 17836, 427, 285, "Conclusion",
      CellTags->"1"]},
  "2"->{
    Cell[132549, 3405, 19323, 438, 278, "Conclusion",
      CellTags->"2"]},
  "3"->{
    Cell[152469, 3861, 20428, 454, 312, "Conclusion",
      CellTags->"3"]},
  "Proposition (Butterfly)"->{
    Cell[175736, 4420, 564, 9, 353, "Input",
      CellTags->"Proposition (Butterfly)"],
    Cell[269961, 6036, 10042, 245, 249, "Conclusion",
      CellTags->"Proposition (Butterfly)"]},
  "KnowledgeBase (Butterfly_g)"->{
    Cell[204521, 4996, 255, 5, 149, "Input",
      CellTags->"KnowledgeBase (Butterfly_g)"]},
  "very-easy"->{
    Cell[537738, 12701, 112, 2, 126, "Subsection",
      CellTags->"very-easy"],
    Cell[537875, 12707, 59, 1, 87, "Subsubsection",
      CellTags->"very-easy"]},
  "very-difficult"->{
    Cell[538179, 12719, 69, 1, 87, "Subsubsection",
      CellTags->"very-difficult"]},
  "difficult"->{
    Cell[538251, 12722, 296, 8, 136, "Text",
      CellTags->"difficult"]},
  "sometimes-easy"->{
    Cell[538584, 12735, 69, 1, 87, "Subsubsection",
      CellTags->"sometimes-easy"],
    Cell[538656, 12738, 215, 5, 100, "Text",
      CellTags->"sometimes-easy"]},
  "improvements"->{
    Cell[538970, 12750, 163, 6, 66, "Text",
      CellTags->"improvements"]},
  "tuning"->{
    Cell[540046, 12790, 214, 5, 65, "Text",
      CellTags->"tuning"]},
  "Groebner-bases-name"->{
    Cell[540549, 12809, 204, 6, 65, "Text",
      CellTags->"Groebner-bases-name"]},
  "right-conference"->{
    Cell[552369, 12993, 96, 1, 87, "Subsubsection",
      CellTags->"right-conference"]},
  "desk"->{
    Cell[553644, 13037, 57, 1, 87, "Subsubsection",
      CellTags->"desk"]},
  "TI-92"->{
    Cell[554235, 13060, 127, 4, 65, "Text",
      CellTags->"TI-92"]},
  "Web"->{
    Cell[555784, 13124, 106, 3, 65, "Text",
      CellTags->"Web"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"division-reduction", 584915, 14162},
  {"application-theory", 585028, 14165},
  {"power", 585200, 14170},
  {"reduction-not-unique", 585295, 14173},
  {"Groebner-bases-construction", 585496, 14178},
  {"algorithm", 585611, 14181},
  {"termination", 585703, 14184},
  {"Gauss-algorithm", 585808, 14187},
  {"simple-equations", 585912, 14190},
  {"complicated-equations", 586028, 14193},
  {"algebraic-relations", 586143, 14196},
  {"Proposition (Pappus)", 586253, 14199},
  {"1", 586441, 14204},
  {"2", 586603, 14209},
  {"3", 586689, 14212},
  {"Proposition (Butterfly)", 586797, 14215},
  {"KnowledgeBase (Butterfly_g)", 587020, 14220},
  {"very-easy", 587131, 14223},
  {"very-difficult", 587317, 14228},
  {"difficult", 587422, 14231},
  {"sometimes-easy", 587520, 14234},
  {"improvements", 587708, 14239},
  {"tuning", 587800, 14242},
  {"Groebner-bases-name", 587899, 14245},
  {"right-conference", 588008, 14248},
  {"desk", 588110, 14251},
  {"TI-92", 588201, 14254},
  {"Web", 588283, 14257}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 64, 0, 53, "SmallText"],

Cell[CellGroupData[{
Cell[1843, 55, 115, 5, 182, "Subtitle"],
Cell[1961, 62, 172, 10, 347, "Subsubtitle"],
Cell[2136, 74, 442, 10, 279, "Text"],

Cell[CellGroupData[{
Cell[2603, 88, 48, 0, 131, "Section"],

Cell[CellGroupData[{
Cell[2676, 92, 46, 0, 126, "Subsection"],

Cell[CellGroupData[{
Cell[2747, 96, 96, 1, 87, "Subsubsection",
  CellTags->"division-reduction"],
Cell[2846, 99, 54, 0, 65, "Text"],

Cell[CellGroupData[{
Cell[2925, 103, 314, 8, 117, "Input"],
Cell[3242, 113, 50, 1, 57, "Output"],
Cell[3295, 116, 50, 1, 58, "Output"]
}, Open  ]],
Cell[3360, 120, 138, 3, 100, "Text"],
Cell[3501, 125, 167, 8, 65, "Text"],

Cell[CellGroupData[{
Cell[3693, 137, 90, 1, 81, "Input"],
Cell[3786, 140, 110, 2, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3933, 147, 88, 1, 81, "Input"],
Cell[4024, 150, 53, 1, 58, "Output"]
}, Open  ]],
Cell[4092, 154, 320, 11, 170, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4449, 170, 53, 0, 87, "Subsubsection"],
Cell[4505, 172, 190, 4, 135, "Text"],
Cell[4698, 178, 186, 5, 100, "Text"],
Cell[4887, 185, 697, 21, 205, "Text"]
}, Open  ]],
Cell[5599, 209, 164, 5, 87, "Subsubsection"],

Cell[CellGroupData[{
Cell[5788, 218, 52, 0, 87, "Subsubsection"],
Cell[5843, 220, 155, 5, 65, "Text"],

Cell[CellGroupData[{
Cell[6023, 229, 105, 2, 83, "Input"],
Cell[6131, 233, 91, 1, 58, "Output"]
}, Open  ]],
Cell[6237, 237, 28, 0, 65, "Text"],

Cell[CellGroupData[{
Cell[6290, 241, 203, 3, 119, "Input"],
Cell[6496, 246, 146, 2, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6679, 253, 160, 2, 83, "Input"],
Cell[6842, 257, 84, 1, 58, "Output"]
}, Open  ]],
Cell[6941, 261, 91, 2, 65, "Text"],
Cell[7035, 265, 71, 0, 65, "Text"],
Cell[7109, 267, 126, 3, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7272, 275, 60, 0, 87, "Subsubsection"],
Cell[7335, 277, 68, 0, 65, "Text"],
Cell[7406, 279, 96, 2, 67, "Text",
  CellTags->"application-theory"],
Cell[7505, 283, 376, 7, 170, "Text",
  CellTags->"application-theory"],
Cell[7884, 292, 66, 1, 67, "Text"],
Cell[7953, 295, 120, 3, 100, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8122, 304, 54, 0, 126, "Subsection"],

Cell[CellGroupData[{
Cell[8201, 308, 69, 0, 87, "Subsubsection"],
Cell[8273, 310, 407, 14, 142, "Text"],
Cell[8683, 326, 375, 7, 242, "Text"],
Cell[9061, 335, 159, 5, 89, "Text",
  CellTags->"power"],
Cell[9223, 342, 226, 11, 67, "Text"],
Cell[9452, 355, 119, 4, 67, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9608, 364, 38, 0, 87, "Subsubsection"],

Cell[CellGroupData[{
Cell[9671, 368, 314, 8, 117, "Input"],
Cell[9988, 378, 50, 1, 57, "Output"],
Cell[10041, 381, 50, 1, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10128, 387, 328, 9, 81, "Input"],
Cell[10459, 398, 87, 1, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10583, 404, 373, 10, 81, "Input"],
Cell[10959, 416, 48, 1, 58, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11056, 423, 50, 0, 87, "Subsubsection"],
Cell[11109, 425, 129, 3, 100, "Text"],
Cell[11241, 430, 66, 1, 67, "Text"],
Cell[11310, 433, 32, 0, 65, "Text"],

Cell[CellGroupData[{
Cell[11367, 437, 175, 3, 153, "Input"],
Cell[11545, 442, 53, 1, 58, "Output"],
Cell[11601, 445, 50, 1, 57, "Output"],
Cell[11654, 448, 50, 1, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11741, 454, 55, 1, 81, "Input"],
Cell[11799, 457, 91, 1, 58, "Output"]
}, Open  ]],
Cell[11905, 461, 20, 0, 65, "Text"],

Cell[CellGroupData[{
Cell[11950, 465, 54, 1, 83, "Input"],
Cell[12007, 468, 51, 1, 58, "Output"]
}, Open  ]],
Cell[12073, 472, 46, 0, 65, "Text"],

Cell[CellGroupData[{
Cell[12144, 476, 97, 2, 81, "Input",
  CellTags->"reduction-not-unique"],
Cell[12244, 480, 82, 1, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12363, 486, 107, 2, 81, "Input",
  CellTags->"reduction-not-unique"],
Cell[12473, 490, 53, 1, 58, "Output"]
}, Open  ]],
Cell[12541, 494, 46, 0, 65, "Text"],

Cell[CellGroupData[{
Cell[12612, 498, 55, 1, 81, "Input"],
Cell[12670, 501, 91, 1, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12798, 507, 78, 1, 81, "Input"],
Cell[12879, 510, 53, 1, 58, "Output"]
}, Open  ]],
Cell[12947, 514, 46, 0, 65, "Text"],

Cell[CellGroupData[{
Cell[13018, 518, 55, 1, 81, "Input"],
Cell[13076, 521, 91, 1, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13204, 527, 73, 1, 81, "Input"],
Cell[13280, 530, 53, 1, 58, "Output"]
}, Open  ]],
Cell[13348, 534, 87, 2, 65, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13472, 541, 138, 5, 88, "Subsubsection"],

Cell[CellGroupData[{
Cell[13635, 550, 63, 1, 81, "Input"],
Cell[13701, 553, 78, 1, 58, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13828, 560, 56, 0, 87, "Subsubsection"],
Cell[13887, 562, 54, 0, 65, "Text"],

Cell[CellGroupData[{
Cell[13966, 566, 55, 1, 81, "Input"],
Cell[14024, 569, 91, 1, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14152, 575, 89, 1, 83, "Input"],
Cell[14244, 578, 48, 1, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14329, 584, 92, 1, 83, "Input"],
Cell[14424, 587, 85, 1, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14546, 593, 86, 1, 81, "Input"],
Cell[14635, 596, 53, 1, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14737, 603, 51, 0, 87, "Subsubsection"],
Cell[14791, 605, 98, 2, 65, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14938, 613, 58, 0, 126, "Subsection"],

Cell[CellGroupData[{
Cell[15021, 617, 79, 1, 87, "Subsubsection",
  CellTags->"Groebner-bases-construction"],
Cell[15103, 620, 360, 19, 66, "Text"],
Cell[15466, 641, 579, 19, 135, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16082, 665, 37, 0, 87, "Subsubsection"],
Cell[16122, 667, 40, 0, 65, "Text"],
Cell[16165, 669, 470, 15, 118, "Text"],
Cell[16638, 686, 144, 4, 100, "Text",
  CellTags->"algorithm"],
Cell[16785, 692, 643, 24, 337, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17465, 721, 53, 0, 87, "Subsubsection"],
Cell[17521, 723, 57, 0, 65, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17615, 728, 80, 1, 87, "Subsubsection",
  CellTags->"termination"],
Cell[17698, 731, 70, 0, 65, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17805, 736, 40, 0, 87, "Subsubsection"],
Cell[17848, 738, 417, 12, 205, "Text",
  CellTags->"Gauss-algorithm"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18302, 755, 32, 0, 87, "Subsubsection"],
Cell[18337, 757, 35, 0, 65, "Text"],

Cell[CellGroupData[{
Cell[18397, 761, 314, 8, 117, "Input"],
Cell[18714, 771, 50, 1, 57, "Output"],
Cell[18767, 774, 50, 1, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18854, 780, 49, 1, 81, "Input"],
Cell[18906, 783, 70, 1, 58, "Output"]
}, Open  ]],
Cell[18991, 787, 42, 0, 65, "Text"],
Cell[19036, 789, 99, 5, 65, "Text"],

Cell[CellGroupData[{
Cell[19160, 798, 373, 10, 81, "Input"],
Cell[19536, 810, 48, 1, 58, "Output"]
}, Open  ]],
Cell[19599, 814, 42, 0, 65, "Text"],
Cell[19644, 816, 65, 1, 83, "Input"],
Cell[19712, 819, 110, 3, 65, "Text"],
Cell[19825, 824, 185, 5, 101, "Text"],

Cell[CellGroupData[{
Cell[20035, 833, 61, 1, 81, "Input"],
Cell[20099, 836, 91, 1, 58, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20263, 845, 31, 0, 131, "Section"],

Cell[CellGroupData[{
Cell[20319, 849, 61, 0, 126, "Subsection"],

Cell[CellGroupData[{
Cell[20405, 853, 85, 1, 87, "Subsubsection",
  CellTags->"simple-equations"],

Cell[CellGroupData[{
Cell[20515, 858, 314, 8, 117, "Input"],
Cell[20832, 868, 50, 1, 57, "Output"],
Cell[20885, 871, 50, 1, 58, "Output"]
}, Open  ]],
Cell[20950, 875, 35, 0, 65, "Text"],
Cell[20988, 877, 307, 9, 117, "Input"],
Cell[21298, 888, 26, 0, 65, "Text"],

Cell[CellGroupData[{
Cell[21349, 892, 61, 1, 81, "Input"],
Cell[21413, 895, 91, 1, 58, "Output"]
}, Open  ]],
Cell[21519, 899, 223, 5, 102, "Text"],

Cell[CellGroupData[{
Cell[21767, 908, 67, 1, 83, "Input"],
Cell[21837, 911, 79, 1, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21953, 917, 74, 1, 81, "Input"],
Cell[22030, 920, 52, 1, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22119, 926, 61, 1, 83, "Input"],
Cell[22183, 929, 69, 1, 57, "Output"]
}, Open  ]],
Cell[22267, 933, 153, 5, 66, "Text"],

Cell[CellGroupData[{
Cell[22445, 942, 70, 1, 81, "Input"],
Cell[22518, 945, 160, 2, 57, "Output"]
}, Open  ]],
Cell[22693, 950, 165, 5, 102, "Text"],
Cell[22861, 957, 10708, 135, 401, 10607, 132, "GraphicsData", "Metafile", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33606, 1097, 60, 0, 87, "Subsubsection"],
Cell[33669, 1099, 516, 12, 221, "Input",
  CellTags->"complicated-equations"],

Cell[CellGroupData[{
Cell[34210, 1115, 75, 1, 81, "Input"],
Cell[34288, 1118, 822, 12, 407, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35147, 1135, 71, 1, 81, "Input"],
Cell[35221, 1138, 2218, 34, 827, "Output"]
}, Open  ]],
Cell[37454, 1175, 111, 3, 65, "Text"],

Cell[CellGroupData[{
Cell[37590, 1182, 78, 1, 81, "Input"],
Cell[37671, 1185, 5118, 70, 2290, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42826, 1260, 230, 3, 153, "Input"],
Cell[43059, 1265, 897, 13, 337, "Output"]
}, Open  ]],
Cell[43971, 1281, 45, 0, 65, "Text"],
Cell[44019, 1283, 51, 0, 65, "Text"],

Cell[CellGroupData[{
Cell[44095, 1287, 66, 1, 81, "Input"],
Cell[44164, 1290, 932, 17, 227, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45133, 1312, 65, 1, 81, "Input"],
Cell[45201, 1315, 487, 8, 127, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45725, 1328, 82, 1, 81, "Input"],
Cell[45810, 1331, 35, 1, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45882, 1337, 74, 1, 81, "Input"],
Cell[45959, 1340, 181, 3, 110, "Message"],
Cell[46143, 1345, 123, 2, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46303, 1352, 74, 1, 81, "Input"],
Cell[46380, 1355, 238, 4, 57, "Output"]
}, Open  ]],
Cell[46633, 1362, 168, 5, 102, "Text"],

Cell[CellGroupData[{
Cell[46826, 1371, 74, 1, 81, "Input"],
Cell[46903, 1374, 185, 3, 110, "Message"],
Cell[47091, 1379, 147, 2, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47275, 1386, 93, 1, 81, "Input"],
Cell[47371, 1389, 265, 5, 128, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[47697, 1401, 51, 0, 126, "Subsection"],

Cell[CellGroupData[{
Cell[47773, 1405, 35, 0, 87, "Subsubsection"],
Cell[47811, 1407, 55, 1, 65, "Text",
  CellTags->"algebraic-relations"],

Cell[CellGroupData[{
Cell[47891, 1412, 69, 1, 83, "Input"],
Cell[47963, 1415, 63, 1, 58, "Output"]
}, Open  ]],
Cell[48041, 1419, 48, 0, 65, "Text"],

Cell[CellGroupData[{
Cell[48114, 1423, 122, 2, 83, "Input"],
Cell[48239, 1427, 109, 2, 58, "Output"]
}, Open  ]],
Cell[48363, 1432, 17, 0, 65, "Text"],
Cell[48383, 1434, 205, 5, 100, "Text"],
Cell[48591, 1441, 190, 3, 81, "Input"],
Cell[48784, 1446, 20, 0, 65, "Text"],

Cell[CellGroupData[{
Cell[48829, 1450, 174, 3, 83, "Input"],
Cell[49006, 1455, 109, 2, 58, "Output"]
}, Open  ]],
Cell[49130, 1460, 95, 2, 65, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49262, 1467, 64, 0, 87, "Subsubsection"],

Cell[CellGroupData[{
Cell[49351, 1471, 276, 6, 119, "Input"],
Cell[49630, 1479, 612, 9, 163, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50279, 1493, 170, 3, 117, "Input"],
Cell[50452, 1498, 404, 7, 201, "Output"]
}, Open  ]],
Cell[50871, 1508, 292, 6, 137, "Text"],

Cell[CellGroupData[{
Cell[51188, 1518, 217, 4, 117, "Input"],
Cell[51408, 1524, 63, 1, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51508, 1530, 185, 4, 117, "Input"],
Cell[51696, 1536, 509, 9, 201, "Output"]
}, Open  ]],
Cell[52220, 1548, 152, 4, 65, "Text"],

Cell[CellGroupData[{
Cell[52397, 1556, 121, 2, 83, "Input"],
Cell[52521, 1560, 63, 1, 58, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[52645, 1568, 71, 0, 126, "Subsection"],

Cell[CellGroupData[{
Cell[52741, 1572, 35, 0, 87, "Subsubsection"],
Cell[52779, 1574, 229, 4, 135, "Text"],
Cell[53011, 1580, 190, 4, 135, "Text"],
Cell[53204, 1586, 53, 0, 65, "Text"],
Cell[53260, 1588, 462, 9, 275, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53759, 1602, 48, 0, 87, "Subsubsection"],
Cell[53810, 1604, 95, 1, 65, "Text"],
Cell[53908, 1607, 41576, 865, 373, 10348, 475, "GraphicsData", "PostScript", \
"Graphics"],
Cell[95487, 2474, 76, 1, 65, "Text"],
Cell[95566, 2477, 669, 12, 100, "Text"],
Cell[96238, 2491, 75, 1, 65, "Text"],
Cell[96316, 2494, 423, 8, 217, "Input",
  CellTags->"Proposition (Pappus)"],
Cell[96742, 2504, 75, 1, 65, "Text"],

Cell[CellGroupData[{
Cell[96842, 2509, 191, 3, 149, "Input"],
Cell[97036, 2514, 89, 1, 57, "Output"]
}, Open  ]],
Cell[97140, 2518, 180, 5, 100, "Text"],
Cell[97323, 2525, 156, 2, 41, "ProofText"],
Cell[97482, 2529, 9451, 232, 244, "Conclusion",
  CellTags->"Proposition (Pappus)"],
Cell[106936, 2763, 170, 2, 41, "ProofText"],
Cell[107109, 2767, 307, 5, 70, "ProofText"],
Cell[107419, 2774, 172, 2, 41, "ProofText"],
Cell[107594, 2778, 277, 5, 70, "ProofText"],
Cell[107874, 2785, 978, 27, 41, "ProofText"],
Cell[108855, 2814, 215, 2, 41, "ProofText"],
Cell[109073, 2818, 4857, 137, 76, "Expression"],
Cell[113933, 2957, 196, 2, 41, "ProofText"],
Cell[114132, 2961, 18224, 438, 256, "Conclusion",
  CellTags->"1"],
Cell[132359, 3401, 187, 2, 41, "ProofText"],
Cell[132549, 3405, 19323, 438, 278, "Conclusion",
  CellTags->"2"],
Cell[151875, 3845, 591, 14, 70, "ProofText"],
Cell[152469, 3861, 20428, 454, 312, "Conclusion",
  CellTags->"3"],
Cell[172900, 4317, 245, 5, 41, "ProofText"],
Cell[173148, 4324, 341, 7, 41, "ProofText"],
Cell[173492, 4333, 215, 2, 41, "ProofText"],
Cell[173710, 4337, 168, 2, 41, "ProofText"],
Cell[173881, 4341, 381, 8, 41, "ProofText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174299, 4354, 51, 0, 87, "Subsubsection"],
Cell[174353, 4356, 76, 1, 65, "Text"],
Cell[174432, 4359, 1047, 49, 137, "Text"],
Cell[175482, 4410, 62, 1, 65, "Text"],
Cell[175547, 4413, 108, 2, 41, "Subsubsubsection"],
Cell[175658, 4417, 75, 1, 65, "Text"],
Cell[175736, 4420, 564, 9, 353, "Input",
  CellTags->"Proposition (Butterfly)"],
Cell[176303, 4431, 75, 1, 65, "Text"],
Cell[176381, 4434, 103, 2, 81, "Input"],
Cell[176487, 4438, 99, 1, 65, "Text"],
Cell[176589, 4441, 26920, 515, 317, 4826, 238, "GraphicsData", "PostScript", \
"Graphics"],
Cell[203512, 4958, 857, 30, 41, "ProofText"],
Cell[204372, 4990, 68, 1, 65, "Text"],
Cell[204443, 4993, 75, 1, 65, "Text"],
Cell[204521, 4996, 255, 5, 149, "Input",
  CellTags->"KnowledgeBase (Butterfly_g)"],
Cell[204779, 5003, 75, 1, 65, "Text"],
Cell[204857, 5006, 151, 2, 115, "Input"],
Cell[205011, 5010, 99, 1, 65, "Text"],
Cell[205113, 5013, 63280, 965, 616, 4737, 238, "GraphicsData", "PostScript", \
"Graphics"],
Cell[268396, 5980, 857, 30, 41, "ProofText"],
Cell[269256, 6012, 68, 1, 65, "Text"],
Cell[269327, 6015, 75, 1, 65, "Text"],

Cell[CellGroupData[{
Cell[269427, 6020, 195, 3, 149, "Input"],
Cell[269625, 6025, 89, 1, 57, "Output"]
}, Open  ]],
Cell[269729, 6029, 133, 2, 65, "Text"],
Cell[269865, 6033, 93, 1, 41, "ProofText"],
Cell[269961, 6036, 10042, 245, 249, "Conclusion",
  CellTags->"Proposition (Butterfly)"],
Cell[280006, 6283, 107, 1, 41, "ProofText"],
Cell[280116, 6286, 244, 4, 70, "ProofText"],
Cell[280363, 6292, 109, 1, 41, "ProofText"],
Cell[280475, 6295, 214, 4, 70, "ProofText"],
Cell[280692, 6301, 1213, 35, 41, "ProofText"],
Cell[281908, 6338, 152, 1, 41, "ProofText"],
Cell[282063, 6341, 4025, 114, 76, "Expression"],
Cell[286091, 6457, 142, 1, 41, "ProofText"],
Cell[286236, 6460, 17836, 427, 285, "Conclusion",
  CellTags->"1"],
Cell[304075, 6889, 188, 4, 41, "ProofText"],
Cell[304266, 6895, 32107, 790, 408, "ProofText"],
Cell[336376, 7687, 169, 3, 41, "ProofText"],
Cell[336548, 7692, 250, 6, 41, "ProofText"],
Cell[336801, 7700, 176, 3, 41, "ProofText"],
Cell[336980, 7705, 105, 1, 41, "ProofText"],
Cell[337088, 7708, 268, 6, 41, "ProofText"],
Cell[337359, 7716, 317, 7, 41, "ProofText"],
Cell[337679, 7725, 346, 8, 70, "ProofText"],
Cell[338028, 7735, 182, 3, 35, "ProofText"],
Cell[338213, 7740, 79, 1, 65, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[338329, 7746, 104, 2, 119, "Subsubsection"],
Cell[338436, 7750, 244, 5, 137, "Text"],
Cell[338683, 7757, 226, 6, 102, "Text"],
Cell[338912, 7765, 38422, 942, 292, 17627, 681, "GraphicsData", "PostScript", \
"Graphics"],
Cell[377337, 8709, 132, 3, 100, "Text"],
Cell[377472, 8714, 44741, 1149, 293, 22937, 876, "GraphicsData", \
"PostScript", "Graphics"],
Cell[422216, 9865, 131, 3, 100, "Text"],
Cell[422350, 9870, 220, 9, 65, "Text"],
Cell[422573, 9881, 109, 1, 67, "Text"],
Cell[422685, 9884, 462, 18, 100, "Text"],
Cell[423150, 9904, 32, 0, 65, "Text"],

Cell[CellGroupData[{
Cell[423207, 9908, 141, 2, 83, "Input"],
Cell[423351, 9912, 44741, 1149, 293, 22937, 876, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[468107, 11064, 19, 0, 65, "Text"],

Cell[CellGroupData[{
Cell[468151, 11068, 201, 3, 119, "Input"],
Cell[468355, 11073, 44741, 1149, 293, 22937, 876, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[513111, 12225, 68, 0, 65, "Text"],
Cell[513182, 12227, 170, 3, 81, "Input"],
Cell[513355, 12232, 45, 0, 65, "Text"],
Cell[513403, 12234, 79, 1, 81, "Input"],
Cell[513485, 12237, 51, 0, 65, "Text"],
Cell[513539, 12239, 496, 13, 118, "Input"],
Cell[514038, 12254, 98, 1, 67, "Text"],
Cell[514139, 12257, 37, 0, 65, "Text"],
Cell[514179, 12259, 540, 14, 180, "Input"],
Cell[514722, 12275, 38, 0, 65, "Text"],
Cell[514763, 12277, 559, 14, 180, "Input"],
Cell[515325, 12293, 107, 3, 65, "Text"],

Cell[CellGroupData[{
Cell[515457, 12300, 236, 5, 119, "Input"],
Cell[515696, 12307, 37, 1, 57, "Output"]
}, Open  ]],
Cell[515748, 12311, 187, 4, 100, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[515984, 12321, 49, 0, 126, "Subsection"],

Cell[CellGroupData[{
Cell[516058, 12325, 36, 0, 87, "Subsubsection"],
Cell[516097, 12327, 107, 3, 65, "Text"],
Cell[516207, 12332, 125, 3, 100, "Text"],
Cell[516335, 12337, 4664, 60, 271, 4564, 57, "GraphicsData", "Metafile", \
"Graphics"],
Cell[521002, 12399, 73, 0, 65, "Text"],
Cell[521078, 12401, 4664, 60, 319, 4564, 57, "GraphicsData", "Metafile", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[525779, 12466, 78, 2, 87, "Subsubsection"],
Cell[525860, 12470, 200, 5, 102, "Text"],

Cell[CellGroupData[{
Cell[526085, 12479, 104, 2, 83, "Input"],
Cell[526192, 12483, 51, 1, 58, "Output"]
}, Open  ]],
Cell[526258, 12487, 856, 15, 335, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[527151, 12507, 51, 0, 87, "Subsubsection"],
Cell[527205, 12509, 98, 2, 65, "Text"],

Cell[CellGroupData[{
Cell[527328, 12515, 351, 6, 153, "Input"],
Cell[527682, 12523, 187, 4, 58, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[527906, 12532, 372, 6, 189, "Input"],
Cell[528281, 12540, 1901, 32, 443, "Output"]
}, Open  ]],
Cell[530197, 12575, 45, 0, 65, "Text"],
Cell[530245, 12577, 2445, 42, 479, "Input"],
Cell[532693, 12621, 257, 7, 100, "Text"],
Cell[532953, 12630, 4670, 60, 306, 4564, 57, "GraphicsData", "Metafile", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[537684, 12697, 29, 0, 131, "Section"],

Cell[CellGroupData[{
Cell[537738, 12701, 112, 2, 126, "Subsection",
  CellTags->"very-easy"],

Cell[CellGroupData[{
Cell[537875, 12707, 59, 1, 87, "Subsubsection",
  CellTags->"very-easy"],
Cell[537937, 12710, 205, 4, 135, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[538179, 12719, 69, 1, 87, "Subsubsection",
  CellTags->"very-difficult"],
Cell[538251, 12722, 296, 8, 136, "Text",
  CellTags->"difficult"]
}, Open  ]],

Cell[CellGroupData[{
Cell[538584, 12735, 69, 1, 87, "Subsubsection",
  CellTags->"sometimes-easy"],
Cell[538656, 12738, 215, 5, 100, "Text",
  CellTags->"sometimes-easy"]
}, Open  ]],

Cell[CellGroupData[{
Cell[538908, 12748, 59, 0, 87, "Subsubsection"],
Cell[538970, 12750, 163, 6, 66, "Text",
  CellTags->"improvements"],
Cell[539136, 12758, 204, 5, 65, "Text"],
Cell[539343, 12765, 216, 6, 66, "Text"],
Cell[539562, 12773, 153, 2, 65, "Text"],
Cell[539718, 12777, 187, 4, 65, "Text"],
Cell[539908, 12783, 135, 5, 66, "Text"],
Cell[540046, 12790, 214, 5, 65, "Text",
  CellTags->"tuning"],
Cell[540263, 12797, 140, 2, 65, "Text"],
Cell[540406, 12801, 35, 0, 65, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[540490, 12807, 56, 0, 126, "Subsection"],
Cell[540549, 12809, 204, 6, 65, "Text",
  CellTags->"Groebner-bases-name"],
Cell[540756, 12817, 115, 3, 100, "Text"],
Cell[540874, 12822, 10293, 130, 304, 10186, 127, "GraphicsData", "Metafile", \
"Graphics"],
Cell[551170, 12954, 89, 2, 65, "Text"],
Cell[551262, 12958, 543, 13, 380, "Text"],
Cell[551808, 12973, 232, 4, 135, "Text"],
Cell[552043, 12979, 39, 0, 65, "Text"],
Cell[552085, 12981, 161, 3, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[552283, 12989, 61, 0, 126, "Subsection"],

Cell[CellGroupData[{
Cell[552369, 12993, 96, 1, 87, "Subsubsection",
  CellTags->"right-conference"],
Cell[552468, 12996, 275, 7, 101, "Text"],
Cell[552746, 13005, 65, 0, 65, "Text"],
Cell[552814, 13007, 40, 0, 65, "Text"],
Cell[552857, 13009, 218, 7, 66, "Text"],
Cell[553078, 13018, 369, 9, 137, "Text"],
Cell[553450, 13029, 157, 3, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[553644, 13037, 57, 1, 87, "Subsubsection",
  CellTags->"desk"],
Cell[553704, 13040, 240, 6, 136, "Text"],
Cell[553947, 13048, 211, 5, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[554195, 13058, 37, 0, 87, "Subsubsection"],
Cell[554235, 13060, 127, 4, 65, "Text",
  CellTags->"TI-92"]
}, Open  ]],

Cell[CellGroupData[{
Cell[554399, 13069, 34, 0, 87, "Subsubsection"],
Cell[554436, 13071, 226, 6, 101, "Text"],
Cell[554665, 13079, 270, 9, 101, "Text"],
Cell[554938, 13090, 212, 6, 102, "Text"],
Cell[555153, 13098, 248, 7, 137, "Text"],
Cell[555404, 13107, 20, 0, 65, "Text"],
Cell[555427, 13109, 110, 1, 65, "Text"],
Cell[555540, 13112, 169, 5, 100, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[555746, 13122, 35, 0, 87, "Subsubsection"],
Cell[555784, 13124, 106, 3, 65, "Text",
  CellTags->"Web"]
}, Open  ]],

Cell[CellGroupData[{
Cell[555927, 13132, 46, 0, 87, "Subsubsection"],
Cell[555976, 13134, 97, 2, 65, "Text"],
Cell[556076, 13138, 73, 0, 65, "Text"],
Cell[556152, 13140, 34, 0, 65, "Text"],
Cell[556189, 13142, 33, 0, 65, "Text"],
Cell[556225, 13144, 32, 0, 65, "Text"],
Cell[556260, 13146, 19, 0, 65, "Text"],
Cell[556282, 13148, 75, 0, 65, "Text"],
Cell[556360, 13150, 288, 7, 100, "Text"],
Cell[556651, 13159, 289, 7, 100, "Text"],
Cell[556943, 13168, 313, 7, 100, "Text"],
Cell[557259, 13177, 686, 22, 137, "Text"],
Cell[557948, 13201, 684, 21, 171, "Text"],
Cell[558635, 13224, 290, 7, 100, "Text"],
Cell[558928, 13233, 212, 7, 65, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[559201, 13247, 30, 0, 131, "Section"],
Cell[559234, 13249, 32, 0, 65, "Text"],
Cell[559269, 13251, 193, 4, 65, "Text"],
Cell[559465, 13257, 147, 2, 65, "Text"],
Cell[559615, 13261, 160, 2, 65, "Text"],
Cell[559778, 13265, 165, 2, 65, "Text"],
Cell[559946, 13269, 143, 2, 65, "Text"],
Cell[560092, 13273, 191, 4, 65, "Text"],
Cell[560286, 13279, 149, 2, 65, "Text"],
Cell[560438, 13283, 269, 8, 102, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

